/*!
 *  Lang.js for Laravel localization in JavaScript.
 *
 *  @version 1.1.10
 *  @license MIT https://github.com/rmariuzzo/Lang.js/blob/master/LICENSE
 *  @site    https://github.com/rmariuzzo/Lang.js
 *  @author  Rubens Mariuzzo <rubens@mariuzzo.com>
 */
(function(root,factory){"use strict";if(typeof define==="function"&&define.amd){define([],factory)}else if(typeof exports==="object"){module.exports=factory()}else{root.Lang=factory()}})(this,function(){"use strict";function inferLocale(){if(typeof document!=="undefined"&&document.documentElement){return document.documentElement.lang}}function convertNumber(str){if(str==="-Inf"){return-Infinity}else if(str==="+Inf"||str==="Inf"||str==="*"){return Infinity}return parseInt(str,10)}var intervalRegexp=/^({\s*(\-?\d+(\.\d+)?[\s*,\s*\-?\d+(\.\d+)?]*)\s*})|([\[\]])\s*(-Inf|\*|\-?\d+(\.\d+)?)\s*,\s*(\+?Inf|\*|\-?\d+(\.\d+)?)\s*([\[\]])$/;var anyIntervalRegexp=/({\s*(\-?\d+(\.\d+)?[\s*,\s*\-?\d+(\.\d+)?]*)\s*})|([\[\]])\s*(-Inf|\*|\-?\d+(\.\d+)?)\s*,\s*(\+?Inf|\*|\-?\d+(\.\d+)?)\s*([\[\]])/;var defaults={locale:"en"};var Lang=function(options){options=options||{};this.locale=options.locale||inferLocale()||defaults.locale;this.fallback=options.fallback;this.messages=options.messages};Lang.prototype.setMessages=function(messages){this.messages=messages};Lang.prototype.getLocale=function(){return this.locale||this.fallback};Lang.prototype.setLocale=function(locale){this.locale=locale};Lang.prototype.getFallback=function(){return this.fallback};Lang.prototype.setFallback=function(fallback){this.fallback=fallback};Lang.prototype.has=function(key,locale){if(typeof key!=="string"||!this.messages){return false}return this._getMessage(key,locale)!==null};Lang.prototype.get=function(key,replacements,locale){if(!this.has(key,locale)){return key}var message=this._getMessage(key,locale);if(message===null){return key}if(replacements){message=this._applyReplacements(message,replacements)}return message};Lang.prototype.trans=function(key,replacements){return this.get(key,replacements)};Lang.prototype.choice=function(key,number,replacements,locale){replacements=typeof replacements!=="undefined"?replacements:{};replacements.count=number;var message=this.get(key,replacements,locale);if(message===null||message===undefined){return message}var messageParts=message.split("|");var explicitRules=[];for(var i=0;i<messageParts.length;i++){messageParts[i]=messageParts[i].trim();if(anyIntervalRegexp.test(messageParts[i])){var messageSpaceSplit=messageParts[i].split(/\s/);explicitRules.push(messageSpaceSplit.shift());messageParts[i]=messageSpaceSplit.join(" ")}}if(messageParts.length===1){return message}for(var j=0;j<explicitRules.length;j++){if(this._testInterval(number,explicitRules[j])){return messageParts[j]}}var pluralForm=this._getPluralForm(number);return messageParts[pluralForm]};Lang.prototype.transChoice=function(key,count,replacements){return this.choice(key,count,replacements)};Lang.prototype._parseKey=function(key,locale){if(typeof key!=="string"||typeof locale!=="string"){return null}var segments=key.split(".");var source=segments[0].replace(/\//g,".");return{source:locale+"."+source,sourceFallback:this.getFallback()+"."+source,entries:segments.slice(1)}};Lang.prototype._getMessage=function(key,locale){locale=locale||this.getLocale();key=this._parseKey(key,locale);if(this.messages[key.source]===undefined&&this.messages[key.sourceFallback]===undefined){return null}var message=this.messages[key.source];var entries=key.entries.slice();var subKey="";while(entries.length&&message!==undefined){var subKey=!subKey?entries.shift():subKey.concat(".",entries.shift());if(message[subKey]!==undefined){message=message[subKey];subKey=""}}if(typeof message!=="string"&&this.messages[key.sourceFallback]){message=this.messages[key.sourceFallback];entries=key.entries.slice();subKey="";while(entries.length&&message!==undefined){var subKey=!subKey?entries.shift():subKey.concat(".",entries.shift());if(message[subKey]){message=message[subKey];subKey=""}}}if(typeof message!=="string"){return null}return message};Lang.prototype._findMessageInTree=function(pathSegments,tree){while(pathSegments.length&&tree!==undefined){var dottedKey=pathSegments.join(".");if(tree[dottedKey]){tree=tree[dottedKey];break}tree=tree[pathSegments.shift()]}return tree};Lang.prototype._applyReplacements=function(message,replacements){for(var replace in replacements){message=message.replace(new RegExp(":"+replace,"gi"),function(match){var value=replacements[replace];var allCaps=match===match.toUpperCase();if(allCaps){return value.toUpperCase()}var firstCap=match===match.replace(/\w/i,function(letter){return letter.toUpperCase()});if(firstCap){return value.charAt(0).toUpperCase()+value.slice(1)}return value})}return message};Lang.prototype._testInterval=function(count,interval){if(typeof interval!=="string"){throw"Invalid interval: should be a string."}interval=interval.trim();var matches=interval.match(intervalRegexp);if(!matches){throw"Invalid interval: "+interval}if(matches[2]){var items=matches[2].split(",");for(var i=0;i<items.length;i++){if(parseInt(items[i],10)===count){return true}}}else{matches=matches.filter(function(match){return!!match});var leftDelimiter=matches[1];var leftNumber=convertNumber(matches[2]);if(leftNumber===Infinity){leftNumber=-Infinity}var rightNumber=convertNumber(matches[3]);var rightDelimiter=matches[4];return(leftDelimiter==="["?count>=leftNumber:count>leftNumber)&&(rightDelimiter==="]"?count<=rightNumber:count<rightNumber)}return false};Lang.prototype._getPluralForm=function(count){switch(this.locale){case"az":case"bo":case"dz":case"id":case"ja":case"jv":case"ka":case"km":case"kn":case"ko":case"ms":case"th":case"tr":case"vi":case"zh":return 0;case"af":case"bn":case"bg":case"ca":case"da":case"de":case"el":case"en":case"eo":case"es":case"et":case"eu":case"fa":case"fi":case"fo":case"fur":case"fy":case"gl":case"gu":case"ha":case"he":case"hu":case"is":case"it":case"ku":case"lb":case"ml":case"mn":case"mr":case"nah":case"nb":case"ne":case"nl":case"nn":case"no":case"om":case"or":case"pa":case"pap":case"ps":case"pt":case"so":case"sq":case"sv":case"sw":case"ta":case"te":case"tk":case"ur":case"zu":return count==1?0:1;case"am":case"bh":case"fil":case"fr":case"gun":case"hi":case"hy":case"ln":case"mg":case"nso":case"xbr":case"ti":case"wa":return count===0||count===1?0:1;case"be":case"bs":case"hr":case"ru":case"sr":case"uk":return count%10==1&&count%100!=11?0:count%10>=2&&count%10<=4&&(count%100<10||count%100>=20)?1:2;case"cs":case"sk":return count==1?0:count>=2&&count<=4?1:2;case"ga":return count==1?0:count==2?1:2;case"lt":return count%10==1&&count%100!=11?0:count%10>=2&&(count%100<10||count%100>=20)?1:2;case"sl":return count%100==1?0:count%100==2?1:count%100==3||count%100==4?2:3;case"mk":return count%10==1?0:1;case"mt":return count==1?0:count===0||count%100>1&&count%100<11?1:count%100>10&&count%100<20?2:3;case"lv":return count===0?0:count%10==1&&count%100!=11?1:2;case"pl":return count==1?0:count%10>=2&&count%10<=4&&(count%100<12||count%100>14)?1:2;case"cy":return count==1?0:count==2?1:count==8||count==11?2:3;case"ro":return count==1?0:count===0||count%100>0&&count%100<20?1:2;case"ar":return count===0?0:count==1?1:count==2?2:count%100>=3&&count%100<=10?3:count%100>=11&&count%100<=99?4:5;default:return 0}};return Lang});

(function () {
    Lang = new Lang();
    Lang.setMessages({"ar.auth":{"failed":"\u0628\u064a\u0627\u0646\u0627\u062a \u0627\u0644\u0627\u0639\u062a\u0645\u0627\u062f \u0647\u0630\u0647 \u0644\u0627 \u062a\u062a\u0637\u0627\u0628\u0642 \u0645\u0639 \u0633\u062c\u0644\u0627\u062a\u0646\u0627.","throttle":"\u0645\u062d\u0627\u0648\u0644\u0627\u062a \u062a\u0633\u062c\u064a\u0644 \u062f\u062e\u0648\u0644 \u0643\u062b\u064a\u0631\u0629. \u064a\u0631\u062c\u0649 \u0627\u0644\u0645\u062d\u0627\u0648\u0644\u0629 \u0645\u0631\u0629 \u0623\u062e\u0631\u0649 seconds: \u062b\u0648\u0627\u0646\u064d."},"ar.messages":{"activity_log":{"activity_logs":"\u0633\u062c\u0644\u0627\u062a \u0627\u0644\u0646\u0634\u0627\u0637","loading_more_date":"\u062a\u062d\u0645\u064a\u0644 \u0627\u0644\u0645\u0632\u064a\u062f \u0645\u0646 \u0627\u0644\u0628\u064a\u0627\u0646\u0627\u062a","sorry_we_not_find_any_data":"\u0644\u0627 \u064a\u0645\u0643\u0646\u0646\u0627 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0623\u064a \u0628\u064a\u0627\u0646\u0627\u062a \u060c \u0623\u062f\u062e\u0644 \u0625\u062f\u062e\u0627\u0644\u0627\u064b \u0648\u0627\u062d\u062f\u064b\u0627 \u0639\u0644\u0649 \u0627\u0644\u0623\u0642\u0644","we_could_find_any_data":"\u0644\u0645 \u0646\u062a\u0645\u0643\u0646 \u0645\u0646 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0623\u064a \u0628\u064a\u0627\u0646\u0627\u062a \u0645\u0639\u0630\u0631\u0629"},"address":{"city":"\u0645\u062f\u064a\u0646\u0629","country":"\u0628\u0644\u062f","state":"\u062d\u0627\u0644\u0629","street":"\u0634\u0627\u0631\u0639","zip_code":"\u0627\u0644\u0631\u0645\u0632 \u0627\u0644\u0628\u0631\u064a\u062f\u064a"},"announcement":{"add":"\u0623\u0636\u0641","announcement_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0625\u0639\u0644\u0627\u0646","announcement_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0625\u0639\u0644\u0627\u0646","announcement_not_found":"\u0627\u0644\u0625\u0639\u0644\u0627\u0646 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f","announcement_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0625\u0639\u0644\u0627\u0646 \u0628\u0646\u062c\u0627\u062d.","announcement_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0625\u0639\u0644\u0627\u0646 \u0628\u0646\u062c\u0627\u062d.","edit_announcement":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0625\u0639\u0644\u0627\u0646","message":"\u0631\u0633\u0627\u0644\u0629","new_announcement":"\u0625\u0639\u0644\u0627\u0646 \u062c\u062f\u064a\u062f","no_announcement_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0625\u0639\u0644\u0627\u0646 \u0645\u062a\u0627\u062d","no_announcement_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0625\u0639\u0644\u0627\u0646.","show_my_name":"\u0625\u0638\u0647\u0627\u0631 \u0627\u0633\u0645\u064a","show_to_clients":"\u062a\u0638\u0647\u0631 \u0644\u0644\u0639\u0645\u0644\u0627\u0621","show_to_staff":"\u062a\u0638\u0647\u0631 \u0644\u0644\u0645\u0648\u0638\u0641\u064a\u0646","subject":"\u0645\u0648\u0636\u0648\u0639"},"announcements":"\u0627\u0644\u0625\u0639\u0644\u0627\u0646\u0627\u062a","article":{"add":"\u0623\u0636\u0641","article_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0642\u0627\u0644\u0629","article_not_found":"\u0627\u0644\u0645\u0642\u0627\u0644 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","article_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0645\u0642\u0627\u0644 \u0628\u0646\u062c\u0627\u062d.","article_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0642\u0627\u0644\u0629 \u0628\u0646\u062c\u0627\u062d.","attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","description":"\u0648\u0635\u0641","disabled":"\u0645\u0639\u0627\u0642","edit_article":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0642\u0627\u0644","group":"\u0645\u062c\u0645\u0648\u0639\u0629","internal_article":"\u0627\u0644\u0645\u0627\u062f\u0629 \u0627\u0644\u062f\u0627\u062e\u0644\u064a\u0629","new_article":"\u0645\u0627\u062f\u0629 \u062c\u062f\u064a\u062f\u0629","no_article_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0645\u0642\u0627\u0644 \u0645\u062a\u0627\u062d.","no_article_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0642\u0627\u0644.","subject":"\u0645\u0648\u0636\u0648\u0639","upload_image":"\u062a\u062d\u0645\u064a\u0644 \u0627\u0644\u0635\u0648\u0631"},"article_group":{"add_new_article_group":"\u0623\u0636\u0641 \u0645\u062c\u0645\u0648\u0639\u0629 \u0645\u0642\u0627\u0644\u0627\u062a \u062c\u062f\u064a\u062f\u0629","article_group_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0642\u0627\u0644\u0627\u062a \u0628\u0646\u062c\u0627\u062d.","article_group_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0642\u0627\u0644\u0627\u062a \u0628\u0646\u062c\u0627\u062d.","article_group_used_somewhere_else":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0627\u062f\u0629 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","article_groups":"\u0645\u062c\u0645\u0648\u0639\u0627\u062a \u0627\u0644\u0645\u0642\u0627\u0644\u0627\u062a","color":"\u0627\u0644\u0644\u0648\u0646","edit_article_group":"\u062a\u062d\u0631\u064a\u0631 \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0642\u0627\u0644\u0627\u062a","group_name":"\u0623\u0633\u0645 \u0627\u0644\u0645\u062c\u0645\u0648\u0639\u0629","new_article_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0645\u0642\u0627\u0644\u0627\u062a \u062c\u062f\u064a\u062f\u0629","order":"\u0637\u0644\u0628"},"articles":"\u0645\u0642\u0627\u0644\u0627\u062a","calendars":"\u0627\u0644\u062a\u0642\u0627\u0648\u064a\u0645","change_password":{"change_information_about_yourself_on_this_page":"\u0642\u0645 \u0628\u062a\u063a\u064a\u064a\u0631 \u0627\u0644\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0639\u0646 \u0646\u0641\u0633\u0643 \u0641\u064a \u0647\u0630\u0647 \u0627\u0644\u0635\u0641\u062d\u0629","confirm_password":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","current_password":"\u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0627\u0644\u062d\u0627\u0644\u064a","edit_profile":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","new_password":"\u0643\u0644\u0645\u0629 \u0633\u0631 \u062c\u062f\u064a\u062f\u0629"},"client_dashboard":"\u0644\u0648\u062d\u0629 \u062a\u062d\u0643\u0645 \u0627\u0644\u0639\u0645\u064a\u0644","cms":"\u0633\u0645","comment":{"add_comment":"\u0623\u0636\u0641 \u062a\u0639\u0644\u064a\u0642","added_by":"\u0623\u0636\u064a\u0641 \u0628\u0648\u0627\u0633\u0637\u0629","comments_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u062a\u0639\u0644\u064a\u0642 \u0628\u0646\u062c\u0627\u062d.","comments_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062a\u0639\u0644\u064a\u0642 \u0628\u0646\u062c\u0627\u062d.","edit_comment":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u062a\u0639\u0644\u064a\u0642","new_comment":"\u062a\u0639\u0644\u064a\u0642 \u062c\u062f\u064a\u062f","no_comments_added_yet":"\u0644\u0627 \u062a\u0648\u062c\u062f \u062a\u0639\u0644\u064a\u0642\u0627\u062a \u062d\u062a\u0649 \u0627\u0644\u0622\u0646"},"comments":"\u062a\u0639\u0644\u064a\u0642\u0627\u062a","common":{"action":"\u0639\u0645\u0644","active":"\u0646\u0634\u064a\u0637","add":"\u0623\u0636\u0641","admin_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0644\u0645\u0633\u0624\u0648\u0644","announcement":"\u0625\u0639\u0644\u0627\u0646","apply":"\u064a\u062a\u0642\u062f\u0645","article":"\u0645\u0642\u0627\u0644\u0629 - \u0633\u0644\u0639\u0629","article_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0627\u062f\u0629","assignee":"\u0627\u0644\u0648\u0643\u064a\u0644","attachment_deleted":"\u062a\u0645 \u062d\u0630\u0641 \u0627\u0644\u0645\u0631\u0641\u0642.","back":"\u0639\u0648\u062f\u0629","cancel":"\u0625\u0644\u063a\u0627\u0621","choose":"\u0623\u062e\u062a\u0631","client_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0644\u0639\u0645\u064a\u0644","contract_type":"\u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f","country":"\u062f\u0648\u0644\u0629","created_on":"\u062a\u0645 \u0625\u0646\u0634\u0627\u0624\u0647\u0627 \u0639\u0644\u0649","custom":"\u0627\u0644\u0639\u0627\u062f\u0629","customer":"\u0639\u0645\u064a\u0644","customer_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","data_base_entries":"\u0625\u0638\u0647\u0627\u0631 _START_ \u0625\u0644\u0649 _END_ \u0645\u0646 _TOTAL_ \u0645\u0646 \u0627\u0644\u0625\u062f\u062e\u0627\u0644\u0627\u062a","deactive":"\u0645\u0639\u0637\u0644","default_country_code":"\u0631\u0645\u0632 \u0627\u0644\u0628\u0644\u062f \u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a","delete":"\u062d\u0630\u0641","delete_attachment":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0627 \"\u0627\u0644\u0645\u0631\u0641\u0642\"\u061f","delete_confirm":"\u0623\u0631\u062c\u0648\u0643 \u0623\u0643\u062a\u0628","delete_confirm_common":"\u0647\u0644 \u062a\u0631\u064a\u062f \u0628\u0627\u0644\u062a\u0623\u0643\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0627","delete_note":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0647 \"\u0627\u0644\u0645\u0644\u0627\u062d\u0638\u0629\"\u061f","deleted":"\u062a\u0645 \u0627\u0644\u062d\u0630\u0641!","department":"\u0642\u0633\u0645","description":"\u0648\u0635\u0641","download":"\u062a\u062d\u0645\u064a\u0644","download_as_pdf":"\u062a\u0646\u0632\u064a\u0644 \u0643\u0645\u0644\u0641 PDF","drafted":"\u0635\u0627\u063a","edit":"\u062a\u0639\u062f\u064a\u0644","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","expense":"\u0645\u0635\u0631\u0648\u0641","expense_category":"\u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","filter_by":"(\u062a\u0645\u062a \u062a\u0635\u0641\u064a\u062a\u0647 \u0645\u0646 \u0625\u062c\u0645\u0627\u0644\u064a \u0625\u062f\u062e\u0627\u0644\u0627\u062a _MAX_)","from":"\u0645\u0646","goal":"\u0647\u062f\u0641","has_been_delete":" \u0642\u062f \u062a\u0645 \u062d\u0630\u0641.","incomes_vs_expenses":"\u0627\u0644\u062f\u062e\u0644 \u0645\u0642\u0627\u0628\u0644 \u0627\u0644\u0645\u0635\u0631\u0648\u0641\u0627\u062a","last_updated":"\u0622\u062e\u0631 \u062a\u062d\u062f\u064a\u062b","lead":"\u0642\u064a\u0627\u062f\u0629","lead_source":"\u0645\u0635\u062f\u0631 \u0627\u0644\u062f\u0644\u064a\u0644","menu_entry":"\u0625\u0638\u0647\u0627\u0631 \u0625\u062f\u062e\u0627\u0644\u0627\u062a _MENU_","n\/a":"\u0644\u0627 \u064a\u0648\u062c\u062f","name":"\u0627\u0633\u0645","no":"\u0644\u0627","no_data_available_in_table":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0628\u064a\u0627\u0646\u0627\u062a \u0645\u062a\u0648\u0641\u0631\u0629 \u0641\u064a \u0627\u0644\u062c\u062f\u0648\u0644","no_entry":"\u0625\u0638\u0647\u0627\u0631 0 \u0625\u0644\u0649 0 \u0645\u0646 0 \u0645\u062f\u062e\u0644\u0627\u062a","no_matching":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0633\u062c\u0644\u0627\u062a \u0645\u0637\u0627\u0628\u0642\u0629","note":"\u0645\u0644\u062d\u0648\u0638\u0629","note_delete":"\u062a\u0645 \u062d\u0630\u0641 \u0627\u0644\u0645\u0644\u0627\u062d\u0638\u0629.","of":"\u0645\u0646","ok":"\u0646\u0639\u0645","payment_mode":"\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u062f\u0641\u0639","predefined_reply":"\u0631\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627","product_1":"\u0645\u0646\u062a\u062c","product_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a","product_header":"\u0645\u0646\u062a\u062c","proposal":"\u0639\u0631\u0636","quantity_is_not_greater_than":"\u0627\u0644\u0643\u0645\u064a\u0629 \u0644\u0627 \u062a\u0632\u064a\u062f \u0639\u0646 9999999","save":"\u062d\u0641\u0638","search":"\u0628\u062d\u062b","search_results":"\u0646\u062a\u0627\u0626\u062c \u0627\u0644\u0628\u062d\u062b \u0627\u0644\u062e\u0627\u0635\u0629 \u0628\u0643 \u0647\u0646\u0627 ...","service":"\u062e\u062f\u0645\u0629","showing":"\u0639\u0631\u0636","status":"\u0627\u0644\u062d\u0627\u0644\u0629","tag":"\u0628\u0637\u0627\u0642\u0629 \u0634\u0639\u0627\u0631","tax_rate":"\u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","term_and_conditions":"\u0627\u0644\u0634\u0631\u0648\u0637 \u0648\u0627\u0644\u0623\u062d\u0643\u0627\u0645","ticket_priority":"\u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","to":"\u0625\u0644\u0649","to_delete_this":"\u0644\u062d\u0630\u0641 \u0647\u0630\u0627","total_amount":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a","type_delete":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0643\u062a\u0627\u0628\u0629 \"\u062d\u0630\u0641\" \u0644\u062d\u0630\u0641 \u0647\u0630\u0627","view":"\u0631\u0623\u064a","weekly_payment_records":"\u0633\u062c\u0644\u0627\u062a \u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0623\u0633\u0628\u0648\u0639\u064a\u0629","yes":"\u0646\u0639\u0645"},"company":{"address":"\u0639\u0646\u0648\u0627\u0646","city":"\u0645\u062f\u064a\u0646\u0629","company":"\u0627\u0633\u0645 \u0627\u0644\u0634\u0631\u0643\u0629","company_information_format":"\u062a\u0646\u0633\u064a\u0642 \u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0627\u0644\u0634\u0631\u0643\u0629 (PDF \u0648 HTML)","country_code":"\u0627\u0644\u0631\u0642\u0645 \u0627\u0644\u062f\u0648\u0644\u064a","currency":"\u0639\u0645\u0644\u0629","details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0634\u0631\u0643\u0629","phone":"\u0647\u0627\u062a\u0641","state":"\u062d\u0627\u0644\u0629","vat_number":"\u0638\u0631\u064a\u0628\u0647 \u0627\u0644\u0634\u0631\u0627\u0621","website":"\u0645\u0648\u0642\u0639 \u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a","zip_code":"\u0627\u0644\u0631\u0645\u0632 \u0627\u0644\u0628\u0631\u064a\u062f\u064a"},"company_information":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0627\u0644\u0634\u0631\u0643\u0629","contact":{"active":"\u0646\u0634\u064a\u0637","by_deleting_this_contact":"\u0628\u062d\u0630\u0641 \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0647\u0630\u0647 \u060c \u0633\u064a\u062a\u0645 \u062d\u0630\u0641 \u062c\u0645\u064a\u0639 \u0645\u0634\u0627\u0631\u064a\u0639\u0647\u0627.","contact_details":"\u0628\u064a\u0627\u0646\u0627\u062a \u0627\u0644\u0645\u062a\u0635\u0644","contact_not_found":"\u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f\u0629.","contact_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0628\u0646\u062c\u0627\u062d.","contact_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0628\u0646\u062c\u0627\u062d.","contact_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0628\u0646\u062c\u0627\u062d.","contract":"\u0639\u0642\u062f","contracts":"\u0627\u0646\u0643\u0645\u0627\u0634","credit_note":"\u0627\u0634\u0639\u0627\u0631 \u062f\u0627\u0626\u0646","customer_name":"\u0627\u0633\u0645 \u0627\u0644\u0632\u0628\u0648\u0646","delete_contact_confirm":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u062d\u0630\u0641 \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0647\u0630\u0647\u061f","direction":"\u0627\u062a\u062c\u0627\u0647","edit_contact":"\u062a\u062d\u0631\u064a\u0631 \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644","email_notifications":"\u0627\u0634\u0639\u0627\u0631\u0627\u062a \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a","estimate":"\u062a\u0642\u062f\u064a\u0631","estimates":"\u0627\u0644\u062a\u0642\u062f\u064a\u0631\u0627\u062a","first_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0627\u0648\u0644","full_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0643\u0627\u0645\u0644","impersonate":"\u0627\u0646\u062a\u062d\u0627\u0644 \u0627\u0644\u0634\u062e\u0635\u064a\u0629","inactive":"\u063a\u064a\u0631 \u0646\u0634\u0637","invoice":"\u0641\u0627\u062a\u0648\u0631\u0629","invoices":"\u0641\u0648\u0627\u062a\u064a\u0631","last_name":"\u0627\u0644\u0643\u0646\u064a\u0629","make_sure_to_set_appropriate_permissions_for_this_contact":"\u062a\u0623\u0643\u062f \u0645\u0646 \u062a\u0639\u064a\u064a\u0646 \u0627\u0644\u0623\u0630\u0648\u0646\u0627\u062a \u0627\u0644\u0645\u0646\u0627\u0633\u0628\u0629 \u0644\u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0647\u0630\u0647","new_contact":"\u062c\u0647\u0629 \u0627\u062a\u0635\u0627\u0644 \u062c\u062f\u064a\u062f\u0629","no_contact_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0627\u062a\u0635\u0627\u0644 \u0645\u062a\u0627\u062d.","no_contact_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u062c\u0647\u0629 \u0627\u062a\u0635\u0627\u0644.","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","permissions":"\u0623\u0630\u0648\u0646\u0627\u062a","position":"\u0645\u0648\u0636\u0639","primary_contact":"\u0627\u062a\u0635\u0627\u0644 \u0631\u0626\u064a\u0633\u064a","project":"\u0645\u0634\u0631\u0648\u0639","projects":"\u0627\u0644\u0645\u0634\u0627\u0631\u064a\u0639","proposals":"\u0627\u0642\u062a\u0631\u0627\u062d\u0627\u062a","send_password_email":"\u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","send_welcome_email":"\u0644\u0627 \u062a\u0631\u0633\u0644 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0627\u0644\u062a\u0631\u062d\u064a\u0628\u064a","support":"\u0627\u0644\u062f\u0639\u0645","task":"\u0645\u0647\u0645\u0629","tickets":"\u0627\u0644\u062a\u0630\u0627\u0643\u0631"},"contacts":"\u062c\u0647\u0627\u062a \u0627\u0644\u0627\u062a\u0635\u0627\u0644","contract":{"add":"\u0623\u0636\u0641","contract_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0642\u062f","contract_list":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0639\u0642\u0648\u062f","contract_not_found":"\u0627\u0644\u0639\u0642\u062f \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f","contract_summary":"\u0645\u0644\u062e\u0635 \u0627\u0644\u0639\u0642\u062f","contract_type_id":"\u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f","contract_value":"\u0642\u064a\u0645\u0629 \u0627\u0644\u0639\u0642\u062f","contracts_by_type":"\u0627\u0644\u0639\u0642\u0648\u062f \u062d\u0633\u0628 \u0627\u0644\u0646\u0648\u0639","contracts_expiring_this_month":"\u0627\u0644\u0639\u0642\u0648\u062f \u062a\u0646\u062a\u0647\u064a \u0647\u0630\u0627 \u0627\u0644\u0634\u0647\u0631","contracts_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0639\u0642\u062f \u0628\u0646\u062c\u0627\u062d.","contracts_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0639\u0642\u062f \u0628\u0646\u062c\u0627\u062d.","contracts_value_by_type":"\u0642\u064a\u0645\u0629 \u0627\u0644\u0639\u0642\u0648\u062f \u062d\u0633\u0628 \u0627\u0644\u0646\u0648\u0639","customer_id":"\u0627\u0644\u0632\u0628\u0648\u0646","description":"\u0648\u0635\u0641","edit_contract":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0639\u0642\u062f","end_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0646\u062a\u0647\u0627\u0621","is_hide":"\u0625\u062e\u0641\u0627\u0621 \u0639\u0646 \u0627\u0644\u0639\u0645\u064a\u0644","is_trash":"\u0642\u0645\u0627\u0645\u0629\u060c \u064a\u062f\u0645\u0631\u060c \u064a\u0647\u062f\u0645","new_contract":"\u0639\u0642\u062f \u062c\u062f\u064a\u062f","no_contract_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0639\u0642\u062f \u0645\u062a\u0627\u062d","no_contract_found":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0639\u0642\u062f.","sign":"\u0625\u0634\u0627\u0631\u0629","start_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0628\u062f\u0621","subject":"\u0645\u0648\u0636\u0648\u0639","task":"\u0645\u0647\u0645\u0629"},"contract_type":{"add_new_contract_type":"\u0623\u0636\u0641 \u0646\u0648\u0639 \u0639\u0642\u062f \u062c\u062f\u064a\u062f","contract_by_type":"\u0627\u0644\u0639\u0642\u062f \u062d\u0633\u0628 \u0627\u0644\u0646\u0648\u0639","contract_type_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f \u0628\u0646\u062c\u0627\u062d.","contract_type_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f \u0628\u0646\u062c\u0627\u062d.","contract_type_used_somewhere_else":"\u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","contract_value_by_type":"\u0642\u064a\u0645\u0629 \u0627\u0644\u0639\u0642\u062f \u062d\u0633\u0628 \u0627\u0644\u0646\u0648\u0639","edit_contract_type":"\u062a\u062d\u0631\u064a\u0631 \u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f","new_contract_type":"\u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f \u0627\u0644\u062c\u062f\u064a\u062f"},"contract_types":"\u0623\u0646\u0648\u0627\u0639 \u0627\u0644\u0639\u0642\u0648\u062f","contracts":"\u0627\u0646\u0643\u0645\u0627\u0634","countries":"\u0628\u0644\u062f\u0627\u0646","country":{"add":"\u064a\u0636\u064a\u0641","country_not_found":"\u0627\u0644\u0628\u0644\u062f \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","country_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0628\u0644\u062f \u0628\u0646\u062c\u0627\u062d.","country_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0628\u0644\u062f \u0628\u0646\u062c\u0627\u062d.","country_used_somewhere_else":"\u062a\u0633\u062a\u062e\u062f\u0645 \u0627\u0644\u062f\u0648\u0644\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","edit_country":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062f\u0648\u0644\u0629","name":"\u0627\u0633\u0645","new_country":"\u0628\u0644\u062f \u062c\u062f\u064a\u062f","no_country_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0628\u0644\u062f \u0645\u062a\u0627\u062d.","no_country_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0628\u0644\u062f."},"credit_note":{"authorized_signature":"\u062a\u0648\u0642\u064a\u0639 \u0645\u0639\u062a\u0645\u062f","client_note":"\u0645\u0644\u062d\u0648\u0638\u0629","closed":"\u0645\u063a\u0644\u0642","credit_note":"\u0627\u0634\u0639\u0627\u0631 \u062f\u0627\u0626\u0646","credit_note_date":"\u062a\u0627\u0631\u064a\u062e \u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646","credit_note_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646","credit_note_details_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062a\u0641\u0627\u0635\u064a\u0644 \u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646 \u0628\u0646\u062c\u0627\u062d.","credit_note_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646.","credit_note_number":"\u0631\u0642\u0645 \u0625\u0634\u0639\u0627\u0631 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646","credit_note_pdf":"\u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646 PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646 \u0628\u0646\u062c\u0627\u062d.","credit_note_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646 \u0628\u0646\u062c\u0627\u062d.","drafted":"\u0635\u0627\u063a","edit_credit_note":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646","invoice_credited":"\u0645\u0635\u062f\u0642 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","mark_as_closed":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0645\u063a\u0644\u0642","mark_as_draft":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0645\u0633\u0648\u062f\u0629","mark_as_open":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \"\u0645\u0641\u062a\u0648\u062d\"","mark_as_void":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0628\u0627\u0637\u0644\u0629","new_credit_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0626\u062a\u0645\u0627\u0646\u064a\u0629 \u062c\u062f\u064a\u062f\u0629","no_credit_note_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0645\u0630\u0643\u0631\u0629 \u0627\u0626\u062a\u0645\u0627\u0646 \u0645\u062a\u0627\u062d\u0629.","no_credit_note_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0630\u0643\u0631\u0629 \u0627\u0626\u062a\u0645\u0627\u0646.","open":"\u0627\u0641\u062a\u062d","quantity_is_not_greater_than":"\u0627\u0644\u0643\u0645\u064a\u0629 \u0644\u0627 \u062a\u0632\u064a\u062f \u0639\u0646 9999999","reference":"\u0645\u0631\u062c\u0639","refunds":"\u0627\u0644\u0645\u0628\u0627\u0644\u063a \u0627\u0644\u0645\u0633\u062a\u0631\u062f\u0629","save_and_send":"\u062d\u0641\u0638 \u0648\u0625\u0631\u0633\u0627\u0644","save_as_draft":"\u062d\u0641\u0638 \u0643\u0645\u0633\u0648\u062f\u0629","terms_and_conditions":"\u0627\u0644\u0628\u0646\u0648\u062f \u0648 \u0627\u0644\u0638\u0631\u0648\u0641","title":"\u0639\u0646\u0648\u0627\u0646","view_credit_note_as_customer":"\u0639\u0631\u0636 \u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646 \u0643\u0639\u0645\u064a\u0644","void":"\u0628\u0627\u0637\u0644"},"credit_notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646","customer":{"add_address_details":"\u0623\u0636\u0641 \u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","address":"\u0639\u0646\u0648\u0627\u0646","address_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0646\u0648\u0627\u0646","address_not_found":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0646\u0648\u0627\u0646 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","billing_address":"\u0639\u0646\u0648\u0627\u0646 \u0648\u0635\u0648\u0644 \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","billing_address_details_not_available":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631 \u063a\u064a\u0631 \u0645\u062a\u0648\u0641\u0631\u0629","by_deleting_this_customer":"\u0628\u062d\u0630\u0641 \u0647\u0630\u0627 \u0627\u0644\u0639\u0645\u064a\u0644 \u060c \u0633\u064a\u062a\u0645 \u062d\u0630\u0641 \u062c\u0645\u064a\u0639 \u0645\u0634\u0627\u0631\u064a\u0639\u0647 \u060c \u0633\u064a\u062a\u0645 \u062d\u0630\u0641 \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0648\u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0648\u0627\u0644\u062a\u0642\u062f\u064a\u0631 \u0648\u0645\u0630\u0643\u0631\u0629 \u0627\u0644\u0627\u0626\u062a\u0645\u0627\u0646 \u0648\u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d \u0648\u0627\u0644\u0639\u0642\u062f.","city":"\u0645\u062f\u064a\u0646\u0629","company_name":"\u0627\u0633\u0645 \u0627\u0644\u0634\u0631\u0643\u0629","copy_billing_address":"\u0646\u0633\u062e \u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","country":"\u0628\u0644\u062f","currency":"\u0639\u0645\u0644\u0629","customer_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0645\u064a\u0644","customer_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0639\u0645\u064a\u0644 \u0628\u0646\u062c\u0627\u062d.","customer_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0639\u0645\u064a\u0644 \u0628\u0646\u062c\u0627\u062d.","customers":"\u0627\u0644\u0632\u0628\u0627\u0626\u0646","default_language":"\u0627\u0644\u0644\u063a\u0629 \u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a\u0629","delete_customer_confirm":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0627 \u0627\u0644\u0639\u0645\u064a\u0644\u061f","do_not_fill_shipping_address_customer_invoices":"\u0644\u0627 \u062a\u0645\u0644\u0623 \u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0634\u062d\u0646 \u0625\u0630\u0627 \u0644\u0645 \u062a\u0633\u062a\u062e\u062f\u0645 \u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0634\u062d\u0646 \u0641\u064a \u0641\u0648\u0627\u062a\u064a\u0631 \u0627\u0644\u0639\u0645\u064a\u0644","edit_customer":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0639\u0645\u064a\u0644","groups":"\u0645\u062c\u0645\u0648\u0639\u0627\u062a","new_customer":"\u0639\u0645\u064a\u0644 \u062c\u062f\u064a\u062f","no_customer_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0632\u0628\u0648\u0646 \u0645\u062a\u0627\u062d","no_customer_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0632\u0628\u0648\u0646.","phone":"\u0647\u0627\u062a\u0641","same_as_a_customer_info":"\u0646\u0641\u0633 \u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0627\u0644\u0639\u0645\u064a\u0644","search_customer":"\u0627\u0644\u0628\u062d\u062b \u0639\u0646 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","shipping_address":"\u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0634\u062d\u0646","shipping_address_details_not_available":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0634\u062d\u0646 \u063a\u064a\u0631 \u0645\u062a\u0648\u0641\u0631\u0629","state":"\u062d\u0627\u0644\u0629","street":"\u0634\u0627\u0631\u0639","total_contact":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0632\u0628\u0648\u0646 \u0645\u062a\u0627\u062d.","total_customers":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0639\u0645\u0644\u0627\u0621","total_project":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0645\u0634\u0631\u0648\u0639","type":"\u0646\u0648\u0639","vat_number":"\u0638\u0631\u064a\u0628\u0647 \u0627\u0644\u0634\u0631\u0627\u0621","website":"\u0645\u0648\u0642\u0639 \u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a","zip_code":"\u0627\u0644\u0631\u0645\u0632 \u0627\u0644\u0628\u0631\u064a\u062f\u064a"},"customer_group":{"action":"\u0639\u0645\u0644","add_new_customer_group":"\u0625\u0636\u0627\u0641\u0629 \u0645\u062c\u0645\u0648\u0639\u0629 \u0639\u0645\u0644\u0627\u0621 \u062c\u062f\u064a\u062f\u0629","customer_group_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0639\u0645\u0644\u0627\u0621 \u0628\u0646\u062c\u0627\u062d.","customer_group_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0639\u0645\u0644\u0627\u0621 \u0628\u0646\u062c\u0627\u062d.","description":"\u0648\u0635\u0641","edit_customer_group":"\u062a\u062d\u0631\u064a\u0631 \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","name":"\u0627\u0633\u0645","new_customer_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0639\u0645\u0644\u0627\u0621 \u062c\u062f\u064a\u062f\u0629"},"customer_groups":"\u0645\u062c\u0645\u0648\u0639\u0627\u062a \u0627\u0644\u0639\u0645\u0644\u0627\u0621","customers":"\u0627\u0644\u0632\u0628\u0627\u0626\u0646","dashboard":"\u0644\u0648\u062d\u0629 \u0627\u0644\u0642\u064a\u0627\u062f\u0629","department":{"department_not_found":"\u0642\u0633\u0645 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","department_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0642\u0633\u0645 \u0628\u0646\u062c\u0627\u062d.","department_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0642\u0633\u0645 \u0628\u0646\u062c\u0627\u062d.","departments":"\u0627\u0644\u0623\u0642\u0633\u0627\u0645","edit_department":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0642\u0633\u0645","hide_from_clients":"\u0625\u062e\u0641\u0627\u0621 \u0639\u0646 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","new_department":"\u0642\u0633\u0645 \u062c\u062f\u064a\u062f","no_department_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0642\u0633\u0645 \u0645\u062a\u0627\u062d.","no_department_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0642\u0633\u0645."},"edit_profile":{"change_password":"\u063a\u064a\u0631 \u0643\u0644\u0645\u0629 \u0627\u0644\u0633\u0631","edit_profile":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","hello":"\u0645\u0631\u062d\u0628\u0627","hi":"\u0645\u0631\u062d\u0628\u0627","login":"\u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644","login_register":"\u062f\u062e\u0648\u0644\u062a\u0633\u062c\u064a\u0644","logout":"\u062a\u0633\u062c\u064a\u0644 \u062e\u0631\u0648\u062c","mark_all_as_read":"\u0627\u0634\u0631 \u0639\u0644\u064a\u0647\u0627 \u0628\u0627\u0646\u0647\u0627 \u0642\u0631\u0627\u062a","notification":"\u0625\u0634\u0639\u0627\u0631\u0627\u062a","register":"\u062a\u0633\u062c\u064a\u0644","welcome":"\u0623\u0647\u0644\u0627 \u0628\u0643"},"email":{"email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","forgot_password":"\u0647\u0644 \u0646\u0633\u064a\u062a \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","recalled_your_login_info":"\u062a\u0630\u0643\u0631\u062a \u0645\u0639\u0644\u0648\u0645\u0627\u062a \u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644 \u0627\u0644\u062e\u0627\u0635\u0629 \u0628\u0643\u061f","reset_password":"\u0625\u0639\u0627\u062f\u0629 \u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","send_reset_link":"\u0625\u0631\u0633\u0627\u0644 \u0631\u0627\u0628\u0637 \u0625\u0639\u0627\u062f\u0629 \u062a\u0639\u064a\u064a\u0646","sign_in":"\u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644"},"email_template":{"available_merge_fields":"\u062d\u0642\u0648\u0644 \u0627\u0644\u062f\u0645\u062c \u0627\u0644\u0645\u062a\u0627\u062d\u0629","disabled":"\u0645\u0639\u0627\u0642","edit_email_template":"\u062a\u062d\u0631\u064a\u0631 \u0642\u0627\u0644\u0628 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","email_message":"\u0631\u0633\u0627\u0644\u0629 \u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a\u0629","enable":"\u0645\u0645\u0643\u0646","from_name":"\u0645\u0646 \u0627\u0644\u0627\u0633\u0645","send_plain_text":"\u0625\u0631\u0633\u0627\u0644 \u0643\u0646\u0635 \u0639\u0627\u062f\u064a","subject":"\u0645\u0648\u0636\u0648\u0639","template_name":"\u0627\u0633\u0645 \u0627\u0644\u0642\u0627\u0644\u0628"},"email_templates":"\u0642\u0648\u0627\u0644\u0628 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","error":"\u062e\u0637\u0623","estimate":{"accepted":"\u0642\u0628\u0644\u062a","adjustment":"\u062a\u0639\u062f\u064a\u0644","amount":"\u0643\u0645\u064a\u0629","authorized_signature":"\u062a\u0648\u0642\u064a\u0639 \u0645\u0639\u062a\u0645\u062f","bill_to":"\u0641\u0627\u062a\u0648\u0631\u0629 \u0627\u0644\u0649","convert_estimate":"\u062a\u062d\u0648\u064a\u0644 \u0627\u0644\u062a\u0642\u062f\u064a\u0631","convert_estimate_to_invoice":"\u062a\u062d\u0648\u064a\u0644 \u0627\u0644\u062a\u0642\u062f\u064a\u0631 \u0625\u0644\u0649 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","declined":"\u0631\u0641\u0636","discount":"\u062e\u0635\u0645","draft":"\u0645\u0634\u0631\u0648\u0639","drafted":"\u0635\u0627\u063a","edit_estimate":"\u062a\u062d\u0631\u064a\u0631 \u062a\u0642\u062f\u064a\u0631","estimate":"\u062a\u0642\u062f\u064a\u0631","estimate_date":"\u0627\u0644\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0645\u0642\u062f\u0631","estimate_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062a\u0642\u062f\u064a\u0631","estimate_not_found":"\u0627\u0644\u062a\u0642\u062f\u064a\u0631 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f","estimate_number":"\u0627\u0644\u0631\u0642\u0645 \u0627\u0644\u0645\u0642\u062f\u0631","estimate_overview":"\u0646\u0638\u0631\u0629 \u0639\u0627\u0645\u0629 \u062a\u0642\u062f\u064a\u0631\u064a\u0629","estimate_pdf":"\u062a\u0642\u062f\u064a\u0631 PDF","estimate_prefix":"EN-","estimate_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u062a\u0642\u062f\u064a\u0631 \u0628\u0646\u062c\u0627\u062d.","estimate_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0642\u062f\u064a\u0631 \u0628\u0646\u062c\u0627\u062d.","estimate_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062a\u0642\u062f\u064a\u0631 \u0628\u0646\u062c\u0627\u062d.","expired":"\u0645\u0646\u062a\u0647\u064a\u0629 \u0627\u0644\u0635\u0644\u0627\u062d\u064a\u0629","expiry_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0646\u062a\u0647\u0627\u0621","item":"\u0627\u0644\u0645\u0646\u062a\u062c","mark_as_accepted":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \"\u0645\u0642\u0628\u0648\u0644\"","mark_as_declined":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0639\u0644\u0649 \u0623\u0646\u0647 \u0645\u0631\u0641\u0648\u0636","mark_as_draft":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0645\u0633\u0648\u062f\u0629","mark_as_expired":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \"\u0645\u0646\u062a\u0647\u064a \u0627\u0644\u0635\u0644\u0627\u062d\u064a\u0629\"","mark_as_send":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0625\u0631\u0633\u0627\u0644","more":"\u0623\u0643\u062b\u0631","new_estimate":"\u062a\u0642\u062f\u064a\u0631 \u062c\u062f\u064a\u062f","no_estimate_available":"\u0644\u0627 \u062a\u0642\u062f\u064a\u0631 \u0645\u062a\u0627\u062d","no_estimate_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u062a\u0642\u062f\u064a\u0631.","not_sent":"\u0644\u0645 \u062a\u0631\u0633\u0644","qty":"\u0627\u0644\u0643\u0645\u064a\u0629","rate":"\u0645\u0639\u062f\u0644","save_and_send":"\u062d\u0641\u0638 \u0648\u0625\u0631\u0633\u0627\u0644","save_as_draft":"\u062d\u0641\u0638 \u0643\u0645\u0633\u0648\u062f\u0629","sent":"\u0623\u0631\u0633\u0644\u062a","ship_to":"\u0633\u0627\u0641\u0631 \u0639\u0644\u0649 \u0645\u062a\u0646 \u0633\u0641\u064a\u0646\u0629 \u0644","status":"\u0627\u0644\u062d\u0627\u0644\u0629","sub_total":"\u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0641\u0631\u0639\u064a","task":"\u0645\u0647\u0645\u0629","taxes":"\u0627\u0644\u0636\u0631\u0627\u0626\u0628","terms_conditions":"\u0627\u0644\u0628\u0646\u0648\u062f \u0648 \u0627\u0644\u0638\u0631\u0648\u0641","title":"\u0639\u0646\u0648\u0627\u0646","total":"\u0645\u062c\u0645\u0648\u0639","total_estimate":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u062a\u0642\u062f\u064a\u0631\u0627\u062a","total_estimates":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u062a\u0642\u062f\u064a\u0631\u0627\u062a","view_estimate_as_customer":"\u0639\u0631\u0636 \u062a\u0642\u062f\u064a\u0631 \u0643\u0639\u0645\u064a\u0644"},"estimates":"\u0627\u0644\u062a\u0642\u062f\u064a\u0631\u0627\u062a","expense":{"add":"\u0623\u0636\u0641","amount":"\u0643\u0645\u064a\u0629","amount_with_tax":"\u0627\u0644\u0645\u0628\u0644\u063a \u0645\u0639 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","apply_tax":"\u062a\u0637\u0628\u064a\u0642 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","apply_tax_message":"\u0637\u0631\u062d \u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0636\u0631\u064a\u0628\u0629 \u0645\u0646 \u0627\u0644\u0645\u0628\u0644\u063a","attachment":"\u0627\u0644\u0645\u0631\u0641\u0642","auto_create_invoice":"\u0625\u0646\u0634\u0627\u0621 \u0641\u0627\u062a\u0648\u0631\u0629 \u062a\u0644\u0642\u0627\u0626\u064a\u0629","billable":"\u0642\u0627\u0628\u0644 \u0644\u0644\u0641\u0648\u062a\u0631\u0629","choose_file":"\u0627\u062e\u062a\u0631 \u0645\u0644\u0641","currency":"\u0639\u0645\u0644\u0629","customer":"\u0627\u0644\u0632\u0628\u0648\u0646","details":"\u062a\u0641\u0627\u0635\u064a\u0644","edit_expense":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_amount":"\u0645\u0628\u0644\u063a \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_category":"\u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_category_by_chart":"\u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u062d\u0633\u0628 \u0627\u0644\u0631\u0633\u0645 \u0627\u0644\u0628\u064a\u0627\u0646\u064a","expense_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_list":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_not_found":"\u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f\u0629.","expense_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u0628\u0646\u062c\u0627\u062d.","expense_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u0628\u0646\u062c\u0627\u062d.","infinity":"\u0645\u0627 \u0644\u0627 \u0646\u0647\u0627\u064a\u0629","name":"\u0627\u0633\u0645","new_expense":"\u0646\u0641\u0642\u0629 \u062c\u062f\u064a\u062f\u0629","no_expense_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0645\u0635\u0627\u0631\u064a\u0641 \u0645\u062a\u0627\u062d\u0629.","no_expense_found":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0645\u0635\u0627\u0631\u064a\u0641.","note":"\u0645\u0644\u062d\u0648\u0638\u0629","notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a","payment_mode":"\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u062f\u0641\u0639","preview_attachment":"\u0645\u0639\u0627\u064a\u0646\u0629 \u0627\u0644\u0645\u0631\u0641\u0642","receipt_attachment":"\u0645\u0631\u0641\u0642 \u0627\u0644\u0627\u0633\u062a\u0644\u0627\u0645","reference":"\u0645\u0631\u062c\u0639","reminders":"\u062a\u0630\u0643\u064a\u0631","send_email":"\u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0625\u0644\u0649 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0644\u0644\u0639\u0645\u064a\u0644 \u0639\u0646\u062f \u0625\u0639\u0627\u062f\u0629 \u0625\u0646\u0634\u0627\u0621 \u062d\u0633\u0627\u0628","tax_1":"\u0627\u0644\u0636\u0631\u064a\u0628\u0629 1 (\u066a)","tax_2":"\u0627\u0644\u0636\u0631\u064a\u0628\u0629 2 (\u066a)","tax_applied":"\u062a\u0645 \u062a\u0637\u0628\u064a\u0642 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","view_attachment":"\u0639\u0631\u0636 \u0627\u0644\u0645\u0631\u0641\u0642\u0627\u062a"},"expense_by_category":"\u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u062d\u0633\u0628 \u0627\u0644\u0641\u0626\u0629","expense_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_category":{"add_new_expense_category":"\u0625\u0636\u0627\u0641\u0629 \u0641\u0626\u0629 \u0645\u0635\u0627\u0631\u064a\u0641 \u062c\u062f\u064a\u062f\u0629","edit_category":"\u062a\u062d\u0631\u064a\u0631 \u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_categories":"\u0641\u0626\u0627\u062a \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_category":"\u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","expense_category_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u0628\u0646\u062c\u0627\u062d.","expense_category_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u0628\u0646\u062c\u0627\u062d.","expense_category_used_somewhere_else":"\u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","new_category":"\u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641 \u0627\u0644\u062c\u062f\u064a\u062f\u0629"},"expenses":"\u0646\u0641\u0642\u0627\u062a","general":"\u062c\u0646\u0631\u0627\u0644 \u0644\u0648\u0627\u0621","goal":{"achievement":"\u0625\u0646\u062c\u0627\u0632","add":"\u0623\u0636\u0641","description":"\u0648\u0635\u0641","edit_goal":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0647\u062f\u0641","end_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0646\u062a\u0647\u0627\u0621","goal_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0647\u062f\u0641","goal_id":"\u0646\u0648\u0639 \u0627\u0644\u0647\u062f\u0641","goal_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0647\u062f\u0641 \u0628\u0646\u062c\u0627\u062d.","goal_type":"\u0646\u0648\u0639 \u0627\u0644\u0647\u062f\u0641","goal_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0647\u062f\u0641 \u0628\u0646\u062c\u0627\u062d.","is_not_notify":"\u0625\u062e\u0637\u0627\u0631 \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646 \u0639\u0646\u062f\u0645\u0627 \u0641\u0634\u0644 \u0627\u0644\u0647\u062f\u0641 \u0641\u064a \u062a\u062d\u0642\u064a\u0642","is_notify":"\u0625\u062e\u0637\u0627\u0631 \u0627\u0644\u0645\u0648\u0638\u0641\u064a\u0646 \u0639\u0646\u062f \u062a\u062d\u0642\u064a\u0642 \u0627\u0644\u0647\u062f\u0641","new_goal":"\u0627\u0644\u0647\u062f\u0641 \u0627\u0644\u062c\u062f\u064a\u062f","no_goal_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0647\u062f\u0641 \u0645\u062a\u0627\u062d.","no_goal_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0647\u062f\u0641.","progress":"\u0627\u0644\u062a\u0642\u062f\u0645","staff_member":"\u0645\u0648\u0638\u0641","start_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0628\u062f\u0621","subject":"\u0645\u0648\u0636\u0648\u0639","user_id":"\u0645\u0648\u0638\u0641"},"goal_type":{"description":"\u0648\u0635\u0641","edit_goal_type":"\u062a\u062d\u0631\u064a\u0631 \u0646\u0648\u0639 \u0627\u0644\u0647\u062f\u0641","name":"\u0627\u0633\u0645","new_goal_type":"\u0646\u0648\u0639 \u0627\u0644\u0647\u062f\u0641 \u0627\u0644\u062c\u062f\u064a\u062f"},"goals":"\u0627\u0644\u0623\u0647\u062f\u0627\u0641","incomes":"\u0627\u0644\u062f\u062e\u0644","invoice":{"activity_log":"\u0633\u062c\u0644 \u0627\u0644\u0646\u0634\u0627\u0637\u0627\u062a","add_item":"\u0623\u0636\u0641 \u0645\u0646\u062a\u062c","add_shipping_address":"\u0623\u0636\u0641 \u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0634\u062d\u0646","adjustment":"\u062a\u0639\u062f\u064a\u0644","admin_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0625\u062f\u0627\u0631\u064a\u0629","allowed_payment_modes_for_this_invoice":"\u0637\u0631\u0642 \u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0645\u0633\u0645\u0648\u062d \u0628\u0647\u0627 \u0644\u0647\u0630\u0647 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","amount":"\u0643\u0645\u064a\u0629","amount_due":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0645\u0633\u062a\u062d\u0642","authorized_signature":"\u062a\u0648\u0642\u064a\u0639 \u0645\u0639\u062a\u0645\u062f","bank":"\u0645\u0635\u0631\u0641","bill_tasks":"\u0645\u0647\u0627\u0645 \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","bill_to":"\u0641\u0627\u062a\u0648\u0631\u0629 \u0627\u0644\u0649","cancelled":"\u0623\u0644\u063a\u064a\u062a","client_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u0627\u0644\u0639\u0645\u064a\u0644","currency":"\u0639\u0645\u0644\u0629","customer":"\u0627\u0644\u0632\u0628\u0648\u0646","discount":"\u062e\u0635\u0645","discount_type":"\u0646\u0648\u0639 \u0627\u0644\u062e\u0635\u0645","draft":"\u0645\u0634\u0631\u0648\u0639","drafted":"\u0635\u0627\u063a","due_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0633\u062a\u062d\u0642\u0627\u0642","edit_contract_type":"\u062a\u062d\u0631\u064a\u0631 \u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f","edit_invoice":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","fixed":"\u062b\u0627\u0628\u062a","hours":"\u0633\u0627\u0639\u0627\u062a","hsn_tax":"\u0631\u0645\u0632 \u0636\u0631\u064a\u0628\u0629 HSN","invoice":"\u0641\u0627\u062a\u0648\u0631\u0629","invoice_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","invoice_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","invoice_not_found":"\u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f\u0629.","invoice_number":"\u0631\u0642\u0645 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","invoice_overview":"\u0646\u0638\u0631\u0629 \u0639\u0627\u0645\u0629 \u0639\u0644\u0649 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","invoice_payments":"\u0645\u062f\u0641\u0648\u0639\u0627\u062a \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","invoice_pdf":"\u0641\u0627\u062a\u0648\u0631\u0629 \u0628\u0635\u064a\u063a\u0629 PDF","invoice_prefix":"INV-","invoice_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","invoice_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","item":"\u0627\u0644\u0645\u0646\u062a\u062c","mark_as_cancelled":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \"\u0645\u0644\u063a\u0627\u0629\"","mark_as_draft":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0645\u0633\u0648\u062f\u0629","mark_as_paid":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0645\u062f\u0641\u0648\u0639","mark_as_partially_paid":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0639\u0644\u0649 \u0623\u0646\u0647 \u0645\u062f\u0641\u0648\u0639 \u062c\u0632\u0626\u064a\u064b\u0627","mark_as_sent":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0645\u0631\u0633\u0644\u0629","more":"\u0623\u0643\u062b\u0631","new_contract_type":"\u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f \u0627\u0644\u062c\u062f\u064a\u062f","new_invoice":"\u0641\u0627\u062a\u0648\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","no_invoice_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0641\u0627\u062a\u0648\u0631\u0629 \u0645\u062a\u0627\u062d\u0629.","no_invoice_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0641\u0627\u062a\u0648\u0631\u0629.","no_payments_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0645\u062f\u0641\u0648\u0639\u0627\u062a \u0645\u062a\u0627\u062d\u0629","not_sent":"\u0644\u0645 \u062a\u0631\u0633\u0644","notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a","offline_payment":"\u0627\u0644\u062f\u0641\u0639 \u062f\u0648\u0646 \u0627\u062a\u0635\u0627\u0644","online_payment":"\u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a","overdue":"\u062a\u0623\u062e\u0631","paid":"\u062f\u0641\u0639","paid_cap":"\u062f\u0641\u0639","partially_paid":"\u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0629 \u062c\u0632\u0626\u064a\u0627","partially_paid_cap":"\u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0629 \u062c\u0632\u0626\u064a\u0627","pay_now":"\u0627\u062f\u0641\u0639 \u0627\u0644\u0622\u0646","payment":"\u062f\u0641\u0639","payment_details":"\u0628\u064a\u0627\u0646\u0627\u062a \u0627\u0644\u062f\u0641\u0639","payments":"\u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0627\u062a","prevent_sending_overdue_reminders_for_this_invoice":"\u0645\u0646\u0639 \u0625\u0631\u0633\u0627\u0644 \u062a\u0630\u0643\u064a\u0631\u0627\u062a \u0645\u062a\u0623\u062e\u0631\u0629 \u0644\u0647\u0630\u0647 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","qty":"\u0627\u0644\u0643\u0645\u064a\u0629","qty\/hours":"\u0627\u0644\u0643\u0645\u064a\u0629 \/ \u0633\u0627\u0639\u0629","qty_hours":"\u0627\u0644\u0643\u0645\u064a\u0629 \/ \u0633\u0627\u0639\u0629","quick_invoices_info":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631 \u0627\u0644\u0633\u0631\u064a\u0639\u0629","recurring_invoice":"\u0641\u0627\u062a\u0648\u0631\u0629 \u0645\u062a\u0643\u0631\u0631\u0629","reminders":"\u062a\u0630\u0643\u064a\u0631","sale_agent":"\u0648\u0643\u064a\u0644 \u0628\u064a\u0639","save_and_send":"\u062d\u0641\u0638 \u0648\u0625\u0631\u0633\u0627\u0644","save_as_draft":"\u062d\u0641\u0638 \u0643\u0645\u0633\u0648\u062f\u0629","ship_to":"\u0633\u0627\u0641\u0631 \u0639\u0644\u0649 \u0645\u062a\u0646 \u0633\u0641\u064a\u0646\u0629 \u0644","show_quantity_as":"\u0625\u0638\u0647\u0627\u0631 \u0627\u0644\u0643\u0645\u064a\u0629 \u0628\u0627\u0633\u0645","sub_total":"\u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0641\u0631\u0639\u064a","task":"\u0645\u0647\u0645\u0629","taxes":"\u0627\u0644\u0636\u0631\u0627\u0626\u0628","terms_conditions":"\u0627\u0644\u0628\u0646\u0648\u062f \u0648 \u0627\u0644\u0638\u0631\u0648\u0641","title":"\u0639\u0646\u0648\u0627\u0646","total":"\u0645\u062c\u0645\u0648\u0639","total_invoices":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","total_paid":"\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0645\u0628\u0627\u0644\u063a \u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0629","transactions":"\u0627\u0644\u0645\u0639\u0627\u0645\u0644\u0627\u062a","unmark_as_cancelled":"\u0625\u0644\u063a\u0627\u0621 \u0627\u0644\u062a\u062d\u062f\u064a\u062f \u0643\u0645\u0644\u063a\u064a","unpaid":"\u063a\u064a\u0631 \u0645\u062f\u0641\u0648\u0639","unpaid_cap":"\u063a\u064a\u0631 \u0645\u062f\u0641\u0648\u0639","view_invoice_as_customer":"\u0639\u0631\u0636 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0643\u0639\u0645\u064a\u0644"},"invoices":"\u0641\u0648\u0627\u062a\u064a\u0631","kanban_list":"\u0642\u0627\u0626\u0645\u0629 \u0643\u0627\u0646\u0628\u0627\u0646","kanban_view":"\u0643\u0627\u0646\u0628\u0627\u0646 \u0631\u0623\u064a","last_week_payments":"\u0645\u062f\u0641\u0648\u0639\u0627\u062a \u0627\u0644\u0623\u0633\u0628\u0648\u0639 \u0627\u0644\u0645\u0627\u0636\u064a","lead":{"chart":"\u062c\u062f\u0648\u0644","contacted_today":"\u0627\u062a\u0635\u0644 \u0627\u0644\u064a\u0648\u0645","convert_to_customer":"\u0627\u0644\u062a\u062d\u0648\u064a\u0644 \u0625\u0644\u0649 \u0627\u0644\u0639\u0645\u064a\u0644","date_contacted":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u062a\u0635\u0627\u0644","details":"\u062a\u0641\u0627\u0635\u064a\u0644","edit_lead":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0631\u0635\u0627\u0635","estimate_budget":"\u062a\u0642\u062f\u064a\u0631 \u0627\u0644\u0645\u064a\u0632\u0627\u0646\u064a\u0629","lead_convert_customer":"\u064a\u0624\u062f\u064a \u062a\u062d\u0648\u064a\u0644 \u0627\u0644\u0639\u0645\u064a\u0644","lead_convert_customer_chart":"\u0645\u062e\u0637\u0637 \u0639\u0645\u064a\u0644 \u062a\u062d\u0648\u064a\u0644 \u0627\u0644\u0631\u0635\u0627\u0635","lead_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644","lead_list":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0631\u0635\u0627\u0635","lead_not_found":"\u0627\u0644\u0631\u0635\u0627\u0635 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","lead_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0631\u0635\u0627\u0635 \u0628\u0646\u062c\u0627\u062d.","lead_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644 \u0628\u0646\u062c\u0627\u062d.","lead_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644 \u0628\u0646\u062c\u0627\u062d.","leads_overview":"\u0646\u0638\u0631\u0629 \u0639\u0627\u0645\u0629 \u0639\u0644\u0649 \u0627\u0644\u0639\u0645\u0644\u0627\u0621 \u0627\u0644\u0645\u062a\u0648\u0642\u0639\u064a\u0646","member":"\u0639\u0636\u0648","name":"\u0627\u0633\u0645","new_lead":"\u0642\u064a\u0627\u062f\u0629 \u062c\u062f\u064a\u062f\u0629","no_lead_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u062f\u0644\u064a\u0644 \u0645\u062a\u0627\u062d.","no_lead_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0627\u0644\u0631\u0635\u0627\u0635.","notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a","reminder":"\u062a\u0630\u0643\u064a\u0631","source":"\u0645\u0635\u062f\u0631"},"lead_convert_to_customer":"\u064a\u0624\u062f\u064a \u062a\u062d\u0648\u064a\u0644 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","lead_source":{"add":"\u0627\u0633\u0645","edit_lead_source":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635","lead_source_count":"\u0639\u062f\u062f \u0627\u0644\u0631\u0635\u0627\u0635","lead_source_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635.","lead_source_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635 \u0628\u0646\u062c\u0627\u062d.","lead_source_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0645\u0635\u062f\u0631 \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644 \u0628\u0646\u062c\u0627\u062d.","lead_source_used_somewhere":"\u064a\u0633\u062a\u062e\u062f\u0645 \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","name":"\u0627\u0633\u0645","new_lead_source":"\u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635 \u0627\u0644\u062c\u062f\u064a\u062f","no_lead_source_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635 \u0645\u062a\u0627\u062d.","no_lead_source_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635."},"lead_sources":"\u0645\u0635\u0627\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635","lead_status":{"add":"\u0627\u0633\u0645","add_new_lead_status":"\u0625\u0636\u0627\u0641\u0629 \u062d\u0627\u0644\u0629 \u0639\u0645\u064a\u0644 \u0645\u062d\u062a\u0645\u0644 \u062c\u062f\u064a\u062f","color":"\u0627\u0644\u0644\u0648\u0646","edit_lead_status":"\u062a\u062d\u0631\u064a\u0631 \u062d\u0627\u0644\u0629 \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644","lead_status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u0631\u0635\u0627\u0635","lead_status_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u062d\u0627\u0644\u0629 \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644 \u0628\u0646\u062c\u0627\u062d.","lead_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u0639\u0645\u064a\u0644 \u0627\u0644\u0645\u062d\u062a\u0645\u0644 \u0628\u0646\u062c\u0627\u062d.","lead_status_used_somewhere_else":"\u062d\u0627\u0644\u0629 \u0627\u0644\u0631\u0635\u0627\u0635 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","name":"\u0627\u0633\u0645","new_lead_status":"\u062d\u0627\u0644\u0629 \u0639\u0645\u064a\u0644 \u0645\u062d\u062a\u0645\u0644 \u062c\u062f\u064a\u062f\u0629","order":"\u0637\u0644\u0628"},"leads":"\u064a\u0624\u062f\u064a","list_view":"\u0642\u0627\u0626\u0645\u0629 \u0631\u0623\u064a","login":{"admin":"\u0645\u0634\u0631\u0641","client":"\u0639\u0645\u064a\u0644","create_one":"\u0627\u0635\u0646\u0639 \u0648\u0627\u062d\u062f\u0627","don't have an account":"\u0644\u0627 \u062a\u0645\u0644\u0643 \u062d\u0633\u0627\u0628\u061f","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","forgot_password":"\u0647\u0644 \u0646\u0633\u064a\u062a \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","login":"\u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","remember_me":"\u062a\u0630\u0643\u0631\u0646\u0649"},"member":{"add":"\u0623\u0636\u0641","by_deleting_this_member":"\u0628\u062d\u0630\u0641 \u0647\u0630\u0627 \u0627\u0644\u0639\u0636\u0648 \u0643\u0644 \u0645\u0634\u0631\u0648\u0639\u0647 \u060c \u0633\u064a\u062a\u0645 \u062d\u0630\u0641 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d \u0648\u0627\u0644\u0647\u062f\u0641.","choose":"\u0623\u062e\u062a\u0631","created_on":"\u062a\u0645 \u0625\u0646\u0634\u0627\u0624\u0647\u0627 \u0639\u0644\u0649","default_language":"\u0627\u0644\u0644\u063a\u0629 \u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a\u0629","delete_member_confirm":"\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u062d\u0630\u0641 \u0647\u0630\u0627 \u0627\u0644\u0639\u0636\u0648\u061f","direction":"\u0627\u062a\u062c\u0627\u0647","edit_member":"\u062a\u062d\u0631\u064a\u0631 \u0639\u0636\u0648","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","email_is_not_verified":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","email_is_verified":"\u062a\u0645 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","email_verified":"\u062a\u0645 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","email_verified_successfully":"\u062a\u0645 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0628\u0646\u062c\u0627\u062d.","email_verify":"\u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","facebook":"\u0645\u0648\u0642\u0639 \u0627\u0644\u062a\u0648\u0627\u0635\u0644 \u0627\u0644\u0627\u062c\u062a\u0645\u0627\u0639\u064a \u0627\u0644\u0641\u064a\u0633\u0628\u0648\u0643","first_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0627\u0648\u0644","hourly_rate":"\u0627\u0644\u0645\u0639\u062f\u0644 \u0628\u0627\u0644\u0633\u0627\u0639\u0629","image":"\u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","is_administrator":"\u0645\u062f\u064a\u0631","is_enable":"\u062a\u0645\u0643\u064a\u0646 \u0627\u0644\u0645\u0635\u0627\u062f\u0642\u0629 \u0627\u0644\u062b\u0646\u0627\u0626\u064a\u0629","last_name":"\u0627\u0644\u0643\u0646\u064a\u0629","linkedin":"\u0644\u064a\u0646\u0643\u062f \u0625\u0646","member_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0636\u0648","member_informations":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0627\u0644\u0627\u0639\u0636\u0627\u0621","member_not_found":"\u0645\u0633\u062a\u062e\u062f\u0645 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","member_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0639\u0636\u0648 \u0628\u0646\u062c\u0627\u062d.","member_security":"\u0639\u0636\u0648 \u0627\u0644\u0623\u0645\u0646","member_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u0639\u0636\u0648 \u0628\u0646\u062c\u0627\u062d.","member_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0639\u0636\u0648 \u0628\u0646\u062c\u0627\u062d.","new_member":"\u0639\u0636\u0648 \u062c\u062f\u064a\u062f","no_member_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0639\u0636\u0648 \u0645\u062a\u0627\u062d.","no_member_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0639\u0636\u0648.","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","password_confirmation":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","permissions":"\u0623\u0630\u0648\u0646\u0627\u062a","phone":"\u0647\u0627\u062a\u0641","profile":"\u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","resend_email_verification":"\u0625\u0639\u0627\u062f\u0629 \u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u062a\u062d\u0642\u0642 \u0645\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","send_welcome_email":"\u0625\u0631\u0633\u0627\u0644 \u0628\u0631\u064a\u062f \u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u062a\u0631\u062d\u064a\u0628\u064a","skype":"\u0633\u0643\u0627\u064a\u0628","staff_member":"\u0644\u064a\u0633 \u0645\u0646 \u0623\u0639\u0636\u0627\u0621 \u0647\u064a\u0626\u0629 \u0627\u0644\u062a\u062f\u0631\u064a\u0633","total_members":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0623\u0639\u0636\u0627\u0621","verification_mail_has_been_sent":"\u062a\u0645 \u0625\u0631\u0633\u0627\u0644 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0644\u0644\u062a\u062d\u0642\u0642 \u0628\u0646\u062c\u0627\u062d."},"members":"\u0623\u0641\u0631\u0627\u062f","menu_settings":"\u0625\u0639\u062f\u0627\u062f\u0627\u062a \u0627\u0644\u0642\u0627\u0626\u0645\u0629","months":{"apr":"\u0623\u0628\u0631\u064a\u0644","aug":"\u0623\u063a\u0633\u0637\u0633","dec":"\u062f\u064a\u0633\u0645\u0628\u0631","feb":"\u0641\u0628\u0631\u0627\u064a\u0631","jan":"\u064a\u0646\u0627\u064a\u0631","jul":"\u064a\u0648\u0644\u064a\u0648","jun":"\u064a\u0648\u0646\u064a\u0648","mar":"\u0645\u0627\u0631\u0633","may":"\u0645\u0627\u064a\u0648","nov":"\u0646\u0648\u0641\u0645\u0628\u0631","oct":"\u0623\u0643\u062a\u0648\u0628\u0631","sep":"\u0633\u0628\u062a\u0645\u0628\u0631"},"new_language":"\u0644\u063a\u0629 \u062c\u062f\u064a\u062f\u0629","no_matching_records_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0633\u062c\u0644\u0627\u062a \u0645\u0637\u0627\u0628\u0642\u0629","note":{"add_note":"\u0627\u0636\u0641 \u0645\u0644\u0627\u062d\u0638\u0629","edit_note":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0630\u0643\u0631\u0629","new_note":"\u0645\u0644\u0627\u062d\u0638\u0629 \u062c\u062f\u064a\u062f\u0629","no_notes_added_yet":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0645\u0644\u0627\u062d\u0638\u0627\u062a \u0645\u0636\u0627\u0641\u0629 \u062d\u062a\u0649 \u0627\u0644\u0622\u0646","notes_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0645\u0644\u0627\u062d\u0638\u0629 \u0628\u0646\u062c\u0627\u062d.","notes_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0644\u0627\u062d\u0638\u0629 \u0628\u0646\u062c\u0627\u062d."},"notes":"\u0645\u0644\u0627\u062d\u0638\u0627\u062a","notification":{"all_notification_read_successfully":"\u062a\u0645\u062a \u0642\u0631\u0627\u0621\u0629 \u062c\u0645\u064a\u0639 \u0627\u0644\u0625\u0634\u0639\u0627\u0631\u0627\u062a \u0628\u0646\u062c\u0627\u062d.","empty_notifications":"\u0644\u0645 \u0646\u062a\u0645\u0643\u0646 \u0645\u0646 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0623\u064a \u0625\u062e\u0637\u0627\u0631\u0627\u062a","mark_all_as_read":"\u0627\u0634\u0631 \u0639\u0644\u064a\u0647\u0627 \u0628\u0627\u0646\u0647\u0627 \u0642\u0631\u0627\u062a","notification_read_successfully":"\u062a\u0645\u062a \u0642\u0631\u0627\u0621\u0629 \u0627\u0644\u0625\u062e\u0637\u0627\u0631 \u0628\u0646\u062c\u0627\u062d.","notifications":"\u0625\u0634\u0639\u0627\u0631\u0627\u062a"},"others":"\u0627\u0644\u0622\u062e\u0631\u064a\u0646","payment":{"amount":"\u0643\u0645\u064a\u0629","amount_received":"\u062a\u0645 \u0627\u0633\u062a\u0644\u0627\u0645 \u0627\u0644\u0645\u0628\u0644\u063a","date":"\u062a\u0627\u0631\u064a\u062e","new_payment":"\u062f\u0641\u0639 \u062c\u062f\u064a\u062f","note":"\u0645\u0644\u062d\u0648\u0638\u0629","payment_date":"\u0645\u0648\u0639\u062f \u0627\u0644\u062f\u0641\u0639","payment_mode":"\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u062f\u0641\u0639","payment_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u062f\u0641\u0639 \u0628\u0646\u062c\u0627\u062d.","send_mail_to_customer_contacts":"\u0644\u0627 \u062a\u0631\u0633\u0644 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0627\u0644\u0645\u0633\u062c\u0644 \u0644\u062f\u0641\u0639 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 \u0625\u0644\u0649 \u062c\u0647\u0627\u062a \u0627\u062a\u0635\u0627\u0644 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","transaction_id":"\u0631\u0642\u0645 \u0627\u0644\u0645\u0639\u0627\u0645\u0644\u0629","your_payment_is_completed":"\u0627\u0643\u062a\u0645\u0644\u062a \u0639\u0645\u0644\u064a\u0629 \u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u062e\u0627\u0635\u0629 \u0628\u0643 \u0628\u0646\u062c\u0627\u062d.","your_payment_is_ont_completed":"\u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u062e\u0627\u0635 \u0628\u0643 \u0644\u0645 \u064a\u0643\u062a\u0645\u0644."},"payment_mode":{"active":"\u0646\u0634\u064a\u0637","add_new_payment_mode":"\u0623\u0636\u0641 \u0637\u0631\u064a\u0642\u0629 \u062f\u0641\u0639 \u062c\u062f\u064a\u062f\u0629","bank_accounts":"\u062d\u0633\u0627\u0628\u0627\u062a \u0628\u0646\u0643\u064a\u0629","edit_payment_mode":"\u062a\u062d\u0631\u064a\u0631 \u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639","expenses_only":"\u0627\u0644\u0645\u0635\u0631\u0648\u0641\u0627\u062a \u0641\u0642\u0637","invoices_only":"\u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631 \u0641\u0642\u0637","new_payment_mode":"\u0648\u0636\u0639 \u062f\u0641\u0639 \u062c\u062f\u064a\u062f","no_payment_mode_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0637\u0631\u064a\u0642\u0629 \u062f\u0641\u0639 \u0645\u062a\u0627\u062d\u0629.","no_payment_mode_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639.","on_invoice_pdf":"\u0639\u0644\u0649 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629 PDF","payment_mode_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639","payment_mode_not_found":"\u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","payment_mode_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639 \u0628\u0646\u062c\u0627\u062d.","payment_mode_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639 \u0628\u0646\u062c\u0627\u062d.","payment_mode_used_somewhere_else":"\u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631.","selected_by_default_on_invoice":"\u0645\u062d\u062f\u062f \u0628\u0634\u0643\u0644 \u0627\u0641\u062a\u0631\u0627\u0636\u064a \u0641\u064a \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","show":"\u062a\u0628\u064a\u0646"},"payment_modes":"\u0637\u0631\u0642 \u0627\u0644\u062f\u0641\u0639","placeholder":{"add_note":"\u0627\u0636\u0641 \u0645\u0644\u0627\u062d\u0638\u0629...","add_product":"\u0623\u0636\u0641 \u0645\u0646\u062a\u062c","bill_tasks":"\u0645\u0647\u0627\u0645 \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","contact_number_is_invalid_number":"\u0631\u0642\u0645 \u0627\u0644\u0627\u062a\u0635\u0627\u0644 \u0647\u0648 \u0631\u0642\u0645 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d","enter_email":"\u0623\u062f\u062e\u0644 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","invalid_country_code":"\u0631\u0645\u0632 \u0627\u0644\u062f\u0648\u0644\u0629 \u063a\u064a\u0631 \u0635\u062d\u064a\u062d","invalid_number":"\u0631\u0642\u0645 \u0635\u0627\u0644\u062d","search_customers":"\u0627\u0644\u0628\u062d\u062b \u0639\u0646 \u0627\u0644\u0639\u0645\u0644\u0627\u0621","search_menu":"\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0628\u062d\u062b","select_article_group":"\u062d\u062f\u062f \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0642\u0627\u0644\u0627\u062a","select_assignee":"\u062d\u062f\u062f \u0627\u0644\u0645\u0639\u064a\u0646","select_billing_type":"\u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","select_contact":"\u062d\u062f\u062f \u062c\u0647\u0627\u062a \u0627\u0644\u0627\u062a\u0635\u0627\u0644","select_contract_type":"\u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u0639\u0642\u062f","select_country":"\u062d\u062f\u062f \u0627\u0644\u062f\u0648\u0644\u0629","select_currency":"\u0627\u062e\u062a\u0631 \u0627\u0644\u0639\u0645\u0644\u0629","select_customer":"\u062d\u062f\u062f \u0627\u0644\u0639\u0645\u064a\u0644","select_department":"\u062d\u062f\u062f \u0627\u0644\u0642\u0633\u0645","select_discount_type":"\u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u062e\u0635\u0645","select_document_type":" \u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u062e\u0635\u0645","select_email_status":"\u062d\u062f\u062f \u062d\u0627\u0644\u0629 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","select_email_template":"\u062d\u062f\u062f \u0642\u0627\u0644\u0628 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","select_expanse_category":"\u062d\u062f\u062f \u0641\u0626\u0629 \u0627\u0644\u0645\u0635\u0627\u0631\u064a\u0641","select_file":"\u062d\u062f\u062f \u0645\u0644\u0641","select_goal":"\u062d\u062f\u062f \u0627\u0644\u0647\u062f\u0641","select_goal_type":"\u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u0647\u062f\u0641","select_group":"\u062d\u062f\u062f \u0627\u0644\u0645\u062c\u0645\u0648\u0639\u0627\u062a","select_groups":"\u062d\u062f\u062f \u0627\u0644\u0645\u062c\u0645\u0648\u0639\u0627\u062a","select_internal_article":"\u062d\u062f\u062f \u0645\u0642\u0627\u0644 \u062f\u0627\u062e\u0644\u064a","select_item":"\u062d\u062f\u062f \u0627\u0644\u0628\u0646\u062f","select_language":"\u0627\u062e\u062a\u0627\u0631 \u0627\u0644\u0644\u063a\u0629","select_lead":"\u062d\u062f\u062f \u0627\u0644\u0631\u0635\u0627\u0635","select_lead_source":"\u062d\u062f\u062f \u0645\u0635\u062f\u0631 \u0627\u0644\u0631\u0635\u0627\u0635","select_member":"\u062d\u062f\u062f \u0639\u0636\u0648","select_option":"\u062d\u062f\u062f \u0627\u0644\u062e\u064a\u0627\u0631","select_payment_mode":"\u062d\u062f\u062f \u0648\u0636\u0639 \u0627\u0644\u062f\u0641\u0639","select_predefined_reply":"\u062d\u062f\u062f \u0627\u0644\u0631\u062f \u0627\u0644\u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627","select_priority":"\u062d\u062f\u062f \u0627\u0644\u0623\u0648\u0644\u0648\u064a\u0629","select_product":"\u062d\u062f\u062f \u0627\u0644\u0645\u0646\u062a\u062c","select_product_group":"\u062d\u062f\u062f \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a","select_reminder_to":"\u062d\u062f\u062f \u062a\u0630\u0643\u064a\u0631 \u0628\u0640","select_sale_agent":"\u062d\u062f\u062f \u0648\u0643\u064a\u0644 \u0627\u0644\u0628\u064a\u0639","select_service":"\u0627\u062e\u062a\u0631 \u0627\u0644\u062e\u062f\u0645\u0629","select_show_to_client":"\u062d\u062f\u062f \u0625\u0638\u0647\u0627\u0631 \u0644\u0644\u0639\u0645\u064a\u0644","select_source":"\u0627\u062e\u062a\u0631 \u0645\u0635\u062f\u0631","select_status":"\u062d\u062f\u062f \u0627\u0644\u062d\u0627\u0644\u0629","select_tags":"\u062d\u062f\u062f \u0627\u0644\u0639\u0644\u0627\u0645\u0627\u062a","select_tax":"\u062d\u062f\u062f \u0627\u0644\u0636\u0631\u0627\u0626\u0628","select_tax1":"\u062d\u062f\u062f \u0627\u0644\u0636\u0631\u064a\u0628\u0629 1","select_tax2":"\u062d\u062f\u062f \u0627\u0644\u0636\u0631\u064a\u0628\u0629 2","select_template_type":"\u062d\u062f\u062f \u0646\u0648\u0639 \u0627\u0644\u0646\u0645\u0648\u0630\u062c","select_ticket_priority":"\u062d\u062f\u062f \u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","too_long":"\u0637\u0648\u064a\u0644 \u062c\u062f\u0627","too_short":"\u0642\u0635\u064a\u0631 \u062c\u062f\u0627","valid_number":"\u0631\u0642\u0645 \u0635\u0627\u0644\u062d"},"please_enter_language_short_code":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0631\u0645\u0632 \u0627\u0644\u0644\u063a\u0629 \u0627\u0644\u0642\u0635\u064a\u0631. \u0623\u064a \u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 = en.","predefined_replies":"\u0627\u0644\u0631\u062f\u0648\u062f \u0627\u0644\u0645\u062d\u062f\u062f\u0629 \u0645\u0633\u0628\u0642\u064b\u0627","predefined_reply":{"add":"\u0623\u0636\u0641","add_new_predefined_reply":"\u0625\u0636\u0627\u0641\u0629 \u0631\u062f \u062c\u062f\u064a\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627","body":"\u0627\u0644\u062c\u0633\u0645","edit_predefined_reply":"\u062a\u062d\u0631\u064a\u0631 \u0631\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627","new_predefined_reply":"\u0631\u062f \u062c\u062f\u064a\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627","no_predefined_reply_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0631\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627 \u0645\u062a\u0627\u062d.","no_predefined_reply_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0631\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627.","predefined_reply_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0631\u062f \u0627\u0644\u0645\u062d\u062f\u062f\u0629 \u0645\u0633\u0628\u0642\u064b\u0627","predefined_reply_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0627\u0644\u0631\u062f \u0627\u0644\u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627.","predefined_reply_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0631\u062f \u0627\u0644\u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627 \u0628\u0646\u062c\u0627\u062d.","predefined_reply_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0631\u062f \u0627\u0644\u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627 \u0628\u0646\u062c\u0627\u062d.","reply_name":"\u0627\u0633\u0645 \u0627\u0644\u0631\u062f"},"product_group":{"add_new_product_group":"\u0623\u0636\u0641 \u0645\u062c\u0645\u0648\u0639\u0629 \u0645\u0646\u062a\u062c\u0627\u062a \u062c\u062f\u064a\u062f\u0629","edit_product_group":"\u062a\u062d\u0631\u064a\u0631 \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a","new_product_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0645\u0646\u062a\u062c\u0627\u062a \u062c\u062f\u064a\u062f\u0629","product_group_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a \u0628\u0646\u062c\u0627\u062d.","product_group_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a \u0628\u0646\u062c\u0627\u062d.","product_group_used_somewhere_else":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a \u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631."},"product_groups":"\u0645\u062c\u0645\u0648\u0639\u0627\u062a \u0627\u0644\u0645\u0646\u062a\u062c\u0627\u062a","products":{"edit_product":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0646\u062a\u062c","new_product":"\u0645\u0646\u062a\u062c \u062c\u062f\u064a\u062f","product_group":"\u0645\u062c\u0645\u0648\u0639\u0629 \u0627\u0644\u0639\u0646\u0635\u0631","product_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0645\u0646\u062a\u062c \u0628\u0646\u062c\u0627\u062d.","product_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0646\u062a\u062c \u0628\u0646\u062c\u0627\u062d.","products":"\u0645\u0646\u062a\u062c\u0627\u062a","rate":"\u0645\u0639\u062f\u0644","tax":"\u0636\u0631\u064a\u0628\u0629","title":"\u0639\u0646\u0648\u0627\u0646","unit":"\u0648\u062d\u062f\u0629"},"profile":"\u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","project":{"admin_area":"\u0645\u0646\u0637\u0642\u0629 \u0627\u0644\u0645\u0634\u0631\u0641","allow_customer_to":"\u0627\u0644\u0633\u0645\u0627\u062d \u0644\u0644\u0639\u0645\u0644\u0627\u0621","billing_type":"\u0646\u0648\u0639 \u0627\u0644\u0641\u0627\u062a\u0648\u0631\u0629","calculate_progress_through_tasks":"\u0627\u062d\u0633\u0628 \u0627\u0644\u062a\u0642\u062f\u0645 \u0645\u0646 \u062e\u0644\u0627\u0644 \u0627\u0644\u0645\u0647\u0627\u0645","cancelled":"\u0623\u0644\u063a\u064a\u062a","comment_on_project_tasks":"\u0627\u0644\u062a\u0639\u0644\u064a\u0642 \u0639\u0644\u0649 \u0645\u0647\u0627\u0645 \u0627\u0644\u0645\u0634\u0631\u0648\u0639","create_tasks":"\u0625\u0646\u0634\u0627\u0621 \u0627\u0644\u0645\u0647\u0627\u0645","customer":"\u0627\u0644\u0632\u0628\u0648\u0646","deadline":"\u0627\u0644\u0645\u0648\u0639\u062f \u0627\u0644\u0646\u0647\u0627\u0626\u064a","edit_project":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0634\u0631\u0648\u0639","edit_tasks":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0647\u0627\u0645","estimated_hours":"\u0627\u0644\u0633\u0627\u0639\u0627\u062a \u0627\u0644\u0645\u0642\u062f\u0631\u0629","finished":"\u062a\u0645 \u0627\u0644\u0627\u0646\u062a\u0647\u0627\u0621 \u0645\u0646","hide_project_tasks_on_main_tasks_table":"\u0625\u062e\u0641\u0627\u0621 \u0645\u0647\u0627\u0645 \u0627\u0644\u0645\u0634\u0631\u0648\u0639 \u0641\u064a \u062c\u062f\u0648\u0644 \u0627\u0644\u0645\u0647\u0627\u0645 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629","in_progress":"\u0641\u064a \u062a\u0642\u062f\u0645","members":"\u0627\u062a\u0635\u0644","new_project":"\u0645\u0634\u0631\u0648\u0639 \u062c\u062f\u064a\u062f","no_project_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0645\u0634\u0631\u0648\u0639 \u0645\u062a\u0627\u062d","no_project_found":"\u0627\u0644\u0645\u0634\u0631\u0648\u0639 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f","not_started":"\u0644\u0645 \u064a\u0628\u062f\u0623","on_hold":"\u0641\u064a \u0627\u0644\u0627\u0646\u062a\u0638\u0627\u0631","only_task_created_from_contact":"\u062a\u0645 \u0625\u0646\u0634\u0627\u0621 \u0627\u0644\u0645\u0647\u0645\u0629 \u0641\u0642\u0637 \u0645\u0646 \u062c\u0647\u0629 \u0627\u0644\u0627\u062a\u0635\u0627\u0644","open_discussions":"\u0645\u0646\u0627\u0642\u0634\u0627\u062a \u0645\u0641\u062a\u0648\u062d\u0629","progress":"\u062a\u0642\u062f\u0645","project_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0634\u0631\u0648\u0639","project_name":"\u0627\u0633\u0645 \u0627\u0644\u0645\u0634\u0631\u0648\u0639","project_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0645\u0634\u0631\u0648\u0639 \u0628\u0646\u062c\u0627\u062d.","project_settings":"\u0625\u0639\u062f\u0627\u062f\u0627\u062a \u0627\u0644\u0645\u0634\u0631\u0648\u0639","project_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0634\u0631\u0648\u0639 \u0628\u0646\u062c\u0627\u062d.","projects_summary":"\u0645\u0644\u062e\u0635 \u0627\u0644\u0645\u0634\u0627\u0631\u064a\u0639","quick_invoices_info":"\u0645\u0639\u0644\u0648\u0645\u0627\u062a \u0633\u0631\u064a\u0639\u0629 \u0639\u0646 \u0627\u0644\u0641\u0648\u0627\u062a\u064a\u0631","send_project_created_email":"\u0625\u0631\u0633\u0627\u0644 \u0628\u0631\u064a\u062f \u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u062a\u0645 \u0625\u0646\u0634\u0627\u0624\u0647 \u0644\u0644\u0645\u0634\u0631\u0648\u0639","start_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0628\u062f\u0621","statistics_by_project_status":"\u0627\u0644\u0625\u062d\u0635\u0627\u0626\u064a\u0627\u062a \u062d\u0633\u0628 \u062d\u0627\u0644\u0629 \u0627\u0644\u0645\u0634\u0631\u0648\u0639","status":"\u0627\u0644\u062d\u0627\u0644\u0629","task":"\u0645\u0647\u0645\u0629","total_projects":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0645\u0634\u0627\u0631\u064a\u0639","upload_attachments_on_tasks":"\u062a\u062d\u0645\u064a\u0644 \u0627\u0644\u0645\u0631\u0641\u0642\u0627\u062a \u0639\u0644\u0649 \u0627\u0644\u0645\u0647\u0627\u0645","upload_files":"\u062a\u062d\u0645\u064a\u0644 \u0627\u0644\u0645\u0644\u0641\u0627\u062a","view_account_statement":"\u0639\u0631\u0636 \u0643\u0634\u0641 \u0627\u0644\u062d\u0633\u0627\u0628","view_activity_log":"\u0639\u0631\u0636 \u0633\u062c\u0644 \u0627\u0644\u0646\u0634\u0627\u0637","view_finance_overview":"\u0639\u0631\u0636 \u0646\u0638\u0631\u0629 \u0639\u0627\u0645\u0629 \u0639\u0644\u0649 \u0627\u0644\u062a\u0645\u0648\u064a\u0644","view_gantt":"\u0639\u0631\u0636 \u062c\u0627\u0646\u062a","view_milestones":"\u0639\u0631\u0636 \u0645\u0639\u0627\u0644\u0645","view_task_attachments":"\u0639\u0631\u0636 \u0645\u0631\u0641\u0642\u0627\u062a \u0627\u0644\u0645\u0647\u0645\u0629","view_task_checklist_items":"\u0639\u0631\u0636 \u0639\u0646\u0627\u0635\u0631 \u0642\u0627\u0626\u0645\u0629 \u0645\u0631\u0627\u062c\u0639\u0629 \u0627\u0644\u0645\u0647\u0627\u0645","view_task_comments":"\u0639\u0631\u0636 \u062a\u0639\u0644\u064a\u0642\u0627\u062a \u0627\u0644\u0645\u0647\u0645\u0629","view_task_total_logged_time":"\u0639\u0631\u0636 \u0625\u062c\u0645\u0627\u0644\u064a \u0648\u0642\u062a \u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u0645\u0647\u0645\u0629","view_tasks":"\u0639\u0631\u0636 \u0627\u0644\u0645\u0647\u0627\u0645","view_team_members":"\u0639\u0631\u0636 \u0623\u0639\u0636\u0627\u0621 \u0627\u0644\u0641\u0631\u064a\u0642","view_timesheets":"\u0639\u0631\u0636 \u0627\u0644\u062c\u062f\u0627\u0648\u0644 \u0627\u0644\u0632\u0645\u0646\u064a\u0629","visible_tables":"\u062c\u062f\u0627\u0648\u0644 \u0645\u0631\u0626\u064a\u0629"},"projects":"\u0627\u0644\u0645\u0634\u0627\u0631\u064a\u0639","proposal":{"accept":"\u0642\u0628\u0648\u0644","accepted":"\u0642\u0628\u0644\u062a","adjustment":"\u062a\u0639\u062f\u064a\u0644","amount":"\u0643\u0645\u064a\u0629","amount_due":"\u0627\u0644\u0645\u0628\u0644\u063a \u0627\u0644\u0645\u0633\u062a\u062d\u0642","assigned":"\u062a\u0639\u064a\u064a\u0646","authorized_signature":"\u062a\u0648\u0642\u064a\u0639 \u0645\u0639\u062a\u0645\u062f","bank":"\u0645\u0635\u0631\u0641","bill_to":"\u0641\u0627\u062a\u0648\u0631\u0629 \u0627\u0644\u0649","comments":"\u062a\u0639\u0644\u064a\u0642\u0627\u062a","convert":"\u062a\u062d\u0648\u064a\u0644","convert_proposal":"\u062a\u062d\u0648\u064a\u0644 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","date":"\u062a\u0627\u0631\u064a\u062e","decline":"\u0627\u0646\u062e\u0641\u0627\u0636","declined":"\u0631\u0641\u0636","discount":"\u062e\u0635\u0645","draft":"\u0645\u0634\u0631\u0648\u0639","drafted":"\u0635\u0627\u063a","edit_proposal":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","item":"\u0627\u0644\u0645\u0646\u062a\u062c","lead":"\u0642\u064a\u0627\u062f\u0629","mark_as_accepted":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \"\u0645\u0642\u0628\u0648\u0644\"","mark_as_declined":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0639\u0644\u0649 \u0623\u0646\u0647 \u0645\u0631\u0641\u0648\u0636","mark_as_draft":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0645\u0633\u0648\u062f\u0629","mark_as_open":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \"\u0645\u0641\u062a\u0648\u062d\"","mark_as_revised":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0645\u0646\u0642\u062d\u0629","mark_as_send":"\u0648\u0636\u0639 \u0639\u0644\u0627\u0645\u0629 \u0643\u0625\u0631\u0633\u0627\u0644","member":"\u0639\u0636\u0648","new_proposal":"\u0639\u0631\u0636 \u062c\u062f\u064a\u062f","no_payments_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u062f\u0641\u0639 \u0645\u062a\u0627\u062d","no_proposal_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0639\u0631\u0636 \u0645\u062a\u0627\u062d.","no_proposal_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0627\u0642\u062a\u0631\u0627\u062d.","offline_payment":"\u0627\u0644\u062f\u0641\u0639 \u062f\u0648\u0646 \u0627\u062a\u0635\u0627\u0644","online_payment":"\u0627\u0644\u062f\u0641\u0639 \u0627\u0644\u0627\u0644\u0643\u062a\u0631\u0648\u0646\u064a","open":"\u0627\u0641\u062a\u062d","open_till":"\u0627\u0641\u062a\u062d \u062d\u062a\u0649","pay_now":"\u0627\u062f\u0641\u0639 \u0627\u0644\u0622\u0646","payment":"\u062f\u0641\u0639","proposal":"\u0627\u0642\u062a\u0631\u0627\u062d","proposal_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","proposal_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","proposal_not_found":"\u0627\u0644\u0639\u0631\u0636 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f.","proposal_number":"\u0631\u0642\u0645 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","proposal_overview":"\u0646\u0638\u0631\u0629 \u0639\u0627\u0645\u0629 \u0639\u0644\u0649 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","proposal_pdf":"\u0627\u0642\u062a\u0631\u0627\u062d PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d \u0628\u0646\u062c\u0627\u062d.","proposal_to":"\u0627\u0642\u062a\u0631\u0627\u062d \u0644","proposal_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d \u0628\u0646\u062c\u0627\u062d.","qty":"\u0627\u0644\u0643\u0645\u064a\u0629","rate":"\u0645\u0639\u062f\u0644","related":"\u0630\u0627\u062a \u0635\u0644\u0629","revised":"\u0645\u0631\u0627\u062c\u0639\u0629","save_and_send":"\u062d\u0641\u0638 \u0648\u0625\u0631\u0633\u0627\u0644","save_as_draft":"\u062d\u0641\u0638 \u0643\u0645\u0633\u0648\u062f\u0629","sent":"\u0623\u0631\u0633\u0644\u062a","ship_to":"\u0633\u0627\u0641\u0631 \u0639\u0644\u0649 \u0645\u062a\u0646 \u0633\u0641\u064a\u0646\u0629 \u0644","status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","sub_total":"\u0627\u0644\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0641\u0631\u0639\u064a","subject":"\u0645\u0648\u0636\u0648\u0639","task":"\u0645\u0647\u0645\u0629","taxes":"\u0627\u0644\u0636\u0631\u0627\u0626\u0628","title":"\u0639\u0646\u0648\u0627\u0646","to":"\u0625\u0644\u0649","total":"\u0645\u062c\u0645\u0648\u0639","total_paid":"\u0645\u062c\u0645\u0648\u0639 \u0627\u0644\u0645\u0628\u0627\u0644\u063a \u0627\u0644\u0645\u062f\u0641\u0648\u0639\u0629","total_proposal":"\u0625\u062c\u0645\u0627\u0644\u064a \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d","transactions":"\u0627\u0644\u0645\u0639\u0627\u0645\u0644\u0627\u062a","view_proposal_as_customer":"\u0639\u0631\u0636 \u0627\u0644\u0627\u0642\u062a\u0631\u0627\u062d \u0643\u0639\u0645\u064a\u0644"},"proposals":"\u0627\u0642\u062a\u0631\u0627\u062d\u0627\u062a","range":{"day":"\u064a\u0648\u0645","last_30":"\u0622\u062e\u0631 30 \u064a\u0648\u0645\u064b\u0627","last_month":"\u0627\u0644\u0634\u0647\u0631 \u0627\u0644\u0645\u0627\u0636\u064a","last_week":"\u0627\u0644\u0623\u0633\u0628\u0648\u0639 \u0627\u0644\u0645\u0627\u0636\u064a","month":"\u0634\u0647\u0631","this_month":"\u0647\u0630\u0627 \u0627\u0644\u0634\u0647\u0631","this_week":"\u0647\u0630\u0627 \u0627\u0644\u0627\u0633\u0628\u0648\u0639","today":"\u0627\u0644\u064a\u0648\u0645","week":"\u0623\u0633\u0628\u0648\u0639"},"register":{"already_have_an_account":"\u0647\u0644 \u0644\u062f\u064a\u0643 \u062d\u0633\u0627\u0628\u061f","choose":"\u0623\u062e\u062a\u0631","confirm_password":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","first_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0627\u0648\u0644","last_name":"\u0627\u0644\u0643\u0646\u064a\u0629","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","phone":"\u0647\u0627\u062a\u0641","profile_picture":"\u0627\u0644\u0635\u0648\u0631\u0647 \u0627\u0644\u0634\u062e\u0635\u064a\u0647","register":"\u062a\u0633\u062c\u064a\u0644","sign_in":"\u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644"},"reminder":{"add_new":"\u0627\u0636\u0641 \u062c\u062f\u064a\u062f","description":"\u0648\u0635\u0641","edit_reminder":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u062a\u0630\u0643\u064a\u0631","email_status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","is_notified":"\u062a\u0645 \u0625\u062e\u0637\u0627\u0631\u0647","new_reminder":"\u062a\u0630\u0643\u064a\u0631 \u062c\u062f\u064a\u062f","no":"\u0631\u0642\u0645","note":"\u0645\u0644\u062d\u0648\u0638\u0629","note_text":"\u064a\u0631\u062c\u0649 \u0645\u0644\u0627\u062d\u0638\u0629 \u0623\u0646\u0647 \u064a\u062c\u0628 \u0639\u0644\u064a\u0643 \u062a\u062d\u062f\u064a\u062f \u0648\u0642\u062a \u062a\u0627\u0631\u064a\u062e UTC \u060c \u062d\u064a\u062b \u062a\u0642\u0648\u0645 \u0645\u0647\u0627\u0645 cron \u0628\u0625\u0631\u0633\u0627\u0644 \u062a\u0630\u0643\u064a\u0631\u0627\u062a \u062d\u0633\u0628 \u0648\u0642\u062a UTC.","notified_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0625\u0646\u0630\u0627\u0631","reminder_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u062a\u0630\u0643\u064a\u0631 \u0628\u0646\u062c\u0627\u062d.","reminder_to":"\u062a\u0630\u0643\u064a\u0631","reminder_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062a\u0630\u0643\u064a\u0631 \u0628\u0646\u062c\u0627\u062d.","send_email_reminder":"\u0625\u0631\u0633\u0627\u0644 \u0628\u0631\u064a\u062f \u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0644\u0644\u062a\u0630\u0643\u064a\u0631","sent":"\u0623\u0631\u0633\u0644\u062a","set_reminder":"\u062a\u0639\u064a\u064a\u0646 \u062a\u0630\u0643\u064a\u0631","ticket_reminder":"\u062a\u0630\u0643\u064a\u0631\u0627\u062a \u062a\u0630\u0643\u0631\u0629","yes":"\u0646\u0639\u0645"},"reminders":"\u062a\u0630\u0643\u064a\u0631","reset":{"confirm_password":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","recalled_your_login_info":"\u062a\u0630\u0643\u0631\u062a \u0645\u0639\u0644\u0648\u0645\u0627\u062a \u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644 \u0627\u0644\u062e\u0627\u0635\u0629 \u0628\u0643\u061f","reset_password":"\u0625\u0639\u0627\u062f\u0629 \u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","set_a_new_password":"\u0642\u0645 \u0628\u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0645\u0631\u0648\u0631 \u062c\u062f\u064a\u062f\u0629","sign_in":"\u062a\u0633\u062c\u064a\u0644 \u0627\u0644\u062f\u062e\u0648\u0644"},"sales":"\u0645\u0628\u064a\u0639\u0627\u062a","service":{"add":"\u0623\u0636\u0641","edit_service":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062e\u062f\u0645\u0629","name":"\u0627\u0633\u0645","new_service":"\u062e\u062f\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","no_service_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u062e\u062f\u0645\u0629 \u0645\u062a\u0627\u062d\u0629.","no_service_found":"\u0644\u0627 \u062a\u0648\u062c\u062f \u062e\u062f\u0645\u0629.","service_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0627\u0644\u062e\u062f\u0645\u0629.","service_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u062e\u062f\u0645\u0629 \u0628\u0646\u062c\u0627\u062d.","service_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062e\u062f\u0645\u0629 \u0628\u0646\u062c\u0627\u062d.","service_used_somewhere_else":"\u0627\u0644\u062e\u062f\u0645\u0629 \u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631."},"services":"\u062e\u062f\u0645\u0627\u062a","setting":{"application_name":"\u0627\u0633\u0645 \u0627\u0644\u0634\u0631\u0643\u0629","choose":"\u0623\u062e\u062a\u0631","company_domain":"\u0645\u062c\u0627\u0644 \u0627\u0644\u0634\u0631\u0643\u0629","current_version":"\u0627\u0644\u0646\u0633\u062e\u0629 \u0627\u0644\u062d\u0627\u0644\u064a\u0629","favicon":"\u0641\u0627\u0641\u064a\u0643\u0648\u0646","file_type":"\u0646\u0648\u0639 \u0627\u0644\u0645\u0644\u0641","logo":"\u0634\u0639\u0627\u0631 \u0627\u0644\u0634\u0631\u0643\u0629","setting_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0625\u0639\u062f\u0627\u062f \u0628\u0646\u062c\u0627\u062d."},"settings":"\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a","staff":"\u0627\u0644\u0639\u0627\u0645\u0644\u064a\u0646","status":{"additional_contact":"\u062c\u0647\u0629 \u0627\u062a\u0635\u0627\u0644 \u0625\u0636\u0627\u0641\u064a\u0629","answered":"\u0623\u062c\u0627\u0628","attempted":"\u062d\u0627\u0648\u0644","cancelled":"\u0623\u0644\u063a\u064a\u062a","closed":"\u0645\u063a\u0644\u0642","contacted":"\u062a\u0645 \u0627\u0644\u0627\u062a\u0635\u0627\u0644","finished":"\u062a\u0645 \u0627\u0644\u0627\u0646\u062a\u0647\u0627\u0621 \u0645\u0646","in_progress":"\u0641\u064a \u062a\u0642\u062f\u0645","new_opportunity":"\u0641\u0631\u0635\u0629 \u062c\u062f\u064a\u062f\u0629","not_attempted":"\u0644\u0645 \u062a\u062d\u0627\u0648\u0644","not_started":"\u0644\u0645 \u064a\u0628\u062f\u0623","on_hold":"\u0641\u064a \u0627\u0644\u0627\u0646\u062a\u0638\u0627\u0631","open":"\u0627\u0641\u062a\u062d"},"success":"\u0627\u0644\u0646\u062c\u0627\u062d","support":"\u0627\u0644\u062f\u0639\u0645","tag":{"add":"\u0623\u0636\u0641","add_new_tag":"\u0623\u0636\u0641 \u0639\u0644\u0627\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","description":"\u0648\u0635\u0641","edit_tag":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0639\u0644\u0627\u0645\u0629","name":"\u0627\u0633\u0645","new_tag":"\u0639\u0644\u0627\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","no_tag_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0639\u0644\u0627\u0645\u0629 \u0645\u062a\u0627\u062d\u0629.","no_tag_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0639\u0644\u0627\u0645\u0629.","tag_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0639\u0644\u0627\u0645\u0629","tag_not_found":"\u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f\u0629.","tag_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0628\u0646\u062c\u0627\u062d.","tag_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0639\u0644\u0627\u0645\u0629 \u0628\u0646\u062c\u0627\u062d."},"tags":"\u0627\u0644\u0639\u0644\u0627\u0645\u0627\u062a","task":{"awaiting_feedback":"\u0641\u0649 \u0627\u0646\u062a\u0638\u0627\u0631 \u0627\u0644\u062a\u0642\u064a\u064a\u0645","billable":"\u0642\u0627\u0628\u0644 \u0644\u0644\u0641\u0648\u062a\u0631\u0629","completed":"\u0645\u0646\u062c\u0632","due_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0627\u0633\u062a\u062d\u0642\u0627\u0642","edit_task":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0645\u0647\u0645\u0629","hourly_rate":"\u0627\u0644\u0645\u0639\u062f\u0644 \u0628\u0627\u0644\u0633\u0627\u0639\u0629","in_progress":"\u0641\u064a \u062a\u0642\u062f\u0645","name":"\u0627\u0633\u0645","new_task":"\u0645\u0647\u0645\u0629 \u062c\u062f\u064a\u062f\u0629","no_task_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0645\u0647\u0645\u0629 \u0645\u062a\u0627\u062d\u0629.","not_started":"\u0644\u0645 \u064a\u0628\u062f\u0623","priority":"\u0623\u0641\u0636\u0644\u064a\u0629","public":"\u0639\u0627\u0645\u0629","related_to":"\u0645\u062a\u0639\u0644\u0642 \u0628","start_date":"\u062a\u0627\u0631\u064a\u062e \u0627\u0644\u0628\u062f\u0621","status":"\u0627\u0644\u062d\u0627\u0644\u0629","subject":"\u0645\u0648\u0636\u0648\u0639","task_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u0645\u0647\u0645\u0629","task_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u0645\u0647\u0645\u0629 \u0628\u0646\u062c\u0627\u062d.","task_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u0645\u0647\u0645\u0629 \u0628\u0646\u062c\u0627\u062d.","task_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0647\u0645\u0629 \u0628\u0646\u062c\u0627\u062d.","testing":"\u0627\u062e\u062a\u0628\u0627\u0631\u0627\u062a","ticket":"\u062a\u0630\u0643\u0631\u0629"},"tasks":"\u0645\u0647\u0627\u0645","tax_rate":{"edit_tax_rate":"\u062a\u062d\u0631\u064a\u0631 \u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","new_tax_rate":"\u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629 \u0627\u0644\u062c\u062f\u064a\u062f","no_tax_rate_available":"\u0644\u0627 \u064a\u0648\u062c\u062f \u0645\u0639\u062f\u0644 \u0636\u0631\u064a\u0628\u0629 \u0645\u062a\u0627\u062d.","no_tax_rate_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629.","tax_rate":"\u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629","tax_rate_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629 \u0628\u0646\u062c\u0627\u062d.","tax_rate_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0645\u0639\u062f\u0644 \u0627\u0644\u0636\u0631\u064a\u0628\u0629 \u0628\u0646\u062c\u0627\u062d."},"tax_rates":"\u0645\u0639\u062f\u0644\u0627\u062a \u0627\u0644\u0636\u0631\u0627\u0626\u0628","this_week_payments":"\u0645\u062f\u0641\u0648\u0639\u0627\u062a \u0647\u0630\u0627 \u0627\u0644\u0623\u0633\u0628\u0648\u0639","ticket":{"add":"\u0623\u0636\u0641","added_by":"\u0623\u0636\u064a\u0641 \u0628\u0648\u0627\u0633\u0637\u0629","assign_to":"\u064a\u0633\u0646\u062f \u0625\u0644\u0649","attachments":"\u0627\u0644\u0645\u0631\u0641\u0642\u0627\u062a","body":"\u0627\u0644\u062c\u0633\u0645","cc":"CC","contact":"\u0627\u062a\u0635\u0644","department":"\u0642\u0633\u0645","details":"\u062a\u0641\u0627\u0635\u064a\u0644","edit_ticket":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","name":"\u0627\u0633\u0645","new_ticket":"\u062a\u0630\u0643\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","no_ticket_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u062a\u0630\u0643\u0631\u0629 \u0645\u062a\u0627\u062d\u0629.","no_ticket_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u062a\u0630\u0643\u0631\u0629.","note":"\u0645\u0644\u062d\u0648\u0638\u0629","predefined_reply":"\u0631\u062f \u0645\u062d\u062f\u062f \u0645\u0633\u0628\u0642\u064b\u0627","priority":"\u0623\u0641\u0636\u0644\u064a\u0629","reminder":"\u062a\u0630\u0643\u064a\u0631","service":"\u0627\u0644\u062e\u062f\u0645\u0627\u062a","subject":"\u0645\u0648\u0636\u0648\u0639","tags":"\u0627\u0644\u0639\u0644\u0627\u0645\u0627\u062a","task":"\u0645\u0647\u0645\u0629","ticket_details":"\u062a\u0641\u0627\u0635\u064a\u0644 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","ticket_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0627\u0644\u062a\u0630\u0643\u0631\u0629.","ticket_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_to_contact":"\u062a\u0630\u0643\u0631\u0629 \u0644\u0644\u0627\u062a\u0635\u0627\u0644","ticket_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_without_contact":"\u062a\u0630\u0643\u0631\u0629 \u0628\u062f\u0648\u0646 \u0627\u062a\u0635\u0627\u0644","tickets_status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0627\u0643\u0631","you_can_add_multiples_images_and_files":"\u064a\u0645\u0643\u0646\u0643 \u0625\u0636\u0627\u0641\u0629 \u0635\u0648\u0631 \u0648\u0645\u0644\u0641\u0627\u062a \u0645\u062a\u0639\u062f\u062f\u0629"},"ticket_priorities":"\u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","ticket_priority":{"add":"\u0623\u0636\u0641","add_new_ticket_priority":"\u0623\u0636\u0641 \u0623\u0648\u0644\u0648\u064a\u0629 \u062a\u0630\u0643\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","edit_ticket_priority":"\u062a\u062d\u0631\u064a\u0631 \u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","name":"\u0627\u0633\u0645","new_ticket_priority":"\u0623\u0648\u0644\u0648\u064a\u0629 \u062a\u0630\u0643\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","no_ticket_priority_available":"\u0644\u0627 \u062a\u0648\u062c\u062f \u0623\u0648\u0644\u0648\u064a\u0629 \u062a\u0630\u0643\u0631\u0629 \u0645\u062a\u0627\u062d\u0629.","no_ticket_priority_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629.","ticket_priority_not_found":"\u0644\u0645 \u064a\u062a\u0645 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629.","ticket_priority_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_priority_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_priority_used_somewhere_else":"\u0623\u0648\u0644\u0648\u064a\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631."},"ticket_status":{"add":"\u0623\u0636\u0641","add_new_ticket_status":"\u0625\u0636\u0627\u0641\u0629 \u062d\u0627\u0644\u0629 \u062a\u0630\u0643\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","color":"\u0627\u0644\u0644\u0648\u0646","edit_ticket_status":"\u062a\u062d\u0631\u064a\u0631 \u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","name":"\u0627\u0633\u0645","new_ticket_status":"\u062d\u0627\u0644\u0629 \u062a\u0630\u0643\u0631\u0629 \u062c\u062f\u064a\u062f\u0629","status_order":"\u062a\u0631\u062a\u064a\u0628 \u0627\u0644\u062d\u0627\u0644\u0629","ticket_status":"\u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629","ticket_status_saved_successfully":"\u062a\u0645 \u062d\u0641\u0638 \u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_status_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0628\u0646\u062c\u0627\u062d.","ticket_status_used_somewhere_else":"\u062d\u0627\u0644\u0629 \u0627\u0644\u062a\u0630\u0643\u0631\u0629 \u0645\u0633\u062a\u062e\u062f\u0645\u0629 \u0641\u064a \u0645\u0643\u0627\u0646 \u0622\u062e\u0631."},"tickets":"\u0627\u0644\u062a\u0630\u0627\u0643\u0631","translation_manager":"\u0645\u062f\u064a\u0631 \u0627\u0644\u062a\u0631\u062c\u0645\u0629","translator_manager":{"edit_language":"\u062a\u062d\u0631\u064a\u0631 \u0627\u0644\u0644\u063a\u0629","language_added_successfully":"\u062a\u0645\u062a \u0625\u0636\u0627\u0641\u0629 \u0627\u0644\u0644\u063a\u0629 \u0628\u0646\u062c\u0627\u062d.","language_short_code":"\u0627\u0644\u0631\u062c\u0627\u0621 \u0625\u062f\u062e\u0627\u0644 \u0631\u0645\u0632 \u0627\u0644\u0644\u063a\u0629 \u0627\u0644\u0642\u0635\u064a\u0631. \u0623\u064a \u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 = en","language_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0644\u063a\u0629 \u0628\u0646\u062c\u0627\u062d.","translation":"\u062a\u0631\u062c\u0645\u0629"},"user":{"change_language":"\u062a\u063a\u064a\u064a\u0631 \u0627\u0644\u0644\u063a\u0629","change_password":"\u063a\u064a\u0631 \u0643\u0644\u0645\u0629 \u0627\u0644\u0633\u0631","edit_profile":"\u062a\u0639\u062f\u064a\u0644 \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","email":"\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a","first_name":"\u0627\u0644\u0627\u0633\u0645 \u0627\u0644\u0627\u0648\u0644","language":"\u0644\u063a\u0629","language_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0644\u063a\u0629 \u0628\u0646\u062c\u0627\u062d.","last_name":"\u0627\u0644\u0643\u0646\u064a\u0629","logout":"\u062a\u0633\u062c\u064a\u0644 \u062e\u0631\u0648\u062c","name":"\u0627\u0633\u0645","password":"\u0643\u0644\u0645\u0647 \u0627\u0644\u0633\u0631","password_confirmation":"\u062a\u0623\u0643\u064a\u062f \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631","password_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0643\u0644\u0645\u0629 \u0627\u0644\u0633\u0631 \u0628\u0646\u062c\u0627\u062d.","phone":"\u0647\u0627\u062a\u0641","profile":"\u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a","profile_updated_successfully":"\u062a\u0645 \u062a\u062d\u062f\u064a\u062b \u0627\u0644\u0645\u0644\u0641 \u0627\u0644\u0634\u062e\u0635\u064a \u0628\u0646\u062c\u0627\u062d.","return_to_admin":"\u0627\u0644\u0639\u0648\u062f\u0629 \u0625\u0644\u0649 \u0627\u0644\u0645\u0633\u0624\u0648\u0644"},"users":"\u0627\u0644\u0645\u0633\u062a\u062e\u062f\u0645\u0648\u0646","weekdays":{"fri":"\u0627\u0644\u0627\u0628","mon":"\u0645","sat":"\u0633","sun":"\u0633","thu":"\u062a\u064a","tue":"\u062a\u064a","wed":"\u062f\u0628\u0644\u064a\u0648"}},"ar.pagination":{"next":"\u0627\u0644\u062a\u0627\u0644\u064a & \u0631\u0642\u0648\u0648];","previous":"& \u0642\u0648\u0648; \u0627\u0644\u0633\u0627\u0628\u0642"},"ar.passwords":{"reset":"\u062a\u0645 \u0625\u0639\u0627\u062f\u0629 \u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0627\u0644\u062e\u0627\u0635\u0629 \u0628\u0643!","sent":"\u0644\u0642\u062f \u0623\u0631\u0633\u0644\u0646\u0627 \u0631\u0627\u0628\u0637 \u0625\u0639\u0627\u062f\u0629 \u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u0628\u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a!","throttled":"\u064a\u0631\u062c\u0649 \u0627\u0644\u0627\u0646\u062a\u0638\u0627\u0631 \u0642\u0628\u0644 \u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u0645\u062d\u0627\u0648\u0644\u0629.","token":"\u0627\u0644\u0631\u0645\u0632 \u0627\u0644\u0645\u0645\u064a\u0632 \u0644\u0625\u0639\u0627\u062f\u0629 \u062a\u0639\u064a\u064a\u0646 \u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d.","user":"\u0644\u0627 \u064a\u0645\u0643\u0646\u0646\u0627 \u0627\u0644\u0639\u062b\u0648\u0631 \u0639\u0644\u0649 \u0645\u0633\u062a\u062e\u062f\u0645 \u0628\u0639\u0646\u0648\u0627\u0646 \u0627\u0644\u0628\u0631\u064a\u062f \u0627\u0644\u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0647\u0630\u0627."},"ar.validation":{"accepted":"\u064a\u062c\u0628 \u0642\u0628\u0648\u0644 :attribute.","active_url":":attribute  \u0644\u064a\u0633\u062a \u0639\u0646\u0648\u0627\u0646 URL \u0635\u0627\u0644\u062d\u064b\u0627.","after":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u062a\u0627\u0631\u064a\u062e \u0628\u0639\u062f :date .","after_or_equal":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u062a\u0627\u0631\u064a\u062e\u064b\u0627 \u0623\u0648 \u064a\u0633\u0627\u0648\u064a :date .","alpha":"\u0642\u062f \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0623\u062d\u0631\u0641 \u0641\u0642\u0637.","alpha_dash":"\u0642\u062f \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0623\u062d\u0631\u0641 \u0648\u0623\u0631\u0642\u0627\u0645 \u0648\u0634\u0631\u0637\u0627\u062a \u0648\u0634\u0631\u0637\u0627\u062a \u0633\u0641\u0644\u064a\u0629 \u0641\u0642\u0637.","alpha_num":"\u0642\u062f \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0623\u062d\u0631\u0641 \u0648\u0623\u0631\u0642\u0627\u0645 \u0641\u0642\u0637.","array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute \u0635\u0641\u064a\u0641\u064b\u0627.","attributes":[],"before":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u062a\u0627\u0631\u064a\u062e \u0642\u0628\u0644 :date .","before_or_equal":" \u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0629 \u062a\u0627\u0631\u064a\u062e \u0642\u0628\u0644 \u0623\u0648 \u064a\u0633\u0627\u0648\u064a :date .","between":{"array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0628\u064a\u0646 :min \u0648 max items: .","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0628\u064a\u0646: min \u0648 max kilobytes: .","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0628\u064a\u0646 :min \u0648 :max .","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0628\u064a\u0646 :min \u0648 :max \u062d\u0631\u0648\u0641 ."},"boolean":"\u064a\u062c\u0628 \u0623\u0646 \u064a\u0643\u0648\u0646 \u062d\u0642\u0644 attribute true: \u0623\u0648 false.","confirmed":"\u0644\u0627 \u064a\u062a\u0637\u0627\u0628\u0642 \u062a\u0623\u0643\u064a\u062f :attribute.","custom":{"attribute-name":{"rule-name":"\u0631\u0633\u0627\u0644\u0629 \u0645\u062e\u0635\u0635\u0629"}},"date":":attribute \u0644\u064a\u0633 \u062a\u0627\u0631\u064a\u062e\u064b\u0627 \u0635\u0627\u0644\u062d\u064b\u0627.","date_equals":":\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute \u062a\u0627\u0631\u064a\u062e \u064a\u0633\u0627\u0648\u064a: date.","date_format":":attribute \u0644\u0627 \u062a\u062a\u0648\u0627\u0641\u0642 \u0645\u0639 \u0627\u0644\u062a\u0646\u0633\u064a\u0642: \u0627\u0644\u062a\u0646\u0633\u064a\u0642.","different":" \u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0648 \u0623\u062e\u0631\u0649 \u0645\u062e\u062a\u0644\u0641\u0629.","digits":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0636\u063a\u0637 digits:.","digits_between":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0628\u064a\u0646 :min \u0648 max digits: .","dimensions":":attribute \u0644\u0647\u0627 \u0623\u0628\u0639\u0627\u062f \u0635\u0648\u0631\u0629 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d\u0629.","distinct":"\u064a\u062d\u062a\u0648\u064a \u062d\u0642\u0644 :attribute \u0642\u064a\u0645\u0629 \u0645\u0643\u0631\u0631\u0629.","email":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0639\u0646\u0648\u0627\u0646 \u0628\u0631\u064a\u062f \u0625\u0644\u0643\u062a\u0631\u0648\u0646\u064a \u0635\u0627\u0644\u062d.","ends_with":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0646\u062a\u0647\u064a :attribute \u0628\u0625\u062d\u062f\u0649 \u0627\u0644\u0642\u064a\u0645 values : \u0627\u0644\u0642\u064a\u0645.","exists":":attribute \u0627\u0644\u0645\u062d\u062f\u062f\u0629 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d\u0629.","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0645\u0644\u0641\u064b\u0627.","filled":"\u064a\u062c\u0628 \u0623\u0646 \u064a\u062d\u062a\u0648\u064a \u062d\u0642\u0644 :attribute \u0639\u0644\u0649 \u0642\u064a\u0645\u0629.","gt":{"array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0639\u0646\u0627\u0635\u0631 \u0623\u0643\u062b\u0631 \u0645\u0646 value:.","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute :greater: \u0645\u0646 \u0627\u0644\u0642\u064a\u0645\u0629 \u0628\u0627\u0644\u0643\u064a\u0644\u0648\u0628\u0627\u064a\u062a.","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0643\u0628\u0631 \u0645\u0646  value: .","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0643\u0628\u0631 \u0645\u0646 value: \u0627\u0644\u0623\u062d\u0631\u0641."},"gte":{"array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0639\u0646\u0627\u0635\u0631 \u0623\u0648 \u0623\u0643\u062b\u0631 value: .","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0643\u0628\u0631 \u0645\u0646 \u0623\u0648 \u062a\u0633\u0627\u0648\u064a value: \u0643\u064a\u0644\u0648 \u0628\u0627\u064a\u062a.","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0643\u0628\u0631 \u0645\u0646 \u0623\u0648 \u062a\u0633\u0627\u0648\u064a value:.","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 Attribute: \u0623\u0643\u0628\u0631 \u0645\u0646 \u0623\u0648 \u062a\u0633\u0627\u0648\u064a value: \u0627\u0644\u0634\u062e\u0635\u064a\u0627\u062a."},"image":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0635\u0648\u0631\u0629.","in":":attribute \u0627\u0644\u0645\u062d\u062f\u062f\u0629 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d\u0629.","in_array":"\u062d\u0642\u0644 :attribute \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f \u0641\u064a other: .","integer":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0639\u062f\u062f\u064b\u0627 \u0635\u062d\u064a\u062d\u064b\u0627.","ip":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0639\u0646\u0648\u0627\u0646 IP \u0635\u0627\u0644\u062d\u064b\u0627.","ipv4":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0639\u0646\u0648\u0627\u0646 IPv4 \u0635\u0627\u0644\u062d\u064b\u0627.","ipv6":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0639\u0646\u0648\u0627\u0646 IPv6 \u0635\u0627\u0644\u062d\u064b\u0627.","json":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0633\u0644\u0633\u0644\u0629 JSON \u0635\u0627\u0644\u062d\u0629.","lt":{"array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0639\u0646\u0627\u0635\u0631 \u0623\u0642\u0644 \u0645\u0646 value: .","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0642\u0644 \u0645\u0646 value: \u0628\u0627\u0644\u0643\u064a\u0644\u0648\u0628\u0627\u064a\u062a.","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0642\u0644 \u0645\u0646 value:.","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0642\u0644 \u0645\u0646 \u0623\u062d\u0631\u0641 value: ."},"lte":{"array":"\u064a\u062c\u0628 \u0623\u0644\u0627 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0623\u0643\u062b\u0631 \u0645\u0646 \u0639\u0646\u0627\u0635\u0631 value: .","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0642\u0644 \u0645\u0646 \u0623\u0648 \u062a\u0633\u0627\u0648\u064a value: \u0628\u0627\u0644\u0643\u064a\u0644\u0648\u0628\u0627\u064a\u062a.","numeric":":attribute \u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 \u0623\u0642\u0644 \u0645\u0646 \u0623\u0648 \u062a\u0633\u0627\u0648\u064a: value.","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0642\u0644 \u0645\u0646 \u0623\u0648 \u062a\u0633\u0627\u0648\u064a \u0623\u062d\u0631\u0641 value: ."},"max":{"array":"\u0644\u0627 \u064a\u062c\u0648\u0632 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0623\u0643\u062b\u0631 \u0645\u0646 :max \u0627\u0644\u0623\u0642\u0635\u0649 \u0644\u0644\u0639\u0646\u0627\u0635\u0631.","file":"\u0642\u062f \u0644\u0627 \u062a\u0643\u0648\u0646 :attribute \u0623\u0643\u0628\u0631 \u0645\u0646 \u0643\u064a\u0644\u0648\u0628\u0627\u064a\u062a :max \u0623\u0642\u0635\u0649.","numeric":"\u0644\u0627 \u064a\u062c\u0648\u0632 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0623\u0643\u0628\u0631 \u0645\u0646 :max .","string":":\u0644\u0627 \u064a\u062c\u0648\u0632 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute \u0623\u0643\u0628\u0631 \u0645\u0646:max \u0627\u0644\u0623\u0642\u0635\u0649 \u0644\u0639\u062f\u062f \u0627\u0644\u0623\u062d\u0631\u0641."},"mimes":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0645\u0644\u0641\u064b\u0627 \u0645\u0646 \u0627\u0644\u0646\u0648\u0639 values: .","mimetypes":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0645\u0644\u0641\u064b\u0627 \u0645\u0646 \u0627\u0644\u0646\u0648\u0639 values: .","min":{"array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 \u0627\u0644\u0623\u0642\u0644 \u0639\u0646\u0627\u0635\u0631 :min .","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute :min minobobes: \u0639\u0644\u0649 \u0627\u0644\u0623\u0642\u0644.","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute :min: \u0639\u0644\u0649 \u0627\u0644\u0623\u0642\u0644.","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0627\u0644\u0623\u0642\u0644 :min  \u0627\u0644\u0623\u062d\u0631\u0641."},"not_in":":attribute \u0627\u0644\u0645\u062d\u062f\u062f\u0629 \u063a\u064a\u0631 \u0635\u0627\u0644\u062d\u0629.","not_regex":"\u062a\u0646\u0633\u064a\u0642 :attribute \u063a\u064a\u0631 \u0635\u0627\u0644\u062d.","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0631\u0642\u0645\u064b\u0627.","password":"\u0643\u0644\u0645\u0629 \u0627\u0644\u0645\u0631\u0648\u0631 \u063a\u064a\u0631 \u0635\u062d\u064a\u062d\u0629.","present":"\u064a\u062c\u0628 \u0623\u0646 \u064a\u0643\u0648\u0646 \u062d\u0642\u0644 :attribute \u0645\u0648\u062c\u0648\u062f\u064b\u0627.","regex":"\u062a\u0646\u0633\u064a\u0642 :attribute \u063a\u064a\u0631 \u0635\u0627\u0644\u062d.","required":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628.","required_if":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628 \u0639\u0646\u062f\u0645\u0627 \u064a\u0643\u0648\u0646 other: \u064a\u0643\u0648\u0646 value: .","required_unless":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628 \u0625\u0644\u0627 \u0625\u0630\u0627 \u0643\u0627\u0646 other: \u064a\u0643\u0648\u0646 value: .","required_with":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628 \u0639\u0646\u062f \u0648\u062c\u0648\u062f \u0627\u0644\u0642\u064a\u0645.","required_with_all":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628 \u0639\u0646\u062f\u0645\u0627 values: \u0645\u0648\u062c\u0648\u062f\u0629.","required_without":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628 \u0639\u0646\u062f\u0645\u0627 values: \u063a\u064a\u0631 \u0645\u0648\u062c\u0648\u062f\u0629.","required_without_all":"\u062d\u0642\u0644 :attribute \u0645\u0637\u0644\u0648\u0628 \u0639\u0646\u062f \u0639\u062f\u0645 \u0648\u062c\u0648\u062f \u0623\u064a \u0645\u0646 values: .","same":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062a\u0637\u0627\u0628\u0642 :attribute \u0648 other: .","size":{"array":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u062d\u062a\u0648\u064a :attribute \u0639\u0644\u0649 size: \u0639\u0646\u0627\u0635\u0631 .","file":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0628\u0627\u0644\u0643\u064a\u0644\u0648\u0628\u0627\u064a\u062a size: .","numeric":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0633\u064a\u0632 size: .","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0627\u0644\u0623\u062d\u0631\u0641: size: ."},"starts_with":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0628\u062f\u0623 :attribute \u0628\u0625\u062d\u062f\u0649 \u0627\u0644\u0642\u064a\u0645 \u0627\u0644\u062a\u0627\u0644\u064a\u0629 values: .","string":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0633\u0644\u0633\u0644\u0629.","timezone":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0645\u0646\u0637\u0642\u0629 \u0635\u0627\u0644\u062d\u0629.","unique":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 :attribute \u0645\u0646\u0637\u0642\u0629 \u0635\u0627\u0644\u062d\u0629.","uploaded":"\u0641\u0634\u0644 :attribute \u0641\u064a \u0627\u0644\u062a\u062d\u0645\u064a\u0644.","url":"\u062a\u0646\u0633\u064a\u0642 :attribute \u063a\u064a\u0631 \u0635\u0627\u0644\u062d.","uuid":"\u064a\u062c\u0628 \u0623\u0646 \u062a\u0643\u0648\u0646 attribute UUID: \u0635\u0627\u0644\u062d\u064b\u0627."},"de.auth":{"failed":"Diese Anmeldeinformationen stimmen nicht mit unseren Aufzeichnungen \u00fcberein.","throttle":"Zu viele Anmeldeversuche. Bitte versuchen Sie es erneut in: seconds Sekunden."},"de.messages":{"activity_log":{"activity_logs":"Aktivit\u00e4tsprotokolle","loading_more_date":"Weitere Daten laden","sorry_we_not_find_any_data":"Wir k\u00f6nnen keine Daten finden, machen Sie mindestens 1 Eintrag","we_could_find_any_data":"Wir konnten keine Daten finden. Entschuldigung"},"address":{"city":"Stadt","country":"Land","state":"Zustand","street":"Stra\u00dfe","zip_code":"Postleitzahl"},"announcement":{"add":"Hinzuf\u00fcgen","announcement_date":"Ank\u00fcndigungsdatum","announcement_details":"Ank\u00fcndigungsdetails","announcement_not_found":"Ank\u00fcndigung nicht gefunden.","announcement_saved_successfully":"Ank\u00fcndigung erfolgreich gespeichert.","announcement_updated_successfully":"Ank\u00fcndigung erfolgreich aktualisiert.","edit_announcement":"Ank\u00fcndigung bearbeiten","message":"Botschaft","new_announcement":"Neue Ank\u00fcndigung","no_announcement_available":"Keine Ank\u00fcndigung verf\u00fcgbar","no_announcement_found":"Keine Ank\u00fcndigung gefunden.","show_my_name":"Zeige meinen Namen","show_to_clients":"Kunden anzeigen","show_to_staff":"Mitarbeitern anzeigen Show","subject":"Gegenstand"},"announcements":"Ank\u00fcndigungen","article":{"add":"Hinzuf\u00fcgen","article_details":"Artikeldetails","article_not_found":"Artikel nicht gefunden.","article_saved_successfully":"Artikel erfolgreich gespeichert.","article_updated_successfully":"Artikel erfolgreich aktualisiert.","attachment":"Anhang","description":"Beschreibung","disabled":"Behindert","edit_article":"Artikel bearbeiten","group":"Gruppe","internal_article":"Interner Artikel","new_article":"Neuer Artikel","no_article_available":"Kein Artikel verf\u00fcgbar.","no_article_found":"Kein Artikel gefunden.","subject":"Gegenstand","upload_image":"Bild hochladen"},"article_group":{"add_new_article_group":"Neue Artikelgruppe hinzuf\u00fcgen","article_group_saved_successfully":"Artikelgruppe erfolgreich gespeichert.","article_group_updated_successfully":"Artikelgruppe erfolgreich aktualisiert.","article_group_used_somewhere_else":"Artikelgruppe an anderer Stelle verwendet.","article_groups":"Artikelgruppen","color":"Farbe","edit_article_group":"Artikelgruppe bearbeiten","group_name":"Gruppenname","new_article_group":"Neue Artikelgruppe","order":"Auftrag"},"articles":"Artikel","calendars":"Kalender","change_password":{"change_information_about_yourself_on_this_page":" \u00c4ndern Sie die Informationen \u00fcber sich selbst auf dieser Seite.","confirm_password":"Best\u00e4tige das Passwort","current_password":"derzeitiges Passwort","edit_profile":"Profil bearbeiten","new_password":"Neues Kennwort"},"client_dashboard":"Client-Dashboard","cms":"CMS","comment":{"add_comment":"Einen Kommentar hinzuf\u00fcgen","added_by":"Hinzugef\u00fcgt von","comments_saved_successfully":"Kommentar erfolgreich gespeichert.","comments_updated_successfully":"Kommentar erfolgreich aktualisiert.","edit_comment":"Kommentar bearbeiten","new_comment":"Neuer Kommentar","no_comments_added_yet":"Noch keine Kommentare hinzugef\u00fcgt"},"comments":"Bemerkungen","common":{"action":"Aktion","active":"Aktiv","add":"Hinzuf\u00fcgen","admin_note":"Hinweis f\u00fcr Administratoren","announcement":"Bekanntmachung","apply":"Sich bewerben","article":"Artikel","article_group":"Artikelgruppe","assignee":"Beauftragter","attachment_deleted":"Anhang wurde gel\u00f6scht.","back":"Zur\u00fcck","cancel":"Stornieren","choose":"W\u00e4hlen","client_note":"Kundenhinweis","contract_type":"Vertragstyp","country":"Land","created_on":"Erstellt am","custom":"Brauch","customer":"Kunde","customer_group":"Kundengruppe","data_base_entries":"Showing _START_ to _END_ of _TOTAL_ entries","deactive":"Deaktivieren","default_country_code":"Standard-L\u00e4ndercode","delete":"L\u00f6schen","delete_attachment":"M\u00f6chten Sie diesen \"Anhang\" wirklich l\u00f6schen?","delete_confirm":"Bitte gib ein","delete_confirm_common":"M\u00f6chten Sie dies wirklich l\u00f6schen?","delete_note":"M\u00f6chten Sie diese \"Notiz\" wirklich l\u00f6schen?","deleted":"Gel\u00f6scht!","department":"Abteilung","description":"Beschreibung","download":"Herunterladen","download_as_pdf":"Als PDF herunterladen","drafted":"Entworfen","edit":"Bearbeiten","email":"Email","expense":"Aufwand","expense_category":"Ausgabenkategorie","filter_by":"(filtered from _MAX_ total entries)","from":"Aus","goal":"Tor","has_been_delete":" wurde gel\u00f6scht..","incomes_vs_expenses":"Einnahmen vs. Ausgaben","last_updated":"Letzte Aktualisierung","lead":"F\u00fchren","lead_source":"Hauptquelle","menu_entry":"Show _MENU_ entries","n\/a":"N\/A","name":"Name","no":"Nein","no_data_available_in_table":"Keine Daten in der Tabelle verf\u00fcgbar","no_entry":"Showing 0 to 0 of 0 entries","no_matching":"No matching records found","note":"Hinweis","note_delete":"Hinweis wurde gel\u00f6scht.","of":"Von","ok":"OK","payment_mode":"Zahlungsart","predefined_reply":"Vordefinierte Antwort","product_1":"Produkt","product_group":"Produktgruppe","product_header":"Produkt","proposal":"Vorschlag","quantity_is_not_greater_than":"Die Menge ist nicht gr\u00f6\u00dfer als 9999999","save":"sparen","search":"Suche","search_results":"Ihre Suchergebnisse finden Sie hier ...","service":"Service","showing":"Zeigen","status":"Status","tag":"Schild","tax_rate":"Steuersatz","term_and_conditions":"Allgemeine Gesch\u00e4ftsbedingungen","ticket_priority":"Ticketpriorit\u00e4t","to":"Zu","to_delete_this":"um dies zu l\u00f6schen","total_amount":"Gesamtsumme","type_delete":"Bitte geben Sie \"delete\" ein, um dies zu l\u00f6schen","view":"Aussicht","weekly_payment_records":"W\u00f6chentliche Zahlungsaufzeichnungen","yes":"Ja"},"company":{"address":"Adresse","city":"Stadt","company":"Name der Firma","company_information_format":"Unternehmensinformationsformat (PDF und HTML)","country_code":"Landesvorwahl","currency":"W\u00e4hrung","details":"W\u00e4hrung","phone":"Telefon","state":"Zustand","vat_number":"Umsatzsteuer-Identifikationsnummer","website":"Webseite","zip_code":"Postleitzahl"},"company_information":"Firmeninformation","contact":{"active":"Aktiv","by_deleting_this_contact":"Durch L\u00f6schen dieses Kontakts wird sein gesamtes Projekt gel\u00f6scht.","contact_details":"Kontaktdetails","contact_not_found":"Kontakt nicht gefunden.","contact_saved_successfully":"Kontakt erfolgreich gespeichert.","contact_status_updated_successfully":"Kontaktstatus erfolgreich aktualisiert.","contact_updated_successfully":"Kontakt erfolgreich aktualisiert.","contract":"Vertrag","contracts":"Vertr\u00e4ge","credit_note":"Gutschrift","customer_name":"Kundenname","delete_contact_confirm":"M\u00f6chten Sie diesen Kontakt wirklich l\u00f6schen?","edit_contact":"Kontakt bearbeiten","email_notifications":"E-Mail Benachrichtigungen","estimate":"Sch\u00e4tzen","estimates":"Sch\u00e4tzungen","first_name":"Vorname","full_name":"Vollst\u00e4ndiger Name","impersonate":"Imitieren","inactive":"Inaktiv","invoice":"Rechnung","invoices":"Rechnungen","last_name":"Nachname","make_sure_to_set_appropriate_permissions_for_this_contact":"Stellen Sie sicher, dass Sie die entsprechenden Berechtigungen f\u00fcr diesen Kontakt festlegen","new_contact":"Neuer Kontakt","no_contact_available":"Es ist kein Kontakt verf\u00fcgbar.","no_contact_found":"Kein Kontakt gefunden.","password":"Passwort","permissions":"Berechtigungen","position":"Position","primary_contact":"Hauptansprechpartner","project":"Projekt","projects":"Projekte","proposals":"Vorschl\u00e4ge","send_password_email":"Senden Sie eine SET-Passwort-E-Mail","send_welcome_email":"Senden Sie keine Willkommens-E-Mail","support":"Unterst\u00fctzung","task":"Aufgabe","tickets":"Tickets"},"contacts":"Kontakte","contract":{"add":"Hinzuf\u00fcgen","authorized_signature":"Autorisierte Unterschrift","contract_details":"Vertragsdetails","contract_list":"Vertragsliste","contract_not_found":"Vertrag nicht gefunden.","contract_summary":"Vertragszusammenfassung","contract_type_id":"Vertragstyp","contract_value":"Vertragswert","contracts_by_type":"Vertr\u00e4ge nach Typ","contracts_expiring_this_month":"Vertr\u00e4ge, die diesen Monat auslaufen","contracts_saved_successfully":"Vertrag erfolgreich gespeichert.","contracts_updated_successfully":"Vertrag erfolgreich aktualisiert.","contracts_value_by_type":"Vertragswert nach Typ","customer_id":"Kunde","description":"Beschreibung","edit_contract":"Vertrag bearbeiten","end_date":"Endtermin","is_hide":"Vor Kunden verstecken","is_trash":"M\u00fcll","new_contract":"Neuer Vertrag","no_contract_available":"Kein Vertrag verf\u00fcgbar","no_contract_found":"Kein Vertrag gefunden.","sign":"Zeichen","start_date":"Anfangsdatum","subject":"Gegenstand","task":"Aufgabe"},"contract_type":{"add_new_contract_type":"Neuen Vertragstyp hinzuf\u00fcgen","contract_by_type":"Vertrag nach Typ","contract_type_saved_successfully":"Vertragsart erfolgreich gespeichert.","contract_type_updated_successfully":"Vertragsart erfolgreich aktualisiert.","contract_type_used_somewhere_else":"Vertragstyp, der an anderer Stelle verwendet wird.","contract_value_by_type":"Vertragswert nach Typ","edit_contract_type":"Vertragstyp bearbeiten","new_contract_type":"Neue Vertragsart"},"contract_types":"Vertragsarten","contracts":"Vertr\u00e4ge","countries":"L\u00e4nder","country":{"add":"Hinzuf\u00fcgen","country_not_found":"Land nicht gefunden.","country_saved_successfully":"Land erfolgreich gespeichert.","country_updated_successfully":"Land erfolgreich aktualisiert.","country_used_somewhere_else":"Land woanders verwendet.","edit_country":"Land bearbeiten","name":"Name","new_country":"Neues Land","no_country_available":"Kein Land verf\u00fcgbar.","no_country_found":"Kein Land gefunden."},"credit_note":{"authorized_signature":"Autorisierte Unterschrift","client_note":"Hinweis","closed":"Geschlossen","credit_note":"Gutschrift","credit_note_date":"Datum der Gutschrift","credit_note_details":"Details zur Gutschrift","credit_note_details_updated_successfully":"Gutschriftdetails erfolgreich aktualisiert.","credit_note_not_found":"Gutschrift nicht gefunden.","credit_note_number":"Gutscheinnummer","credit_note_pdf":"Gutschrift PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"Gutschrift erfolgreich gespeichert.","credit_note_updated_successfully":"Gutschrift erfolgreich aktualisiert.","drafted":"Entworfen","edit_credit_note":"Gutschrift bearbeiten","invoice_credited":"Rechnung gutgeschrieben","mark_as_closed":"Als geschlossen markieren","mark_as_draft":"Als Entwurf markieren","mark_as_open":"Als offen markieren","mark_as_void":"Als nichtig markieren","new_credit_note":"Neue Gutschrift","no_credit_note_available":"Keine Gutschrift verf\u00fcgbar.","no_credit_note_found":"Keine Gutschrift gefunden.","open":"\u00d6ffnen","quantity_is_not_greater_than":"Menge ist nicht gr\u00f6\u00dfer als 9999999","reference":"Referenz","refunds":"R\u00fcckerstattungen","save_and_send":"Speichern & senden","save_as_draft":"Als Entwurf speichern","terms_and_conditions":"Terms & amp; Bedingungen","title":"Titel","view_credit_note_as_customer":"Gutschrift als Kunde anzeigen","void":"Leere"},"credit_notes":"Gutschriften","customer":{"add_address_details":"Adressdetails hinzuf\u00fcgen","address":"Adresse","address_details":"Adressen Details","address_not_found":"Adressdetails nicht gefunden.","billing_address":"Rechnungsadresse","billing_address_details_not_available":"Details zur Rechnungsadresse nicht verf\u00fcgbar","by_deleting_this_customer":"Durch L\u00f6schen des gesamten Projekts dieses Kunden werden Kontakt, Rechnung, Kostenvoranschlag, Gutschrift, Angebot und Vertrag gel\u00f6scht.","city":"Stadt","company_name":"Name der Firma","copy_billing_address":"Rechnungsadresse kopieren","country":"Land","currency":"W\u00e4hrung","customer_details":"Kundendetails","customer_saved_successfully":"Kunde erfolgreich gespeichert.","customer_updated_successfully":"Kunde erfolgreich aktualisiert.","customers":"Kunden","default_language":"Standardsprache","delete_customer_confirm":"M\u00f6chten Sie diesen Kunden wirklich l\u00f6schen?","do_not_fill_shipping_address_customer_invoices":"Geben Sie keine Lieferadresseninformationen ein, wenn Sie die Lieferadresse nicht auf Kundenrechnungen verwenden","edit_customer":"Kunden bearbeiten","groups":"Gruppen","new_customer":"Neukunde","no_customer_available":"Kein Kunde verf\u00fcgbar.","no_customer_found":"Kein Kunde gefunden.","phone":"Telefon","same_as_a_customer_info":"Gleich wie Kundeninfo","search_customer":"Search Customer","shipping_address":"Lieferanschrift","shipping_address_details_not_available":"Angaben zur Lieferadresse nicht verf\u00fcgbar","state":"Zustand","street":"Stra\u00dfe","task":"Aufgabe","total_contact":"Gesamtkontakt","total_customers":"Kunden insgesamt","total_project":"Gesamtprojekt","type":"Art","vat_number":"Umsatzsteuer-Identifikationsnummer","website":"Webseite","zip_code":"Postleitzahl"},"customer_group":{"action":"Aktion","add_new_customer_group":"Neue Kundengruppe hinzuf\u00fcgen","customer_group_saved_successfully":"Kundengruppe erfolgreich gespeichert.","customer_group_updated_successfully":"Kundengruppe erfolgreich aktualisiert.","description":"Beschreibung","edit_customer_group":"Kundengruppe bearbeiten","name":"Name","new_customer_group":"Neue Kundengruppe"},"customer_groups":"Kundengruppen","customers":"Kunden","dashboard":"Instrumententafel","department":{"department_not_found":"Abteilung nicht gefunden.","department_saved_successfully":"Abteilung erfolgreich gespeichert.","department_updated_successfully":"Abteilung erfolgreich aktualisiert.","departments":"Abteilungen","edit_department":"Abteilung bearbeiten","hide_from_clients":"Vor Kunden verstecken","new_department":"Neue Abteilung","no_department_available":"Keine Abteilung verf\u00fcgbar.","no_department_found":"Keine Abteilung gefunden."},"edit_profile":{"change_password":"\u00c4ndere das Passwort","edit_profile":"Profil bearbeiten","hello":"Hallo","hi":"Hallo","login":"Anmeldung","login_register":"Anmeldung Registrieren","logout":"Ausloggen","mark_all_as_read":"Markiere alle als gelesen","notification":"Benachrichtigungen","register":"Registrieren","welcome":"Herzlich willkommen"},"email":{"email":"Email","forgot_password":"Passwort vergessen","recalled_your_login_info":"Haben Sie Ihre Anmeldedaten abgerufen?","reset_password":"Passwort zur\u00fccksetzen","send_reset_link":"Reset-Link senden","sign_in":"Anmelden"},"email_template":{"available_merge_fields":"Verf\u00fcgbare Zusammenf\u00fchrungsfelder","disabled":"Behindert","edit_email_template":"E-Mail-Vorlage bearbeiten","email_message":"E-Mail Nachricht","enable":"Aktivieren","from_name":"Von Namen","send_plain_text":"Als Klartext senden","subject":"Gegenstand","template_name":"Vorlagenname"},"email_templates":"E-Mail-Vorlagen","error":"Fehler","estimate":{"accepted":"AKZEPTIERT","adjustment":"Einstellung","amount":"Menge","amount_due":"Offener Betrag","authorized_signature":"Autorisierte Unterschrift","bill_to":"Gesetzesentwurf f\u00fcr","client_note":"Kundenhinweis","convert_estimate":"Sch\u00e4tzung konvertieren","convert_estimate_to_invoice":"Kostenvoranschlag erfolgreich in Rechnung konvertieren.","declined":"ABGELEHNT","discount":"Rabatt","draft":"ENTWURF","drafted":"Entworfen","edit_estimate":"Sch\u00e4tzung bearbeiten","estimate":"Sch\u00e4tzen","estimate_date":"Sch\u00e4tzdatum","estimate_details":"Details sch\u00e4tzen","estimate_not_found":"Sch\u00e4tzung nicht gefunden.","estimate_number":"Gesch\u00e4tzte Anzahl","estimate_overview":"SCH\u00c4TZUNGS\u00dcBERSICHT","estimate_pdf":"PDF sch\u00e4tzen","estimate_prefix":"EN-","estimate_saved_successfully":"Sch\u00e4tzung erfolgreich gespeichert.","estimate_status_updated_successfully":"Sch\u00e4tzungsstatus erfolgreich aktualisiert.","estimate_updated_successfully":"Sch\u00e4tzung erfolgreich aktualisiert.","expired":"ABGELAUFEN","expiry_date":"Verfallsdatum","item":"Produkt","mark_as_accepted":"Als akzeptiert markieren","mark_as_declined":"Als abgelehnt markieren","mark_as_draft":"Als Entwurf markieren","mark_as_expired":"Als abgelaufen markieren","mark_as_send":"Als senden markieren","more":"Mehr","new_estimate":"Neue Sch\u00e4tzung","no_estimate_available":"Keine Sch\u00e4tzung verf\u00fcgbar","no_estimate_found":"Keine Sch\u00e4tzung gefunden.","not_sent":"NICHT GESENDET","qty":"Menge","rate":"Bewertung","save_and_send":"Speichern & senden","save_as_draft":"Als Entwurf speichern","sent":"GESCHICKT","ship_to":"Ausliefern","status":"Status","sub_total":"Zwischensumme","task":"Aufgabe","taxes":"Steuern","terms_conditions":"Terms & amp; Bedingungen","title":"Titel","total":"Gesamt","total_estimates":"Gesamtsch\u00e4tzungen","total_paid":"Ganz bezahlt","view_estimate_as_customer":"Sch\u00e4tzung als Kunde anzeigen"},"estimates":"Sch\u00e4tzungen","expense":{"add":"Hinzuf\u00fcgen","amount":"Menge","amount_with_tax":"Betrag mit Steuern","apply_tax":"Steuern anwenden","apply_tax_message":"Steuerbetrag vom Betrag abziehen","attachment":"Anhang","auto_create_invoice":"Rechnung automatisch erstellen","billable":"Abrechnungsf\u00e4hig","choose_file":"Datei w\u00e4hlen","currency":"W\u00e4hrung","customer":"Kunde","details":"Einzelheiten","edit_expense":"Kosten bearbeiten","expense_amount":"Ausgabenbetrag","expense_category":"Ausgabenkategorie","expense_category_by_chart":"Ausgabenkategorie nach Diagramm","expense_date":"Aufwandsdatum","expense_details":"Aufwandsdetails","expense_list":"Spesenliste","expense_not_found":"Aufwand nicht gefunden.","expense_saved_successfully":"Kosten erfolgreich gespeichert.","expense_updated_successfully":"Kosten erfolgreich aktualisiert.","name":"Name","new_expense":"Neue Ausgaben","no_expense_available":"Keine Kosten verf\u00fcgbar.","no_expense_found":"Keine Kosten gefunden.","note":"Hinweis","notes":"Anmerkungen","payment_mode":"Zahlungsart","preview_attachment":"Vorschau des Anhangs","receipt_attachment":"Quittungsanhang","reference":"Referenz","reminders":"Erinnerung","send_email":"Senden Sie die Rechnung an die Kunden-E-Mail, wenn die Kosten neu erstellt wurden","tax_1":"Steuer 1 (in%)","tax_2":"Steuer 2 (in%)","tax_applied":"Steuer angewendet","view_attachment":"Anhang ansehen"},"expense_by_category":"Ausgaben nach Kategorie","expense_categories":"Ausgabenkategorien","expense_category":{"add_new_expense_category":"Neue Ausgabenkategorie hinzuf\u00fcgen","edit_category":"Ausgabenkategorie bearbeiten","expense_categories":"Ausgabenkategorien","expense_category":"Ausgabenkategorie","expense_category_saved_successfully":"Spesenkategorie erfolgreich gespeichert.","expense_category_updated_successfully":"Ausgabenkategorie erfolgreich aktualisiert.","expense_category_used_somewhere_else":"An anderer Stelle verwendete Ausgabenkategorie.","new_category":"Neue Ausgabenkategorie"},"expenses":"Kosten","general":"Allgemeines","goal":{"achievement":"Leistung","add":"Hinzuf\u00fcgen","description":"Beschreibung","edit_goal":"Ziel bearbeiten","end_date":"Endtermin","goal_details":"Zieldetails","goal_id":"Zieltyp","goal_saved_successfully":"Ziel erfolgreich gespeichert.","goal_type":"Zieltyp","goal_updated_successfully":"Ziel erfolgreich aktualisiert.","is_not_notify":"Benachrichtigen Sie die Mitarbeiter, wenn das Ziel nicht erreicht wurde","is_notify":"Benachrichtigen Sie die Mitarbeiter, wenn das Ziel erreicht ist","new_goal":"Neues Ziel","no_goal_available":"Kein Ziel verf\u00fcgbar.","no_goal_found":"Ziel nicht gefunden.","progress":"Fortschritt","staff_member":"Mitarbeiter","start_date":"Anfangsdatum","subject":"Gegenstand","user_id":"Mitarbeiter"},"goal_type":{"description":"Beschreibung","edit_goal_type":"Zieltyp bearbeiten","name":"Name","new_goal_type":"Neuer Zieltyp"},"goals":"Tore","incomes":"Einkommen","invoice":{"activity_log":"Aktivit\u00e4tsprotokoll","add_item":"Produkt hinzuf\u00fcgen","add_shipping_address":"Lieferadresse hinzuf\u00fcgen","adjustment":"Einstellung","admin_note":"Hinweis f\u00fcr Administratoren","allowed_payment_modes_for_this_invoice":"Zul\u00e4ssige Zahlungsmodi f\u00fcr diese Rechnung","amount":"Menge","amount_due":"Offener Betrag","authorized_signature":"Autorisierte Unterschrift","bank":"Bank","bill_tasks":"Rechnungsaufgaben","bill_to":"Gesetzesentwurf f\u00fcr","cancelled":"ABGESAGT","client_note":"Kundenhinweis","currency":"W\u00e4hrung","customer":"Kunde","discount":"Rabatt","discount_type":"Rabattart","draft":"ENTWURF","drafted":"Entworfen","due_date":"Geburtstermin","edit_contract_type":"Vertragstyp bearbeiten","edit_invoice":"Rechnung bearbeiten","fixed":"Fest","hours":"Std","hsn_tax":"HSN-Steuergesetzbuch","invoice":"Rechnung","invoice_date":"Rechnungsdatum","invoice_details":"Rechnungs-Details","invoice_not_found":"Rechnung nicht gefunden.","invoice_number":"Rechnungsnummer","invoice_overview":"RECHNUNGS\u00dcBERSICHT","invoice_payments":"Rechnungszahlungen","invoice_pdf":"Rechnung PDF","invoice_prefix":"INV-","invoice_saved_successfully":"Rechnung erfolgreich gespeichert.","invoice_updated_successfully":"Rechnung erfolgreich aktualisiert.","item":"Produkt","mark_as_cancelled":"Als abgebrochen markieren","mark_as_draft":"Als Entwurf markieren","mark_as_paid":"Als bezahlt markieren","mark_as_partially_paid":"Als teilweise bezahlt markieren","mark_as_sent":"Als gesendet markieren","more":"Mehr","new_contract_type":"Neue Vertragsart","new_invoice":"Neue Rechnung","no_invoice_available":"Keine Rechnung verf\u00fcgbar.","no_invoice_found":"Keine Rechnung gefunden.","no_payments_available":"Keine Zahlungen verf\u00fcgbar","not_sent":"NICHT GESENDET","notes":"Anmerkungen","offline_payment":"Offline-Zahlung","online_payment":"Online-Zahlung","overdue":"\u00dcBERF\u00c4LLIG","paid":"Bezahlt","paid_cap":"BEZAHLT","partially_paid":"Teilweise bezahlt","partially_paid_cap":"TEILWEISE BEZAHLT","pay_now":"Zahlen Sie jetzt","payment":"Zahlung","payment_details":"Zahlungsdetails","payments":"Zahlungen","prevent_sending_overdue_reminders_for_this_invoice":"Verhindern Sie das Senden \u00fcberf\u00e4lliger Erinnerungen f\u00fcr diese Rechnung","qty":"Menge","qty\/hours":"Menge \/ Stunden","qty_hours":"Menge \/ Stunden","quick_invoices_info":"Schnelle Rechnungsinfo","recurring_invoice":"Wiederkehrende Rechnung","reminders":"Erinnerungen","sale_agent":"Verkaufsagent","save_and_send":"Speichern & senden","save_as_draft":"Als Entwurf speichern","ship_to":"Ausliefern","show_quantity_as":"Menge anzeigen als","sub_total":"Zwischensumme","task":"Aufgabe","taxes":"Steuern","terms_conditions":"Terms & amp; Bedingungen","title":"Titel","total":"Gesamt","total_invoices":"Rechnungen insgesamt","total_paid":"Ganz bezahlt","transactions":"Transaktionen","unmark_as_cancelled":"Unmarkiert als abgebrochen","unpaid":"Unbezahlt","unpaid_cap":"UNBEZAHLT","view_invoice_as_customer":"Rechnung als Kunde anzeigen"},"invoices":"Rechnungen","kanban_list":"KANBAN-Liste","kanban_view":"KANBAN Aussicht","last_week_payments":"Zahlungen der letzten Woche","lead":{"assigned":"Zugewiesen","chart":"Diagramm","contacted_today":"Heute kontaktiert","convert_to_customer":"Zum Kunden konvertieren","date_contacted":"Datum der Kontaktaufnahme","details":"Einzelheiten","edit_lead":"Lead bearbeiten","estimate_budget":"Budget sch\u00e4tzen","lead_convert_customer":"Lead Convert Kunde","lead_convert_customer_chart":"Lead Convert Customer Chart","lead_details":"Lead Details","lead_list":"Lead-Liste","lead_not_found":"Blei nicht gefunden.","lead_saved_successfully":"Lead erfolgreich gespeichert.","lead_status_updated_successfully":"Lead-Status erfolgreich aktualisiert.","lead_updated_successfully":"Lead erfolgreich aktualisiert.","leads_overview":"Leads \u00dcbersicht","name":"Name","new_lead":"Neuer Lead","no_lead_available":"Kein Blei verf\u00fcgbar.","no_lead_found":"Kein Blei gefunden.","notes":"Anmerkungen","reminder":"Erinnerung","source":"Quelle","task":"Aufgabe"},"lead_convert_to_customer":"Lead in Kunden umwandeln","lead_source":{"add":"Hinzuf\u00fcgen","edit_lead_source":"Lead-Quelle bearbeiten","lead_source_count":"Lead-Anzahl","lead_source_not_found":"Bleiquelle nicht gefunden.","lead_source_saved_successfully":"Lead-Quelle erfolgreich gespeichert.","lead_source_updated_successfully":"Lead-Quelle erfolgreich aktualisiert.","name":"Name","new_lead_source":"Neue Bleiquelle","no_lead_source_available":"Keine Lead-Quelle verf\u00fcgbar.","no_lead_source_found":"Keine Bleiquelle gefunden."},"lead_sources":"Leitquellen","lead_status":{"add":"Hinzuf\u00fcgen","add_new_lead_status":"Neuen Lead-Status hinzuf\u00fcgen","color":"Farbe","edit_lead_status":"Lead-Status bearbeiten","lead_status":"Lead-Status","lead_status_saved_successfully":"Lead-Status erfolgreich gespeichert.","lead_status_updated_successfully":"Lead-Status erfolgreich aktualisiert.","lead_status_used_somewhere_else":"An anderer Stelle verwendeter Lead-Status.","name":"Name","new_lead_status":"Neuer Lead Status","order":"Auftrag"},"leads":"F\u00fchrt","list_view":"Liste Aussicht","login":{"admin":"Administrator","client":"Klient","create_one":"Erstelle einen","don't have an account":"Sie haben noch keinen Account?","email":"Email","forgot_password":"Passwort vergessen","login":"Anmeldung","password":"Passwort","remember_me":"Behalte mich in Erinnerung"},"member":{"add":"Hinzuf\u00fcgen","by_deleting_this_member":"Durch L\u00f6schen dieses Mitglieds werden alle Projekte, Vorschl\u00e4ge und Ziele gel\u00f6scht.","choose":"W\u00e4hlen","created_on":"Erstellt am","default_language":"Standardsprache","delete_member_confirm":"M\u00f6chten Sie dieses Mitglied wirklich l\u00f6schen?","direction":"Richtung","edit_member":"Mitglied bearbeiten","email":"Email","email_is_not_verified":"E-Mail ist nicht verifiziert","email_is_verified":"E-Mail wird \u00fcberpr\u00fcft","email_verified":"Email \u00fcberpr\u00fcft","email_verified_successfully":"E-Mail erfolgreich verifiziert.","email_verify":"E-Mail-Best\u00e4tigung","facebook":"Facebook","first_name":"Vorname","hourly_rate":"Stundensatz","image":"Profil","is_administrator":"Administrator","is_enable":"Aktivieren Sie die Zwei-Faktor-Authentifizierung","last_name":"Nachname","linkedin":"Linkedin","member":"Mitglied","member_details":"Mitgliederdetails","member_informations":"Mitgliederinformation","member_not_found":"Mitglied nicht gefunden.","member_saved_successfully":"Mitglied erfolgreich gespeichert.","member_security":"Mitgliedssicherheit","member_status_updated_successfully":"Mitgliedsstatus erfolgreich aktualisiert.","member_updated_successfully":"Mitglied erfolgreich aktualisiert.","new_member":"Neues Mitglied","no_member_available":"Kein Mitglied verf\u00fcgbar.  ","no_member_found":"Kein Mitglied gefunden.","password":"Passwort","password_confirmation":"Best\u00e4tige das Passwort","permissions":"Berechtigungen","phone":"Telefon","profile":"Profil","resend_email_verification":"E-Mail-Best\u00e4tigung erneut senden","send_welcome_email":"Begr\u00fc\u00dfungs-E-Mail senden","skype":"Skypen","staff_member":"Nicht Mitarbeiter","total_members":"Mitglieder insgesamt","verification_mail_has_been_sent":"Best\u00e4tigungs-E-Mail wurde erfolgreich gesendet."},"members":"Mitglieder","menu_settings":"Men\u00fceinstellungen","months":{"apr":"Apr","aug":"Aug","dec":"Dec","feb":"Feb","jan":"Jan","jul":"Juli","jun":"Jun","mar":"Besch\u00e4digen","may":"Kann","nov":"Nov","oct":"Okt","sep":"Sep"},"new_language":"Neue Sprache","no_matching_records_found":"Keine \u00fcbereinstimmenden Aufzeichnungen gefunden","note":{"add_note":"Notiz hinzuf\u00fcgen","edit_note":"Notiz bearbeiten","new_note":"Neuer Hinweis","no_notes_added_yet":"Noch keine Notizen hinzugef\u00fcgt","notes_saved_successfully":"Notiz erfolgreich gespeichert.","notes_updated_successfully":"Notiz erfolgreich aktualisiert."},"notes":"Anmerkungen","notification":{"all_notification_read_successfully":"Alle Benachrichtigungen erfolgreich gelesen.","empty_notifications":"Wir konnten keine Benachrichtigungen finden","mark_all_as_read":"Markiere alle als gelesen","notification_read_successfully":"Benachrichtigung erfolgreich gelesen.","notifications":"Benachrichtigungen"},"others":"Andere","payment":{"amount":"Menge","amount_received":"Erhaltener Betrag","date":"Datum","new_payment":"Neue Zahlung","note":"Hinweis","payment_date":"Zahlungsdatum","payment_mode":"Zahlungsart","payment_saved_successfully":"Zahlung erfolgreich gespeichert.","send_mail_to_customer_contacts":"Senden Sie keine per E-Mail erfasste Rechnungszahlung an Kundenkontakte","transaction_id":"Transaktions-ID","your_payment_is_completed":"Ihre Zahlung wurde erfolgreich abgeschlossen.","your_payment_is_ont_completed":"Ihre Zahlung ist nicht abgeschlossen."},"payment_mode":{"active":"Aktiv","add_new_payment_mode":"Neuen Zahlungsmodus hinzuf\u00fcgen","bank_accounts":"Bankkonten","edit_payment_mode":"Zahlungsmodus bearbeiten","expenses_only":"Nur Ausgaben","invoices_only":"Nur Rechnungen","new_payment_mode":"Neuer Zahlungsmodus","no_payment_mode_available":"Kein Zahlungsmodus verf\u00fcgbar.","no_payment_mode_found":"Kein Zahlungsmodus gefunden.","on_invoice_pdf":"auf Rechnung PDF","payment_mode_details":"Details zum Zahlungsmodus","payment_mode_not_found":"Zahlungsmodus nicht gefunden.","payment_mode_saved_successfully":"Zahlungsmodus erfolgreich gespeichert.","payment_mode_updated_successfully":"Zahlungsmodus erfolgreich aktualisiert.","payment_mode_used_somewhere_else":"Zahlungsmodus, der woanders verwendet wird.","selected_by_default_on_invoice":"Standardm\u00e4\u00dfig auf Rechnung ausgew\u00e4hlt","show":"Show"},"payment_modes":"Zahlungsmodi","placeholder":{"add_note":"Notiz hinzuf\u00fcgen...","add_product":"Produkt hinzuf\u00fcgen","bill_tasks":"Rechnungsaufgaben","contact_number_is_invalid_number":"Kontaktnummer ist ung\u00fcltige Nummer","enter_email":"Email eingeben","invalid_country_code":"Ung\u00fcltiger L\u00e4ndercode","invalid_number":"Ung\u00fcltige Nummer","search_customers":"Kunden suchen","search_menu":"Suchmen\u00fc","select_article_group":"Artikelgruppe ausw\u00e4hlen","select_assignee":"W\u00e4hlen Sie Beauftragter aus","select_billing_type":"W\u00e4hlen Sie den Abrechnungstyp aus","select_contact":"W\u00e4hlen Sie Kontakte","select_contract_type":"Vertragstyp ausw\u00e4hlen","select_country":"Land ausw\u00e4hlen","select_currency":"W\u00e4hrung w\u00e4hlen","select_customer":"W\u00e4hlen Sie Kunde aus","select_department":"Abteilung ausw\u00e4hlen","select_discount_type":"Rabattart ausw\u00e4hlen","select_document_type":"Rabatttyp ausw\u00e4hlen","select_email_status":"W\u00e4hlen Sie E-Mail-Status aus","select_email_template":"W\u00e4hlen Sie E-Mail-Vorlage aus","select_expanse_category":"Kostenkategorie ausw\u00e4hlen","select_file":"Datei aussuchen","select_goal":"W\u00e4hlen Sie Ziel aus","select_goal_type":"W\u00e4hlen Sie Zieltyp aus","select_group":"W\u00e4hlen Sie Gruppen aus","select_groups":"W\u00e4hlen Sie Gruppen aus","select_internal_article":"W\u00e4hlen Sie Interner Artikel","select_item":"Men\u00fcpunkt w\u00e4hlen","select_language":"Sprache ausw\u00e4hlen","select_lead":" W\u00e4hlen Sie Leitung aus","select_lead_source":"W\u00e4hlen Sie Lead-Quelle aus","select_member":"Mitglied ausw\u00e4hlen","select_option":"W\u00e4hle eine Option","select_payment_mode":"Zahlungsmodus ausw\u00e4hlen","select_predefined_reply":"W\u00e4hlen Sie Vordefinierte Antwort ausy","select_priority":"W\u00e4hlen Sie Priorit\u00e4t aus","select_product":"Ausgew\u00e4hltes Produkt","select_product_group":"Produktgruppe ausw\u00e4hlen","select_reminder_to":"W\u00e4hlen Sie Erinnerung an","select_sale_agent":"W\u00e4hlen Sie Verkaufsvertreter aus","select_service":"Dienst ausw\u00e4hlen","select_show_to_client":"W\u00e4hlen Sie Dem Kunden zeigen aus","select_source":"Quelle ausw\u00e4hlen","select_status":"Status ausw\u00e4hlen","select_tags":"W\u00e4hlen Sie Tags aus","select_tax":"W\u00e4hlen Sie Steuern aus","select_tax1":"W\u00e4hlen Sie Steuer 1","select_tax2":"W\u00e4hlen Sie Steuer 2","select_template_type":"Vorlagentyp ausw\u00e4hlen","select_ticket_priority":"W\u00e4hlen Sie Ticketpriorit\u00e4t aus","too_long":"Zu lang","too_short":"Zu kurz","valid_number":"G\u00fcltige Nummer"},"please_enter_language_short_code":"Bitte geben Sie den Sprachcode ein. d.h. Englisch = en.","predefined_replies":"Vordefinierte Antworten","predefined_reply":{"add":"Hinzuf\u00fcgen","add_new_predefined_reply":"Neue vordefinierte Antwort hinzuf\u00fcgen","body":"K\u00f6rper","edit_predefined_reply":"Vordefinierte Antwort bearbeiten","new_predefined_reply":"Neue vordefinierte Antwort","no_predefined_reply_available":"Keine vordefinierte Antwort verf\u00fcgbar.","no_predefined_reply_found":"Keine vordefinierte Antwort gefunden.","predefined_reply_details":"Vordefinierte Antwortdetails","predefined_reply_not_found":"Vordefinierte Antwort nicht gefunden.","predefined_reply_saved_successfully":"Vordefinierte Antwort erfolgreich gespeichert.","predefined_reply_updated_successfully":"Vordefinierte Antwort erfolgreich aktualisiert.","reply_name":"Antwort Name"},"product_group":{"add_new_product_group":"Neue Produktgruppe hinzuf\u00fcgen","edit_product_group":"Produktgruppe bearbeiten","new_product_group":"Neue Produktgruppe","product_group_saved_successfully":"Produktgruppe erfolgreich gespeichert","product_group_updated_successfully":"Produktgruppe erfolgreich aktualisiert.","product_group_used_somewhere_else":"Produktgruppe woanders verwendet."},"product_groups":"Produktgruppen","products":{"edit_product":"Produkt bearbeiten","new_product":"Neues Produkt","product_group":"Produktgruppe","product_saved_successfully":"Produkt erfolgreich gespeichert.","product_updated_successfully":"Produkt erfolgreich aktualisiert.","products":"Produkte","rate":"Bewertung","tax":"MwSt","title":"Titel","unit":"Einheit"},"profile":"Profil","project":{"admin_area":"Admin-Bereich","allow_customer_to":"Kunden erlauben","billing_type":"Abrechnungsart","calculate_progress_through_tasks":"Berechnen Sie den Fortschritt durch Aufgaben","cancelled":"Abgesagt","comment_on_project_tasks":"Kommentar zu Projektaufgaben","create_tasks":"Aufgaben erstellen","customer":"Kunde","deadline":"Frist","edit_project":"Projekt bearbeiten","edit_tasks":"Aufgaben bearbeiten","estimated_hours":"Gesch\u00e4tzte Stunden","finished":"Fertig","hide_project_tasks_on_main_tasks_table":"Projektaufgaben in der Hauptaufgabentabelle ausblenden","in_progress":"In Bearbeitung","members":"Kontakt","new_project":"Neues Projekt","no_project_available":"Kein Projekt verf\u00fcgbar","no_project_found":"Projekt nicht gefunden","not_started":"Nicht angefangen","on_hold":"In Wartestellung","only_task_created_from_contact":"Nur aus Kontakt erstellte Aufgabe","open_discussions":"offene Diskussionen","progress":"Fortschritt","project_details":"Projekt Details","project_name":"Projektname","project_saved_successfully":"Projekt erfolgreich gespeichert.","project_settings":"Projekt Einstellungen","project_updated_successfully":"Projekt erfolgreich aktualisiert.","projects_summary":"Projektzusammenfassung","quick_invoices_info":"Schnelle Rechnungsinformationen","send_project_created_email":"Senden Sie eine vom Projekt erstellte E-Mail","start_date":"Anfangsdatum","statistics_by_project_status":"Statistik nach Projektstatus","status":"Status","task":"Aufgabe","total_projects":"Projekte insgesamt","upload_attachments_on_tasks":"Laden Sie Anh\u00e4nge zu Aufgaben hoch","upload_files":"Daten hochladen","view_account_statement":"Kontoauszug anzeigen","view_activity_log":"Aktivit\u00e4tsprotokoll anzeigen","view_finance_overview":"Finanz\u00fcbersicht anzeigen","view_gantt":"Ansicht Gantt","view_milestones":"Meilensteine anzeigen","view_task_attachments":"Aufgabenanh\u00e4nge anzeigen","view_task_checklist_items":"Aufgaben-Checklistenelemente anzeigen","view_task_comments":"Aufgabenkommentare anzeigen","view_task_total_logged_time":"Gesamte protokollierte Zeit der Aufgabe anzeigen","view_tasks":"Aufgaben anzeigen","view_team_members":"Teammitglieder anzeigen","view_timesheets":"Arbeitszeittabellen anzeigen","visible_tables":"Sichtbare Tabellen"},"projects":"Projekte","proposal":{"accept":"AKZEPTIEREN","accepted":"AKZEPTIERT","adjustment":"Einstellung","amount":"Menge","amount_due":"Offener Betrag","assigned":"Zugewiesen","authorized_signature":"Autorisierte Unterschrift","bank":"Bank","bill_to":"Gesetzesentwurf f\u00fcr","comments":"Bemerkungen","convert":"Konvertieren","convert_proposal":"Vorschlag konvertieren","date":"Datum","decline":"ABLEHNEN","declined":"ABGELEHNT","discount":"Rabatt","draft":"ENTWURF","drafted":"Entworfen","edit_proposal":"Vorschlag bearbeiten","item":"Produkt","lead":"F\u00fchren","mark_as_accepted":"Als akzeptiert markieren","mark_as_declined":"Als abgelehnt markieren","mark_as_draft":"Als Entwurf markieren","mark_as_open":"Als offen markieren","mark_as_revised":"Als \u00fcberarbeitet markieren","mark_as_send":"Als senden markieren","member":"Mitglied","new_proposal":"Neuer Vorschlag","no_payments_available":"Keine Zahlung verf\u00fcgbar","no_proposal_available":"Kein Vorschlag verf\u00fcgbar.","no_proposal_found":"Kein Vorschlag gefunden.","offline_payment":"Offline-Zahlung","online_payment":"Onlinebezahlung","open":"\u00d6FFNEN","open_till":"\u00d6ffnen Sie bis","pay_now":"ZAHLEN SIE JETZT","payment":"Zahlung","proposal":"Vorschlag","proposal_date":"Vorschlagsdatum","proposal_details":"Angebotsdetails","proposal_not_found":"Vorschlag nicht gefunden.","proposal_number":"Angebotsnummer","proposal_overview":"VORSCHLAGS\u00dcBERSICHT","proposal_pdf":"Vorschlag PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"Angebot erfolgreich gespeichert.","proposal_to":"Vorschlag an","proposal_updated_successfully":"Angebot erfolgreich aktualisiert.","qty":"Menge","rate":"Bewertung","related":"verbunden","revised":"\u00dcBERARBEITET","save_and_send":"Speichern & senden","save_as_draft":"Als Entwurf speichern","sent":"GESCHICKT","ship_to":"Ausliefern","status":"Angebotsstatus","sub_total":"Zwischensumme","subject":"Gegenstand","task":"Aufgabe","taxes":"Steuern","to":"Zu","total":"Gesamt","total_paid":"Ganz bezahlt","total_proposal":"Gesamtvorschlag","transactions":"Transaktionen","view_proposal_as_customer":"Angebot als Kunde anzeigen"},"proposals":"Vorschl\u00e4ge","range":{"last_30":"Letzte 30 Tage","last_month":"Im vergangenen Monat","last_week":"Letzte Woche","this_month":"Diesen Monat","this_week":"In dieser Woche","today":"Heute"},"register":{"already_have_an_account":"Sie haben bereits ein Konto?","choose":"W\u00e4hlen","confirm_password":"Best\u00e4tige das Passwort","email":"Email","first_name":"Vorname","last_name":"Nachname","password":"Passwort","phone":"Telefon","profile_picture":"Profilbild","register":"Registrieren","sign_in":"Anmelden"},"reminder":{"add_new":"Neue hinzuf\u00fcgen","description":"Beschreibung","edit_reminder":"Erinnerung bearbeiten","email_status":"E-Mail-Status","is_notified":"Wird benachrichtigt","new_reminder":"Neue Erinnerung","no":"Nein","note":"Notiz","note_text":"Bitte beachten Sie, dass Sie die UTC-Datumszeit ausw\u00e4hlen m\u00fcssen, da die Cronjobs Erinnerungen gem\u00e4\u00df UTC-Zeit senden.","notified_date":"Benachrichtigungsdatum","reminder_saved_successfully":"Erinnerung erfolgreich gespeichert.","reminder_to":"Erinnerung an","reminder_updated_successfully":"Erinnerung erfolgreich aktualisiert.","send_email_reminder":"Erinnerungs-E-Mail senden","sent":"Gesendet","set_reminder":"Erinnerung einstellen","ticket_reminder":"Ticketerinnerung","yes":"Ja"},"reminders":"Erinnerungen","reset":{"confirm_password":"Best\u00e4tige das Passwort","email":"Email","password":"Passwort","recalled_your_login_info":"Haben Sie Ihre Anmeldedaten abgerufen?","reset_password":"Passwort zur\u00fccksetzen","set_a_new_password":"Legen Sie ein neues Passwort fest","sign_in":"Anmelden"},"sales":"Der Umsatz","service":{"add":"Hinzuf\u00fcgen","edit_service":"Service bearbeiten","name":"Name","new_service":"Neuer Service","no_service_available":"Kein Service verf\u00fcgbar.","no_service_found":"Kein Service gefunden.","service_saved_successfully":"Dienst erfolgreich gespeichert.","service_updated_successfully":"Dienst erfolgreich aktualisiert.","service_used_somewhere_else":"Dienst woanders verwendet."},"services":"Dienstleistungen","setting":{"application_name":"Name der Anwendung","choose":"W\u00e4hlen","company_domain":"Unternehmensdom\u00e4ne","current_version":"Aktuelle Version","favicon":"Favicon","file_type":"Dateityp","logo":"Firmenlogo","setting_updated_successfully":"Einstellung erfolgreich aktualisiert."},"settings":"die Einstellungen","staff":"Mitarbeiter","status":{"additional_contact":"Zus\u00e4tzlicher Kontakt","answered":"Antwortete","attempted":"Versucht","cancelled":"Abgesagt","closed":"Geschlossen","contacted":"Kontaktiert","finished":"Fertig","in_progress":"In Bearbeitung","new_opportunity":"Neue Chance","not_attempted":"Nicht versucht","not_started":"Nicht angefangen","on_hold":"In Wartestellung","open":"\u00d6ffnen"},"success":"Erfolg","support":"Unterst\u00fctzung","tag":{"add":"Hinzuf\u00fcgen","add_new_tag":"Neues Tag hinzuf\u00fcgen","description":"Beschreibung","edit_tag":"Tag bearbeiten","name":"Name","new_tag":"Neuer Tag","no_tag_available":"Kein Tag verf\u00fcgbar.","no_tag_found":"Kein Tag gefunden.   ","tag_details":"Tag-Details","tag_not_found":"Tag nicht gefunden.","tag_saved_successfully":"Tag erfolgreich gespeichert.","tag_updated_successfully":"Tag erfolgreich aktualisiert."},"tags":"Stichworte","task":{"awaiting_feedback":"Erwarte Feedback","billable":"Abrechnungsf\u00e4hig","completed":"Abgeschlossen","due_date":"Geburtstermin","edit_task":"Aufgabe bearbeiten","hourly_rate":"Stundensatz","in_progress":"In Bearbeitung","name":"Name","new_task":"Neue Aufgabe","no_task_available":"Keine Aufgabe verf\u00fcgbar.","not_started":"Nicht angefangen","priority":"Priorit\u00e4t","public":"\u00d6ffentlichkeit","related_to":"Bez\u00fcglich","start_date":"Anfangsdatum","status":"Status","subject":"Gegenstand","task_details":"Aufgabendetails","task_saved_successfully":"Aufgabe erfolgreich gespeichert.","task_status_updated_successfully":"Aufgabenstatus erfolgreich aktualisiert.","task_updated_successfully":"Aufgabe erfolgreich aktualisiert.","testing":"Testen","ticket":"Fahrkarte"},"tasks":"Aufgaben","tax_rate":{"edit_tax_rate":"Steuersatz bearbeiten","new_tax_rate":"Neuer Steuersatz","no_tax_rate_available":"Kein Steuersatz verf\u00fcgbar.","no_tax_rate_found":"Kein Steuersatz gefunden.","tax_rate":"Steuersatz","tax_rate_not_found":"Steuersatz nicht gefunden.","tax_rate_saved_successfully":"Steuersatz erfolgreich gespeichert.","tax_rate_updated_successfully":"Steuersatz erfolgreich aktualisiert."},"tax_rates":"Steuers\u00e4tze","this_week_payments":"Zahlungen dieser Woche","ticket":{"add":"Hinzuf\u00fcgen","added_by":"Hinzugef\u00fcgt von","assign_to":"Zuweisen","attachments":"Anh\u00e4nge","body":"K\u00f6rper","cc":"CC","contact":"Kontakt","department":"Abteilung","details":"Einzelheiten","edit_ticket":"Ticket bearbeiten","email":"Email","name":"Name","new_ticket":"Neues Ticket","no_ticket_available":"Kein Ticket verf\u00fcgbar.","no_ticket_found":"Kein Ticket gefunden.","note":"Hinweis","predefined_reply":"Vordefinierte Antwort","priority":"Priorit\u00e4t","reminder":"Erinnerung","service":"Bedienung","subject":"Gegenstand","tags":"Stichworte","task":"Aufgabe","ticket_details":"Ticketdetails","ticket_not_found":"Ticket nicht gefunden.","ticket_saved_successfully":"Ticket erfolgreich gespeichert.","ticket_status_updated_successfully":"Ticketstatus erfolgreich aktualisiert.","ticket_to_contact":"Ticket zum Kontakt","ticket_updated_successfully":"Ticket erfolgreich aktualisiert.","ticket_without_contact":"Ticket ohne Kontakt","tickets_status":"Ticketstatus","you_can_add_multiples_images_and_files":"Sie k\u00f6nnen mehrere Bilder und Dateien hinzuf\u00fcgen"},"ticket_priorities":"Ticketpriorit\u00e4t","ticket_priority":{"add":"Hinzuf\u00fcgen","add_new_ticket_priority":"Neue Ticketpriorit\u00e4t hinzuf\u00fcgen","edit_ticket_priority":"Ticketpriorit\u00e4t bearbeiten","name":"Name","new_ticket_priority":"Neue Ticketpriorit\u00e4t","no_ticket_priority_available":"Keine Ticketpriorit\u00e4t verf\u00fcgbar.","no_ticket_priority_found":"Keine Ticketpriorit\u00e4t gefunden.","ticket_priority_not_found":"Ticketpriorit\u00e4t nicht gefunden.","ticket_priority_saved_successfully":"Ticketpriorit\u00e4t erfolgreich gespeichert.","ticket_priority_updated_successfully":"Ticketpriorit\u00e4t erfolgreich aktualisiert.","ticket_priority_used_somewhere_else":"Ticketpriorit\u00e4t an anderer Stelle verwendet."},"ticket_status":{"add":"Hinzuf\u00fcgen","add_new_ticket_status":"Neuen Ticketstatus hinzuf\u00fcgen","color":"Farbe","edit_ticket_status":"Ticketstatus bearbeiten","name":"Name","new_ticket_status":"Neuer Ticketstatus","status_order":"Statusreihenfolge","ticket_status":"Ticketstatus","ticket_status_saved_successfully":"Ticketstatus erfolgreich gespeichert.","ticket_status_updated_successfully":"Ticketstatus erfolgreich aktualisiert.","ticket_status_used_somewhere_else":"Ticketstatus an anderer Stelle verwendet."},"tickets":"Tickets","translation_manager":"\u00dcbersetzungsmanager","translator_manager":{"edit_language":"Sprache bearbeiten","language_added_successfully":"Sprache erfolgreich hinzugef\u00fcgt.","language_short_code":"Bitte Kurzcode der Sprache eingeben. dh Englisch = en","language_updated_successfully":"Sprache erfolgreich aktualisiert.","translation":"\u00dcbersetzung"},"user":{"change_language":"Sprache \u00e4ndern","change_password":"\u00c4ndere das Passwort","edit_profile":"Profil bearbeiten","email":"Email","first_name":"Vorname","language":"Sprache","language_updated_successfully":"Sprache erfolgreich aktualisiert.","last_name":"Nachname","logout":"Ausloggen","name":"Name","password":"Passwort","password_confirmation":"Best\u00e4tige das Passwort","password_updated_successfully":"Passwort erfolgreich aktualisiert.","phone":"Telefon","profile":"Profil","profile_updated_successfully":"Profil erfolgreich aktualisiert.","return_to_admin":"Zur\u00fcck zum Administrator"},"users":"Benutzer","weekdays":{"fri":"FR","mon":"MO","sat":"Sa","sun":"SONNE","thu":"DO","tue":"DI","wed":"HEIRATEN"}},"de.pagination":{"next":"N\u00e4chster &raquo;","previous":"&laquo; Bisherige"},"de.passwords":{"reset":"Dein Passwort wurde zur\u00fcck gesetzt!","sent":"Wir haben Ihren Link zum Zur\u00fccksetzen Ihres Passworts per E-Mail gesendet!","throttled":"Bitte warten Sie, bevor Sie es erneut versuchen.","token":"Dieses Token zum Zur\u00fccksetzen des Passworts ist ung\u00fcltig.","user":"Wir k\u00f6nnen keinen Benutzer mit dieser E-Mail-Adresse finden. "},"de.validation":{"accepted":"Das :attribute muss akzeptiert werden.","active_url":"Das :attribute ist keine g\u00fcltige URL.","after":"Das :attribute muss ein Datum nach :date sein.","after_or_equal":"Das :attribute muss ein Datum nach oder gleich :date sein.","alpha":"Das :attribute darf nur Buchstaben enthalten.","alpha_dash":"Das :attribute darf nur Buchstaben, Zahlen, Bindestriche und Unterstriche enthalten.","alpha_num":"Das :attribute darf nur Buchstaben und Zahlen enthalten.","array":"Das :attribute muss ein Array sein.","attributes":[],"before":"Das :attribute muss ein Datum vor :date sein.","before_or_equal":"Das :attribute muss ein Datum vor oder gleich :date sein.","between":{"array":"Das :attribute muss zwischen :min und :max Elementen.","file":"Das :attribute muss zwischen :min und :max Kilobyte.","numeric":"Das :attribute muss zwischen :min und :max.","string":"Das :attribute muss zwischen den Zeichen :min und :max."},"boolean":"Das :attribute muss wahr oder falsch sein.","confirmed":"Die Best\u00e4tigung des :attribute stimmt nicht \u00fcberein.","custom":{"attribute-name":{"rule-name":"benutzerdefinierte Nachricht"}},"date":"Das :attribute ist kein g\u00fcltiges Datum.","date_equals":"Das :attribute muss ein Datum sein, das gleich :date ist.","date_format":"Das :attribute stimmt nicht mit dem Format :format \u00fcberein.","different":"Das :attribute und :other muss unterschiedlich sein.","digits":"Das :attribute muss sein: digits Ziffern.","digits_between":"Das :attribute muss zwischen den Ziffern :min und :max liegen.","dimensions":"Das :attribute hat ung\u00fcltige Bildabmessungen.","distinct":"Das :attribute hat einen doppelten Wert.","email":"Das :attribute muss eine g\u00fcltige E-Mail-Adresse sein.","ends_with":"Das :attribute muss mit einem der folgenden Werte enden :values.","exists":"Das :attribute selected ist ung\u00fcltig.","file":"Das :attribute muss eine Datei sein.","filled":"Das :attribute muss einen Wert haben.","gt":{"array":"Das :attribute muss mehr als :value-Elemente enthalten.","file":"Das :attribute muss gr\u00f6\u00dfer sein als :value Kilobyte.","numeric":"Das :attribute muss gr\u00f6\u00dfer als: value sein.","string":"Das :attribute muss gr\u00f6\u00dfer sein als :value Zeichen."},"gte":{"array":"Das :attribute muss mindestens :value-Elemente enthalten.","file":"Das :attribute muss gr\u00f6\u00dfer oder gleich :value Kilobyte sein.","numeric":"Das :attribute muss gr\u00f6\u00dfer oder gleich :value sein.","string":"Das :attribute muss gr\u00f6\u00dfer oder gleich :value zeichen sein."},"image":"Das :attribute muss ein Bild sein.","in":"Das :attribute selected ist ung\u00fcltig.","in_array":"Das :attribute existiert nicht in :other.","integer":"Das :attribute muss eine Ganzzahl sein.","ip":"Das :attribute muss eine g\u00fcltige IP-Adresse sein.","ipv4":"Das :attribute muss eine g\u00fcltige IPv4-Adresse sein.","ipv6":"Das :attribute muss eine g\u00fcltige IPv6-Adresse sein.","json":"Das :attribute muss eine g\u00fcltige JSON-Zeichenfolge sein.","lt":{"array":"Das :attribute muss weniger als :value-Elemente enthalten.","file":"Das :attribute muss kleiner als :value Kilobyte sein.","numeric":"Das :attribute muss kleiner als :value sein.","string":"Das :attribute muss kleiner als :value sein."},"lte":{"array":"Das :attribute darf nicht mehr als :value-Elemente enthalten.","file":"Das :attribute muss kleiner oder gleich :value Kilobyte sein.","numeric":"Das :attribute muss kleiner oder gleich :value sein.","string":"Das :attribute muss kleiner oder gleich :value zeichen sein."},"max":{"array":"Das :attribute darf nicht mehr als :max Elemente enthalten.","file":"Das :attribute darf nicht gr\u00f6\u00dfer als :max Kilobyte sein.","numeric":"Das :attribute darf nicht gr\u00f6\u00dfer sein als :max.","string":"Das :attribute darf nicht gr\u00f6\u00dfer als :max Zeichen sein."},"mimes":"Das :attribute muss eine Datei vom Typ :values sein.","mimetypes":"Das :attribute muss eine Datei vom Typ :values sein.","min":{"array":"Das :attribute muss mindestens :min Elemente enthalten.","file":"Das :attribute muss mindestens :min Kilobyte betragen.","numeric":"Das :attribute muss mindestens :min sein.","string":"Das :attribute muss mindestens :min Zeichen enthalten."},"not_in":"Das :attribute selected ist ung\u00fcltig.","not_regex":"Das :attribute ist ung\u00fcltig.","numeric":"Das :attribute muss eine Zahl sein.","password":"Das Passwort ist inkorrekt.","present":"Das :attribute muss vorhanden sein.","regex":"Das :attribute ist ung\u00fcltig.","required":"Das Feld :attribute ist erforderlich.","required_if":"Das Feld :attribute ist erforderlich, wenn :other :value ist.","required_unless":"Das :attribute ist erforderlich, es sei denn :other befindet sich in :values.","required_with":"Das :attribute ist erforderlich, wenn :values vorhanden ist.","required_with_all":"Das :attribute ist erforderlich, wenn :value vorhanden sind.","required_without":"Das Feld :attribute ist erforderlich, wenn :value nicht vorhanden sind.","required_without_all":"Das Feld :attribute ist erforderlich, wenn keiner der :value vorhanden ist.","same":"Das :attribute und :other m\u00fcssen \u00fcbereinstimmen.","size":{"array":"Das :attribute muss Elemente der: size enthalten.","file":"Das :attribute muss: size Kilobyte sein.","numeric":"Das :attribute muss: size sein.","string":"Das :attribute muss Zeichen der: size sein."},"starts_with":"Das :attribute muss mit einem der folgenden Werte beginnen :value.","string":"Das :attribute muss eine Zeichenfolge sein.","timezone":"Das :attribute muss eine g\u00fcltige Zone sein.","unique":"Das :attribute wurde bereits \u00fcbernommen.","uploaded":"Das :attribute konnte nicht hochgeladen werden.","url":"Das :attribute ist ung\u00fcltig.","uuid":"Das :attribute muss eine g\u00fcltige UUID sein."},"en.auth":{"failed":"These credentials do not match our records.","password":"The provided password is incorrect.","throttle":"Too many login attempts. Please try again in :seconds seconds."},"en.messages":{"activity_log":{"activity_logs":"Activity Logs","loading_more_date":"Loading More Data","sorry_we_not_find_any_data":"Sorry, we can't find any data, make at least 1 entry","we_could_find_any_data":"We couldn't find any data"},"address":{"city":"City","country":"Country","state":"State","street":"Street","zip_code":"Zip code"},"announcement":{"add":"Add","announcement_date":"Announcement Date","announcement_details":"Announcement Details","announcement_not_found":"Announcement Not Found.","announcement_saved_successfully":"Announcement saved successfully.","announcement_updated_successfully":"Announcement updated successfully.","edit_announcement":"Edit Announcement","message":"Message","new_announcement":"New Announcement","no_announcement_available":"No Announcement Available.","no_announcement_found":"No Announcement Found.","show_my_name":"Show My Name","show_to_clients":"Show To Clients","show_to_staff":"Show To Staff","subject":"Subject"},"announcements":"Announcements","article":{"add":"Add","article_details":"Article Details","article_not_found":"Article Not Found.","article_saved_successfully":"Article saved successfully.","article_updated_successfully":"Article updated successfully.","attachment":"Attachment","description":"Description","disabled":"Disabled","edit_article":"Edit Article","group":"Group","internal_article":"Internal Article","new_article":"New Article","no_article_available":"No Article Available.","no_article_found":"No Article Found.","subject":"Subject","upload_image":"Upload Image"},"article_group":{"add_new_article_group":"Add New Article Group","article_group_saved_successfully":"Article Group Saved successfully.","article_group_updated_successfully":"Article Group updated successfully.","article_group_used_somewhere_else":"Article Group used somewhere else.","article_groups":"Article Groups","color":"Color","edit_article_group":"Edit Article Group","group_name":"Group Name","new_article_group":"New Article Group","order":"Order"},"articles":"Articles","billing_type":"Billing Type","calendars":"Calendars","change_password":{"change_information_about_yourself_on_this_page":" Change information about yourself on this page.","confirm_password":"Confirm Password","current_password":"Current Password","edit_profile":"Edit Profile","new_password":"New Password"},"client_dashboard":"Client Dashboard","cms":"CMS","comment":{"add_comment":"Add Comment","added_by":"Added By","comments_saved_successfully":"Comment saved successfully.","comments_updated_successfully":"Comment updated successfully.","edit_comment":"Edit Comment","new_comment":"New Comment","no_comments_added_yet":"No Comments Added Yet"},"comments":"Comments","common":{"action":"Action","active":"Active","add":"Add","admin_note":"Admin Note","announcement":"Announcement","apply":"Apply","article":"Article","article_group":"Article Group","assignee":"Assignee","attachment_deleted":"Attachment has been deleted.","back":"Back","cancel":"Cancel","choose":"Choose","client_note":"Client Note","completed":"Completed","contract_type":"Contract Type","country":"Country","created_on":"Created On","custom":"Custom","customer":"Customer","customer_group":"Customer Group","data_base_entries":"Showing _START_ to _END_ of _TOTAL_ entries","deactive":"Deactive","default_country_code":"Default Country Code","delete":"Delete","delete_attachment":"Are you sure want to delete this \"Attachment\" ?","delete_confirm":"Please type","delete_confirm_common":"Are you sure want to delete this","delete_note":"Are you sure want to delete this \"Note\" ?","deleted":"Deleted!","department":"Department","description":"Description","download":"Download","download_as_pdf":"Download As PDF","drafted":"Drafted","edit":"Edit","email":"Email","expense":"Expense","expense_category":"Expense Category","filter_by":"(filtered from _MAX_ total entries)","from":"From","goal":"Goal","has_been_delete":" has been deleted.","incomes_vs_expenses":"Incomes Vs Expenses","last_updated":"Last Updated","lead":"Lead","lead_source":"Lead Source","menu_entry":"Show _MENU_ entries","n\/a":"N\/A","name":"Name","no":"No","no_data_available_in_table":"No Data Available In Table","no_entry":"Showing 0 to 0 of 0 entries","no_matching":"No matching records found","note":"Note","note_delete":"Note has been deleted.","of":"Of","ok":"OK","payment_mode":"Payment Mode","pending":"Pending","predefined_reply":"Predefined Reply","product_1":"Product","product_group":"Product Group","product_header":"Product","proposal":"Proposal","quantity_is_not_greater_than":"Quantity is not greater than 9999999","save":"Save","search":"Search","search_results":"Your Search Results Goes Here...","service":"Service","showing":"Showing","status":"Status","tag":"Tag","tax_rate":"Tax Rate","term_and_conditions":"Term & Conditions","this_week":"The Week","ticket_priority":"Ticket Priority","to":"To","to_delete_this":"to delete this","total_amount":"Total Amount","type_delete":"Please type \"delete\" to delete this","view":"View","weekly_payment_records":"Weekly Payment Records","yes":"Yes"},"company":{"address":"Address","city":"City","company":"Company Name","company_information_format":"Company Information Format (PDF and HTML)","country_code":"Country Code","currency":"Currency","details":"Company Details","phone":"Phone","state":"State","vat_number":"VAT Number","website":"Website","zip_code":"Zip Code"},"company_information":"Company Information","contact":{"active":"Active","by_deleting_this_contact":"By deleting this contact all its project will be deleted.","contact_details":"Contact Details","contact_not_found":"Contact Not Found.","contact_saved_successfully":"Contact saved successfully.","contact_status_updated_successfully":"Contact status updated successfully.","contact_updated_successfully":"Contact updated successfully.","contract":"Contract","contracts":"Contracts","credit_note":"Credit Note","customer_name":"Customer Name","deactive":"Deactive","delete_contact_confirm":"Are you sure want to delete this contact?","edit_contact":"Edit Contact","email_notifications":"Email Notifications","estimate":"Estimate","estimates":"Estimates","first_name":"First Name","full_name":"Full Name","impersonate":"Impersonate","invoice":"Invoice","invoices":"Invoices","last_name":"Last Name","make_sure_to_set_appropriate_permissions_for_this_contact":"Make sure to set appropriate permissions for this contact","new_contact":"New Contact","no_contact_available":"No Contact Available.","no_contact_found":"No Contact Found.","password":"Password","permissions":"Permissions","position":"Position","primary_contact":"Primary Contact","project":"Project","projects":"Projects","proposals":"Proposals","send_password_email":"Send SET Password Email","send_welcome_email":"Do Not Send Welcome Email","support":"Support","task":"Task","tickets":"Tickets"},"contacts":"Contacts","contract":{"add":"Add","authorized_signature":"Authorized Signature","contract_details":"Contract Details","contract_list":"Contract List","contract_not_found":"Contract Not Found.","contract_pdf":"Contract PDF","contract_summary":"Contract Summary","contract_type_id":"Contract Type","contract_value":"Contract Value","contracts_by_type":"Contracts By Type","contracts_expiring_this_month":"Contracts Expiring This Month","contracts_saved_successfully":"Contract saved successfully.","contracts_updated_successfully":"Contract updated successfully.","contracts_value_by_type":"Contracts Value By Type","customer_id":"Customer","description":"Description","details":"Details","edit_contract":"Edit Contract","end_date":"End Date","is_hide":"Hide from customer","is_trash":"Trash","new_contract":"New Contract","no_contract_available":"No Contract Available","no_contract_found":"No Contract Found.","sign":"Sign","start_date":"Start Date","subject":"Subject","task":"Task"},"contract_type":{"add_new_contract_type":"Add New Contract Type","contract_by_type":"Contract By Type","contract_type_saved_successfully":"Contract Type saved successfully.","contract_type_updated_successfully":"Contract Type updated successfully.","contract_type_used_somewhere_else":"Contract Type used somewhere else.","contract_value_by_type":"Contract Value By Type","edit_contract_type":"Edit Contract Type","new_contract_type":"New Contract Type"},"contract_types":"Contract Types","contracts":"Contracts","countries":"Countries","country":{"add":"Add","country_not_found":"Country Not Found.","country_saved_successfully":"Country saved successfully.","country_updated_successfully":"Country updated successfully.","country_used_somewhere_else":"Country used somewhere else.","edit_country":"Edit Country","name":"Name","new_country":"New Country","no_country_available":"No Country Available.","no_country_found":"No Country Found."},"credit_note":{"authorized_signature":"Authorized Signature","client_note":"Note","closed":"Closed","credit_note":"Credit Note","credit_note_date":"Credit Note Date","credit_note_details":"Credit Note Details","credit_note_details_updated_successfully":"Credit Note details updated successfully.","credit_note_not_found":"Credit Note Not Found.","credit_note_number":"Credit Note Number","credit_note_pdf":"Credit Note PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"Credit Note saved successfully.","credit_note_updated_successfully":"Credit Note updated successfully.","drafted":"Drafted","edit_credit_note":"Edit Credit Note","invoice_credited":"Invoice Credited","mark_as_closed":"Mark As Closed","mark_as_draft":"Mark As Draft","mark_as_open":"Mark As Open","mark_as_void":"Mark As Void","new_credit_note":"New Credit Note","no_credit_note_available":"No Credit Note Available.","no_credit_note_found":"No Credit Note Found.","open":"Open","quantity_is_not_greater_than":"Quantity is not greater than 9999999","reference":"Reference","refunds":"Refunds","save_and_send":"Save & Send","save_as_draft":"Save As Draft","terms_and_conditions":"Terms & Conditions","title":"Title","view_credit_note_as_customer":"View Credit Note As Customer","void":"Void"},"credit_notes":"Credit Notes","customer":{"add_address_details":"Add Address Details","address":"Address","address_details":"Address Details","address_not_found":"Address Details Not Found.","billing_address":"Billing Address","billing_address_details_not_available":"Billing Address Details Not Available","by_deleting_this_customer":"By deleting this customer all its project, contact, invoice, estimate, credit note, proposal and contract will be deleted.","city":"City","company_name":"Company Name","copy_billing_address":"Copy Billing Address","country":"Country","currency":"Currency","customer_details":"Customer Details","customer_saved_successfully":"Customer saved successfully.","customer_updated_successfully":"Customer updated successfully.","customers":"Customers","default_language":"Default Language","delete_customer_confirm":"Are you sure want to delete this customer?","do_not_fill_shipping_address_customer_invoices":"Do not fill shipping address information if you won't use shipping address on customer invoices","edit_customer":"Edit Customer","groups":"Groups","new_customer":"New Customer","no_customer_available":"No Customer Available.","no_customer_found":"No Customer Found.","phone":"Phone","same_as_a_customer_info":"Same as Customer Info","search_customer":"Search Customer","shipping_address":"Shipping Address","shipping_address_details_not_available":"Shipping Address Details Not Available","state":"State","street":"Street","total_contact":"Total Contact","total_customers":"Total Customers","total_project":"Total Project","type":"Type","vat_number":"VAT Number","website":"Website","zip_code":"Zip Code"},"customer_group":{"action":"Action","customer_group_saved_successfully":"Customer Group saved successfully.","customer_group_updated_successfully":"Customer Group updated successfully.","description":"Description","edit_customer_group":"Edit Customer Group","name":"Name","new_customer_group":"New Customer Group"},"customer_groups":"Customer Groups","customers":"Customers","dashboard":"Dashboard","department":{"department_not_found":"Department Not Found.","department_saved_successfully":"Department saved successfully.","department_updated_successfully":"Department updated successfully.","departments":"Departments","edit_department":"Edit Department","hide_from_clients":"Hide from clients","new_department":"New Department","no_department_available":"No Department Available.","no_department_found":"No Department Found."},"edit_profile":{"change_password":"Change Password","edit_profile":"Edit Profile","hello":"Hello","hi":"Hi","login":"Login","login_register":"Login \/ Register","logout":"Logout","mark_all_as_read":"Mark All As Read","notification":"Notifications","register":"Register","welcome":"Welcome"},"email":{"email":"Email","forgot_password":"Forgot Password","recalled_your_login_info":"Recalled your login info?","reset_password":"Reset Password","send_reset_link":"Send Reset Link","sign_in":"Sign In"},"email_template":{"available_merge_fields":"Available merge fields","disabled":"Disabled","edit_email_template":"Edit Email Template","email_message":"Email Message","enable":"Enable","from_name":"From Name","send_plain_text":"Send as Plaintext","subject":"Subject","template_name":"Template Name"},"email_templates":"Email Templates","error":"Error","estimate":{"accepted":"Accepted","adjustment":"Adjustment","amount":"Amount","amount_due":"Amount Due","authorized_signature":"Authorized Signature","bill_to":"Bill To","client_note":"Client Note","convert_estimate":"Convert Estimate","convert_estimate_to_invoice":"Convert Estimate To Invoice Successfully.","declined":"Declined","discount":"Discount","draft":"Draft","drafted":"Drafted","edit_estimate":"Edit Estimate","estimate":"Estimate","estimate_date":"Estimate Date","estimate_details":"Estimate Details","estimate_not_found":"Estimate Not Found.","estimate_number":"Estimate Number","estimate_overview":"ESTIMATE OVERVIEW","estimate_pdf":"Estimate PDF","estimate_prefix":"EN-","estimate_saved_successfully":"Estimate saved successfully.","estimate_status_updated_successfully":"Estimate status updated successfully.","estimate_updated_successfully":"Estimate updated successfully.","expired":"Expired","expiry_date":"Expiry Date","item":"Product","mark_as_accepted":"Mark As Accepted","mark_as_declined":"Mark As Declined","mark_as_draft":"Mark As Draft","mark_as_expired":"Mark As Expired","mark_as_send":"Mark As Sent","more":"More","new_estimate":"New Estimate","no_estimate_available":"No Estimate Available","no_estimate_found":"No Estimate Found.","not_sent":"Not Sent","qty":"Qty","rate":"Rate","save_and_send":"Save & Send","save_as_draft":"Save As Draft","sent":"Sent","ship_to":"Ship To","status":"Status","sub_total":"Sub Total","task":"Task","taxes":"Taxes","terms_conditions":"Terms & Conditions","title":"Title","total":"Total","total_estimates":"Total Estimates","total_paid":"Total Paid","view_estimate_as_customer":"View Estimate As Customer"},"estimates":"Estimates","expense":{"add":"Add","amount":"Amount","amount_with_tax":"Amount With Tax","apply_tax":"Apply Tax","apply_tax_message":"Subtract Tax total from amount","attachment":"Attachment","auto_create_invoice":"Auto Create Invoice","billable":"Billable","choose_file":"Choose file","currency":"Currency","customer":"Customer","details":"Details","edit_expense":"Edit Expense","expense_amount":"Expense Amount","expense_category":"Expense Category","expense_category_by_chart":"Expense Category By Chart","expense_date":"Expense Date","expense_details":"Expense Details","expense_list":"Expense List","expense_saved_successfully":"Expense saved successfully.","expense_updated_successfully":"Expense updated successfully.","name":"Name","new_expense":"New Expense","no_expense_available":"No Expense Available.","no_expense_found":"No Expense Found.","note":"Note","notes":"Notes","payment_mode":"Payment Mode","preview_attachment":"Preview Attachment","reference":"Reference","reminders":"Reminder","send_email":"Send the invoice to customer email when expense re-created","tax_1":"Tax 1 (in %)","tax_2":"Tax 2 (in %)","tax_applied":"Tax Applied","view_attachment":"View Attachment"},"expense_by_category":"Expense By Category","expense_categories":"Expense Categories","expense_category":{"add_new_expense_category":"Add New Expense Category","edit_category":"Edit Expense Category","expense_categories":"Expense Categories","expense_category":"Expense Category","expense_category_saved_successfully":"Expense Category saved successfully.","expense_category_updated_successfully":"Expense Category updated successfully.","expense_category_used_somewhere_else":"Expense Category used somewhere else.","new_category":"New Expense Category"},"expenses":"Expenses","general":"General","goal":{"achievement":"Achievement","add":"Add","description":"Description","edit_goal":"Edit Goal","end_date":"End Date","goal_details":"Goal Details","goal_id":"Goal Type","goal_saved_successfully":"Goal saved successfully.","goal_type":"Goal Type","goal_updated_successfully":"Goal updated successfully.","is_not_notify":"Notify staff members when goal failed to achieve","is_notify":"Notify staff members when goal achieve","member":"Member","new_goal":"New Goal","no_goal_available":"No Goal Available.","no_goal_found":"No Goal Found.","progress":"Progress","start_date":"Start Date","subject":"Subject","user_id":"Staff Member"},"goal_type":{"description":"Description","edit_goal_type":"Edit Goal Type","name":"Name","new_goal_type":"New Goal Type"},"goals":"Goals","incomes":"Incomes","invoice":{"activity_log":"Activity Log","add_item":"Add Product","add_shipping_address":"Add shipping address","adjustment":"Adjustment","admin_note":"Admin Note","allowed_payment_modes_for_this_invoice":"Allowed Payment Modes","amount":"Amount","amount_due":"Amount Due","authorized_signature":"Authorized Signature","bank":"Bank","bill_tasks":"Bill Tasks","bill_to":"Bill to","cancelled":"Cancelled","client_note":"Client Note","currency":"Currency","customer":"Customer","discount":"Discount","discount_type":"Discount Type","draft":"Draft","drafted":"Drafted","due_date":"Due Date","edit_contract_type":"Edit Contract Type","edit_invoice":"Edit Invoice","fixed":"Fixed","hours":"Hours","hsn_tax":"HSN Tax Code","invoice":"Invoice","invoice_date":"Invoice Date","invoice_details":"Invoice Details","invoice_not_found":"Invoice Not Found.","invoice_number":"Invoice Number","invoice_overview":"INVOICE OVERVIEW","invoice_payments":"Invoice Payments","invoice_pdf":"Invoice PDF","invoice_prefix":"INV-","invoice_saved_successfully":"Invoice saved successfully.","invoice_updated_successfully":"Invoice updated successfully.","item":"Product","mark_as_cancelled":"Mark As Cancelled","mark_as_draft":"Mark As Draft","mark_as_paid":"Mark As Paid","mark_as_partially_paid":"Mark As Partially Paid","mark_as_sent":"Mark As Sent","more":"More","new_contract_type":"New Contract Type","new_invoice":"New Invoice","no_invoice_available":"No Invoice Available.","no_invoice_found":"No Invoice Found.","no_payments_available":"No payments available","not_sent":"Not Sent","notes":"Notes","offline_payment":"Offline Payment","online_payment":"Online Payment","overdue":"Overdue","paid":"Paid","paid_cap":"Paid","partially_paid":"Partially Paid","partially_paid_cap":"Partially Paid","pay_now":"Pay Now","payment":"Payment","payment_details":"Payment details","payments":"Payments","prevent_sending_overdue_reminders_for_this_invoice":"Prevent sending overdue reminders for this invoice","qty":"Qty","qty\/hours":"Qty\/Hours","qty_hours":"Qty\/Hours","quick_invoices_info":"Quick Invoices Info","recurring_invoice":"Recurring Invoice","reminders":"Reminders","sale_agent":"Sale Agent","save_and_send":"Save & Send","save_as_draft":"Save As Draft","ship_to":"Ship to","show_quantity_as":"Show quantity as","sub_total":"Sub Total","task":"Task","taxes":"Taxes","terms_conditions":"Terms & Conditions","title":"Title","total":"Total","total_invoices":"Total Invoices","total_paid":"Total Paid","transactions":"Transactions","unmark_as_cancelled":"Unmark As Cancelled","unpaid":"Unpaid","unpaid_cap":"Unpaid","view_invoice_as_customer":"View Invoice As Customer"},"invoices":"Invoices","kanban_list":"KANBAN List","kanban_view":"KANBAN View","last_week_payments":"Last Week Payments","lead":{"chart":"Chart","contact":"Contact","contacted_today":"Contacted Today","convert_to_customer":"Convert To Customer","customer":"Customer","date_contacted":"Date Contacted","details":"Details","edit_lead":"Edit Lead","estimate_budget":"Estimate Budget","lead_convert_customer":"Lead Convert Customer","lead_convert_customer_chart":"Lead Convert Customer Chart","lead_details":"Lead Details","lead_list":"Lead List","lead_not_found":"Lead Not Found.","lead_saved_successfully":"Lead saved successfully.","lead_status_updated_successfully":"Lead status updated successfully.","lead_updated_successfully":"Lead updated successfully.","leads_overview":"Leads Overview","member":"Member","name":"Name","new_lead":"New Lead","no_lead_available":"No Lead Available.","no_lead_found":"No Lead Found.","notes":"Notes","reminder":"Reminder","source":"Source","task":"Task"},"lead_convert_to_customer":"Lead Convert To Customer","lead_source":{"add":"Add","edit_lead_source":"Edit Lead Source","lead_source_count":"Lead Count","lead_source_not_found":"Lead Source Not Found.","lead_source_saved_successfully":"Lead Source saved successfully.","lead_source_updated_successfully":"Lead Source updated successfully.","lead_source_used_somewhere":"Lead Source used somewhere else.","name":"Name","new_lead_source":"New Lead Source","no_lead_source_available":"No Lead Source Available.","no_lead_source_found":"No Lead Source Found."},"lead_sources":"Lead Sources","lead_status":{"add":"Add","add_new_lead_status":"Add New Lead Status","color":"Color","edit_lead_status":"Edit Lead Status","lead_status":"Lead Status","lead_status_saved_successfully":"Lead Status saved successfully.","lead_status_updated_successfully":"Lead Status updated successfully.","lead_status_used_somewhere_else":"Lead Status used somewhere else.","name":"Name","new_lead_status":"New Lead Status","order":"Order"},"leads":"Leads","list_view":"List View","login":{"admin":"Admin","client":"Client","create_one":"Create One","don't have an account":"Don't have an account?","email":"Email","forgot_password":"Forgot Password","login":"Login","password":"Password","remember_me":"Remember Me"},"member":{"add":"Add","by_deleting_this_member":"By deleting this member all its project, proposal and goal will be deleted.","choose":"Choose","created_on":"Created On","default_language":"Default Language","delete_member_confirm":"Are you sure want to delete this member?","direction":"Direction","edit_member":"Edit Member","email":"Email","email_is_not_verified":"Email is not verified","email_is_verified":"Email is verified","email_verified":"Email Verified","email_verified_successfully":"Email Verified successfully.","email_verify":"Email Verify","facebook":"Facebook","first_name":"First Name","hourly_rate":"Hourly Rate","image":"Profile","is_administrator":"Administrator","is_enable":"Enable Two Factor Authentication","last_name":"Last Name","linkedin":"Linkedin","member_details":"Member Details","member_informations":"Member Informations","member_not_found":"Member Not Found.","member_saved_successfully":"Member saved successfully.","member_security":"Member Security","member_status_updated_successfully":"Member status updated successfully.","member_updated_successfully":"Member updated successfully.","new_member":"New Member","no_member_available":"No Member Available.","no_member_found":"No Member Found.","password":"Password","password_confirmation":"Confirm Password","permissions":"Permissions","phone":"Phone","profile":"Profile","resend_email_verification":"Resend Email Verification","send_welcome_email":"Send Welcome Email","skype":"Skype","staff_member":"Not Staff Member","total_members":"Total Members","verification_mail_has_been_sent":"Verification email has been sent successfully."},"members":"Members","menu_settings":"Menu Settings","months":{"apr":"Apr","aug":"Aug","dec":"Dec","feb":"Feb","jan":"Jan","jul":"Jul","jun":"Jun","mar":"Mar","may":"May","nov":"Nov","oct":"Oct","sep":"Sep"},"new_language":"New Language","no_matching_records_found":"No Matching Records Found","note":{"add_note":"Add Note","edit_note":"Edit Note","new_note":"New Note","no_notes_added_yet":"No Notes Added Yet","notes_saved_successfully":"Note saved successfully.","notes_updated_successfully":"Note updated successfully."},"notes":"Notes","notification":{"all_notification_read_successfully":"All Notification read successfully.","empty_notifications":"We couldn't find any notifications","mark_all_as_read":"Mark All As Read","notification_read_successfully":"Notification read successfully.","notifications":"Notifications"},"others":"Others","payment":{"amount":"Amount","amount_received":"Amount Received","date":"Date","new_payment":"New Payment","note":"Note","payment_date":"Payment Date","payment_mode":"Payment Mode","payment_saved_successfully":"Payment saved successfully.","send_mail_to_customer_contacts":"Do not send invoice payment recorded email to customer contacts","transaction_id":"Transaction ID","your_payment_is_completed":"Your Payment is successfully completed.","your_payment_is_ont_completed":"Your Payment is not completed."},"payment_mode":{"active":"Active","add_new_payment_mode":"Add New Payment Mode","bank_accounts":"Bank Accounts","edit_payment_mode":"Edit Payment Mode","expenses_only":"Expenses only","invoices_only":"Invoices only","new_payment_mode":"New Payment Mode","no_payment_mode_available":"No Payment Mode Available.","no_payment_mode_found":"No Payment Mode Found.","on_invoice_pdf":"on Invoice PDF","payment_mode_details":"Payment Mode Details","payment_mode_not_found":"Payment Mode Not Found.","payment_mode_saved_successfully":"Payment Mode saved successfully.","payment_mode_updated_successfully":"Payment Mode updated successfully.","payment_mode_used_somewhere_else":"Payment Mode used somewhere else.","selected_by_default_on_invoice":"Selected by default on invoice","show":"Show"},"payment_modes":"Payment Modes","placeholder":{"add_note":"Add Note...","add_product":"Add Product","bill_tasks":"Bill Tasks","contact_number_is_invalid_number":"Contact number is invalid number","invalid_country_code":"Invalid country code","invalid_number":"Invalid Number","search_customers":"Search Customers","search_menu":"Search Menu","select_article_group":"Select Article Group","select_assignee":"Select Assignee","select_billing_type":"Select Billing Type","select_contact":"Select Contacts","select_contract_type":"Select Contract Type","select_country":"Select Country","select_currency":"Select Currency","select_customer":"Select Customer","select_department":"Select Department","select_discount_type":"Select Discount Type","select_document_type":"Select discount type","select_email_status":"Select Email Status","select_email_template":"Select Email Template","select_expanse_category":"Select Expense Category","select_file":"Select File","select_goal":"Select Goal","select_goal_type":"Select Goal Type","select_group":"Select Groups","select_groups":"Select Groups","select_internal_article":"Select Internal Article","select_item":"Select Item","select_language":"Select Language","select_lead":" Select Lead","select_lead_source":"Select Lead Source","select_member":"Select Member","select_option":"Select Option","select_payment_mode":"Select Payment Mode","select_predefined_reply":"Select Predefined Reply","select_priority":"Select Priority","select_product":"Select Product","select_product_group":"Select Product Group","select_reminder_to":"Select Reminder To","select_sale_agent":"Select Sale Agent","select_service":"Select Service","select_show_to_client":"Select Show To Client","select_source":"Select Source","select_status":"Select Status","select_tags":"Select Tags","select_tax":"Select tax","select_tax1":"Select Tax 1","select_tax2":"Select Tax 2","select_template_type":"Select Template Type","select_ticket_priority":"Select Ticket Priority","too_long":"Too long","too_short":"Too short","valid_number":"Valid Number"},"please_enter_language_short_code":"Please enter language short code. i.e English = en.","predefined_replies":"Predefined Replies","predefined_reply":{"add":"Add","add_new_predefined_reply":"Add New Predefined Reply","body":"Body","edit_predefined_reply":"Edit Predefined Reply","new_predefined_reply":"New Predefined Reply","no_predefined_reply_available":"No Predefined Reply Available","no_predefined_reply_found":"No Predefined Reply Found.","predefined_reply_details":"Predefined Reply Details","predefined_reply_not_found":"Predefined Reply Not Found","predefined_reply_saved_successfully":"Predefined Reply saved successfully.","predefined_reply_updated_successfully":"Predefined Reply updated successfully.","reply_name":"Reply Name"},"product_group":{"add_new_product_group":"Add New Product Group","edit_product_group":"Edit Product Group","new_product_group":"New Product Group","product_group_saved_successfully":"Product Group saved successfully.","product_group_updated_successfully":"Product Group updated successfully.","product_group_used_somewhere_else":"Product Group used somewhere else."},"product_groups":"Product Groups","products":{"edit_product":"Edit Product","new_product":"New Product","product_group":"Product Group","product_saved_successfully":"Product saved successfully.","product_updated_successfully":"Product updated successfully.","products":"Products","rate":"Rate","tax":"Tax","title":"Title","unit":"Unit"},"profile":"Profile","project":{"admin_area":"Admin area","allow_customer_to":"Allow customer to","billing_type":"Billing Type","calculate_progress_through_tasks":"Calculate progress through tasks","cancelled":"Cancelled","comment_on_project_tasks":"Comment on project tasks","create_tasks":"Create tasks","customer":"Customer","deadline":"Deadline","details":"Details","edit_project":"Edit Project","edit_tasks":"Edit tasks","estimated_hours":"Estimated Hours","finished":"Finished","hide_project_tasks_on_main_tasks_table":"Hide project tasks on main tasks table","in_progress":"In Progress","members":"Contact","new_project":"New Project","no_project_available":"No Project Available","no_project_found":"No Project Found","not_started":"Not Started","on_hold":"On Hold","only_task_created_from_contact":"Only task created from contact","open_discussions":"Open discussions","progress":"Progress","project_details":"Project Details","project_name":"Project Name","project_not_found":"Project Not Found","project_saved_successfully":"Project saved successfully.","project_settings":"Project Settings","project_updated_successfully":"Project updated successfully.","projects_summary":"Projects Summary","quick_invoices_info":"Quick Invoices Info","send_project_created_email":"Send project created email","start_date":"Start Date","statistics_by_project_status":"Statistics By Project Status","status":"Status","task":"Task","total_projects":"Total Projects","upload_attachments_on_tasks":"Upload attachments on tasks","upload_files":"Upload files","view_account_statement":"View Account Statement","view_activity_log":"View activity log","view_finance_overview":"View finance overview","view_gantt":"View Gantt","view_milestones":"view milestones","view_task_attachments":"View task attachments","view_task_checklist_items":"View task checklist items","view_task_comments":"View task comments","view_task_total_logged_time":"View task total logged time","view_tasks":"View tasks","view_team_members":"View team members","view_timesheets":"View timesheets","visible_tables":"Visible Tables"},"projects":"Projects","proposal":{"accept":"ACCEPT","accepted":"Accepted","adjustment":"Adjustment","amount":"Amount","amount_due":"Amount Due","assigned":"Assigned","authorized_signature":"Authorized Signature","bank":"Bank","bill_to":"Bill To","comments":"Comments","convert":"Convert","convert_proposal":"Convert Proposal","date":"Date","decline":"Decline","declined":"Declined","discount":"Discount","draft":"Draft","drafted":"Drafted","edit_proposal":"Edit Proposal","item":"Product","lead":"Lead","mark_as_accepted":"Mark As Accepted","mark_as_declined":"Mark As Declined","mark_as_draft":"Mark As Draft","mark_as_open":"Mark As Open","mark_as_revised":"Mark As Revised","mark_as_send":"Mark As Send","member":"Member","new_proposal":"New Proposal","no_payments_available":"No Payment Available","no_proposal_available":"No Proposal Available.","no_proposal_found":"No Proposal Found.","offline_payment":"Offline Payment","online_payment":"Online Payment","open":"Open","open_till":"Open Till","pay_now":"PAY NOW","payment":"Payment","proposal":"Proposal","proposal_date":"Proposal Date","proposal_details":"Proposal Details","proposal_not_found":"Proposal Not Found.","proposal_number":"Proposal Number","proposal_overview":"PROPOSAL OVERVIEW","proposal_pdf":"Proposal PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"Proposal saved successfully.","proposal_to":"Proposal To","proposal_updated_successfully":"Proposal updated successfully.","qty":"Qty","rate":"Rate","related":"Related","revised":"Revised","save_and_send":"Save & Send","save_as_draft":"Save As Draft","sent":"Sent","ship_to":"Ship To","status":"Proposal Status","sub_total":"Sub Total","task":"Task","taxes":"Taxes","title":"Title","to":"To","total":"Total","total_paid":"Total Paid","total_proposal":"Total Proposals","transactions":"Transactions","view_proposal_as_customer":"View Proposal As Customer"},"proposals":"Proposals","range":{"day":"Day","last_30":"Last 30 Days","last_month":"Last Month","last_week":"Last Week","month":"Month","this_month":"This Month","this_week":"This Week","today":"Today","week":"Week"},"register":{"already_have_an_account":"Already have an account?","choose":"Choose","confirm_password":"Confirm Password","email":"Email","first_name":"First Name","last_name":"Last Name","password":"Password","phone":"Phone","profile_picture":"Profile Picture","register":"Register","sign_in":"Sign In"},"reminder":{"add_new":"Add New","description":"Description","edit_reminder":"Edit Reminder","email_status":"Email Status","is_notified":"Is Notified","new_reminder":"New Reminder","no":"No","note":"Note","note_text":"Please note that you have to select the UTC date time, as the cron jobs sending reminders as per UTC time.","notified_date":"Notification Date","reminder_saved_successfully":"Reminder saved successfully.","reminder_to":"Reminder To","reminder_updated_successfully":"Reminder updated successfully.","save_reminder":"Save Reminder","send_email_reminder":"Send Reminder Email","sent":"Sent","set_reminder":"Set Reminder","ticket_reminder":"Ticket Reminders","yes":"Yes"},"reminders":"Reminders","reset":{"confirm_password":"Confirm Password","email":"Email","password":"Password","recalled_your_login_info":"Recalled your login info?","reset_password":"Reset Password","set_a_new_password":"Set a New Password","sign_in":"Sign In"},"sales":"Sales","service":{"add":"Add","edit_service":"Edit Service","name":"Name","new_service":"New Service","no_service_available":"No Service Available.","no_service_found":"No Service Found.","service_not_found":"Service Not Found.","service_saved_successfully":"Service saved successfully.","service_updated_successfully":"Service updated successfully.","service_used_somewhere_else":"Service used somewhere else."},"services":"Services","setting":{"application_name":"Application Name","choose":"Choose","company_domain":"Company Domain","current_version":"Current Version","favicon":"Favicon","file_type":"File Type","logo":"Company Logo","setting_updated_successfully":"Setting updated successfully."},"settings":"Settings","staff":"Staff","status":{"additional_contact":"Additional Contact","answered":"Answered","attempted":"Attempted","cancelled":"Cancelled","closed":"Closed","contacted":"Contacted","finished":"Finished","in_progress":"In Progress","new_opportunity":"New Opportunity","not_attempted":"Not Attempted","not_started":"Not Started","on_hold":"On Hold","open":"Open"},"success":"Success","support":"Support","tag":{"add":"Add","add_new_tag":"Add New Tag","description":"Description","edit_tag":"Edit Tag","name":"Name","new_tag":"New Tag","no_tag_available":"No Tag Available.","no_tag_found":"No Tag Found.","tag_details":"Tag Details","tag_not_found":"Tag Not Found.","tag_saved_successfully":"Tag saved successfully.","tag_updated_successfully":"Tag updated successfully."},"tags":"Tags","task":{"awaiting_feedback":"Awaiting Feedback","billable":"Billable","completed":"Completed","due_date":"Due Date","edit_task":"Edit Task","hourly_rate":"Hourly Rate","in_progress":"In Progress","name":"Name","new_task":"New Task","no_task_available":"No Task Available.","not_started":"Not Started","priority":"Priority","public":"Public","related_to":"Related To","start_date":"Start Date","status":"Status","subject":"Subject","task_details":"Task Details","task_saved_successfully":"Task saved successfully.","task_status_updated_successfully":"Task status updated successfully.","task_updated_successfully":"Task updated successfully.","testing":"Testing","ticket":"Ticket"},"tasks":"Tasks","tax_rate":{"edit_tax_rate":"Edit Tax Rate","new_tax_rate":"New Tax Rate","no_tax_rate_available":"No Tax Rate Available.","no_tax_rate_found":"No Tax Rate Found.","tax_rate":"Tax Rate","tax_rate_not_found":"Tax Rate Not Found.","tax_rate_saved_successfully":"Tax Rate saved successfully.","tax_rate_updated_successfully":"Tax Rate updated successfully."},"tax_rates":"Tax Rates","this_week_payments":"This Week Payments","ticket":{"add":"Add","added_by":"Added By","assign_to":"Member","attachments":"Attachments","body":"Body","cc":"CC","contact":"Contact","department":"Department","details":"Details","edit_ticket":"Edit Ticket","email":"Email","name":"Name","new_ticket":"New Ticket","no_ticket_available":"No Ticket Available.","no_ticket_found":"No Ticket Found.","note":"Note","predefined_reply":"Predefined Reply","priority":"Priority","reminder":"Reminder","service":"Service","subject":"Subject","tags":"Tags","task":"Task","ticket_details":"Ticket Details","ticket_not_found":"Ticket Not Found.","ticket_saved_successfully":"Ticket saved successfully.","ticket_status_updated_successfully":"Ticket status updated successfully.","ticket_to_contact":"Ticket To Contact","ticket_updated_successfully":"Ticket updated successfully.","ticket_without_contact":"Ticket without Contact","tickets_status":"Tickets Status","you_can_add_multiples_images_and_files":"You can add multiples images and files"},"ticket_priorities":"Ticket Priorities","ticket_priority":{"add":"Add","add_new_ticket_priority":"Add New Ticket Priority","edit_ticket_priority":"Edit Ticket Priority","name":"Name","new_ticket_priority":"New Ticket Priority","no_ticket_priority_available":"No Ticket Priority Available.","no_ticket_priority_found":"No Ticket Priority Found.","ticket_priority_not_found":"Ticket Priority Not Found.","ticket_priority_saved_successfully":"Ticket Priority saved successfully.","ticket_priority_updated_successfully":"Ticket Priority updated successfully.","ticket_priority_used_somewhere_else":"Ticket Priority used somewhere else."},"ticket_status":{"add":"Add","add_new_ticket_status":"Add New Ticket Status","color":"Color","edit_ticket_sltatus":"Edit Ticket StatusEdit Ticket Status","name":"Name","new_ticket_status":"New Ticket Status","status_order":"Status Order","ticket_status":"Ticket Status","ticket_status_saved_successfully":"Ticket Status saved successfully.","ticket_status_updated_successfully":"Ticket Status updated successfully.","ticket_status_used_somewhere_else":"Ticket Status used somewhere else."},"tickets":"Tickets","translation_manager":"Translation Manager","translator_manager":{"edit_language":"Edit Language","language_added_successfully":"Language added successfully.","language_short_code":"Please enter language short code. i.e English = en","language_updated_successfully":"Language Updated Successfully.","translation":"Translation"},"user":{"change_language":"Change Language","change_password":"Change Password","edit_profile":"Edit Profile","email":"Email","first_name":"First Name","language":"Language","language_updated_successfully":"Language updated successfully.","last_name":"Last Name","logout":"Logout","name":"Name","password":"Password","password_confirmation":"Confirm Password","password_updated_successfully":"Password updated successfully.","phone":"Phone","profile":"Profile","profile_updated_successfully":"Profile updated successfully.","return_to_admin":"Return To Admin"},"users":"Users","weekdays":{"fri":"FRI","mon":"MON","sat":"SAT","sun":"SUN","thu":"THU","tue":"TUE","wed":"WED"}},"en.pagination":{"next":"Next &raquo;","previous":"&laquo; Previous"},"en.passwords":{"reset":"Your password has been reset!","sent":"We have emailed your password reset link!","throttled":"Please wait before retrying.","token":"This password reset token is invalid.","user":"We can't find a user with that email address."},"en.validation":{"accepted":"The :attribute must be accepted.","accepted_if":"The :attribute must be accepted when :other is :value.","active_url":"The :attribute is not a valid URL.","after":"The :attribute must be a date after :date.","after_or_equal":"The :attribute must be a date after or equal to :date.","alpha":"The :attribute must only contain letters.","alpha_dash":"The :attribute must only contain letters, numbers, dashes and underscores.","alpha_num":"The :attribute must only contain letters and numbers.","array":"The :attribute must be an array.","attributes":[],"before":"The :attribute must be a date before :date.","before_or_equal":"The :attribute must be a date before or equal to :date.","between":{"array":"The :attribute must have between :min and :max items.","file":"The :attribute must be between :min and :max kilobytes.","numeric":"The :attribute must be between :min and :max.","string":"The :attribute must be between :min and :max characters."},"boolean":"The :attribute field must be true or false.","confirmed":"The :attribute confirmation does not match.","current_password":"The password is incorrect.","custom":{"attribute-name":{"rule-name":"custom-message"}},"date":"The :attribute is not a valid date.","date_equals":"The :attribute must be a date equal to :date.","date_format":"The :attribute does not match the format :format.","different":"The :attribute and :other must be different.","digits":"The :attribute must be :digits digits.","digits_between":"The :attribute must be between :min and :max digits.","dimensions":"The :attribute has invalid image dimensions.","distinct":"The :attribute field has a duplicate value.","email":"The :attribute must be a valid email address.","ends_with":"The :attribute must end with one of the following: :values.","exists":"The selected :attribute is invalid.","file":"The :attribute must be a file.","filled":"The :attribute field must have a value.","gt":{"array":"The :attribute must have more than :value items.","file":"The :attribute must be greater than :value kilobytes.","numeric":"The :attribute must be greater than :value.","string":"The :attribute must be greater than :value characters."},"gte":{"array":"The :attribute must have :value items or more.","file":"The :attribute must be greater than or equal :value kilobytes.","numeric":"The :attribute must be greater than or equal :value.","string":"The :attribute must be greater than or equal :value characters."},"image":"The :attribute must be an image.","in":"The selected :attribute is invalid.","in_array":"The :attribute field does not exist in :other.","integer":"The :attribute must be an integer.","ip":"The :attribute must be a valid IP address.","ipv4":"The :attribute must be a valid IPv4 address.","ipv6":"The :attribute must be a valid IPv6 address.","json":"The :attribute must be a valid JSON string.","lt":{"array":"The :attribute must have less than :value items.","file":"The :attribute must be less than :value kilobytes.","numeric":"The :attribute must be less than :value.","string":"The :attribute must be less than :value characters."},"lte":{"array":"The :attribute must not have more than :value items.","file":"The :attribute must be less than or equal :value kilobytes.","numeric":"The :attribute must be less than or equal :value.","string":"The :attribute must be less than or equal :value characters."},"max":{"array":"The :attribute must not have more than :max items.","file":"The :attribute must not be greater than :max kilobytes.","numeric":"The :attribute must not be greater than :max.","string":"The :attribute must not be greater than :max characters."},"mimes":"The :attribute must be a file of type: :values.","mimetypes":"The :attribute must be a file of type: :values.","min":{"array":"The :attribute must have at least :min items.","file":"The :attribute must be at least :min kilobytes.","numeric":"The :attribute must be at least :min.","string":"The :attribute must be at least :min characters."},"multiple_of":"The :attribute must be a multiple of :value.","not_in":"The selected :attribute is invalid.","not_regex":"The :attribute format is invalid.","numeric":"The :attribute must be a number.","password":"The password is incorrect.","present":"The :attribute field must be present.","prohibited":"The :attribute field is prohibited.","prohibited_if":"The :attribute field is prohibited when :other is :value.","prohibited_unless":"The :attribute field is prohibited unless :other is in :values.","regex":"The :attribute format is invalid.","required":"The :attribute field is required.","required_if":"The :attribute field is required when :other is :value.","required_unless":"The :attribute field is required unless :other is in :values.","required_with":"The :attribute field is required when :values is present.","required_with_all":"The :attribute field is required when :values are present.","required_without":"The :attribute field is required when :values is not present.","required_without_all":"The :attribute field is required when none of :values are present.","same":"The :attribute and :other must match.","size":{"array":"The :attribute must contain :size items.","file":"The :attribute must be :size kilobytes.","numeric":"The :attribute must be :size.","string":"The :attribute must be :size characters."},"starts_with":"The :attribute must start with one of the following: :values.","string":"The :attribute must be a string.","timezone":"The :attribute must be a valid timezone.","unique":"The :attribute has already been taken.","uploaded":"The :attribute failed to upload.","url":"The :attribute must be a valid URL.","uuid":"The :attribute must be a valid UUID."},"es.auth":{"failed":"Estas credenciales no coinciden con nuestros registros.","throttle":"Demasiados intentos de inicio de sesi\u00f3n. Por favor intente nuevamente en: seconds segundos."},"es.messages":{"activity_log":{"activity_logs":"Registros de actividad","loading_more_date":"Cargando m\u00e1s datos","sorry_we_not_find_any_data":"No podemos encontrar ning\u00fan dato, haga al menos 1 entrada","we_could_find_any_data":"No pudimos encontrar ning\u00fan dato Lo sentimos"},"address":{"city":"Ciudad","country":"Pa\u00eds","state":"Estado","street":"Calle","zip_code":"C\u00f3digo postal"},"announcement":{"add":"Agregar","announcement_date":"Fecha de anuncio","announcement_details":"Detalles del anuncio","announcement_saved_successfully":"Anuncio guardado correctamente.","announcement_updated_successfully":"Anuncio actualizado con \u00e9xito.","edit_announcement":"Editar anuncio","message":"Mensaje","new_announcement":"Nuevo anuncio","no_announcement_available":"No hay anuncios disponibles.","no_announcement_found":"No se ha encontrado ning\u00fan anuncio.","show_my_name":"Mostrar mi nombre","show_to_clients":"Mostrar a los clientes","show_to_staff":"Mostrar al personal","subject":"Asunto"},"announcements":"Anuncios","article":{"add":"Agregar","article_details":"Detalles del art\u00edculo","article_not_found":"Art\u00edculo no encontrado.","article_saved_successfully":"Art\u00edculo guardado correctamente.","article_updated_successfully":"Art\u00edculo actualizado con \u00e9xito.","attachment":"Adjunto archivo","description":"Descripci\u00f3n","disabled":"Deshabilitado","edit_article":"Editar art\u00edculo","group":"Grupo","internal_article":"Art\u00edculo interno","new_article":"Nuevo art\u00edculo","no_article_available":"No hay art\u00edculo disponible.","no_article_found":"No se ha encontrado ning\u00fan art\u00edculo.","subject":"Asunto","upload_image":"Subir imagen"},"article_group":{"add_new_article_group":"Agregar nuevo grupo de art\u00edculos","article_group_saved_successfully":"Grupo de art\u00edculos guardado correctamente.","article_group_updated_successfully":"Grupo de art\u00edculos actualizado con \u00e9xito.","article_group_used_somewhere_else":"Art\u00edculo Grupo utilizado en otro lugar.","article_groups":"Grupos de art\u00edculos","color":"Color","edit_article_group":"Editar grupo de art\u00edculos","group_name":"Nombre del grupo","new_article_group":"Nuevo grupo de art\u00edculos","order":"Orden"},"articles":"Art\u00edculos","calendars":"Calendarios","change_password":{"change_information_about_yourself_on_this_page":"Cambiar informaci\u00f3n sobre usted en esta p\u00e1gina","confirm_password":"Confirmar contrase\u00f1a","current_password":"Contrase\u00f1a actual","edit_profile":"Editar perfil","new_password":"Nueva contrase\u00f1a"},"client_dashboard":"Panel de cliente","cms":"CMS","comment":{"add_comment":"Agregar comentario","added_by":"A\u00f1adido por","comments_saved_successfully":"Comentario guardado correctamente.","comments_updated_successfully":"Comentario actualizado correctamente.","edit_comment":"Editar comentario","new_comment":"Nuevo comentario","no_comments_added_yet":"A\u00fan no se han a\u00f1adido comentarios"},"comments":"Comentarios","common":{"action":"Acci\u00f3n","active":"Activo","add":"Agregar","admin_note":"Nota de administrador","announcement":"Anuncio","apply":"Aplicar","article":"Art\u00edculo","article_group":"Grupo de art\u00edculos","assignee":"Cesionario","attachment_deleted":"Se ha eliminado el archivo adjunto.","back":"Atr\u00e1s","cancel":"Cancelar","choose":"Choose","client_note":"Nota del cliente","contract_type":"tipo de contrato","country":"Pa\u00eds","created_on":"Creado el","custom":"Disfraz","customer":"Cliente","customer_group":"grupo de clientes","data_base_entries":"Mostrando _START_ a _END_ de _TOTAL_ entradas","deactive":"Inactivo","default_country_code":"C\u00f3digo de pa\u00eds predeterminado","delete":"Eliminar","delete_attachment":"\u00bfEst\u00e1 seguro de que desea eliminar este \"archivo adjunto\"?","delete_confirm":"Por favor escribe","delete_confirm_common":"estas seguro que quieres borrar esto","delete_note":"\u00bfEst\u00e1 seguro de que desea eliminar esta \"Nota\"?","deleted":"\u00a1Eliminado!","department":"Departamento","description":"Descripci\u00f3n","download":"Descargar","download_as_pdf":"Descargar como PDF","drafted":"Redactado","edit":"Editar","email":"Correo electr\u00f3nico","expense":"Gastos","expense_category":"Categor\u00eda de gastos","filter_by":"(filtrado de _MAX_ entradas totales)","from":"De","goal":"Meta","has_been_delete":" ha sido eliminado..","incomes_vs_expenses":"Ingresos Vs Gastos","last_updated":"\u00daltima actualizaci\u00f3n","lead":"Guiar","lead_source":"Fuente de plomo","menu_entry":"Mostrar entradas de _MENU_","n \/ a":"N \/ A","name":"Nombre","no":"No","no_data_available_in_table":"No hay datos disponibles en la tabla","no_entry":"Mostrando 0 a 0 de 0 entradas","no_matching":"No se encontraron registros coincidentes","note":"Nota","note_delete":"La nota ha sido eliminada.","of":"De","ok":"OK","payment_mode":"Modo de pago","predefined_reply":"Respuesta predefinida","product_1":"Producto","product_group":"Grupo de productos","product_header":"Producto","proposal":"Propuesta","quantity_is_not_greater_than":"La cantidad no es mayor que 9999999","save":"Guardar","search":"Buscar","search_results":"Los resultados de su b\u00fasqueda van aqu\u00ed ...","service":"Servicio","showing":"Demostraci\u00f3n","status":"Estado","tag":"Etiqueta","tax_rate":"Tasa de impuesto","term_and_conditions":"T\u00e9rmino y condiciones","ticket_priority":"Prioridad de entradas","to":"A","to_delete_this":"para borrar esto","total_amount":"Cantidad total","type_delete":"Escriba \"delete\" para eliminar esto","view":"Ver","weekly_payment_records":"Registros de pagos semanales","yes":"S\u00ed"},"company":{"address":"Direcci\u00f3n","city":"Ciudad","company":"Nombre de la empresa","company_information_format":"Formato de informaci\u00f3n de la empresa (PDF y HTML)","country_code":"C\u00f3digo de pa\u00eds","currency":"Moneda","details":"Detalles de la empresa","phone":"Tel\u00e9fono","state":"Estado","vat_number":"N\u00famero de IVA","website":"Sitio web","zip_code":"C\u00f3digo postal"},"company_information":"Informaci\u00f3n de la empresa","contact":{"active":"Activo","by_deleting_this_contact":"Al eliminar este contacto se eliminar\u00e1 todo su proyecto.","contact_details":"Detalles de contacto","contact_not_found":"Contacto no encontrado.","contact_saved_successfully":"Contacto guardado correctamente.","contact_status_updated_successfully":"Estado de contacto actualizado con \u00e9xito.","contact_updated_successfully":"Contacto actualizado con \u00e9xito.","contract":"Contrato","contracts":"Contratos","credit_note":"Nota de cr\u00e9dito","customer_name":"Nombre del cliente","deactive":"Inactivo","delete_contact_confirm":"\u00bfEst\u00e1 seguro de que desea eliminar este contacto?","direction":"Direcci\u00f3n","edit_contact":"Editar contacto","email_notifications":"Notificaci\u00f3nes de Correo Electr\u00f3nico","estimate":"Estimar","estimates":"Estimados","first_name":"Nombre","full_name":"Nombre completo","impersonate":"Personificar","invoice":"Factura","invoices":"Facturas","last_name":"Apellido","make_sure_to_set_appropriate_permissions_for_this_contact":"Aseg\u00farese de establecer los permisos apropiados para este contacto","new_contact":"Nuevo contacto","no_contact_available":"No hay contacto disponible.","no_contact_found":"No se encontr\u00f3 ning\u00fan contacto.","password":"Contrase\u00f1a","permissions":"Permisos","position":"Posici\u00f3n","primary_contact":"Contacto primario","project":"Proyecto","projects":"Proyectos","proposals":"Propuestas","send_password_email":"Enviar correo electr\u00f3nico de contrase\u00f1a SET","send_welcome_email":"No enviar correo electr\u00f3nico de bienvenida","support":"Apoyo","task":"Tarea","tickets":"Entradas"},"contacts":"Contactos","contract":{"add":"Agregar","contract_details":"Detalles del contrato","contract_list":"Lista de contratos","contract_not_found":"Contrat introuvable","contract_summary":"Resumen del contrato","contract_type_id":"Tipo de contrato","contract_value":"Valor del contrato","contracts_by_type":"Contratos por tipo","contracts_expiring_this_month":"Contratos que vencen este mes","contracts_saved_successfully":"Contrato guardado correctamente.","contracts_updated_successfully":"Contrato actualizado con \u00e9xito.","contracts_value_by_type":"Valor de los contratos por tipo","customer_id":"Cliente","description":"Descripci\u00f3n","edit_contract":"Editar contrato","end_date":"Fecha de finalizaci\u00f3n","is_hide":"Ocultar al cliente","is_trash":"Papelera","new_contract":"Nuevo contrato","no_contract_available":"Aucun contrat disponible","no_contract_found":"No se encontr\u00f3 contrato.","optional_signature":"Firma autorizada","sign":"Sign","start_date":"Fecha de inicio","subject":"Asunto","task":"Tarea"},"contract_type":{"add_new_contract_type":"Agregar nuevo tipo de contrato","contract_by_type":"Vertrag nach Typ","contract_type_saved_successfully":"Tipo de contrato guardado correctamente.","contract_type_updated_successfully":"Tipo de contrato actualizado correctamente.","contract_type_used_somewhere_else":"Tipo de contrato utilizado en otro lugar.","contract_value_by_type":"Vertragswert nach Typ","edit_contract_type":"Editar tipo de contrato","new_contract_type":"Nuevo tipo de contrato"},"contract_types":"Tipos de contrato","contracts":"Contratos","countries":"Los paises","country":{"add":"Agregar","country_not_found":"Pa\u00eds no encontrado.","country_saved_successfully":"Pa\u00eds guardado correctamente.","country_updated_successfully":"Pa\u00eds actualizado con \u00e9xito.","country_used_somewhere_else":"Pa\u00eds utilizado en otro lugar.","edit_country":"Editar pa\u00eds","name":"Nombre","new_country":"Nuevo pa\u00eds","no_country_available":"No hay pa\u00eds disponible.","no_country_found":"No se ha encontrado ning\u00fan pa\u00eds."},"credit_note":{"client_note":"Nota","closed":"Cerrada","credit_note":"Nota de cr\u00e9dito","credit_note_date":"Fecha de nota de cr\u00e9dito","credit_note_details":"Detalles de la nota de cr\u00e9dito","credit_note_details_updated_successfully":"Detalles de la nota de cr\u00e9dito actualizados con \u00e9xito.","credit_note_not_found":"Gutschrift nicht gefunden.","credit_note_number":"N\u00famero de nota de cr\u00e9dito","credit_note_pdf":"Nota de cr\u00e9dito PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"Nota de cr\u00e9dito guardada con \u00e9xito.","credit_note_updated_successfully":"Nota de cr\u00e9dito actualizada con \u00e9xito.","drafted":"Redactada","edit_credit_note":"Editar nota de cr\u00e9dito","invoice_credited":"Factura acreditada","mark_as_closed":"Marcar como cerrado","mark_as_draft":"Marcar como borrador","mark_as_open":"Marcar como abierto","mark_as_void":"Marcar como vac\u00edo","new_credit_note":"Nueva nota de cr\u00e9dito","no_credit_note_available":"Keine Gutschrift verf\u00fcgbar.","no_credit_note_found":"No se encontr\u00f3 ninguna nota de cr\u00e9dito.","open":"Abierta","optional_signature":"Firma autorizada","quantity_is_not_greater_than":"La cantidad no es mayor que 9999999","reference":"Referencia","refunds":"Reembolsos","save_and_send":"Guardar y enviar","save_as_draft":"Guardar como borrador","terms_and_conditions":"T\u00e9rminos y condiciones","title":"T\u00edtulo","view_credit_note_as_customer":"Ver nota de cr\u00e9dito como cliente","void":"Vac\u00eda"},"credit_notes":"Notas de cr\u00e9dito","customer":{"add_address_details":"Agregar detalles de direcci\u00f3n","address":"Direcci\u00f3n","address_details":"Detalles de la direcci\u00f3n","address_not_found":"Detalles de la direcci\u00f3n no encontrados","billing_address":"Direcci\u00f3n de facturaci\u00f3n","billing_address_details_not_available":"Detalles de la direcci\u00f3n de facturaci\u00f3n no disponibles","by_deleting_this_customer":"Al eliminar este cliente se eliminar\u00e1 todo su proyecto, contacto, factura, presupuesto, nota de cr\u00e9dito, propuesta y contrato.","city":"Ciudad","company_name":"Nombre de la empresa","copy_billing_address":"Copiar direcci\u00f3n de facturaci\u00f3n","country":"Pa\u00eds","currency":"Moneda","customer_details":"Detalles del cliente","customer_saved_successfully":"El cliente se guard\u00f3 correctamente.","customer_updated_successfully":"El cliente se actualiz\u00f3 correctamente.","customers":"Clientes","default_language":"Idioma predeterminado","delete_customer_confirm":"\u00bfEst\u00e1 seguro de que desea eliminar este cliente?","do_not_fill_shipping_address_customer_invoices":"Geben Sie keine Lieferadresseninformationen ein, wenn Sie die Lieferadresse nicht auf Kundenrechnungen verwenden","edit_customer":"Editar cliente","groups":"Grupos","new_customer":"Nuevo cliente","no_customer_available":"No hay cliente disponible.","no_customer_found":"No se ha encontrado ning\u00fan cliente.","phone":"Tel\u00e9fono","same_as_a_customer_info":"Igual que la informaci\u00f3n del cliente","search_customer":"Buscar cliente","shipping_address":"Direcci\u00f3n de env\u00edo","shipping_address_details_not_available":"Detalles de la direcci\u00f3n de env\u00edo no disponibles","state":"Estado","street":"Calle","total_contact":"Contacto total","total_customers":"Clientes totales","total_project":"Proyecto total","type":"Tipo","vat_number":"N\u00famero de IVA","website":"Sitio web","zip_code":"C\u00f3digo postal"},"customer_group":{"action":"Acci\u00f3n","add_new_customer_group":"Agregar nuevo grupo de clientes","customer_group_saved_successfully":"Grupo de clientes guardado correctamente.","customer_group_updated_successfully":"Grupo de clientes actualizado con \u00e9xito.","description":"Descripci\u00f3n","edit_customer_group":"Editar grupo de clientes","name":"Nombre","new_customer_group":"Nuevo grupo de clientes"},"customer_groups":"Grupos de clientes","customers":"Clientes","dashboard":"Tablero","department":{"department_not_found":"Departamento no encontrado.","department_saved_successfully":"Departamento guardado con \u00e9xito.","department_updated_successfully":"Departamento actualizado con \u00e9xito.","departments":"Departamentos","edit_department":"Editar departamento","hide_from_clients":"Ocultar a los clientes","new_department":"Nuevo departamento","no_department_available":"No hay departamento disponible.","no_department_found":"No se encontr\u00f3 ning\u00fan departamento."},"edit_profile":{"change_password":"Cambiar contrase\u00f1a","edit_profile":"Editar perfil","hello":"Hola","hi":"Hola","login":"Iniciar sesi\u00f3n","login_register":"Iniciar sesi\u00f3n \/ Registrarse","logout":"Cerrar sesi\u00f3n","mark_all_as_read":"Marcar todo como le\u00eddo","notification":"Notificaciones","register":"Registrarse","welcome":"Bienvenido"},"email":{"email":"Correo electr\u00f3nico","forgotten_password":"Olvid\u00e9 mi contrase\u00f1a","recalled_your_login_info":"\u00bfRecuperaron su informaci\u00f3n de inicio de sesi\u00f3n?","reset_password":"Restablecer contrase\u00f1a","send_reset_link":"Enviar restablecer enlace","sign_in":"Iniciar sesi\u00f3n"},"email_template":{"available_merge_fields":"Campos de fusi\u00f3n disponibles","disabled":"Deshabilitado","edit_email_template":"Editar plantilla de correo electr\u00f3nico","email_message":"Mensaje de correo electr\u00f3nico","enable":"Habilitar","from_name":"De nombre","send_plain_text":"Enviar como texto sin formato","subject":"Asunto","template_name":"Nombre de plantilla"},"email_templates":"Plantillas de correo electr\u00f3nico","error":"Error","estimate":{"Authorized_signature":"Firma autorizada","accept":"ACEPTADO","accepted":"ACEPTADO","adjustment":"Ajustamiento","amount":"Cantidad","amount_due":"Monto adeudado","bill_to":"Facturar a","client_note":"Nota del cliente","convert_estimate":"Convertir estimaci\u00f3n","convert_estimate_to_invoice":"Convertir presupuesto a factura correctamente.","declined":"RECHAZADO","discount":"Descuento","draft":"SEQU\u00cdA","drafted":"Redactada","edit_estimate":"Editar estimaci\u00f3n","estimate":"Estimar","estimate_date":"Fecha estimada","estimate_details":"Detalles estimados","estimate_not_found":"Estimaci\u00f3n no encontrada","estimate_number":"Numero Estimado","estimate_overview":"RESUMEN ESTIMADO","estimate_pdf":"PDF estimado","estimate_prefix":"EN-","estimate_saved_successfully":"Estimaci\u00f3n guardada con \u00e9xito.","estimate_status_updated_successfully":"Estado estimado actualizado con \u00e9xito.","estimate_updated_successfully":"Estimaci\u00f3n actualizada correctamente.","expired":"CADUCADO","expiry_date":"Fecha de vencimiento","item":"Producto","mark_as_accepted":"Marcar como aceptado","mark_as_declined":"Marcar como rechazado","mark_as_draft":"Marcar como borrador","mark_as_expired":"Marcar como caducado","mark_as_send":"Marcar como env\u00edo","more":"M\u00e1s","new_estimate":"Nueva estimaci\u00f3n","no_estimate_available":"No se dispone de estimaciones","no_estimate_found":"No se encontr\u00f3 ninguna estimaci\u00f3n.","not_sent":"NO ENVIADO","qty":"Cant.","rate":"Velocidad","save_and_send":"Guardar y enviar","save_as_draft":"Guardar como borrador","sent":"EXPEDIDO","ship_to":"Enviar a","status":"Estado","sub_total":"Sub Total","task":"Tarea","taxes":"Impuestos","terms_conditions":"T\u00e9rminos y condiciones","title":"T\u00edtulo","total":"Total","total_estimates":"Estimaciones totales","total_paid":"Total pagado","view_estimate_as_customer":"Ver estimaci\u00f3n como cliente"},"estimates":"Estimados","expense":{"add":"Agregar","amount":"Cantidad","amount_with_tax":"Cantidad con impuestos","apply_tax":"Aplicar impuesto","apply_tax_message":"Restar total de impuestos del importe","attachment":"Adjunto archivo","auto_create_invoice":"Crear factura autom\u00e1ticamente","billable":"Facturable","choose_file":"Elegir archivo","currency":"Moneda","customer":"Cliente","details":"Detalles","edit_expense":"Editar gasto","expense_amount":"Importe del gasto","expense_category":"Detalles de gastos","expense_category_by_chart":"Categor\u00eda de gastos por gr\u00e1fico","expense_date":"Fecha de gastos","expense_list":"Lista de gastos","expense_not_found":"Gastos no encontrados.","expense_saved_successfully":"Gasto guardado con \u00e9xito.","expense_updated_successfully":"Gasto actualizado con \u00e9xito.","name":"Nombre","new_expense":"Nuevo gasto","no_expense_available":"No hay gastos disponibles.","no_expense_found":"No se encontraron gastos.","note":"Nota","notes":"Notas","payment_mode":"Modo de pago","preview_attachment":"Vista previa del archivo adjunto","reference":"Referencia","reminders":"Recordatorio","send_email":"Enviar la factura al correo electr\u00f3nico del cliente cuando se vuelven a crear los gastos","tax_1":"Impuesto 1 (en%)","tax_2":"Impuesto 2 (en%)","tax_applied":"Impuesto aplicado","ticket_attachment":"Adjunto de recibo","view_attachment":"Ver archivo adjunto"},"expense_by_category":"Gasto por categor\u00eda","expense_categories":"Categor\u00edas de gastos","expense_category":{"add_new_expense_category":"Agregar nueva categor\u00eda de gastos","edit_category":"Editar categor\u00eda de gastos","expense_categories":"Categor\u00edas de gastos","expense_category":"Categor\u00eda de gastos","expense_category_saved_successfully":"Categor\u00eda de gastos guardada correctamente.","expense_category_updated_successfully":"Categor\u00eda de gastos actualizada con \u00e9xito.","expense_category_used_somewhere_else":"Categor\u00eda de gastos utilizada en otro lugar.","new_category":"Nueva categor\u00eda de gastos"},"expenses":"Gastos","general":"General","goal":{"achievement":"Logro","add":"Agregar","description":"Descripci\u00f3n","edit_goal":"Editar objetivo","end_date":"Fecha de finalizaci\u00f3n","goal_details":"Detalles del objetivo","goal_id":"Tipo de objetivo","goal_saved_successfully":"Objetivo guardado con \u00e9xito.","goal_type":"Tipo de objetivo","goal_updated_successfully":"Objetivo actualizado con \u00e9xito.","is_not_notify":"Notificar a los miembros del personal cuando el objetivo no se logr\u00f3","is_notify":"Notificar a los miembros del personal cuando se logre el objetivo","new_goal":"Nuevo objetivo","no_goal_available":"No hay objetivo disponible.","no_goal_found":"No se ha encontrado ning\u00fan objetivo.","progress":"Progreso","staff_member":"Miembro del personal","start_date":"Fecha de inicio","subject":"Asunto","user_id":"Miembro del personal"},"goal_type":{"description":"Descripci\u00f3n","edit_goal_type":"Editar tipo de objetivo","name":"Nombre","new_goal_type":"Nuevo tipo de objetivo"},"goals":"Objetivos","incomes":"Ingresos","invoice":{"activity_log":"Registro de actividad","add_item":"A\u00f1adir Producto","add_shipping_address":"Agregar direcci\u00f3n de env\u00edo","adjustment":"Ajustamiento","admin_note":"Nota de administrador","allowed_payment_modes_for_this_invoice":"Modos de pago permitidos para esta factura","amount":"Cantidad","amount_due":"Monto adeudado","bank":"Banco","bill_tasks":"Bill Tasks","bill_to":"Facturar a","cancelled":"CANCELADO","client_note":"Nota del cliente","currency":"Moneda","customer":"Cliente","discount":"Descuento","discount_type":"Tipo de descuento","draft":"SEQU\u00cdA","drafted":"Redactada","due_date":"Fecha de vencimiento","edit_contract_type":"Editar tipo de contrato","edit_invoice":"Editar factura","fixed":"Fijo","hours":"Horas","hsn_tax":"C\u00f3digo fiscal HSN","invoice":"Factura","invoice_date":"Fecha de factura","invoice_details":"Detalles de la factura","invoice_not_found":"Factura no encontrada.","invoice_number":"N\u00famero de factura","invoice_overview":"DESCRIPCI\u00d3N GENERAL DE LA FACTURA","invoice_payments":"Pagos de facturas","invoice_pdf":"Factura PDF","invoice_prefix":"INV-","invoice_saved_successfully":"Factura guardada correctamente.","invoice_updated_successfully":"Factura actualizada correctamente.","item":"Producto","mark_as_cancelled":"Marcar como cancelado","mark_as_draft":"Marcar como borrador","mark_as_paid":"Marcar como pagado","mark_as_partially_paid":"Marcar como parcialmente pagado","mark_as_sent":"Marcar como enviado","more":"M\u00e1s","new_contract_type":"Nuevo tipo de contrato","new_invoice":"Nueva factura","no_invoice_available":"No hay factura disponible.","no_invoice_found":"No se encontr\u00f3 ninguna factura.","no_payments_available":"No hay pagos disponibles","not_sent":"NO ENVIADO","notes":"Notas","offline_payment":"Pago sin conexi\u00f3n","online_payment":"Pago en l\u00ednea","optional_signature":"Firma autorizada","overdue":"ATRASADO","paid":"Pagado","paid_cap":"PAGADO","partially_paid":"Parcialmente pagado","partially_paid_cap":"PARCIALMENTE PAGADO","pay_now":"Pagar ahora","payment":"Pago","payment_details":"Detalles del pago","payments":"Pagos","prevent_sending_overdue_reminders_for_this_invoice":"Evitar el env\u00edo de recordatorios vencidos para esta factura","qty":"Cant.","qty \/ hours":"Cant. \/ Horas","qty_hours":"Cantidad \/ horas","quick_invoices_info":"Informaci\u00f3n de Facturas R\u00e1pidas","recurring_invoice":"Factura recurrente","reminders":"Recordatorios","sale_agent":"Agente de ventas","save_and_send":"Guardar y enviar","save_as_draft":"Guardar como borrador","ship_to":"Enviar a","show_quantity_as":"Mostrar cantidad como","sub_total":"Sub Total","task":"Tarea","taxes":"Impuestos","terms_conditions":"T\u00e9rminos y condiciones","title":"T\u00edtulo","total":"Total","total_invoices":"Facturas totales","total_paid":"Total pagado","transactions":"Actas","unmark_as_cancelled":"Desmarcar como cancelado","unpaid":"Sin pagar","unpaid_cap":"NO PAGADO","view_invoice_as_customer":"Ver factura como cliente"},"invoices":"Facturas","kanban_list":"Lista KANBAN","kanban_view":"Ver KANBAN","last_week_payments":"Pagos de la semana pasada","lead":{"chart":"Gr\u00e1fico","contacted_today":"Contactado hoy","convert_to_customer":"Convertir a cliente","date_contacted":"Fecha contactada","details":"Detalles","edit_lead":"Editar cliente potencial","estimate_budget":"Presupuesto estimado","lead_convert_customer":"Cliente de conversi\u00f3n de clientes potenciales","lead_convert_customer_chart":"Tabla de clientes potenciales convertidos","lead_details":"Detalles del cliente potencial","lead_list":"Lista de clientes potenciales","lead_not_found":"Prospect non trouv\u00e9.","lead_saved_successfully":"Prospecto guardado con \u00e9xito.","lead_status_updated_successfully":"Estado de cliente potencial actualizado con \u00e9xito.","lead_updated_successfully":"Prospecto actualizado con \u00e9xito.","leads_overview":"Descripci\u00f3n general de los clientes potenciales","member":"Miembro","name":"Nombre","new_lead":"Nuevo cliente potencial","no_lead_available":"No hay plomo disponible.","no_lead_found":"No se encontr\u00f3 plomo.","notes":"Notas","reminder":"Recordatorio","source":"Fuente","task":"Tarea"},"lead_convert_to_customer":"Convertir prospecto en cliente","lead_source":{"add":"Agregar","edit_lead_source":"Editar fuente principal","lead_source_count":"Recuento de clientes potenciales","lead_source_not_found":"Fuente de plomo no encontrada.","lead_source_saved_successfully":"Fuente de cliente potencial guardada correctamente.","lead_source_updated_successfully":"Fuente de cliente potencial actualizada con \u00e9xito.","name":"Nombre","new_lead_source":"Nueva fuente de leads","no_lead_source_available":"No hay fuente de plomo disponible.","no_lead_source_found":"No se encontr\u00f3 ninguna fuente de plomo."},"lead_sources":"Fuentes de plomo","lead_status":{"add":"Agregar","add_new_lead_status":"Agregar nuevo estado de cliente potencial","color":"Color","edit_lead_status":"Editar estado del lead","lead_status":"Estado del cliente potencial","lead_status_saved_successfully":"Estado del cliente potencial guardado correctamente.","lead_status_updated_successfully":"Estado de cliente potencial actualizado con \u00e9xito.","lead_status_used_somewhere_else":"Estado del cliente potencial utilizado en otro lugar.","name":"Nombre","new_lead_status":"Nuevo estado del cliente potencial","order":"Orden"},"leads":"Gu\u00edas","list_view":"Lista Ver","login":{"admin":"Administrador","client":"Cliente","create_one":"Crear uno","don't have an account":" Don't have an account?","email":"Correo electr\u00f3nico","forgotten_password":"Olvid\u00e9 mi contrase\u00f1a","login":"Iniciar sesi\u00f3n","password":"Contrase\u00f1a","remember_me":"Recordarme"},"member":{"add":"Agregar","by_deleting_this_member":"Al eliminar este miembro se eliminar\u00e1 todo su proyecto, propuesta y objetivo.","choose":"Choose","created_on":"Creado el","default_language":"Idioma predeterminado","delete_member_confirm":"\u00bfEst\u00e1 seguro de que desea eliminar este miembro?","direction":"Direcci\u00f3n","edit_member":"Editar miembro","email":"Correo electr\u00f3nico","email_is_not_verified":"Correo no identificado","email_is_verified":"El correo electr\u00f3nico est\u00e1 verificado","email_verified":"Correo Electr\u00f3nico Verificado","email_verified_successfully":"Correo electr\u00f3nico verificado con \u00e9xito.","email_verify":"Correo electr\u00f3nico Verificar","facebook":"Facebook","first_name":"Nombre","hourly_rate":"Tarifa por hora","image":"Perfil","is_administrator":"Administrador","is_enable":"Habilitar autenticaci\u00f3n de dos factores","last_name":"Apellido","linkedin":"LinkedIn","member_details":"Detalles del miembro","member_informations":"Informaci\u00f3n de miembro","member_not_found":"Miembro no encontrado.","member_saved_successfully":"Miembro guardado correctamente.","member_security":"Seguridad de miembros","member_status_updated_successfully":"Estado de miembro actualizado con \u00e9xito.","member_updated_successfully":"Miembro actualizado con \u00e9xito.","new_member":"Nuevo miembro","no_member_available":"No hay miembros disponibles.","no_member_found":"No se ha encontrado ning\u00fan miembro.","password":"Contrase\u00f1a","password_confirmation":"Confirmar contrase\u00f1a","permissions":"Permisos","phone":"Tel\u00e9fono","profile":"Perfil","resend_email_verification":"Reenviar verificaci\u00f3n de correo electr\u00f3nico","send_welcome_email":"Enviar correo electr\u00f3nico de bienvenida","skype":"skype","staff_member":"No miembro del personal","total_members":"Miembros totales","verification_mail_has_been_sent":"El correo electr\u00f3nico de verificaci\u00f3n se ha enviado correctamente."},"members":"Miembros","menu_settings":"Configuraci\u00f3n del men\u00fa","months":{"apr":"Abr","aug":"Ago","dec":"Dic","feb":"Feb","jan":"Ene","jul":"Jul","jun":"Jun","mar":"Mar","may":"Mayo","nov":"Nov","oct":"Oct","sep":"Sep"},"new_language":"Nuevo idioma","no_matching_records_found":"No se encontraron registros coincidentes","note":{"add_note":"Agregar nota","edit_note":"Editar nota","new_note":"Nueva nota","no_notes_added_yet":"No se agregaron notas todav\u00eda","notes_saved_successfully":"Nota guardada correctamente.","notes_updated_successfully":"Nota actualizada correctamente."},"notes":"Notas","notification":{"all_notification_read_successfully":"Todas las notificaciones se leyeron correctamente.","empty_notifications":"No pudimos encontrar ninguna notificaci\u00f3n","mark_all_as_read":"Marcar todo como leido","notification_read_successfully":"Notificaci\u00f3n le\u00edda con \u00e9xito.","notifications":"Notificaciones"},"others":"otras","payment":{"amount":"Cantidad","amount_received":"Cantidad recibida","date":"Fecha","new_payment":"Nuevo pago","note":"Nota","payment_date":"Fecha de pago","payment_mode":"Modo de pago","payment_saved_successfully":"Pago guardado con \u00e9xito.","send_mail_to_customer_contacts":"No enviar correos electr\u00f3nicos grabados de pago de facturas a contactos de clientes","transaction_id":"ID de transacci\u00f3n","your_payment_is_completed":"Su pago se complet\u00f3 con \u00e9xito.","your_payment_is_ont_completed":"Su pago no se ha completado."},"payment_mode":{"active":"Activo","add_new_payment_mode":"Agregar nuevo modo de pago","bank_accounts":"Cuentas bancarias","edit_payment_mode":"Editar modo de pago","invoices_only":"Solo facturas","new_payment_mode":"Nuevo modo de pago","no_payment_mode_available":"No hay modo de pago disponible.","no_payment_mode_found":"No se encontr\u00f3 ning\u00fan modo de pago.","on_invoice_pdf":"en Factura PDF","payment_mode_details":"Detalles del modo de pago","payment_mode_not_found":"Modo de pago no encontrado.","payment_mode_saved_successfully":"Modo de pago guardado correctamente.","payment_mode_updated_successfully":"Modo de pago actualizado con \u00e9xito.","payment_mode_used_somewhere_else":"Modo de pago utilizado en otro lugar.","selected_by_default_on_invoice":"Seleccionado por defecto en la factura","services_only":"Solo gastos","show":"Mostrar"},"payment_modes":"Modos de pago","placeholder":{"add_note":"A\u00f1adir la nota...","add_product":"Agregar producto","bill_tasks":"Facturar tareas","contact_number_is_invalid_number":"El n\u00famero de contacto no es un n\u00famero v\u00e1lido","enter_email":"Ingrese correo electr\u00f3nico","invalid_country_code":"C\u00f3digo de pa\u00eds no v\u00e1lido","invalid_number":"N\u00famero invalido","search_customers":"Buscar clientes","search_menu":"Men\u00fa de b\u00fasqueda","select_article_group":"Seleccionar grupo de art\u00edculos","select_assignee":"Seleccionar cesionario","select_billing_type":"Seleccionar tipo de facturaci\u00f3n","select_contact":"Seleccione Contactos","select_contract_type":"Seleccionar tipo de contrato","select_country":"Seleccionar pa\u00eds","select_currency":"Seleccione el tipo de moneda","select_customer":"Seleccionar cliente","select_department":"Seleccionar Departamento","select_discount_type":"Seleccionar tipo de descuento","select_document_type":"Seleccionar tipo de descuento","select_email_status":"Seleccione el estado del correo electr\u00f3nico","select_email_template":"Seleccionar plantilla de correo electr\u00f3nico","select_expanse_category":"Seleccionar categor\u00eda de gastos","select_file":"Seleccione Archivo","select_goal":"Seleccionar objetivo","select_goal_type":"Seleccionar tipo de objetivo","select_group":"Seleccionar grupos","select_groups":"Seleccionar grupos","select_internal_article":"Seleccionar art\u00edculo interno","select_item":"Seleccione un art\u00edculo","select_language":"Seleccione el idioma","select_lead":" Seleccionar cliente potencial","select_lead_source":"Seleccionar fuente de prospectos","select_member":"Seleccionar miembro","select_option":"Seleccionar opci\u00f3n","select_payment_mode":"Seleccionar modo de pago","select_predefined_reply":"Seleccionar respuesta predefinida","select_priority":"Seleccionar prioridad","select_product":"Seleccionar producto","select_product_group":"Seleccionar grupo de productos","select_reminder_to":"Seleccione Recordatorio para","select_sale_agent":"Seleccionar agente de ventas","select_service":"Seleccionar servicio","select_show_to_client":"Seleccione Mostrar al cliente","select_source":"Seleccionar fuente","select_status":"Seleccionar estado,","select_tags":"Seleccionar etiquetas","select_tax":"Seleccionar impuesto","select_tax1":"Seleccione Impuesto 1","select_tax2":"Seleccione Impuesto 2","select_template_type":"Seleccionar tipo de plantilla","select_ticket_priority":"Seleccionar prioridad de entradas","too_long":"Demasiado largo","too_short":"Demasiado corto","valid_number":"N\u00famero v\u00e1lido"},"please_enter_language_short_code":"Ingrese el c\u00f3digo corto del idioma. es decir, ingl\u00e9s = en.","predefined_replies":"Respuestas predefinidas","predefined_reply":{"add":"Agregar","add_new_predefined_reply":"Agregar nueva respuesta predefinida","body":"Cuerpo","edit_predefined_reply":"Editar respuesta predefinida","new_predefined_reply":"Nueva respuesta predefinida","no_predefined_reply_available":"No hay respuesta predefinida disponible.","no_predefined_reply_found":"No se encontr\u00f3 una respuesta predefinida.","predefined_reply_details":"Detalles de respuesta predefinidos","predefined_reply_not_found":"Respuesta predefinida no encontrada.","predefined_reply_saved_successfully":"Respuesta predefinida guardada correctamente.","predefined_reply_updated_successfully":"Respuesta predefinida actualizada correctamente.","reply_name":"Nombre de respuesta"},"product_group":{"add_new_product_group":"Agregar nuevo grupo de productos","edit_product_group":"Editar grupo de productos","new_product_group":"Nuevo grupo de productos","product_group_saved_successfully":"Grupo de productos guardado correctamente.","product_group_updated_successfully":"Grupo de productos actualizado con \u00e9xito.","product_group_used_somewhere_else":"Grupo de productos utilizado en otro lugar."},"product_groups":"Grupos de productos","products":{"edit_product":"Editar productoo","new_product":"Nuevo producto","product_group":"Grupo de productos","product_saved_successfully":"Producto guardado correctamente.","product_updated_successfully":"Producto actualizado correctamente.","products":"Productos","rate":"Velocidad","tax":"Impuesto","title":"T\u00edtulo","unit":"Unidad"},"profile":"Perfil","project":{"Calculate_progress_through_tasks":"Calcular el progreso a trav\u00e9s de las tareas","admin_area":"\u00e1rea de administraci\u00f3n","allow_customer_to":"Permitir al cliente","billing_type":"Tipo de facturaci\u00f3n","cancelled":"Cancelado","comment_on_project_tasks":"comentar las tareas del proyecto","create_tasks":"crear tareas","customer":"Cliente","deadline":"Fecha l\u00edmite","edit_project":"Editar proyecto","edit_tasks":"editar tareas","estimated_hours":"Horas estimadas","finished":"Terminado","hide_project_tasks_on_main_tasks_table":"ocultar tareas del proyecto en la tabla de tareas principal","in_progress":"En progreso","members":"Contacto","new_project":"Nuevo proyecto","no_project_available":"Ning\u00fan proyecto disponible","no_project_found":"Proyecto no encontrado","not_started":"No iniciado","on_hold":"En espera","only_task_created_from_contact":"solo tarea creada a partir del contacto","open_discussions":"discusiones abiertas","progress":"Progreso","project_details":"Detalles del proyecto","project_name":"Nombre del proyecto","project_saved_successfully":"Proyecto guardado correctamente.","project_settings":"Configuraci\u00f3n del proyecto","project_updated_successfully":"Proyecto actualizado correctamente.","projects_summary":"Resumen de proyectos","quick_invoices_info":"Informaci\u00f3n r\u00e1pida de facturas","send_project_created_email":"Enviar correo electr\u00f3nico creado por el proyecto","start_date":"Fecha de inicio","statistics_by_project_status":"Estad\u00edsticas por estado del proyecto","status":"Estado","task":"Tarea","total_projects":"Proyectos totales","upload_attachments_on_tasks":"cargar archivos adjuntos en tareas","upload_files":"subir archivos","view_account_statement":"Ver estado de cuenta","view_activity_log":"ver registro de actividad","view_finance_overview":"ver resumen de finanzas","view_gantt":"ver Gantt","view_milestones":"ver hitos","view_task_attachments":"ver archivos adjuntos de tareas","view_task_checklist_items":"ver elementos de la lista de verificaci\u00f3n de tareas","view_task_comments":"ver comentarios de tareas","view_task_total_logged_time":"ver el tiempo total registrado de la tarea","view_tasks":"ver tareas","view_team_members":"ver miembros del equipo","view_timesheets":"ver hojas de tiempo","visible_tables":"Tablas visibles"},"projects":"Proyectos","proposal":{"accept":"ACEPTAR","accepted":"ACEPTADO","adjustment":"Ajuste","amount":"Cantidad","amount_due":"Monto adeudado","assigned":"Asignado","authorized_signature":"Firma autorizada","bank":"Banco","bill_to":"Facturar a","comments":"Comentarios","convert":"Convertir","convert_proposal":"Convertir propuesta","date":"Fecha","decline":"DISMINUCI\u00d3N","declined":"RECHAZADO","discount":"Descuento","draft":"SEQU\u00cdA","drafted":"Redactada","edit_proposal":"Editar propuesta","item":"Art\u00edculo","lead":"Plomo","mark_as_accepted":"Marcar como aceptado","mark_as_declined":"Marcar como rechazado","mark_as_draft":"Marcar como borrador","mark_as_open":"Marcar como abierto","mark_as_revised":"Marcar como revisado","mark_as_send":"Marcar como env\u00edo","member":"Miembro","new_proposal":"Nueva propuesta","no_payments_available":"No hay pago disponible","no_proposal_available":"No hay propuesta disponible.","no_proposal_found":"No se encontr\u00f3 ninguna propuesta.","offer_details":"Detalles de la propuesta","offline_payment":"Pago sin conexi\u00f3n","online_payment":"Pago en l\u00ednea","open":"ABIERTO","open_till":"Abrir hasta","pay_now":"PAGAR AHORA","payment":"Pago","proposal":"Propuesta","proposal_date":"Fecha de propuesta","proposal_not_found":"Propuesta no encontrada.","proposal_number":"Numero de propuesta","proposal_overview":"RESUMEN DE LA PROPUESTA","proposal_pdf":"PDF de propuesta","proposal_prefix":"PRO-","proposal_saved_successfully":"Propuesta guardada correctamente.","proposal_to":"Propuesta a","proposal_updated_successfully":"Propuesta actualizada correctamente.","qty":"Cant.","rate":"Velocidad","related":"Relacionado","revised":"REVISADO","save_and_send":"Guardar y enviar","save_as_draft":"Guardar como borrador","sent":"ENVIADO","ship_to":"Enviar a","status":"Estado de propuesta","sub_total":"Sub Total","subject":"Sujeto","task":"Tarea","taxes":"Impuestos","to":"To","total":"Total","total_paid":"Total pagado","total_proposal":"Propuesta total","transactions":"Transacciones","view_proposal_as_customer":"Ver propuesta como cliente"},"proposals":"Propuestas","range":{"last_30":"\u00daltimos 30 d\u00edas","last_month":"El mes pasado","last_week":"La semana pasada","this_month":"Este mes","this_week":"Esta semana","today":"Este Dia"},"register":{"already_have_an_account":"\u00bfYa tienes una cuenta?","choose":"Choose","confirm_password":"Confirmar contrase\u00f1a","email":"Correo electr\u00f3nico","first_name":"Nombre","last_name":"Apellido","password":"Contrase\u00f1a","phone":"Tel\u00e9fono","profile_picture":"Imagen de perfil","register":"Registrarse","sign_in":"Iniciar sesi\u00f3n"},"reminder":{"add_new":"Agregar nuevo","description":"Descripci\u00f3n","edit_reminder":"Editar recordatorio","email_status":"Estado del correo electr\u00f3nico","is_notified":"Se notifica","new_reminder":"Nuevo recordatorio","no":"No","note":"Nota","note_text":"Tenga en cuenta que debe seleccionar la fecha y hora UTC, ya que los trabajos cron env\u00edan recordatorios seg\u00fan la hora UTC.","notified_date":"Fecha de notificaci\u00f3n","reminder_saved_successfully":"Recordatorio guardado correctamente.","reminder_to":"Recordatorio para","reminder_updated_successfully":"Recordatorio actualizado correctamente.","send_email_reminder":"Enviar correo electr\u00f3nico de recordatorio","sent":"Enviada","set_reminder":"Establecer recordatorio","ticket_reminder":"Recordatorios de tickets","yes":"S\u00ed"},"reminders":"Recordatorios","reset":{"confirm_password":"Confirmar contrase\u00f1a","email":"Correo electr\u00f3nico","password":"Contrase\u00f1a","recalled_your_login_info":"\u00bfRecuperaron su informaci\u00f3n de inicio de sesi\u00f3n?","reset_password":"Restablecer contrase\u00f1a","set_a_new_password":"Establecer una nueva contrase\u00f1a","sign_in":"Iniciar sesi\u00f3n"},"sales":"Ventas","service":{"add":"Agregar","edit_service":"Editar servicio","name":"Nombre","new_service":"Nuevo servicio","no_service_available":"No hay servicio disponible.","no_service_found":"No se encontr\u00f3 servicio.","service_not_found":"Servicio no encontrado.","service_saved_successfully":"Servicio guardado con \u00e9xito.","service_updated_successfully":"Servicio actualizado con \u00e9xito.","service_used_somewhere_else":"Servicio utilizado en otro lugar."},"services":"Servicios","setting":{"application_name":"Nombre de la aplicaci\u00f3n","choose":"Escoger","company_domain":"Dominio de la empresa","current_version":"Versi\u00f3n actual","favicon":"Favicon","file_type":"Tipo de archivo","logo":"Logotipo de la empresa","setting_updated_successfully":"Configuraci\u00f3n actualizada correctamente."},"settings":"Configuraci\u00f3n","staff":"Personal","status":{"additional_contact":"Contacto adicional","answered":"Contestado","attempted":"Intent\u00f3","cancelled":"Cancelado","closed":"Cerrado","contacted":"Contactada","finished":"Terminado","in_progress":"En progreso","new_opportunity":"Nueva oportunidad","not_attempted":"No intentado","not_started":"No iniciado","on_hold":"En espera","open":"Abrir"},"success":"\u00c9xito","support":"Soporte","tag":{"add":"Agregar","add_new_tag":"Agregar nueva etiqueta","description":"Descripci\u00f3n","edit_tag":"Editar etiqueta","name":"Nombre","new_tag":"Nueva etiqueta","no_tag_available":"No hay etiqueta disponible.","no_tag_found":"No se encontr\u00f3 ninguna etiqueta.","tag_details":"Detalles de la etiqueta","tag_not_found":"Etiqueta no encontrada.","tag_saved_successfully":"Etiqueta guardada correctamente.","tag_updated_successfully":"Etiqueta actualizada correctamente."},"tags":"Etiquetas","task":{"awaiting_feedback":"En espera de retroalimentaci\u00f3n","billable":"Facturable","completed":"Terminado","due_date":"Fecha de vencimiento","edit_task":"Editar tarea","hourly_rate":"Tarifa por hora","in_progress":"En progreso","name":"Nombre","new_task":"Nueva tarea","no_task_available":"No hay tarea disponible.","not_started":"No empezado","priority":"Prioridad","public":"P\u00fablico","related_to":"Relacionado con","start_date":"Fecha de inicio","status":"Estado","subject":"Asunto","task_details":"Detalles de la tarea","task_saved_successfully":"Tarea guardada correctamente.","task_status_updated_successfully":"Estado de la tarea actualizado con \u00e9xito.","task_updated_successfully":"Tarea actualizada con \u00e9xito.","testing":"Pruebas","ticket":"Boleto"},"tasks":"Tareas","tax_rate":{"edit_tax_rate":"Editar tasa impositiva","new_tax_rate":"Nueva tasa impositiva","no_tax_rate_available":"No hay tasa de impuestos disponible.","no_tax_rate_found":"No se encontr\u00f3 ninguna tasa de impuestos.","tax_rate":"Tasa de impuestos","tax_rate_not_found":"Tasa de impuestos no encontrada.","tax_rate_saved_successfully":"Tasa de impuestos guardada con \u00e9xito.","tax_rate_updated_successfully":"Tasa de impuestos actualizada correctamente."},"tax_rates":"Tasas de impuestos","this_week_payments":"Pagos de esta semana","ticket":{"add":"Agregar","added_by":"A\u00f1adido por","assign_to":"Asignar a","attachments":"Adjuntos","body":"Cuerpo","cc":"CC","contact":"Contacto","department":"Departamento","details":"Detalles","edit_ticket":"Editar ticket","email":"Correo electr\u00f3nico","name":"Nombre","new_ticket":"Nuevo ticket","no_ticket_available":"No hay boleto disponible.","no_ticket_found":"No se encontr\u00f3 ninguna entrada.","note":"Nota","predefined_reply":"Respuesta predefinida","priority":"Prioridad","reminder":"Recordatorio","service":"Servicio","subject":"Asunto","tags":"Etiquetas","task":"Tarea","ticket_details":"Detalles del ticket","ticket_not_found":"Ticket Not Found.","ticket_saved_successfully":"Boleto guardado con \u00e9xito.","ticket_status_updated_successfully":"Estado del ticket actualizado con \u00e9xito.","ticket_to_contact":"Boleto para contactar","ticket_updated_successfully":"Ticket actualizado con \u00e9xito.","ticket_without_contact":"Ticket sin contacto","tickets_status":"Estado de las entradas","you_can_add_multiples_images_and_files":"Puedes agregar varias im\u00e1genes y archivos."},"ticket_priorities":"Prioridad de ticket","ticket_priority":{"add":"Agregar","add_new_ticket_priority":"Agregar nueva prioridad de ticket","edit_ticket_priority":"Editar prioridad del ticket","name":"Nombre","new_ticket_priority":"Nueva prioridad del ticket","no_ticket_priority_available":"No hay prioridad de entrada disponible.","no_ticket_priority_found":"No se encontr\u00f3 prioridad de ticket.","ticket_priority_not_found":"Prioridad de ticket no encontrada.","ticket_priority_saved_successfully":"La prioridad del ticket se guard\u00f3 correctamente.","ticket_priority_updated_successfully":"Prioridad del ticket actualizada correctamente.","ticket_priority_used_somewhere_else":"Ticket prioritario utilizado en otro lugar."},"ticket_status":{"add":"Agregar","add_new_ticket_status":"Agregar nuevo estado de ticket","color":"Color","edit_ticket_status":"Editar estado del ticket","name":"Nombre","new_ticket_status":"Nuevo estado del ticket","status_order":"Orden de estado","ticket_status":"Estado del ticket","ticket_status_saved_successfully":"Estado del ticket guardado correctamente.","ticket_status_updated_successfully":"Estado del ticket actualizado con \u00e9xito.","ticket_status_used_somewhere_else":"Estado del boleto utilizado en otro lugar."},"tickets":"Entradas","translation_manager":"Gerente de traducci\u00f3n","translator_manager":{"edit_language":"Editar idioma","language_added_successfully":"Idioma agregado correctamente.","language_short_code":"Ingrese el c\u00f3digo corto de idioma. es decir, ingl\u00e9s = en","language_updated_successfully":"Idioma actualizado con \u00e9xito.","translation":"Traducci\u00f3n"},"user":{"change_language":"Cambiar idioma","change_password":"Cambiar contrase\u00f1a","edit_profile":"Editar perfil","email":"Correo electr\u00f3nico","first_name":"Nombre","language_updated_successfully":"Idioma actualizado con \u00e9xito.","last_name":"Apellido","logout":"Cerrar sesi\u00f3n","name":"Nombre","password":"Contrase\u00f1a","password_confirmation":"Confirmar contrase\u00f1a","password_updated_successfully":"Contrase\u00f1a actualizada correctamente.","phone":"Tel\u00e9fono","profile":"Perfil","profile_updated_successfully":"Perfil actualizado correctamente.","return_to_admin":"Volver al administrador"},"users":"Usuarios","weekdays":{"fri":"VIE","mon":"LUN","sat":"Se sent\u00f3","sun":"SOL","thu":"JUE","tue":"MAR","wed":"CASARSE"}},"es.pagination":{"next":"Pr\u00f3ximo &raquo;","previous":"&laquo; Previo"},"es.passwords":{"reset":"Tu contrase\u00f1a ha sido restablecida!","sent":"Hemos enviado su enlace de restablecimiento de contrase\u00f1a por correo electr\u00f3nico!","throttled":"Por favor espere antes de volver a intentar.","token":"Este token de restablecimiento de contrase\u00f1a no es v\u00e1lido.","user":"No podemos encontrar un usuario con esa direcci\u00f3n de correo electr\u00f3nico."},"es.validation":{"accepted":"El :attribute debe ser aceptado.","active_url":"El :attribute no es una URL v\u00e1lida.","after":"El :attribute debe ser una fecha despu\u00e9s de :date.","after_or_equal":"El :attribute debe ser una fecha posterior o igual a :date.","alpha":"El :attribute solo puede contener letras.","alpha_dash":"El :attribute solo puede contener letras, n\u00fameros, guiones y guiones bajos.","alpha_num":"El :attribute solo puede contener letras y n\u00fameros.","array":"El :attribute debe ser una matriz.","attributes":[],"before":"El :attribute debe ser una fecha anterior a :date.","before_or_equal":"El :attribute debe ser una fecha anterior a :date","between":{"array":"El :attribute debe tener entre :min y :max items.","file":"El :attribute debe estar entre :min y :max kilobytes.","numeric":"El :attribute debe estar entre :min y :max.","string":"El :attribute debe estar entre :min y :max caracteres."},"boolean":"El campo: :attribute debe ser verdadero o falso.","confirmed":"La confirmaci\u00f3n de :attribute no coincide.","custom":{"attribute-name":{"rule-name":"mensaje personalizado"}},"date":"El :attribute no es una fecha v\u00e1lida.","date_equals":"El :attribute debe ser una fecha igual a :date.","date_format":"El :attribute no coincide con el formato :format.","different":"El :attribute y :otro deben ser diferentes.","digits":"El :attribute debe ser :d\u00edgitos d\u00edgitos.","digits_between":"El :attribute debe estar entre :min y d\u00edgitos :max imos.","dimensions":"El :attribute tiene dimensiones de imagen no v\u00e1lidas.","distinct":"El campo :attribute tiene un valor duplicado.","email":"El :attribute debe ser una direcci\u00f3n de correo electr\u00f3nico v\u00e1lida.","ends_with":"El :attribute debe terminar con uno de los siguientes :values.","exists":"El :attribute seleccionado: no es v\u00e1lido.","file":"El :attribute debe ser un archivo.","filled":"El campo :attribute debe tener un valor.","gt":{"array":"El :attribute debe tener m\u00e1s de elementos de :value.","file":"El :attribute debe ser mayor que :value kilobytes.","numeric":"El :attribute debe ser mayor que :value.","string":"El :attribute debe ser mayor que caracteres de :value."},"gte":{"array":"El :attribute debe tener elementos de :valor o m\u00e1s.","file":"El :attribute debe ser mayor o igual :value kilobytes.","numeric":"El :attribute debe ser mayor o igual que :value.","string":"El :attribute debe ser mayor o igual que caracteres de :value."},"image":"El :attribute debe ser una imagen.","in":"El :attribute seleccionado: no es v\u00e1lido.","in_array":"El campo :attribute no existe en :other.","integer":"El: :attribute debe ser un entero.","ip":"El: :attribute debe ser una direcci\u00f3n IP v\u00e1lida.","ipv4":"El: :attribute debe ser una direcci\u00f3n IPv4 v\u00e1lida.","ipv6":"El: :attribute debe ser una direcci\u00f3n IPv6 v\u00e1lida.","json":"El :attribute debe ser una cadena JSON v\u00e1lida.","lt":{"array":"El :attribute debe tener menos de elementos de :value.","file":"El :attribute debe ser menor que :value kilobytes.","numeric":"El :attribute debe ser menor que :value.","string":"El :attribute debe ser menor que caracteres de :value."},"lte":{"array":"El :attribute no debe tener m\u00e1s de elementos de :value.","file":"El :attribute debe ser menor o igual :value kilobytes.","numeric":"El :attribute debe ser menor o igual que :value.","string":"El :attribute debe ser menor o igual que caracteres de :value."},"max":{"array":"El :attribute no puede tener m\u00e1s de: elementos :max imos.","file":"El :attribute no puede ser mayor que: kilobytes :max imos.","numeric":"El :attribute no puede ser mayor que :max.","string":"El :attribute no puede ser mayor que: caracteres :max imos."},"mimes":"El :attribute debe ser un archivo de tipo :values.","mimetypes":"El :attribute debe ser un archivo de tipo :values.","min":{"array":"El :attribute debe tener al menos elementos :min imos.","file":"El :attribute debe ser al menos :min kilobytes.","numeric":"El :attribute debe ser al menos :min.","string":"El :attribute debe tener al menos caracteres :min."},"not_in":"El :attribute seleccionado: no es v\u00e1lido.","not_regex":"El formato del :attribute no es v\u00e1lido.","numeric":"El :attribute debe ser un n\u00famero.","password":"La contrase\u00f1a es incorrecta.","present":"El campo de :attribute debe estar presente.","regex":"El formato del :attribute no es v\u00e1lido.","required":"El campo de :attribute es obligatorio.","required_if":"El campo: :attribute es obligatorio cuando :other es :value.","required_unless":"El campo: :attribute es obligatorio a menos que :other est\u00e9 en :values.","required_with":"El campo: :attribute es obligatorio cuando :values est\u00e1n presentes.","required_with_all":"El campo: :attribute es obligatorio cuando los :values est\u00e1n presentes.","required_without":"El campo: :attribute es obligatorio cuando los :values no est\u00e1n presentes.","required_without_all":"El campo: :attribute es obligatorio cuando ninguno de los :values est\u00e1 presente.","same":"El :attribute y :other deben coincidir.","size":{"array":"El :attribute debe contener art\u00edculos de :size.","file":"El :attribute debe ser: size kilobytes.","numeric":"El :attribute debe ser: size.","string":"El :attribute debe ser caracteres de :size."},"starts_with":"El :attribute debe comenzar con uno de los siguientes :values.","string":"El: :attribute debe ser una cadena.","timezone":"El: :attribute debe ser una zona v\u00e1lida.","unique":"El :attribute ya se ha tomado.","uploaded":"El :attribute no se pudo cargar.","url":"El formato del :attribute no es v\u00e1lido.","uuid":"El: :attribute debe ser un UUID v\u00e1lido."},"fr.auth":{"failed":"Ces informations d'identification ne correspondent pas \u00e0 nos enregistrements.","throttle":"Trop de tentatives de connexion. Veuillez r\u00e9essayer dans: seconds secondes."},"fr.messages":{"activity_log":{"activity_logs":"Journaux d'activit\u00e9","loading_more_date":"Chargement de plus de donn\u00e9es","sorry_we_not_find_any_data":"Nous ne pouvons trouver aucune donn\u00e9e, faites au moins 1 entr\u00e9e","we_could_find_any_data":"Nous n'avons trouv\u00e9 aucune donn\u00e9e D\u00e9sol\u00e9"},"address":{"city":"Ville","country":"Pays","state":"Etat","street":"rue","zip_code":"Code postal"},"announcement":{"add":"Ajouter","announcement_date":"Date d'annonce","announcement_details":"D\u00e9tails de l'annonce","announcement_not_found":"Annonce introuvable","announcement_saved_successfully":"Anuncio guardado correctamente.","announcement_updated_successfully":"Anuncio actualizado con \u00e9xito.","edit_announcement":"Modifier l'annonce","message":"Message","new_announcement":"Nouvelle annonce","no_announcement_available":"Aucune annonce disponible","no_announcement_found":"Aucune annonce trouv\u00e9e.","show_my_name":"Afficher mon nom","show_to_clients":"Afficher aux clients","show_to_staff":"Afficher au personnel","subject":"Mati\u00e8re"},"announcements":"Annonces","article":{"add":"Ajouter","article_details":"D\u00e9tails de l'article","article_not_found":"Article introuvable.","article_saved_successfully":"Art\u00edculo guardado correctamente.","article_updated_successfully":"Art\u00edculo actualizado con \u00e9xito.","attachment":"Attachement","description":"La description","disabled":"d\u00e9sactiv\u00e9","edit_article":"Modifier l'article","group":"Groupe","internal_article":"Article interne","new_article":"Nouvel article","no_article_available":"Aucun article disponible.","no_article_found":"Aucun article trouv\u00e9.","subject":"Mati\u00e8re","upload_image":"T\u00e9l\u00e9charger l'image"},"article_group":{"add_new_article_group":"Ajouter un nouveau groupe d'articles","article_group_saved_successfully":"Grupo de art\u00edculos guardado correctamente.","article_group_updated_successfully":"Grupo de art\u00edculos actualizado con \u00e9xito.","article_group_used_somewhere_else":"Groupe d'articles utilis\u00e9 ailleurs.","article_groups":"Groupes d'articles","color":"Couleur","edit_article_group":"Modifier le groupe d'articles","group_name":"Nom de groupe","new_article_group":"Nouveau groupe d'articles","order":"Ordre"},"articles":"Des articles","calendars":"Calendriers","change_password":{"change_information_about_yourself_on_this_page":"Changez les informations vous concernant sur cette page.","confirm_password":"Confirmer le mot de passe","current_password":"Mot de passe actuel","edit_profile":"Modifier le profil","new_password":"Nouveau mot de passe"},"client_dashboard":"Tableau de bord client","cms":"CMS","comment":{"add_comment":"Ajouter un commentaire","added_by":"Ajout\u00e9 par","comments_saved_successfully":"Comentario guardado correctamente.","comments_updated_successfully":"Comentario actualizado correctamente.","edit_comment":"Modifier le commentaire","new_comment":"Nouveau commentaire","no_comments_added_yet":"Aucun commentaire n'a encore \u00e9t\u00e9 ajout\u00e9"},"comments":"commentaires","common":{"action":"action","active":"Actif","add":"Ajouterd","admin_note":"Note d'administration","announcement":"Annonce","apply":"Appliquer","article":"Article","article_group":"Groupe d'articles","assignee":"Cessionnaire","attachment_deleted":"La pi\u00e8ce jointe a \u00e9t\u00e9 supprim\u00e9e.","back":"Arri\u00e8re","cancel":"Annuler","choose":"Choisir","client_note":"Note du client","contract_type":"Type de contrat","country":"Pays","created_on":"Cr\u00e9\u00e9 sur","custom":"Personnalis\u00e9","customer":"Client","customer_group":"Groupe de clients","data_base_entries":"Affichage de _START_ \u00e0 _END_ entr\u00e9es sur _TOTAL_","deactive":"D\u00e9sactiver","default_country_code":"Code pays par d\u00e9faut","delete":"Supprimer","delete_attachment":"Voulez-vous vraiment supprimer cette \"pi\u00e8ce jointe\"?","delete_confirm":"Veuillez saisir","delete_confirm_common":"Voulez-vous vraiment supprimer ce","delete_note":"Voulez-vous vraiment supprimer cette \"Note\"?","deleted":"Supprim\u00e9!","department":"d\u00e9partement","description":"La description","download":"T\u00e9l\u00e9charger","download_as_pdf":"T\u00e9l\u00e9charger au format PDF","drafted":"R\u00e9dig\u00e9","edit":"\u00c9diter","email":"Email","expense":"Frais","expense_category":"Cat\u00e9gorie de d\u00e9penses","filter_by":"(filtr\u00e9 \u00e0 partir de _MAX_ entr\u00e9es au total)","from":"De","goal":"Objectif","has_been_delete":" a \u00e9t\u00e9 supprim\u00e9.","incomes_vs_expenses":"Revenus vs d\u00e9penses","last_updated":"Derni\u00e8re mise \u00e0 jour","lead":"Conduire","lead_source":"Source principale","menu_entry":"Afficher les entr\u00e9es du _MENU_","n\/a":"N\/A","name":"Nom","no":"Non","no_data_available_in_table":"Keine Daten in der Tabelle verf\u00fcgbar","no_entry":"Affichage de 0 \u00e0 0 sur 0 entr\u00e9es","no_matching":"Aucun enregistrements correspondants trouv\u00e9s","note":"Note","note_delete":"La note a \u00e9t\u00e9 supprim\u00e9e.","of":"De","ok":"D'ACCORD","payment_mode":"Mode de paiement","predefined_reply":"R\u00e9ponse pr\u00e9d\u00e9finie","product_1":"Produit","product_group":"Groupe de produits","product_header":"Produit","proposal":"Proposition","quantity_is_not_greater_than":"La cantidad no es mayor que 9999999","save":"sauver","search":"Chercher","search_results":"Vos r\u00e9sultats de recherche vont ici ...","service":"Service","showing":"Montrant","status":"Statut","tag":"\u00c9tiquette","tax_rate":"Taux d'imposition","term_and_conditions":"Termes et conditions","ticket_priority":"Priorit\u00e9 des billets","to":"\u00c0","to_delete_this":"pour supprimer ceci","total_amount":"Montant total","type_delete":"Veuillez taper \"effacer\" pour supprimer ceci","view":"Vue","weekly_payment_records":"Registres des paiements hebdomadaires","yes":"Oui"},"company":{"address":"Adresse","city":"Ville","company":"Nom de la soci\u00e9t\u00e9","company_information_format":"Format des informations sur la soci\u00e9t\u00e9 (PDF et HTML)","country_code":"Code du pays","currency":"Devise","details":"D\u00e9tails de la soci\u00e9t\u00e9","phone":"T\u00e9l\u00e9phone","state":"\u00c9tat","vat_number":"Num\u00e9ro de TVA","website":"Site Internet","zip_code":"Code postal"},"company_information":"Informations sur la soci\u00e9t\u00e9","contact":{"active":"Actif","by_deleting_this_contact":"En supprimant ce contact, tout son projet sera supprim\u00e9.","contact_details":"D\u00e9tails du contact","contact_not_found":"Contact introuvable.","contact_saved_successfully":"Contacto guardado correctamente.","contact_status_updated_successfully":"Estado de contacto actualizado con \u00e9xito.","contact_updated_successfully":"Contacto actualizado con \u00e9xito.","contract":"Contrat","contracts":"Contrats","credit_note":"Note de cr\u00e9dit","customer_name":"Nom du client","deactive":"D\u00e9sactiver","delete_contact_confirm":"Voulez-vous vraiment supprimer ce contact?","direction":"Direction","edit_contact":"Modifier le contact","email_notifications":"Notifications par email","estimate":"Estimation","estimates":"Estimations","first_name":"Pr\u00e9nom","full_name":"Nom complet","impersonate":"Imiter","invoice":"Facture d'achat","invoices":"Les factures","last_name":"Nom de famille","make_sure_to_set_appropriate_permissions_for_this_contact":"Assurez-vous de d\u00e9finir les autorisations appropri\u00e9es pour ce contact","new_contact":"Nouveau contact","no_contact_available":"Aucun contact n'est disponible.","no_contact_found":"Aucun contact trouv\u00e9.","password":"Mot de passe","permissions":"Autorisations","position":"Position","primary_contact":"Premier contact","project":"Projet","projects":"Projets","proposals":"Les propositions","send_password_email":"Envoyer l'e-mail de mot de passe SET","send_welcome_email":"Ne pas envoyer d'e-mail de bienvenue","support":"Soutien","task":"T\u00e2che","tickets":"Des billets"},"contacts":"Contacts","contract":{"add":"Ajouter","authorized_signature":"Signature autoris\u00e9e","contract_details":"D\u00e9tails du contrat","contract_list":"Liste des contrats","contract_not_found":"Contrat introuvable","contract_summary":"R\u00e9sum\u00e9 du contrat","contract_type_id":"Type de contrat","contract_value":"Valeur du contrat","contracts_by_type":"Contrats par type","contracts_expiring_this_month":"Contrats expirant ce mois-ci","contracts_saved_successfully":"Contrato guardado correctamente.","contracts_updated_successfully":"Contrato actualizado con \u00e9xito.","contracts_value_by_type":"Valeur des contrats par type","customer_id":"Client","description":"La description","edit_contract":"Modifier le contrat","end_date":"Date de fin","is_hide":"Cacher du client","is_trash":"Corbeille","new_contract":"Nouveau contrat","no_contract_available":"Aucun contrat disponible","no_contract_found":"Aucun contrat trouv\u00e9.","sign":"Signer","start_date":"Date de d\u00e9but","subject":"Sujet","task":"T\u00e2che"},"contract_type":{"add_new_contract_type":"Ajouter un nouveau type de contrat","contract_by_type":"Contrat par type","contract_type_saved_successfully":"Tipo de contrato guardado correctamente.","contract_type_updated_successfully":"Tipo de contrato actualizado correctamente.","contract_type_used_somewhere_else":"Type de contrat utilis\u00e9 ailleurs.","contract_value_by_type":"Valeur du contrat par type","edit_contract_type":"Modifier le type de contrat","new_contract_type":"Nouveau type de contrat"},"contract_types":"Types de contrat","contracts":"Contrats","countries":"Des pays","country":{"add":"Ajouter","country_not_found":"Pays non trouv\u00e9.","country_saved_successfully":"Pa\u00eds guardado correctamente.","country_updated_successfully":"Pa\u00eds actualizado con \u00e9xito.","country_used_somewhere_else":"Pays utilis\u00e9 ailleurs.","edit_country":"Modifier le pays","name":"Nom","new_country":"Nouveau pays","no_country_available":"Aucun pays disponible.","no_country_found":"Aucun pays trouv\u00e9."},"credit_note":{"authorized_signature":"Signature autoris\u00e9e","client_note":"Remarque","closed":"Ferm\u00e9e","credit_note":"Note de cr\u00e9dit","credit_note_date":"Date de la note de cr\u00e9dit","credit_note_details":"D\u00e9tails de la note de cr\u00e9dit","credit_note_details_updated_successfully":"Detalles de la nota de cr\u00e9dito actualizados con \u00e9xito.","credit_note_not_found":"Note de cr\u00e9dit introuvable.","credit_note_number":"Num\u00e9ro de note de cr\u00e9dit","credit_note_pdf":"Note de cr\u00e9dit PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"Nota de cr\u00e9dito guardada con \u00e9xito.","credit_note_updated_successfully":"Nota de cr\u00e9dito actualizada con \u00e9xito.","drafted":"R\u00e9dig\u00e9","edit_credit_note":"Modifier la note de cr\u00e9dit","invoice_credited":"Facture cr\u00e9dit\u00e9e","mark_as_closed":"Marquer comme ferm\u00e9","mark_as_draft":"Marquer comme brouillon","mark_as_open":"Marquer comme ouvert","mark_as_void":"Marquer comme nul","new_credit_note":"Nouvelle note de cr\u00e9dit","no_credit_note_available":"Aucune note de cr\u00e9dit disponible.","no_credit_note_found":"Aucune note de cr\u00e9dit trouv\u00e9e.","open":"Ouverte","quantity_is_not_greater_than":"La cantidad no es mayor que 9999999","reference":"R\u00e9f\u00e9rence","refunds":"Remboursements","save_and_send":"Enregistrer et envoyer","save_as_draft":"Enregistrer comme brouillon","terms_and_conditions":"Conditions g\u00e9n\u00e9rales","title":"Titre","view_credit_note_as_customer":"Afficher la note de cr\u00e9dit en tant que client","void":"N\u00e9ant"},"credit_notes":"Notes de cr\u00e9dit","customer":{"add_address_details":"Ajouter des d\u00e9tails d'adresse","address":"Adresse","address_details":"D\u00e9tails de l'adresse","address_not_found":"D\u00e9tails d'adresse non trouv\u00e9s.","billing_address":"Adresse de facturation","billing_address_details_not_available":"D\u00e9tails de l'adresse de facturation non disponibles","by_deleting_this_customer":"En supprimant ce client, tout son projet, contact, facture, devis, note de cr\u00e9dit, proposition et contrat seront supprim\u00e9s.","city":"Ville","company_name":"Nom de la compagnie","copy_billing_address":"Copier l'adresse de facturation","country":"Pays","currency":"Devise","customer_details":"D\u00e9tails du client","customer_saved_successfully":"El cliente se guard\u00f3 correctamente.","customer_updated_successfully":"El cliente se actualiz\u00f3 correctamente.","customers":"Les clients","default_language":"Langage par d\u00e9faut","delete_customer_confirm":"Voulez-vous vraiment supprimer ce client?","do_not_fill_shipping_address_customer_invoices":"Ne remplissez pas les informations d'adresse de livraison si vous n'utilisez pas l'adresse de livraison sur les factures des clients","edit_customer":"Modifier le client","groups":"Groupes","new_customer":"Nouveau client","no_customer_available":"Aucun client disponible.","no_customer_found":"Aucun client trouv\u00e9.","phone":"T\u00e9l\u00e9phone","same_as_a_customer_info":"Identique aux informations client","search_customer":"Rechercher un client","shipping_address":"Adresse de livraison","shipping_address_details_not_available":"D\u00e9tails de l'adresse de livraison non disponibles","state":"Etat","street":"rue","total_contact":"Nombre total de contacts","total_customers":"Nombre total de clients","total_project":"Projet total","type":"Type","vat_number":"Num\u00e9ro de TVA","website":"Site Internet","zip_code":"Code postal"},"customer_group":{"action":"action","add_new_customer_group":"Ajouter un nouveau groupe de clients","customer_group_saved_successfully":"Grupo de clientes guardado correctamente.","customer_group_updated_successfully":"Grupo de clientes actualizado con \u00e9xito.","description":"La description","edit_customer_group":"Modifier le groupe de clients","name":"Nom","new_customer_group":"Nouveau groupe de clients"},"customer_groups":"Groupes de clients","customers":"Les clients","dashboard":"Tableau de bord","department":{"department_not_found":"Departamento n\u00e3o encontrado.","department_saved_successfully":"Departamento guardado con \u00e9xito.","department_updated_successfully":"Departamento actualizado con \u00e9xito.","departments":"D\u00e9partements","edit_department":"Modifier le d\u00e9partement","hide_from_clients":"Masquer des clients","new_department":"Nouveau d\u00e9partement","no_department_available":"Nenhum departamento dispon\u00edvel.","no_department_found":"Aucun d\u00e9partement trouv\u00e9."},"edit_profile":{"change_password":"Changer le mot de passe","edit_profile":"Modifier le profil","hello":"Bonjour","hi":"Salut","login":"Connexion","login_register":"Connexion \/ Inscription","logout":"D\u00e9connexion","mark_all_as_read":"Tout marquer comme lu","notification":"Notifications","register":"S'inscrire","welcome":"Bienvenue"},"email":{"email":"E-mail","forgot_password":"Mot de passe oubli\u00e9","recalled_your_login_info":"Vous avez rappel\u00e9 vos informations de connexion?","reset_password":"R\u00e9initialiser le mot de passe","send_reset_link":"Envoyer le lien de r\u00e9initialisation","sign_in":"Se connecter"},"email_template":{"available_merge_fields":"Champs de fusion disponibles","disabled":"D\u00e9sactiv\u00e9","edit_email_template":"Modifier le mod\u00e8le d'e-mail","email_message":"Message \u00e9lectronique","enable":"Activer","from_name":"Du nom","send_plain_text":"Envoyer en texte clair","subject":"Sujet","template_name":"Nom du mod\u00e8le"},"email_templates":"Mod\u00e8les d'e-mails","error":"Erreur","estimate":{"Adjust":"Ajustement","accepted":"ACCEPT\u00c9","amount":"Montant","amount_due":"Montant d\u00fb","authorized_signature":"Signature autoris\u00e9e","bill_to":"Facturer","client_note":"Note client","convert_estimate":"Convertir l'estimation","convert_estimate_to_invoice":"Convertir presupuesto a factura correctamente.","declined":"DIMINU\u00c9","discount":"Remise","draft":"BROUILLON","drafted":"R\u00e9dig\u00e9","edit_estimate":"Modifier l'estimation","estimate":"Estimation","estimate_date":"Date estim\u00e9e","estimate_details":"D\u00e9tails de l'estimation","estimate_not_found":"Estimation introuvable","estimate_number":"Nombre estim\u00e9","estimate_overview":"APER\u00c7U DES ESTIMATIONS","estimate_pdf":"Estimer le PDF","estimate_prefix":"EN-","estimate_saved_successfully":"Estimaci\u00f3n guardada con \u00e9xito.","estimate_status_updated_successfully":"Estado estimado actualizado con \u00e9xito.","estimate_updated_successfully":"Estimaci\u00f3n actualizada correctamente.","expired":"EXPIRED","expiry_date":"Date d'expiration","item":"Produit","mark_as_accepted":"Marquer comme accept\u00e9","mark_as_declined":"Marquer comme refus\u00e9","mark_as_draft":"Marquer comme brouillon","mark_as_expired":"Marquer comme expir\u00e9","mark_as_send":"Marquer comme envoi","more":"Plus","new_estimate":"Nouvelle estimation","no_estimate_available":"Aucune estimation disponible","no_estimate_found":"Aucune estimation trouv\u00e9e.","not_sent":"PAS ENVOY\u00c9","qty":"Qt\u00e9","rate":"Taux","save_and_send":"Enregistrer et envoyer","save_as_draft":"Enregistrer comme brouillon","sent":"EXP\u00c9DI\u00c9","ship_to":"Exp\u00e9dier \u00e0","status":"Statut","sub_total":"Sous-total","task":"T\u00e2che","taxes":"Les imp\u00f4ts","terms_conditions":"Conditions g\u00e9n\u00e9rales","title":"Titre","total":"Total","total_estimates":"Estimations totales","total_paid":"Total pay\u00e9","view_estimate_as_customer":"Afficher l'estimation en tant que client"},"estimates":"Estimations","expense":{"add":"Ajouter","amount":"Montant","amount_with_tax":"Montant avec taxe","apply_tax":"Appliquer la taxe","apply_tax_message":"Soustraire le total des taxes du montant","attachment":"Attachement","auto_create_invoice":"Cr\u00e9er automatiquement une facture","billable":"Facturable","choose_file":"Choisir un fichier","currency":"Devise","customer":"Client","details":"D\u00e9tails","edit_expense":"Modifier les d\u00e9penses","expense_amount":"Montant des d\u00e9penses","expense_category":"Cat\u00e9gorie de d\u00e9penses","expense_category_by_chart":"Cat\u00e9gorie de d\u00e9penses par graphique","expense_date":"Date de la d\u00e9pense","expense_details":"D\u00e9tails des d\u00e9penses","expense_list":"Liste de d\u00e9penses","expense_not_found":"D\u00e9pense non trouv\u00e9e.","expense_saved_successfully":"Gasto guardado con \u00e9xito.","expense_updated_successfully":"Gasto actualizado con \u00e9xito.","name":"Nom","new_expense":"Nouvelle d\u00e9pense","no_expense_available":"Aucune d\u00e9pense disponible.","no_expense_found":"Aucune d\u00e9pense trouv\u00e9e.","note":"Remarque","notes":"Notes","payment_mode":"Mode de paiement","preview_attachment":"Aper\u00e7u de la pi\u00e8ce jointe","reception_attachment":"Pi\u00e8ce jointe au re\u00e7u","reference":"R\u00e9f\u00e9rence","reminders":"Rappel","send_email":"Envoyer la facture au courrier \u00e9lectronique du client lors de la recr\u00e9ation des d\u00e9penses","tax_1":"Taxe 1 (en%)","tax_2":"Taxe 2 (en%)","tax_applied":"Taxe appliqu\u00e9e","view_attachment":"Afficher la pi\u00e8ce jointe"},"expense_by_category":"D\u00e9penses par cat\u00e9gorie","expense_categories":"Cat\u00e9gories de d\u00e9penses","expense_category":{"add_new_expense_category":"Ajouter une nouvelle cat\u00e9gorie de d\u00e9penses","edit_category":"Modifier la cat\u00e9gorie de d\u00e9penses","expense_categories":"Cat\u00e9gories de d\u00e9penses","expense_category":"Cat\u00e9gorie de d\u00e9penses","expense_category_saved_successfully":"Categor\u00eda de gastos guardada correctamente.","expense_category_updated_successfully":"Categor\u00eda de gastos actualizada con \u00e9xito.","expense_category_used_somewhere_else":"Cat\u00e9gorie de d\u00e9penses utilis\u00e9e ailleurs.","new_category":"Nouvelle cat\u00e9gorie de d\u00e9penses"},"expenses":"D\u00e9penses","general":"G\u00e9n\u00e9ral","goal":{"achievement":"R\u00e9ussite","add":"Ajouter","description":"La description","edit_goal":"Modifier l'objectif","end_date":"Date de fin","goal_details":"D\u00e9tails de l'objectif","goal_id":"Type d'objectif","goal_saved_successfully":"Objetivo guardado con \u00e9xito.","goal_type":"Type d'objectif","goal_updated_successfully":"Objetivo actualizado con \u00e9xito.","is_not_notify":"Avertir les membres du personnel lorsque l'objectif n'a pas \u00e9t\u00e9 atteint","is_notify":"Avertir les membres du personnel lorsque l'objectif est atteint","new_goal":"Nouveau but","no_goal_available":"Aucun objectif disponible.","no_goal_found":"Aucun objectif trouv\u00e9.","progress":"Le progr\u00e8s","staff_member":"Membre du staff","start_date":"Date de d\u00e9but","subject":"Mati\u00e8re","user_id":"Membre du personnel"},"goal_type":{"description":"La description","edit_goal_type":"Modifier le type d'objectif","name":"Nom","new_goal_type":"Nouveau type d'objectif"},"goals":"Buts","incomes":"Revenus","invoice":{"activity_log":"Journal d'activit\u00e9","add_item":"Ajouter un produit","add_shipping_address":"Ajouter une adresse de livraison","adjustment":"Ajustement","admin_note":"Note d'administration","allowed_payment_modes_for_this_invoice":"Modes de paiement autoris\u00e9s pour cette facture","amount":"Montant","amount_due":"Montant d\u00fb","authorized_signature":"Signature autoris\u00e9e","bank":"Banque","bill_tasks":"T\u00e2ches de facturation","bill_to":"facturer","cancelled":"ANNUL\u00c9","client_note":"Note du client","currency":"Devise","customer":"Client","discount":"Remise","discount_type":"Type de remise","draft":"BROUILLON","drafted":"R\u00e9dig\u00e9","due_date":"Date d'\u00e9ch\u00e9ance","edit_contract_type":"Modifier le type de contrat","edit_invoice":"Modifier la facture","fixed":"Fix\u00e9","hours":"Heures","hsn_tax":"Code fiscal HSN","invoice":"Facture d'achat","invoice_date":"Date de la facture","invoice_details":"D\u00e9tails de la facture","invoice_not_found":"Facture introuvable.","invoice_number":"Num\u00e9ro de facture","invoice_overview":"APER\u00c7U DE LA FACTURE","invoice_payments":"Paiements de factures","invoice_pdf":"Facture PDF","invoice_prefix":"INV-","invoice_saved_successfully":"Factura guardada correctamente.","invoice_updated_successfully":"Factura actualizada correctamente.","item":"Produit","mark_as_cancelled":"Marquer comme annul\u00e9","mark_as_draft":"Marquer comme brouillon","mark_as_paid":"Marquer comme pay\u00e9","mark_as_partially_paid":"Marquer comme partiellement pay\u00e9","mark_as_sent":"Marquer comme envoy\u00e9","more":"Plus","new_contract_type":"Nouveau type de contrat","new_invoice":"Nouvelle facture","no_invoice_available":"Aucune facture disponible.","no_invoice_found":"Aucune facture trouv\u00e9e.","no_payments_available":"Aucun paiement disponible","not_sent":"PAS ENVOY\u00c9","notes":"Remarques","offline_payment":"Paiement hors ligne","online_payment":"Paiement en ligne","overdue":"EN RETARD","paid":"Pay\u00e9","paid_cap":"PAY\u00c9","partially_paid":"Partiellement pay\u00e9","partially_paid_cap":"PARTIELLEMENT PAY\u00c9","pay_now":"Payez maintenant","payment":"Paiement","payment_details":"D\u00e9tails de paiement","payments":"Paiements","prevent_sending_overdue_reminders_for_this_invoice":"Emp\u00eacher l'envoi de rappels en retard pour cette facture","qty":"Qt\u00e9","qty\/hours":"Qt\u00e9 \/ heures","qty_hours":"Qt\u00e9 \/ heures","quick_invoices_info":"Informations sur les factures rapides","recurring_invoice":"Facture r\u00e9currente","reminders":"Rappels","sale_agent":"Agent de vente","save_and_send":"Enregistrer et envoyer","save_as_draft":"Enregistrer comme brouillon","ship_to":"Envoyez \u00e0","show_quantity_as":"Afficher la quantit\u00e9 comme","sub_total":"Sous-total","task":"T\u00e2che","taxes":"Les imp\u00f4ts","terms_conditions":"termes et conditions","title":"Titre","total":"Total","total_invoices":"Total des factures","total_paid":"Total pay\u00e9","transactions":"Transactions","unmark_as_cancelled":"Annuler la marque comme annul\u00e9","unpaid":"Non pay\u00e9","unpaid_cap":"NON PAY\u00c9","view_invoice_as_customer":"Afficher la facture en tant que client"},"invoices":"Les factures","kanban_list":"Liste KANBAN","kanban_view":"Vue KANBAN","last_week_payments":"Paiements de la semaine derni\u00e8re","lead":{"chart":"Graphique","contacted_today":"Contact\u00e9 aujourd'hui","convert_to_customer":"Convertir en client","date_contacted":"Date de contact","details":"D\u00e9tails","edit_lead":"Modifier le prospect","estimate_budget":"Budget estim\u00e9","lead_convert_customer":"Client de conversion de plomb","lead_convert_customer_chart":"Graphique des clients de conversion de leads","lead_details":"D\u00e9tails du prospect","lead_list":"Liste des prospects","lead_not_found":"Prospect non trouv\u00e9.","lead_saved_successfully":"Prospecto guardado con \u00e9xito.","lead_status_updated_successfully":"Estado de cliente potencial actualizado con \u00e9xito.","lead_updated_successfully":"Prospecto actualizado con \u00e9xito.","leads_overview":"Aper\u00e7u des leads","member":"Membre","name":"Nom","new_lead":"Nouveau prospect","no_lead_available":"Aucune piste disponible.","no_lead_found":"Aucune piste trouv\u00e9e.","notes":"Remarques","reminder":"Rappel","source":"Source","task":"T\u00e2che"},"lead_convert_to_customer":"Convertir le prospect en client","lead_source":{"add":"Ajouter","edit_lead_source":"Modifier la source de la piste","lead_source_count":"Nombre de leads","lead_source_not_found":"Source principale non trouv\u00e9e.","lead_source_saved_successfully":"Fuente de cliente potencial guardada correctamente.","lead_source_updated_successfully":"Fuente de cliente potencial actualizada con \u00e9xito.","name":"Nom","new_lead_source":"Nouvelle source principale","no_lead_source_available":"Aucune source de plomb disponible.","no_lead_source_found":"Aucune source principale trouv\u00e9e."},"lead_sources":"Sources de plomb","lead_status":{"add":"Ajouter","add_new_lead_status":"Ajouter un nouveau statut de prospect","color":"Couleur","edit_lead_status":"Modifier le statut du prospect","lead_status":"Statut du lead","lead_status_saved_successfully":"Estado del cliente potencial guardado correctamente.","lead_status_updated_successfully":"Estado de cliente potencial actualizado con \u00e9xito.","lead_status_used_somewhere_else":"Statut de prospect utilis\u00e9 ailleurs.","name":"Nom","new_lead_status":"Nouveau statut de prospect","order":"Ordre"},"leads":"Pistes","list_view":"Liste Vue","login":{"Remember_me":"Se souvenir de moi","admin":"Administrateur","client":"Client","create_one":"Cr\u00e9er une","don't have an account":"Vous n \\ 'avez pas de compte?","email":"E-mail","forgot_password":"Mot de passe oubli\u00e9","login":"Connexion","password":"Mot de passe"},"member":{"add":"Ajouter","by_deleting_this_member":"En supprimant ce membre, tous ses projets, propositions et objectifs seront supprim\u00e9s.","choose":"Choisir","created_on":"Cr\u00e9\u00e9 le","default_language":"Langue par d\u00e9faut","delete_member_confirm":"Voulez-vous vraiment supprimer ce membre?","direction":"Direction","edit_member":"Modifier le membre","email":"E-mail","email_is_not_verified":"L'email n'est pas verifi\u00e9","email_is_verified":"L'e-mail est v\u00e9rifi\u00e9","email_verified":"email verificado","email_verified_successfully":"Correo electr\u00f3nico verificado con \u00e9xito.","email_verify":"Verifica\u00e7\u00e3o de e-mail","facebook":"Facebook","first_name":"Pr\u00e9nom","hourly_rate":"Tarif horaire","image":"Profil","is_administrator":"Administrateur","is_enable":"Enable Two Factor Authentication","last_name":"Nom de famille","linkedin":"Linkedin","member_details":"D\u00e9tails du membre","member_informations":"Information sur les membres","member_not_found":"Membre introuvable.","member_saved_successfully":"Miembro guardado correctamente.","member_security":"S\u00e9curit\u00e9 des membres","member_status_updated_successfully":"Estado de miembro actualizado con \u00e9xito.","member_updated_successfully":"Miembro actualizado con \u00e9xito.","new_member":"Nouveau membre","no_member_available":"Aucun membre disponible.","no_member_found":"Aucun membre trouv\u00e9.","password":"Mot de passe","password_confirmation":"Confirmer le mot de passe","permissions":"Autorisations","phone":"T\u00e9l\u00e9phone","profile":"Profil","resend_email_verification":"Reenviar verifica\u00e7\u00e3o de e-mail","send_welcome_email":"Envoyer un e-mail de bienvenue","skype":"Skype","staff_member":"Pas membre du personnel","total_members":"Nombre total de membres","verification_mail_has_been_sent":"El correo electr\u00f3nico de verificaci\u00f3n se ha enviado correctamente."},"members":"Membres","menu_settings":"Param\u00e8tres du menu","months":{"apr":"Avr","aug":"Ao\u00fbt","dec":"D\u00e9c","feb":"F\u00e9v","jan":"Jan","jul":"Juil","jun":"Juin","mar":"Mar","may":"Peut","nov":"Nov","oct":"Oct","sep":"Sep"},"new_language":"Nouveau langage","no_matching_records_found":"Aucun enregistrements correspondants trouv\u00e9s","note":{"add_note":"Ajouter une note","edit_note":"Modifier la note","new_note":"Nouvelle note","no_notes_added_yet":"Aucune note ajout\u00e9e pour le moment","notes_saved_successfully":"Nota guardada correctamente.","notes_updated_successfully":"Nota actualizada correctamente."},"notes":"Remarques","notification":{"all_notification_read_successfully":"Todas las notificaciones se leyeron correctamente.","empty_notifications":"Nous n'avons trouv\u00e9 aucune notification","mark_all_as_read":"Tout marquer comme lu","notification_read_successfully":"Notificaci\u00f3n le\u00edda con \u00e9xito.","notifications":"Notifications"},"others":"Autres","payment":{"amount":"Montant","amount_received":"Montant re\u00e7u","date":"Date","new_payment":"Nouveau paiement","note":"Remarque","payment_date":"Date de paiement","payment_mode":"Mode de paiement","payment_saved_successfully":"Pago guardado con \u00e9xito.","send_mail_to_customer_contacts":"Ne pas envoyer de courrier \u00e9lectronique enregistr\u00e9 de paiement de facture aux contacts clients","transaction_id":"ID de transaction","your_payment_is_completed":"Su pago se complet\u00f3 con \u00e9xito.","your_payment_is_ont_completed":"Su pago no se ha completado."},"payment_mode":{"active":"Actif","add_new_payment_mode":"Ajouter un nouveau mode de paiement","bank_accounts":"Comptes bancaires","edit_payment_mode":"Modifier le mode de paiement","expenses_only":"D\u00e9penses seulement","invoices_only":"Factures uniquement","new_payment_mode":"Nouveau mode de paiement","no_payment_mode_available":"Aucun mode de paiement disponible.","no_payment_mode_found":"Aucun mode de paiement trouv\u00e9.","on_invoice_pdf":"sur facture PDF","payment_mode_details":"D\u00e9tails du mode de paiement","payment_mode_not_found":"Mode de paiement introuvable.","payment_mode_saved_successfully":"Modo de pago guardado correctamente.","payment_mode_updated_successfully":"Modo de pago actualizado con \u00e9xito.","payment_mode_used_somewhere_else":"Mode de paiement utilis\u00e9 ailleurs.","selected_by_default_on_invoice":"S\u00e9lectionn\u00e9 par d\u00e9faut sur la facture","show":"Spectacle"},"payment_modes":"Modes de paiement","placeholder":{"add_note":"Ajouter une note...","add_product":"Ajouter un produit","bill_tasks":"T\u00e2ches de facturation","contact_number_is_invalid_number":"Le num\u00e9ro de contact est un num\u00e9ro invalide","enter_email":"Entrez l'e-mail","invalid_country_code":"Code pays invalide","invalid_number":"Num\u00e9ro invalide","search_customers":"Rechercher des clients","search_menu":"Menu de recherche","select_article_group":"S\u00e9lectionner un groupe d'articles","select_assignee":"S\u00e9lectionnez le destinataire","select_billing_type":"S\u00e9lectionnez le type de facturation","select_contact":"S\u00e9lectionnez Contacts","select_contract_type":"S\u00e9lectionnez le type de contrat","select_country":"Choisissez le pays","select_currency":"S\u00e9lectionnez la devise","select_customer":"S\u00e9lectionnez le client","select_department":"S\u00e9lectionnez le d\u00e9partement","select_discount_type":"S\u00e9lectionnez le type de remise","select_document_type":"S\u00e9lectionnez le type de r\u00e9duction","select_email_status":"S\u00e9lectionnez le statut de l'e-mail","select_email_template":"S\u00e9lectionnez le mod\u00e8le d'e-mail","select_expanse_category":"S\u00e9lectionnez la cat\u00e9gorie de d\u00e9penses","select_file":"Choisir le dossier","select_goal":"S\u00e9lectionnez l'objectif","select_goal_type":"S\u00e9lectionnez le type d'objectif","select_group":"S\u00e9lectionner des groupes","select_groups":"S\u00e9lectionner des groupes","select_internal_article":"S\u00e9lectionnez l'article interne","select_item":"S\u00e9lectionnez l'\u00e9l\u00e9ment","select_language":"Choisir la langue","select_lead":"S\u00e9lectionnez le prospect","select_lead_source":"S\u00e9lectionnez la source du prospect","select_member":"S\u00e9lectionnez un membre","select_option":"S\u00e9lectionner une option","select_payment_mode":"S\u00e9lectionnez le mode de paiement","select_predefined_reply":"S\u00e9lectionnez une r\u00e9ponse pr\u00e9d\u00e9finie","select_priority":"S\u00e9lectionnez la priorit\u00e9","select_product":"S\u00e9lectionner un produit","select_product_group":"S\u00e9lectionnez le groupe de produits","select_reminder_to":"S\u00e9lectionnez Rappel \u00e0","select_sale_agent":"S\u00e9lectionnez l'agent de vente","select_service":"S\u00e9lectionnez le service","select_show_to_client":"S\u00e9lectionnez Afficher au client","select_source":"S\u00e9lectionner la source","select_status":"S\u00e9lectionnez le statut,","select_tags":"S\u00e9lectionnez les balises","select_tax":"S\u00e9lectionnez la taxe","select_tax1":"S\u00e9lectionnez Taxe 1","select_tax2":"S\u00e9lectionnez Taxe 2","select_template_type":"S\u00e9lectionnez le type de mod\u00e8le","select_ticket_priority":"S\u00e9lectionnez la priorit\u00e9 des billets","too_long":"Trop long","too_short":"Trop court","valid_number":"Nombre valide"},"please_enter_language_short_code":"Veuillez saisir le code de fonction de la langue. c'est-\u00e0-dire anglais = en.","predefined_replies":"R\u00e9ponses pr\u00e9d\u00e9finies","predefined_reply":{"add":"Ajouter","add_new_predefined_reply":"Ajouter une nouvelle r\u00e9ponse pr\u00e9d\u00e9finie","body":"Corps","edit_predefined_reply":"Modifier la r\u00e9ponse pr\u00e9d\u00e9finie","new_predefined_reply":"Nouvelle r\u00e9ponse pr\u00e9d\u00e9finie","no_predefined_reply_available":"Aucune r\u00e9ponse pr\u00e9d\u00e9finie disponible.","no_predefined_reply_found":"Aucune r\u00e9ponse pr\u00e9d\u00e9finie trouv\u00e9e.","predefined_reply_details":"D\u00e9tails de r\u00e9ponse pr\u00e9d\u00e9finis","predefined_reply_not_found":"R\u00e9ponse pr\u00e9d\u00e9finie introuvable.","predefined_reply_saved_successfully":"Respuesta predefinida guardada correctamente.","predefined_reply_updated_successfully":"Respuesta predefinida actualizada correctamente.","reply_name":"Nom de la r\u00e9ponse"},"product_group":{"add_new_product_group":"Ajouter un nouveau groupe de produits","edit_product_group":"Modifier le groupe de produits","new_product_group":"Nouveau groupe de produits","product_group_saved_successfully":"Grupo de productos guardado correctamente.","product_group_updated_successfully":"Grupo de productos actualizado con \u00e9xito.","product_group_used_somewhere_else":"Groupe de produits utilis\u00e9 ailleurs."},"product_groups":"Groupes de produits","products":{"edit_product":"Modifier le produit","new_product":"Nouveau produit","product_group":"Groupe de produits","product_saved_successfully":"Producto guardado correctamente.","product_updated_successfully":"Producto actualizado correctamente.","products":"Des produits","rate":"Taux","tax":"Taxe","title":"Titre","unit":"Unit\u00e9"},"profile":"Profil","project":{"admin_area":"zone d'administration","allow_customer_to":"Autoriser le client \u00e0","billing_type":"Type de facturation","calculate_progress_through_tasks":"Calculez la progression des t\u00e2ches","cancel":"Annul\u00e9","comment_on_project_tasks":"commentaire sur les t\u00e2ches du projet","create_tasks":"cr\u00e9er des t\u00e2ches","customer":"Client","deadline":"Date limite","done":"Termin\u00e9","edit_project":"Modifier le projet","edit_tasks":"modifier les t\u00e2ches","estimated_hours":"Heures estim\u00e9es","hide_project_tasks_on_main_tasks_table":"masquer les t\u00e2ches du projet sur le tableau des t\u00e2ches principales","in_progress":"En cours","members":"Contact","new_project":"Nouveau projet","no_project_available":"Nenhum projeto dispon\u00edvel","no_project_found":"Projet introuvable","not_started":"Pas commenc\u00e9","on_hold":"En attente","only_task_created_from_contact":"seule t\u00e2che cr\u00e9\u00e9e \u00e0 partir du contact","open_discussions":"discussions ouvertes","progress":"Progression","project_details":"d\u00e9tails du projet","project_name":"Nom du projet","project_saved_successfully":"Proyecto guardado correctamente.","project_settings":"Param\u00e8tres du projet","project_updated_successfully":"Proyecto actualizado correctamente.","projects_summary":"R\u00e9sum\u00e9 des projets","quick_invoices_info":"Informations sur les factures rapides","send_project_created_email":"Envoyer l'e-mail cr\u00e9\u00e9 par le projet","start_date":"Date de d\u00e9but","statistics_by_project_status":"Statistiques par statut de projet","status":"Statut","task":"T\u00e2che","total_projects":"Total des projets","upload_attachments_on_tasks":"t\u00e9l\u00e9charger des pi\u00e8ces jointes sur des t\u00e2ches","upload_files":"t\u00e9l\u00e9charger des fichiers","view_account_statement":"Afficher le relev\u00e9 de compte","view_activity_log":"afficher le journal d'activit\u00e9","view_finance_overview":"voir l'aper\u00e7u des finances","view_gantt":"afficher Gantt","view_milestones":"afficher les jalons","view_task_attachments":"afficher les pi\u00e8ces jointes de la t\u00e2che","view_task_checklist_items":"afficher les \u00e9l\u00e9ments de la liste de contr\u00f4le des t\u00e2ches","view_task_comments":"afficher les commentaires de la t\u00e2che","view_task_total_logged_time":"afficher la dur\u00e9e totale de journalisation de la t\u00e2che","view_tasks":"afficher les t\u00e2ches","view_team_members":"voir les membres de l'\u00e9quipe","view_timesheets":"afficher les feuilles de temps","visible_tables":"Tables visibles"},"projects":"Projets","proposal":{"accept":"ACCEPTER","accepted":"ACCEPT\u00c9","adjustment":"Ajustement","amount":"Montant","amount_due":"Montant d\u00fb","assigned":"Assign\u00e9","authorized_signature":"Signature autoris\u00e9e","bank":"Banque","bill_to":"Facturer \u00e0","comments":"Commentaires","convert":"Convertir","convert_proposal":"Convertir la proposition","date":"Date","decline":"D\u00c9CLIN","declined":"DIMINU\u00c9","discount":"Remise","draft":"BROUILLON","drafted":"R\u00e9dig\u00e9","edit_proposal":"Modifier la proposition","item":"Produit","lead":"Lead","mark_as_accepted":"Marquer comme accept\u00e9","mark_as_declined":"Marquer comme refus\u00e9","mark_as_draft":"Marquer comme brouillon","mark_as_open":"Marquer comme ouvert","mark_as_revised":"Marquer comme r\u00e9vis\u00e9","mark_as_send":"Marquer comme envoi","member":"Membre","new_proposal":"Nouvelle proposition","no_payments_available":"Aucun paiement disponible","no_proposal_available":"Aucune proposition disponible.","no_proposal_found":"Aucune proposition trouv\u00e9e.","offline_payment":"Paiement hors ligne","online_payment":"Paiement en ligne","open":"OUVERT","open_till":"Ouvert jusqu'\u00e0","pay_now":"PAYER MAINTENANT","payment":"Paiement","proposal":"Proposition","proposal_date":"Date de proposition","proposal_details":"D\u00e9tails de la proposition","proposal_not_found":"Proposition introuvable.","proposal_number":"Num\u00e9ro de proposition","proposal_overview":"APER\u00c7U DE LA PROPOSITION","proposal_pdf":"Proposition PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"Propuesta guardada correctamente.","proposal_to":"Proposition \u00e0","proposal_updated_successfully":"Propuesta actualizada correctamente.","qty":"Qt\u00e9","rate":"Taux","related":"en relation","revised":"MODIFI\u00c9","save_and_send":"Enregistrer et envoyer","save_as_draft":"Enregistrer comme brouillon","sent":"EXP\u00c9DI\u00c9","ship_to":"Exp\u00e9dier \u00e0","status":"Statut de la proposition","sub_total":"Sous-total","task":"T\u00e2che","taxes":"Taxes","title":"Titre","to":"\u00c0","total":"Total","total_paid":"Total pay\u00e9","total_proposal":"Proposition totale","transactions":"Transactions","view_proposal_as_customer":"Afficher la proposition en tant que client"},"proposals":"Les propositions","range":{"last_30":"Les 30 derniers jours","last_month":"Le mois dernier","last_week":"La semaine derni\u00e8re","this_month":"Ce mois-ci","this_week":"Cette semaine","today":"Aujourd'hui"},"register":{"already_have_an_account":"Vous avez d\u00e9j\u00e0 un compte?","choose":"Choisir","confirm_password":"Confirmer le mot de passe","email":"E-mail","first_name":"Pr\u00e9nom","last_name":"Nom de famille","password":"Mot de passe","phone":"T\u00e9l\u00e9phone","profile_picture":"Image de profil","register":"S'inscrire","sign_in":"Connexion"},"reminder":{"add_new":"Ajouter nouveau","description":"La description","edit_reminder":"Modifier le rappel","email_status":"\u00c9tat de l'e-mail","is_notified":"Est notifi\u00e9","new_reminder":"Nouveau rappel","no":"Non","note":"Noter","note_text":"Veuillez noter que vous devez s\u00e9lectionner la date et l'heure UTC, car les t\u00e2ches cron envoient des rappels selon l'heure UTC.","notified_date":"Date de notification","reminder_saved_successfully":"Recordatorio guardado correctamente.","reminder_to":"Rappel \u00e0","reminder_updated_successfully":"Recordatorio actualizado correctamente.","send_email_reminder":"Envoyer un e-mail de rappel","sent":"Exp\u00e9di\u00e9","set_reminder":"D\u00e9finir un rappel","ticket_reminder":"Rappels de billets","yes":"Oui"},"reminders":"Rappels","reset":{"confirm_password":"Confirmer le mot de passe","email":"E-mail","password":"Mot de passe","recalled_your_login_info":"Vous avez rappel\u00e9 vos informations de connexion?","reset_password":"R\u00e9initialiser le mot de passe","set_a_new_password":"D\u00e9finir un nouveau mot de passe","sign_in":"Se connecter"},"sales":"Ventes","service":{"add":"Ajouter","edit_service":"Modifier le service","name":"Nom","new_service":"Nouveau service","no_service_available":"Aucun service disponible.","no_service_found":"Aucun service trouv\u00e9.","service_not_found":"Service non trouv\u00e9.","service_saved_successfully":"Servicio guardado con \u00e9xito.","service_updated_successfully":"Servicio actualizado con \u00e9xito.","service_used_somewhere_else":"Service utilis\u00e9 ailleurs."},"services":"Prestations de service","setting":{"application_name":"Nom de l'application","choose":"Choisir","company_domain":"Domaine de l'entreprise","current_version":"Version actuelle","favicon":"Favicon","file_type":"Type de fichier","logo":"Logo de l'entreprise","setting_updated_successfully":"Configuraci\u00f3n actualizada correctamente."},"settings":"Param\u00e8tres","staff":"Personnel","status":{"additional_contact":"Contact suppl\u00e9mentaire","answered":"R\u00e9pondu","attempted":"Tentative","cancelled":"Annul\u00e9","closed":"Ferm\u00e9","contacted":"Contact\u00e9","finished":"Fini","in_progress":"En cours","new_opportunity":"Nouvelle opportunit\u00e9","not_attempted":"Pas tent\u00e9","not_started":"Pas commenc\u00e9","on_hold":"En attente","open":"Ouvert"},"success":"\u00c9xito","support":"Soutien","tag":{"add":"Ajouter","add_new_tag":"Ajouter une nouvelle balise","description":"La description","edit_tag":"Modifier la balise","name":"Nom","new_tag":"Nouveau tag","no_tag_available":"Aucune balise disponible.","no_tag_found":"Aucune balise trouv\u00e9e.","tag_details":"Detalhes da tag","tag_not_found":"Balise introuvable.","tag_saved_successfully":"Etiqueta guardada correctamente.","tag_updated_successfully":"Etiqueta actualizada correctamente."},"tags":"Mots cl\u00e9s","task":{"awaiting_feedback":"En attente d'un retour","billable":"Facturable","completed":"Termin\u00e9","due_date":"Date d'\u00e9ch\u00e9ance","edit_task":"Modifier la t\u00e2che","hourly_rate":"Tarif horaire","in_progress":"En cours","name":"Nom","new_task":"Nouvelle t\u00e2che","no_task_available":"Aucun billet disponible.","not_started":"Pas commenc\u00e9","priority":"Priorit\u00e9","public":"Public","related_to":"Relatif \u00e0","start_date":"Date de d\u00e9but","status":"Statut","subject":"Sujet","task_details":"D\u00e9tails de la t\u00e2che","task_saved_successfully":"Tarea guardada correctamente.","task_status_updated_successfully":"Estado de la tarea actualizado con \u00e9xito.","task_updated_successfully":"Tarea actualizada con \u00e9xito.","testing":"Essai","ticket":"Billet"},"tasks":"T\u00e2ches","tax_rate":{"edit_tax_rate":"Modifier le taux de taxe","new_tax_rate":"Nouveau taux d'imposition","no_tax_rate_available":"Aucun taux de taxe disponible.","no_tax_rate_found":"Aucun taux de taxe trouv\u00e9.","tax_rate":"Taux d'imposition","tax_rate_saved_successfully":"Taux de taxe enregistr\u00e9 avec succ\u00e8s.","tax_rate_updated_successfully":"Taux de taxe mis \u00e0 jour avec succ\u00e8s."},"tax_rates":"Les taux d'imposition","this_week_payments":"Paiements de cette semaine","ticket":{"add":"Ajouter","added_by":"Ajout\u00e9 par","assign_to":"Affecter \u00e0","attachments":"Pi\u00e8ces jointes","body":"Corps","cc":"CC","contact":"Contact","department":"d\u00e9partement","details":"D\u00e9tails","edit_ticket":"Modifier le ticket","email":"Email","name":"Nom","new_ticket":"Nouveau ticket","no_ticket_available":"Aucun billet disponible.","no_ticket_found":"No Ticket Found.","note":"Remarque","predefined_reply":"R\u00e9ponse pr\u00e9d\u00e9finie","priority":"Priorit\u00e9","reminder":"Rappel","service":"Un service","subject":"Mati\u00e8re","tags":"Mots cl\u00e9s","task":"T\u00e2che","ticket_details":"D\u00e9tails du billet","ticket_not_found":"Aucun ticket trouv\u00e9.","ticket_saved_successfully":"Boleto guardado con \u00e9xito.","ticket_status_updated_successfully":"Estado del ticket actualizado con \u00e9xito.","ticket_to_contact":"Billet \u00e0 contacter","ticket_updated_successfully":"Ticket actualizado con \u00e9xito.","ticket_without_contact":"Billet sans contact","tickets_status":"Statut des tickets","you_can_add_multiples_images_and_files":"Vous pouvez ajouter plusieurs images et fichiers"},"ticket_priorities":"Priorit\u00e9 des billets","ticket_priority":{"add":"Ajouter","add_new_ticket_priority":"Ajouter une nouvelle priorit\u00e9 de billet","edit_ticket_priority":"Modifier la priorit\u00e9 du ticket","name":"Nom","new_ticket_priority":"Priorit\u00e9 aux nouveaux billets","no_ticket_priority_available":"Priorit\u00e9 du ticket introuvable.","no_ticket_priority_found":"Aucune priorit\u00e9 de ticket trouv\u00e9e.","ticket_priority_not_found":"Priorit\u00e9 du ticket introuvable.","ticket_priority_saved_successfully":"La prioridad del ticket se guard\u00f3 correctamente.","ticket_priority_updated_successfully":"Prioridad del ticket actualizada correctamente.","ticket_priority_used_somewhere_else":"Ticket Priority utilis\u00e9 ailleurs."},"ticket_status":{"add":"Ajouter","add_new_ticket_status":"Ajouter un nouveau statut de ticket","color":"Couleur","edit_ticket_status":"Modifier le statut du ticket","name":"Nom","new_ticket_status":"Nouveau statut de ticket","status_order":"Ordre de statut","ticket_status":"Statut du ticket","ticket_status_saved_successfully":"Estado del ticket guardado correctamente.","ticket_status_updated_successfully":"Estado del ticket actualizado con \u00e9xito.","ticket_status_used_somewhere_else":"Statut du ticket utilis\u00e9 ailleurs."},"tickets":"Des billets","translation_manager":"Responsable traduction","translator_manager":{"edit_language":"Edit Language","language_added_successfully":"Idioma agregado correctamente.","language_short_code":"Veuillez saisir le code court de la langue. c'est-\u00e0-dire anglais = en","language_updated_successfully":"Langue mise \u00e0 jour avec succ\u00e8s.","translation":"Translation"},"user":{"change_language":"Changer de langue","change_password":"Changer le mot de passe","edit_profile":"Modifier le profil","email":"E-mail","first_name":"Pr\u00e9nom","language":"Langue","language_updated_successfully":"Idioma actualizado correctamente.","last_name":"Nom de famille","logout":"D\u00e9connexion","name":"Nom","password":"Mot de passe","password_confirmation":"Confirmer le mot de passe","password_updated_successfully":"Contrase\u00f1a actualizada correctamente.","phone":"T\u00e9l\u00e9phone","profile":"Profil","profile_updated_successfully":"Perfil actualizado correctamente.","return_to_admin":"Revenir \u00e0 ladministrateur"},"users":"Utilisateurs","weekdays":{"fri":"VEN","mon":"LUN","sat":"Assis","sun":"SOLEIL","thu":"JEU","tue":"MAR","wed":"\u00c9POUSER"}},"fr.pagination":{"next":"Prochain &raquo;","previous":"&laquo; Pr\u00e9c\u00e9dente"},"fr.passwords":{"reset":"Votre mot de passe a \u00e9t\u00e9 r\u00e9initialis\u00e9!","sent":"Nous avons envoy\u00e9 par e-mail votre lien de r\u00e9initialisation de mot de passe!","throttled":"Veuillez patienter avant de r\u00e9essayer.","token":"Ce jeton de r\u00e9initialisation de mot de passe n'est pas valide.","user":"Nous ne pouvons pas trouver un utilisateur avec cette adresse e-mail."},"fr.validation":{"accepted":"L':attribute doit \u00eatre accept\u00e9.","active_url":"L':attribute n'est pas une URL valide.","after":"L':attribute doit \u00eatre une date apr\u00e8s: date.","after_or_equal":"L':attribute doit \u00eatre une date post\u00e9rieure ou \u00e9gale \u00e0: date.","alpha":"L':attribute ne peut contenir que des lettres.","alpha_dash":"L':attribute ne peut contenir que des lettres, des chiffres, des tirets et des traits de soulignement.","alpha_num":"L':attribute ne peut contenir que des lettres et des chiffres.","array":"L':attribute doit \u00eatre un tableau.","attributes":[],"before":"L':attribute doit \u00eatre une date ant\u00e9rieure \u00e0: date.","before_or_equal":"L':attribute doit \u00eatre une date ant\u00e9rieure ou \u00e9gale \u00e0: date.","between":{"array":"L':attribute doit avoir entre: min et: max \u00e9l\u00e9ments.","file":"L':attribute doit \u00eatre compris entre: min et: max kilo-octets.","numeric":"L':attribute doit \u00eatre compris entre: min et: max.","string":"L':attribute doit \u00eatre compris entre: min et: max caract\u00e8res."},"boolean":"Le champ d':attribute doit \u00eatre vrai ou faux.","confirmed":"La confirmation d':attribute ne correspond pas.","custom":{"attribute-name":{"rule-name":"message personnalis\u00e9"}},"date":"L':attribute n'est pas une date valide.","date_equals":"L':attribute doit \u00eatre une date \u00e9gale \u00e0: date.","date_format":"L':attribute ne correspond pas au format: format.","different":"L':attribute et :autre doivent \u00eatre diff\u00e9rents.","digits":"L':attribute doit \u00eatre :chiffres chiffres.","digits_between":"L':attribute doit \u00eatre compris entre :min et :max :chiffres.","dimensions":"L':attribute a des dimensions d'image non valides.","distinct":"L':attribute a des dimensions d'image non valides..","email":"L':attribute doit \u00eatre une adresse e-mail valide.","ends_with":"L':attribute doit se terminer par l'une des valeurs suivantes: :values.","exists":"L':attribute s\u00e9lectionn\u00e9 n'est pas valide.","file":"L':attribute doit \u00eatre un fichier.","filled":"Le champ d':attribute doit avoir une valeur.","gt":{"array":"L':attribute doit avoir plus de \u00e9l\u00e9ments de: value.","file":"L':attribute doit \u00eatre sup\u00e9rieur \u00e0: value kilo-octets.","numeric":"L':attribute doit \u00eatre sup\u00e9rieur \u00e0: value.","string":"L':attribute doit \u00eatre sup\u00e9rieur \u00e0 les caract\u00e8res de: value."},"gte":{"array":"L':attribute doit avoir des \u00e9l\u00e9ments de :value ou plus.","file":"The :attribute must be greater than or equal :value kilobytes.","numeric":"L':attribute doit \u00eatre sup\u00e9rieur ou \u00e9gal \u00e0: value.","string":"L':attribute doit \u00eatre sup\u00e9rieur ou \u00e9gal \u00e0 caract\u00e8res de :value."},"image":"L':attribute doit \u00eatre une image.","in":"L':attribute s\u00e9lectionn\u00e9 n'est pas valide.","in_array":"The :attribute field does not exist in :other.","integer":"L':attribute doit \u00eatre un entier.","ip":"L':attribute doit \u00eatre une adresse IP valide.","ipv4":"L':attribute doit \u00eatre une adresse IPv4 valide.","ipv6":"L':attribute doit \u00eatre une adresse IPv6 valide.","json":"L':attribute doit \u00eatre une cha\u00eene JSON valide.","lt":{"array":"L':attribute doit avoir moins de \u00e9l\u00e9ments de: value.","file":"L':attribute doit \u00eatre inf\u00e9rieur \u00e0: value en kilo-octets.","numeric":"L':attribute doit \u00eatre inf\u00e9rieur \u00e0: value.","string":"L':attribute doit \u00eatre inf\u00e9rieur \u00e0 les caract\u00e8res de: value."},"lte":{"array":"L':attribute ne doit pas avoir plus de \u00e9l\u00e9ments de: value.","file":"L':attribute doit \u00eatre inf\u00e9rieur ou \u00e9gal \u00e0: value kilo-octets.","numeric":"L':attribute doit \u00eatre inf\u00e9rieur ou \u00e9gal \u00e0: value.","string":"L':attribute doit \u00eatre inf\u00e9rieur ou \u00e9gal \u00e0 caract\u00e8res de value."},"max":{"array":"L':attribute ne peut pas avoir plus de: max \u00e9l\u00e9ments.","file":"L':attribute ne doit pas \u00eatre sup\u00e9rieur \u00e0 kilo-octets: max.","numeric":"L':attribute ne doit pas \u00eatre sup\u00e9rieur \u00e0: max.","string":"L':attribute ne doit pas \u00eatre sup\u00e9rieur \u00e0 caract\u00e8res: max."},"mimes":"L':attribute doit \u00eatre un fichier de type:: values.","mimetypes":"L':attribute doit \u00eatre un fichier de type:: values.","min":{"array":"L':attribute doit avoir au moins: min \u00e9l\u00e9ments.","file":"L':attribute doit \u00eatre d'au moins: min kilo-octets.","numeric":"L':attribute doit \u00eatre au moins: min.","string":"L':attribute doit contenir au moins: min caract\u00e8res."},"not_in":"L':attribute s\u00e9lectionn\u00e9 n'est pas valide.","not_regex":"Le format d':attribute n'est pas valide.","numeric":"L':attribute doit \u00eatre un nombre.","password":"Le mot de passe est incorrect.","present":"Le champ d':attribute doit \u00eatre pr\u00e9sent.","regex":"The :attribute format is invalid.","required":"Le champ d':attribute est obligatoire.","required_if":"Le champ: :attribute est obligatoire lorsque :other est: value.","required_unless":"Le champ: :attribute est obligatoire sauf si :other est dans: values.","required_with":"Le champ: :attribute est obligatoire lorsque :values est pr\u00e9sent.","required_with_all":"Le champ: :attribute est obligatoire lorsque: des :values sont pr\u00e9sentes.","required_without":"Le champ: :attribute est obligatoire lorsque :values n'est pas pr\u00e9sent.","required_without_all":"Le champ d':attribute est obligatoire lorsqu'aucune des: values n'est pr\u00e9sente.","same":"L':attribute et :other doivent correspondre.","size":{"array":"L':attribute doit contenir des \u00e9l\u00e9ments de: size.","file":"L':attribute doit \u00eatre: size kilo-octets.","numeric":"L':attribute doit \u00eatre: size.","string":"L':attribute doit \u00eatre caract\u00e8res de: size."},"starts_with":"L':attribute doit commencer par l'une des valeurs suivantes:: values.","string":"L':attribute doit \u00eatre une cha\u00eene.","timezone":"L':attribute doit \u00eatre une zone valide.","unique":"L':attribute a d\u00e9j\u00e0 \u00e9t\u00e9 pris.","uploaded":"L':attribute n'a pas pu \u00eatre t\u00e9l\u00e9charg\u00e9.","url":"Le format d':attribute n'est pas valide.","uuid":"L':attribute doit \u00eatre un UUID valide."},"pt.auth":{"failed":"Essas credenciais n\u00e3o correspondem aos nossos registros.","throttle":"Muitas tentativas de login. Tente novamente em: seconds segundos."},"pt.messages":{"activity_log":{"activity_logs":"Registros de atividades","loading_more_date":"Carregando mais dados","sorry_we_not_find_any_data":"N\u00e3o conseguimos encontrar nenhum dado, fa\u00e7a pelo menos 1 entrada","we_could_find_any_data":"N\u00e3o foi poss\u00edvel encontrar nenhum dado Desculpe"},"address":{"city":"Cidade","country":"Pa\u00eds","state":"Estado","street":"Rua","zip_code":"C\u00f3digo postal"},"announcement":{"add":"Adicionar","announcement_date":"Data de An\u00fancio","announcement_details":"Detalhes do an\u00fancio","announcement_not_found":"An\u00fancio n\u00e3o encontrado","announcement_saved_successfully":"An\u00fancio salvo com sucesso.","announcement_updated_successfully":"An\u00fancio atualizado com sucesso.","edit_announcement":"Editar an\u00fancio","message":"mensagem","new_announcement":"Novo an\u00fancio","no_announcement_available":"Nenhum an\u00fancio dispon\u00edvel","no_announcement_found":"Nenhum an\u00fancio encontrado.","show_my_name":"Mostrar meu nome","show_to_clients":"Mostrar aos clientes","show_to_staff":"Mostrar \u00e0 equipe","subject":"Sujeito"},"announcements":"An\u00fancios","article":{"add":"Adicionar","article_details":"Detalhes do artigo","article_not_found":"Artigo n\u00e3o encontrado.","article_saved_successfully":"Artigo salvo com sucesso.","article_updated_successfully":"Artigo atualizado com sucesso.","attachment":"Anexo","description":"Descri\u00e7\u00e3o","disabled":"Desativado","edit_article":"Editar Artigo","group":"Grupo","internal_article":"Artigo Interno","new_article":"Novo Artigo","no_article_available":"Nenhum artigo dispon\u00edvel.","no_article_found":"Nenhum artigo encontrado.","subject":"Sujeito","upload_image":"Enviar Imagem"},"article_group":{"add_new_article_group":"Adicionar Novo Grupo de Artigo","article_group_saved_successfully":"Grupo de artigos salvo com sucesso.","article_group_updated_successfully":"Grupo de artigos atualizado com sucesso.","article_group_used_somewhere_else":"Grupo de artigos usado em outro lugar.","article_groups":"Grupos de artigos","color":"Cor","edit_article_group":"Editar Grupo de Artigo","group_name":"Nome do grupo","new_article_group":"Novo Grupo de Artigo","order":"Ordem"},"articles":"Artigos","calendars":"Calend\u00e1rios","change_password":{"change_information_about_yourself_on_this_page":"Alterar informa\u00e7\u00f5es sobre voc\u00ea nesta p\u00e1gina.","confirm_password":"Confirmar senha","current_password":"Senha atual","edit_profile":"Editar Perfil","new_password":"Nova senha"},"client_dashboard":"Painel do Cliente","cms":"CMS","comment":{"add_comment":"Adicionar coment\u00e1rio","added_by":"Adicionado por","comments_saved_successfully":"Coment\u00e1rio salvo com sucesso.","comments_updated_successfully":"Coment\u00e1rio atualizado com sucesso.","edit_comment":"Editar coment\u00e1rio","new_comment":"Novo coment\u00e1rio","no_comments_added_yet":"Nenhum coment\u00e1rio adicionado ainda"},"comments":"Coment\u00e1rios","common":{"action":"A\u00e7ao","active":"Ativo","add":"Adicionar","admin_note":"Nota de administrador","announcement":"An\u00fancio","apply":"Aplicar","article":"Artigo","article_group":"Grupo de artigos","assignee":"Cession\u00e1rio","attachment_deleted":"O anexo foi exclu\u00eddo.","back":"Costas","cancel":"Cancelar","choose":"Escolher","client_note":"Nota do cliente","contract_type":"tipo de contrato","country":"Pa\u00eds","created_on":"Criado em","custom":"Personalizado","customer":"Cliente","customer_group":"Grupo de clientes","data_base_entries":"Mostrando _START_ a _END_ de _TOTAL_ entradas","deactive":"Deactive","default_country_code":"C\u00f3digo de pa\u00eds padr\u00e3o","delete":"Excluir","delete_attachment":"Tem certeza de que deseja excluir este \"Anexo\"?","delete_confirm":"Por favor digite","delete_confirm_common":"Tem certeza de que deseja excluir isso","delete_note":"Tem certeza de que deseja excluir esta \"Nota\"?","deleted":"Exclu\u00eddo!","department":"Departamento","description":"Descri\u00e7\u00e3o","download":"Baixar","download_as_pdf":"Baixar como PDF","drafted":"Draftado","edit":"Editar","email":"O email","expense":"Despesa","expense_category":"Categoria de Despesa","filter_by":"(filtrado de _MAX_ entradas totais)","from":"A partir de","goal":"Meta","has_been_delete":" foi deletado  .","incomes_vs_expenses":"Receitas x despesas","last_updated":"Ultima atualiza\u00e7\u00e3o","lead":"Conduzir","lead_source":"Fonte de chumbo","menu_entry":"Mostrar _MENU_ entradas","n \/ a":"N \/ A","name":"Nome","no":"N\u00e3o","no_data_available_in_table":"Sem dados dispon\u00edveis na tabela","no_entry":"Mostrando 0 a 0 de 0 entradas","no_matching":"Nenhum registro correspondente encontrado","note":"Observa\u00e7\u00e3o","note_delete":"A nota foi exclu\u00edda.","of":"Do","ok":"OK","payment_mode":"Modo de pagamento","predefined_reply":"Resposta predefinida","product_1":"produtos","product_group":"Grupo de produtos","product_header":"produtos","proposal":"Proposta","quantity_is_not_greater_than":"A quantidade n\u00e3o \u00e9 maior que 9999999","save":"Salve","search":"Procurar","search_results":"Os resultados da sua pesquisa v\u00e3o aqui ...","service":"Servi\u00e7o","showing":"Mostrando","status":"Status","tag":"Marca\u00e7\u00e3o","tax_rate":"Taxa de imposto","term_and_conditions":"Termo e Condi\u00e7\u00f5es","ticket_priority":"Prioridade do bilhete","to":"Para","to_delete_this":"para deletar isto","total_amount":"Valor total","type_delete":"Por favor, digite \"excluir\" para excluir isso","view":"Vis\u00e3o","weekly_payment_records":"Registros de pagamentos semanais","yes":"sim"},"company":{"address":"Endere\u00e7o","city":"Cidade","company":"Nome da empresa","company_information_format":"Formato de informa\u00e7\u00f5es da empresa (PDF e HTML)","country_code":"C\u00f3digo do pa\u00eds","currency":"Moeda","details":"Detalhes da Companhia","phone":"telefone","state":"Estado","vat_number":"N\u00famero de IVA","website":"Local na rede Internet","zip_code":"C\u00f3digo postal"},"company_information":"Informa\u00e7\u00f5es da Empresa","contact":{"active":"Ativo","by_deleting_this_contact":"Ao excluir este contato, todos os seus projetos ser\u00e3o exclu\u00eddos.","contact_details":"Detalhes do contato","contact_not_found":"Contato n\u00e3o encontrado.","contact_saved_successfully":"Contato salvo com sucesso.","contact_status_updated_successfully":"Status do contato atualizado com sucesso.","contact_updated_successfully":"Contato atualizado com sucesso.","contract":"Contrato","contracts":"Contratos","credit_note":"Nota de cr\u00e9dito","customer_name":"Nome do cliente","deactive":"Desativado","delete_contact_confirm":"Tem certeza de que deseja excluir este contato?","direction":"Dire\u00e7\u00e3o","edit_contact":"Editar contato","email_notifications":"Notifica\u00e7\u00f5es por Email","estimate":"Estimativo","estimates":"Estimativos","first_name":"Nome","full_name":"Nome completo","impersonate":"Personificar","invoice":"Fatura","invoices":"Faturas","last_name":"Sobrenome","make_sure_to_set_appropriate_permissions_for_this_contact":"Certifique-se de definir as permiss\u00f5es apropriadas para este contato","new_contact":"Novo contato","no_contact_available":"Nenhum contato est\u00e1 dispon\u00edvel.","no_contact_found":"Nenhum contato encontrado.","password":"Senha","permissions":"Permiss\u00f5es","position":"Posi\u00e7\u00e3o","primary_contact":"Contato prim\u00e1rio","project":"Projeto","projects":"Projetos","proposals":"Propostas","send_password_email":"Enviar SET senha e-mail","send_welcome_email":"N\u00e3o envie e-mail de boas-vindas","support":"Apoio, suporte","task":"Tarefa","tickets":"Ingressos"},"contacts":"Contatos","contract":{"add":"Adicionar","authorized_signature":"Assinatura autorizada","contract_details":"Detalhes do contrato","contract_list":"Lista de Contratos","contract_not_found":"Contrato n\u00e3o encontrado","contract_summary":"Resumo do Contrato","contract_type_id":"Tipo de contrato","contract_value":"Valor do contrato","contracts_by_type":"Contratos por tipo","contracts_expiring_this_month":"Contratos que expiram neste m\u00eas","contracts_saved_successfully":"Contrato salvo com sucesso.","contracts_updated_successfully":"Contrato atualizado com sucesso.","contracts_value_by_type":"Valor dos contratos por tipo","customer_id":"Cliente","description":"Descri\u00e7\u00e3o","edit_contract":"Editar contrato","end_date":"Data de t\u00e9rmino","is_hide":"Ocultar do cliente","is_trash":"Lixo","new_contract":"Novo contrato","no_contract_available":"Nenhum contrato dispon\u00edvel","no_contract_found":"Nenhum contrato encontrado.","sign":"Placa","start_date":"Data de in\u00edcio","subject":"Sujeito","task":"Tarefa"},"contract_type":{"add_new_contract_type":"Adicionar novo tipo de contrato","contract_by_type":"Contrato por tipo","contract_type_saved_successfully":"Tipo de contrato salvo com sucesso.","contract_type_updated_successfully":"Tipo de contrato atualizado com sucesso.","contract_type_used_somewhere_else":"Tipo de contrato usado em outro lugar.","contract_value_by_type":"Valor do contrato por tipo","edit_contract_type":"Editar tipo de contrato","new_contract_type":"Novo tipo de contrato"},"contract_types":"Tipos de contrato","contracts":"Contratos","countries":"Pa\u00edses","country":{"add":"Adicionar","country_not_found":"Pa\u00eds n\u00e3o encontrado.","country_saved_successfully":"Pa\u00eds salvo com sucesso.","country_updated_successfully":"Pa\u00eds atualizado com sucesso.","country_used_somewhere_else":"Pa\u00eds usado em outro lugar.","edit_country":"Editar Pa\u00eds","name":"Nome","new_country":"Novo pa\u00eds","no_country_available":"Nenhum pa\u00eds dispon\u00edvel.","no_country_found":"Nenhum pa\u00eds encontrado."},"credit_note":{"authorized_signature":"Assinatura autorizada","client_note":"Nota","closed":"Fechadas","credit_note":"Nota de cr\u00e9dito","credit_note_date":"Data da nota de cr\u00e9dito","credit_note_details":"Detalhes da nota de cr\u00e9dito","credit_note_details_updated_successfully":"Detalhes da nota de cr\u00e9dito atualizados com sucesso.","credit_note_not_found":"Nota de cr\u00e9dito n\u00e3o encontrada.","credit_note_number":"N\u00famero da nota de cr\u00e9dito","credit_note_pdf":"Nota de cr\u00e9dito em PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"Nota de cr\u00e9dito salva com sucesso.","credit_note_updated_successfully":"Nota de cr\u00e9dito atualizada com sucesso.","drafted":"Draftado","edit_credit_note":"Editar nota de cr\u00e9dito","invoice_credited":"Fatura creditada","mark_as_closed":"Marcar como fechado","mark_as_draft":"Marcar como rascunho","mark_as_open":"Marcar como aberto","mark_as_void":"Marcar como nulo","new_credit_note":"Nova nota de cr\u00e9dito","no_credit_note_available":"Nenhuma nota de cr\u00e9dito dispon\u00edvel.","no_credit_note_found":"Nenhuma nota de cr\u00e9dito encontrada.","open":"Abrir","quantity_is_not_greater_than":"A quantidade n\u00e3o \u00e9 maior que 9999999","reference":"Refer\u00eancia","refunds":"Reembolsos","save_and_send":"Salvar e enviar","save_as_draft":"Salvar como rascunho","terms_and_conditions":"termos e Condi\u00e7\u00f5es","title":"T\u00edtulo","view_credit_note_as_customer":"Exibir nota de cr\u00e9dito como cliente","void":"Vazia"},"credit_notes":"Notas de credito","customer":{"add_address_details":"Adicionar detalhes de endere\u00e7o","address":"Endere\u00e7o","address_details":"Detalhes do endere\u00e7o","address_not_found":"Detalhes de endere\u00e7o n\u00e3o encontrados.","billing_address":"endere\u00e7o de cobran\u00e7a","billing_address_details_not_available":"Detalhes do endere\u00e7o de cobran\u00e7a n\u00e3o dispon\u00edveis","by_deleting_this_customer":"Ao excluir este cliente todo o seu projeto, contato, fatura, or\u00e7amento, nota de cr\u00e9dito, proposta e contrato ser\u00e3o exclu\u00eddos.","city":"Cidade","company_name":"Nome da empresa","copy_billing_address":"Copiar endere\u00e7o de cobran\u00e7a","country":"Pa\u00eds","currency":"Moeda","customer_details":"Detalhes do cliente","customer_saved_successfully":"Cliente salvo com sucesso.","customer_updated_successfully":"Cliente atualizado com sucesso.","customers":"clientes","default_language":"Idioma padr\u00e3o","delete_customer_confirm":"Tem certeza de que deseja excluir este cliente?","do_not_fill_shipping_address_customer_invoices":"N\u00e3o preencha as informa\u00e7\u00f5es do endere\u00e7o de entrega se voc\u00ea n\u00e3o usar o endere\u00e7o de entrega nas faturas do cliente","edit_customer":"Editar cliente","groups":"Grupos","new_customer":"Novo cliente","no_customer_available":"Nenhum cliente dispon\u00edvel.","no_customer_found":"Nenhum cliente encontrado.","phone":"telefone","same_as_a_customer_info":"Igual \u00e0s informa\u00e7\u00f5es do cliente","search_customer":"Cliente de Pesquisa","shipping_address":"endere\u00e7o de entrega","shipping_address_details_not_available":"Detalhes do endere\u00e7o de entrega n\u00e3o dispon\u00edveis","state":"Estado","street":"Rua","total_contact":"Contato Total","total_customers":"Clientes totais","total_project":"Projeto Total","type":"Tipo","vat_number":"N\u00famero do IVA","website":"Local na rede Internet","zip_code":"C\u00f3digo postal"},"customer_group":{"action":"A\u00e7ao","add_new_customer_group":"Adicionar Novo Grupo de Clientes","customer_group_saved_successfully":"Grupo de clientes salvo com sucesso.","customer_group_updated_successfully":"Grupo de clientes atualizado com sucesso.","description":"Descri\u00e7\u00e3o","edit_customer_group":"Editar Grupo de Clientes","name":"Nome","new_customer_group":"Novo Grupo de Clientes"},"customer_groups":"Grupos de clientes","customers":"clientes","dashboard":"painel de controle","department":{"department_not_found":"Departamento n\u00e3o encontrado.","department_saved_successfully":"Departamento salvo com sucesso.","department_updated_successfully":"Departamento atualizado com sucesso.","departments":"Departamentos","edit_department":"Editar Departamento","hide_from_clients":"Ocultar dos clientes","new_department":"Novo Departamento","no_department_available":"Nenhum departamento dispon\u00edvel.","no_department_found":"Nenhum departamento encontrado."},"edit_profile":{"change_password":"Mudar senha","edit_profile":"Editar Perfil","hello":"Ol\u00e1","hi":"Oi","login":"Conecte-se","login_register":"Conecte-se \/ Registro","logout":"Sair","mark_all_as_read":"Marcar tudo como lido","notification":"Notifica\u00e7\u00f5es","register":"Registro","welcome":"Bem-vinda"},"email":{"email":"O email","forgot_password":"Esqueceu a senha","recalled_your_login_info":"Recuperou suas informa\u00e7\u00f5es de login?","reset_password":"Redefinir senha","send_reset_link":"Enviar link de redefini\u00e7\u00e3o","sign_in":"Assinar em"},"email_template":{"available_merge_fields":"Campos de mesclagem dispon\u00edveis","disabled":"Desativado","edit_email_template":"Editar modelo de email","email_message":"Mensagem de e-mail","enable":"Enable","from_name":"Do nome","send_plain_text":"Enviar como texto simples","subject":"Sujeito","template_name":"Nome do modelo"},"email_templates":"Modelos de Email","error":"Erro","estimate":{"accepted":"ACEITARAM","adjustment":"Ajustamento","amount":"Montante","amount_due":"Quantia devida","authorized_signature":"Assinatura autorizada","bill_to":"Cobran\u00e7a para","client_note":"Nota do cliente","convert_estimate":"Converter estimativa","convert_estimate_to_invoice":"Converter estimativa para fatura com sucesso.","declined":"RECUSADO","discount":"Desconto","draft":"ESBO\u00c7O, PROJETO","drafted":"Draftado","edit_estimate":"Editar estimativa","estimate":"Estimativo","estimate_date":"Data Estimada","estimate_details":"Detalhes da estimativa","estimate_not_found":"Estimativa n\u00e3o encontrada.","estimate_number":"Estimativa de n\u00famero","estimate_overview":"ESTIMATIVA DE VIS\u00c3O GERAL","estimate_pdf":"Estimar PDF","estimate_prefix":"EN-","estimate_saved_successfully":"Estimativa salva com sucesso.","estimate_status_updated_successfully":"Status da estimativa atualizado com sucesso.","estimate_updated_successfully":"Estimativa atualizada com sucesso.","expired":"EXPIRADO","expiry_date":"Data de validade","item":"produtos","mark_as_accepted":"Marcar como aceito","mark_as_declined":"Marcar como recusado","mark_as_draft":"Marcar como rascunho","mark_as_expired":"Marcar como expirado","mark_as_send":"Marcar como envio","more":"Mais","new_estimate":"Nova Estimativa","no_estimate_available":"Sem previs\u00e3o dispon\u00edvel","no_estimate_found":"Nenhuma estimativa encontrada.","not_sent":"N\u00c3O ENVIADO","qty":"Qty","rate":"Taxa","save_and_send":"Salvar e enviar","save_as_draft":"Salvar como rascunho","sent":"ENVIEI","ship_to":"Enviar para","status":"Status","sub_total":"Sub Total","task":"Tarefa","taxes":"Impostos","terms_conditions":"termos e Condi\u00e7\u00f5es","title":"T\u00edtulo","total":"Total","total_estimates":"Estimativas Totais","total_paid":"Total Pago","view_estimate_as_customer":"Ver estimativa como cliente"},"estimates":"Estimativos","expense":{"add":"Adicionar","amount":"Montante","amount_with_tax":"Valor com imposto","apply_tax":"Aplicar imposto","apply_tax_message":"Subtrair o total do imposto do valor","attachment":"Anexo","auto_create_invoice":"Cria\u00e7\u00e3o autom\u00e1tica de fatura","billable":"Fatur\u00e1vel","choose_file":"Escolher arquivo","currency":"Moeda","customer":"Cliente","details":"Detalhes","edit_expense":"Editar despesas","expense_amount":"Valor da Despesa","expense_category":"Categoria de Despesa","expense_category_by_chart":"Categoria de despesas por gr\u00e1fico","expense_date":"Data de Despesa","expense_details":"Detalhes de despesas","expense_list":"Lista de Despesas","expense_not_found":"Despesa n\u00e3o encontrada.","expense_saved_successfully":"Despesa salva com sucesso.","expense_updated_successfully":"Despesa atualizada com sucesso.","name":"Nome","new_expense":"Nova despesa","no_expense_available":"Nenhuma despesa dispon\u00edvel.","no_expense_found":"Nenhuma despesa encontrada.","note":"Note","notes":"Notas","payment_mode":"Modo de pagamento","preview_attachment":"Pr\u00e9-visualizar anexo","receipt_attachment":"Anexo de recibo","reference":"Refer\u00eancia","reminders":"Lembrete","send_email":"Envie a fatura para o e-mail do cliente quando as despesas forem recriadas","tax_1":"Imposto 1 (em%)","tax_2":"Imposto 2 (em%)","tax_applied":"Imposto aplicado","view_attachment":"Ver anexo"},"expense_by_category":"Despesa por categoria","expense_categories":"Categorias de despesas","expense_category":{"add_new_expense_category":"Adicionar nova categoria de despesas","edit_category":"Editar categoria de despesas","expense_categories":"Categorias de despesas","expense_category":"Categoria de despesas","expense_category_saved_successfully":"Categoria de despesa salva com sucesso.","expense_category_updated_successfully":"Categoria de despesas atualizada com sucesso.","expense_category_used_somewhere_else":"Categoria de despesa usada em outro lugar.","new_category":"Nova categoria de despesas"},"expenses":"Despesas","general":"Geral","goal":{"achievement":"Realiza\u00e7\u00e3o","add":"Adicionar","description":"Descri\u00e7\u00e3o","edit_goal":"Editar objetivo","end_date":"Data final","goal_details":"Detalhes da meta","goal_id":"Tipo de objetivo","goal_saved_successfully":"Goal salva com sucesso.","goal_type":"Tipo de objetivo","goal_updated_successfully":"Meta atualizada com sucesso.","is_not_notify":"Notificar os membros da equipe quando a meta n\u00e3o for atingida","is_notify":"Notifique os membros da equipe quando a meta atingir","new_goal":"Novo objetivo","no_goal_available":"Nenhum objetivo dispon\u00edvel.","no_goal_found":"Nenhum objetivo encontrado.","progress":"Progresso","staff_member":"Membro da equipe","start_date":"Data de in\u00edcio","subject":"Sujeito","user_id":"Membro da equipe"},"goal_type":{"description":"Descri\u00e7\u00e3o","edit_goal_type":"Editar tipo de meta","name":"Nome","new_goal_type":"Novo tipo de meta"},"goals":"Metas","incomes":"Rendas","invoice":{"activity_log":"Registro de atividade","add_item":"Adicionar Produto","add_shipping_address":"Adicionar shipping address","adjustment":"Ajustamento","admin_note":"Nota do administrador","allowed_payment_modes_for_this_invoice":"Modos de pagamento permitidos para esta fatura","amount":"Montante","amount_due":"Quantia devida","authorized_signature":"Assinatura autorizada","bank":"Banco","bill_tasks":"Bill Tarefas","bill_to":"Cobran\u00e7a para","cancelled":"CANCELADO","client_note":"Nota do cliente","currency":"Moeda","customer":"Cliente","discount":"Desconto","discount_type":"Tipo de Desconto","draft":"ESBO\u00c7O, PROJETO","drafted":"Draftado","due_date":"Data de vencimento","edit_contract_type":"Editar tipo de contrato","edit_invoice":"Editar fatura","fixed":"Fixo","hours":"Horas","hsn_tax":"C\u00f3digo Fiscal HSN","invoice":"Fatura","invoice_date":"Data da fatura","invoice_details":"Detalhes da fatura","invoice_not_found":"Fatura n\u00e3o encontrada.","invoice_number":"N\u00famero da fatura","invoice_overview":"VIS\u00c3O GERAL DA FATURA","invoice_payments":"Pagamentos de fatura","invoice_pdf":"Fatura em PDF","invoice_prefix":"INV-","invoice_saved_successfully":"Fatura salva com sucesso.","invoice_updated_successfully":"Fatura atualizada com sucesso.","item":"produtos","mark_as_cancelled":"Marcar como cancelado","mark_as_draft":"Marcar como rascunho","mark_as_paid":"Marcar como pago","mark_as_partially_paid":"Marcar como parcialmente pago","mark_as_sent":"Marcar como enviado","more":"Mais","new_contract_type":"Novo Tipo de Contrato","new_invoice":"Nova Fatura","no_invoice_available":"Nenhuma fatura dispon\u00edvel.","no_invoice_found":"Nenhuma fatura encontrada.","no_payments_available":"Nenhum pagamento dispon\u00edvel","not_sent":"N\u00c3O ENVIADO","notes":"Notas","offline_payment":"Offline Payment","online_payment":"Pagamento online","overdue":"VENCIDO","paid":"Pago","paid_cap":"PAGO","partially_paid":"Parcialmente pago","partially_paid_cap":"PARCIALMENTE PAGO","pay_now":"Pague agora","payment":"Forma de pagamento","payment_details":"Detalhes de pagamento","payments":"Pagamentos","prevent_sending_overdue_reminders_for_this_invoice":"Impedir o envio de lembretes vencidos para esta fatura","qty":"Qty","qty\/hours":"Qtd \/ horas","qty_hours":"Qtd \/ horas","quick_invoices_info":"Informa\u00e7\u00f5es r\u00e1pidas sobre faturas","reminders":"Lembretes","sale_agent":"Agente de Venda","save_and_send":"Salvar e enviar","save_as_draft":"Salvar como rascunho","ship_to":"Enviar para","show_quantity_as":"Mostrar quantidade como","sub_total":"Subtotal","task":"Tarefa","taxes":"Impostos","terms_conditions":"termos e Condi\u00e7\u00f5es","title":"Titre","total":"Total","total_invoices":"Faturas totais","total_paid":"Total pago","transactions":"Transa\u00e7\u00f5es","unmark_as_cancelled":"Desmarcar como cancelado","unpaid":"N\u00e3o pago","unpaid_cap":"N\u00c3O PAGA","view_invoice_as_customer":"Exibir fatura como cliente"},"invoices":"Faturas","kanban_list":"Lista KANBAN","kanban_view":"Vis\u00e3o KANBAN","last_week_payments":"Pagamentos da \u00faltima semana","lead":{"chart":"Gr\u00e1fico","contacted_today":"Contatado hoje","convert_to_customer":"Converter em cliente","date_contacted":"Data de contato","details":"Detalhes","edit_lead":"Editar lead","estimate_budget":"Estimation du budget","lead_convert_customer":"Cliente de convers\u00e3o de lead","lead_convert_customer_chart":"Gr\u00e1fico de convers\u00e3o de clientes potenciais","lead_details":"Detalhes do lead","lead_list":"Lista de chumbo","lead_not_found":"Lead n\u00e3o encontrado.","lead_saved_successfully":"Lead salvo com sucesso.","lead_status_updated_successfully":"Status do lead atualizado com sucesso.","lead_updated_successfully":"Lead atualizado com sucesso.","leads_overview":"Vis\u00e3o geral de leads","member":"Membro","name":"Nome","new_lead":"Novo Lead","no_lead_available":"Sem chumbo dispon\u00edvel.","no_lead_found":"Nenhum lead encontrado.","notes":"Notas","reminder":"Lembrete","source":"Fonte","task":"Tarefa"},"lead_convert_to_customer":"Convers\u00e3o de Leads em Clientes","lead_source":{"add":"Adicionar","edit_lead_source":"Editar fonte do lead","lead_source_count":"Contagem de leads","lead_source_not_found":"Fonte de chumbo n\u00e3o encontrada.","lead_source_saved_successfully":"Origem do lead salva com sucesso.","lead_source_updated_successfully":"Origem do lead atualizada com sucesso.","name":"Nome","new_lead_source":"Nova fonte de leads","no_lead_source_available":"Nenhuma fonte de chumbo dispon\u00edvel.","no_lead_source_found":"Nenhuma fonte de chumbo encontrada."},"lead_sources":"Fontes de leads","lead_status":{"add":"Adicionar","add_new_lead_status":"Adicionar novo status de lead","color":"Cor","edit_lead_status":"Editar status do lead","lead_status":"Status do lead","lead_status_saved_successfully":"Status do lead salvo com sucesso.","lead_status_updated_successfully":"Status do lead atualizado com sucesso.","lead_status_used_somewhere_else":"Status do lead usado em outro lugar.","name":"Nome","new_lead_status":"Novo status de lead","order":"Ordem"},"leads":"Conduz","list_view":"Lista Vis\u00e3o","login":{"admin":"Admin","client":"Cliente","don't have an account":"N\u00e3o tem conta?","email":"O email","forgot_password":"Esqueceu a senha","login":"Conecte-se","password":"Senha","remember_me":"Lembre de mim"},"member":{"add":"Adicionar","by_deleting_this_member":"Ao excluir este membro, todos os seus projetos, propostas e metas ser\u00e3o exclu\u00eddos.","choose":"Escolher","created_on":"Criado em","default_language":"Idioma padr\u00e3o","delete_member_confirm":"Tem certeza de que deseja excluir este membro?","direction":"Dire\u00e7\u00e3o","edit_member":"Editar membro","email":"O email","email_is_not_verified":"Email n\u00e3o est\u00e1 verificado","email_is_verified":"Email \u00e9 verificado","email_verified":"email verificado","email_verified_successfully":"E-mail verificado com sucesso.","email_verify":"Verifica\u00e7\u00e3o de e-mail","facebook":"Facebook","first_name":"Nome","hourly_rate":"Taxa hor\u00e1ria","image":"Perfil","is_administrator":"Administrador","is_enable":"Habilitar autentica\u00e7\u00e3o de dois fatores","last_name":"\u00daltimo nome","linkedin":"Linkedin","member_details":"Detalhes do membro","member_informations":"Informa\u00e7\u00e3o do Membro","member_not_found":"Membro n\u00e3o encontrado.","member_saved_successfully":"Membro salvo com sucesso.","member_security":"Seguran\u00e7a do Membro","member_status_updated_successfully":"Status do membro atualizado com sucesso.","member_updated_successfully":"Membro atualizado com sucesso.","new_member":"Novo membro","no_member_available":"Nenhum membro dispon\u00edvel.","no_member_found":"Nenhum membro encontrado.","password":"Senha","password_confirmation":"Confirme a Senha","permissions":"Permiss\u00f5es","phone":"telefone","profile":"Perfil","resend_email_verification":"Reenviar verifica\u00e7\u00e3o de e-mail","send_welcome_email":"Enviar email de boas-vindas","skype":"Skype","staff_member":"N\u00e3o \u00e9 membro da equipe","total_members":"Total de membros","verification_mail_has_been_sent":"O e-mail de verifica\u00e7\u00e3o foi enviado com sucesso."},"members":"Membros","menu_settings":"Configura\u00e7\u00f5es do menu","months":{"apr":"abril","aug":"agosto","dec":"dezembro","feb":"fevereiro","jan":"janeiro","jul":"julho","jun":"junho","mar":"mar\u00e7o","may":"Poderia","nov":"novembro","oct":"Outubro","sep":"setembro"},"new_language":"Nova linguagem","no_matching_records_found":"Nenhum registro correspondente encontrado","note":{"add_note":"Adicionar nota","edit_note":"Editar nota","new_note":"Nova Nota","no_notes_added_yet":"Nenhuma nota adicionada ainda","notes_saved_successfully":"Nota salva com sucesso.","notes_updated_successfully":"Nota atualizada com sucesso."},"notes":"Notas","notification":{"all_notification_read_successfully":"Todas as notifica\u00e7\u00f5es foram lidas com sucesso.","empty_notifications":"N\u00e3o foi poss\u00edvel encontrar nenhuma notifica\u00e7\u00e3o","mark_all_as_read":"Marcar tudo como lido","notification_read_successfully":"Notifica\u00e7\u00e3o lida com sucesso.","notifications":"Notifica\u00e7\u00f5es"},"others":"Autres","payment":{"amount":"Montante","amount_received":"Montante recebido","date":"Encontro","new_payment":"Novo Pagamento","note":"Nota","payment_date":"Data de pagamento","payment_mode":"Modo de pagamento","payment_saved_successfully":"Pagamento salvo com sucesso.","send_mail_to_customer_contacts":"N\u00e3o envie e-mail registrado de pagamento de fatura para os contatos do cliente","transaction_id":"ID de transa\u00e7\u00e3o","your_payment_is_completed":"Seu pagamento foi conclu\u00eddo com sucesso.","your_payment_is_ont_completed":"Seu pagamento n\u00e3o foi conclu\u00eddo."},"payment_mode":{"active":"Ativo","add_new_payment_mode":"Adicionar novo modo de pagamento","bank_accounts":"Contas banc\u00e1rias","edit_payment_mode":"Editar modo de pagamento","expenses_only":"Apenas despesas","invoices_only":"Faturas apenas","new_payment_mode":"Novo modo de pagamento","no_payment_mode_available":"Nenhum modo de pagamento dispon\u00edvel.","no_payment_mode_found":"Nenhum modo de pagamento encontrado.","on_invoice_pdf":"no PDF da fatura","payment_mode_details":"Detalhes do modo de pagamento","payment_mode_not_found":"Modo de pagamento n\u00e3o encontrado.","payment_mode_saved_successfully":"Modo de pagamento salvo com sucesso.","payment_mode_updated_successfully":"Modo de pagamento atualizado com sucesso.","payment_mode_used_somewhere_else":"Modo de pagamento usado em outro lugar.","selected_by_default_on_invoice":"Selecionado por padr\u00e3o na fatura","show":"Mostrar"},"payment_modes":"Modos de pagamento","placeholder":{"add_note":"Adicionar nota...","add_product":"Adicionar produto","bill_tasks":"Faturar Tarefas","contact_number_is_invalid_number":"O n\u00famero de contato \u00e9 um n\u00famero inv\u00e1lido","enter_email":"Digite o e-mail","invalid_country_code":"C\u00f3digo de pa\u00eds inv\u00e1lido","invalid_number":"N\u00famero inv\u00e1lido","search_customers":"Pesquisar clientes","search_menu":"Menu de pesquisa","select_article_group":"Selecionar grupo de artigos","select_assignee":"Selecione o Respons\u00e1vel","select_billing_type":"Selecione o tipo de cobran\u00e7a","select_contact":"Selecionar contatos","select_contract_type":"Selecione o tipo de contrato","select_country":"Selecione o pais","select_currency":"Escolha a moeda","select_customer":"Selecionar cliente","select_department":"Selecionar departamento","select_discount_type":"Selecione o tipo de desconto","select_document_type":"S\u00e9lectionnez le type de r\u00e9duction","select_email_status":"Selecione o status do e-mail","select_email_template":"S\u00e9lectionnez le mod\u00e8le d'e-mail","select_expanse_category":"Selecione a categoria de despesas","select_file":"Choisir le dossier","select_goal":"Selecionar meta","select_goal_type":"Selecione o tipo de meta","select_group":"Selecionar grupos","select_groups":"Selecionar grupos","select_internal_article":"Selecionar artigo interno","select_item":"Selecionar item","select_language":"Selecione o idioma","select_lead":"Selecionar lead","select_lead_source":"S\u00e9lectionnez la source du prospect","select_member":"Selecionar membro","select_option":"Selecionar op\u00e7\u00e3o","select_payment_mode":"Selecione o modo de pagamento","select_predefined_reply":"Selecione a resposta predefinida","select_priority":"Selecionar prioridade","select_product":"Selecionar produto","select_product_group":"Selecionar grupo de produtos","select_reminder_to":"Selecione Lembrete para","select_sale_agent":"Selecionar agente de vendas","select_service":"Selecionar servi\u00e7o","select_show_to_client":"S\u00e9lectionnez Afficher au client","select_source":"Selecione a fonte","select_status":"Selecionar status","select_tags":"Selecionar tags","select_tax":"Selecionar imposto","select_tax1":"Selecione Imposto 1","select_tax2":"Selecione Imposto 2","select_template_type":"S\u00e9lectionnez le type de mod\u00e8le","select_ticket_priority":"S\u00e9lectionnez la priorit\u00e9 des billets","too_long":"Demasiado longo","too_short":"Curto demais","valid_number":"N\u00famero v\u00e1lido"},"please_enter_language_short_code":"Por favor, insira o c\u00f3digo curto do idioma. ou seja, ingl\u00eas = en.","predefined_replies":"Respostas Predefinidas","predefined_reply":{"add":"Adicionar","add_new_predefined_reply":"Adicionar nova resposta predefinida","body":"Corpo","edit_predefined_reply":"Editar resposta predefinida","new_predefined_reply":"Nova resposta predefinida","no_predefined_reply_available":"Nenhuma resposta predefinida dispon\u00edvel.","no_predefined_reply_found":"Nenhuma resposta predefinida encontrada.","predefined_reply_details":"Detalhes de resposta predefinidos","predefined_reply_not_found":"Resposta predefinida n\u00e3o encontrada.","predefined_reply_saved_successfully":"Resposta predefinida salva com sucesso.","predefined_reply_updated_successfully":"Resposta predefinida atualizada com sucesso.","reply_name":"Responder Nome"},"product_group":{"add_new_product_group":"Adicionar Novo Grupo de Produtos","edit_product_group":"Editar Grupo de Produtos","new_product_group":"Novo Grupo de Produtos","product_group_saved_successfully":"Grupo de produtos salvo com sucesso.","product_group_updated_successfully":"Grupo de produtos atualizado com sucesso.","product_group_used_somewhere_else":"Grupo de produtos usado em outro lugar."},"product_groups":"Grupos de Produtos","products":{"edit_product":"Editar Produto","new_product":"Novo produto","product_group":"Grupo de produtos","product_saved_successfully":"Produto salvo com sucesso.","product_updated_successfully":"Produto atualizado com sucesso.","products":"Produtos","rate":"Taxa","tax":"Imposto","title":"T\u00edtulo","unit":"Unidade"},"profile":"Perfil","project":{"admin_area":"\u00e1rea administrativa","allow_customer_to":"Permitir que o cliente","billing_type":"Tipo de cobran\u00e7a","calculate_progress_through_tasks":"Calcule o progresso por meio de tarefas","cancelled":"Cancelado","comment_on_project_tasks":"comentar sobre as tarefas do projeto","create_tasks":"criar tarefas","customer":"Cliente","deadline":"Data limite","edit_project":"Editar projeto","edit_tasks":"editar tarefas","estimated_hours":"Horas Estimadas","finished":"Acabado","hide_project_tasks_on_main_tasks_table":"ocultar tarefas do projeto na tabela de tarefas principais","in_progress":"Em andamento","members":"Contato","new_project":"Novo projeto","no_project_available":"Nenhum projeto dispon\u00edvel","no_project_found":"Projeto n\u00e3o encontrado","not_started":"N\u00e3o iniciado","on_hold":"Em espera","only_task_created_from_contact":"apenas tarefa criada a partir do contato","open_discussions":"discuss\u00f5es abertas","progress":"Progresso","project_details":"Detalhes do projeto","project_name":"Nome do projeto","project_saved_successfully":"Projeto salvo com sucesso.","project_settings":"Configura\u00e7\u00f5es do projeto","project_updated_successfully":"Projeto atualizado com sucesso.","projects_summary":"Resumo dos projetos","quick_invoices_info":"Informa\u00e7\u00f5es r\u00e1pidas sobre faturas","send_project_created_email":"Enviar e-mail do projeto criado","start_date":"Data de in\u00edcio","statistics_by_project_status":"Estat\u00edsticas por status do projeto","status":"Status","task":"Tarefa","total_projects":"Total de Projetos","upload_attachments_on_tasks":"enviar anexos em tarefas","upload_files":"enviar arquivos","view_account_statement":"Exibir extrato da conta","view_activity_log":"ver registro de atividades","view_finance_overview":"ver vis\u00e3o geral das finan\u00e7as","view_gantt":"ver Gantt","view_milestones":"ver marcos","view_task_attachments":"ver anexos de tarefas","view_task_checklist_items":"ver itens da lista de verifica\u00e7\u00e3o de tarefas","view_task_comments":"ver coment\u00e1rios de tarefas","view_task_total_logged_time":"ver o tempo total registrado da tarefa","view_tasks":"ver tarefas","view_team_members":"ver membros da equipe","view_timesheets":"visualizar planilhas de horas","visible_tables":"Tabelas Vis\u00edveis"},"projects":"Projetos","proposal":{"accept":"ACEITAR","accepted":"ACEITARAM","adjustment":"Ajustamento","amount":"Montante","amount_due":"Quantia devida","authorized_signature":"Authorized Signature","bank":"Banco","bill_to":"Bill To","comments":"Coment\u00e1rios","convert":"Converter","convert_proposal":"Converter proposta","date":"Encontro","decline":"DECL\u00cdNIO","declined":"RECUSADO","discount":"Desconto","draft":"ESBO\u00c7O, PROJETO","drafted":"Draftado","edit_proposal":"Editar proposta","item":"produtos","lead":"Conduzir","mark_as_accepted":"Marcar como aceito","mark_as_declined":"Marcar como recusado","mark_as_draft":"Marcar como rascunho","mark_as_open":"Marcar como aberto","mark_as_revised":"Marcar como revisado","mark_as_send":"Marcar como envio","member":"Membro","new_proposal":"Nova Proposta","no_payments_available":"Nenhum pagamento dispon\u00edvel","no_proposal_available":"Nenhuma proposta dispon\u00edvel.","no_proposal_found":"Nenhuma proposta encontrada.","offline_payment":"Pagamento offline","online_payment":"Pagamento online","open":"ABRIR","open_till":"Abrir at\u00e9","pay_now":"PAGUE AGORA","payment":"Forma de pagamento","proposal":"Proposta","proposal_date":"Data da proposta","proposal_details":"Detalhes da Proposta","proposal_not_found":"Proposta n\u00e3o encontrada.","proposal_number":"N\u00famero da proposta","proposal_overview":"VIS\u00c3O GERAL DA PROPOSTA","proposal_pdf":"PDF da proposta","proposal_prefix":"PRO-","proposal_saved_successfully":"Proposta salva com sucesso.","proposal_to":"Proposta para","proposal_updated_successfully":"Proposta atualizada com sucesso.","qty":"Qty","rate":"Taxa","related":"Relacionados","revised":"REVISADO","save_and_send":"Salvar e enviar","save_as_draft":"Salvar como rascunho","sent":"ENVIEI","ship_to":"Enviar para","status":"Status da proposta","sub_total":"Subtotal","subject":"Sujeito","task":"Tarefa","taxes":"Impostos","to":"To","total":"Total","total_paid":"Total Pago","total_proposal":"Proposta Total","transactions":"Transa\u00e7\u00f5es","view_proposal_as_customer":"Exibir proposta como cliente"},"proposals":"Propostas","range":{"last_30":"\u00daltimos 30 dias","last_month":"M\u00eas passado","last_week":"Semana passada","this_month":"Este m\u00eas","this_week":"Essa semana","today":"Hoje"},"register":{"already_have_an_account":"j\u00e1 tem uma conta?","choose":"Escolher","confirm_password":"Confirme a Senha","email":"O email","first_name":"Primeiro nome","last_name":"\u00daltimo nome","password":"Senha","phone":"telefone","profile_picture":"Foto do perfil","register":"Registro","sign_in":"Assinar em"},"reminder":{"add_new":"Adicionar novo","description":"Descri\u00e7\u00e3o","edit_reminder":"Editar lembrete","email_status":"Status do e-mail","is_notified":"\u00c9 notificado","new_reminder":"Novo lembrete","no":"N\u00e3o","note":"Observa\u00e7\u00e3o","note_text":"Observe que voc\u00ea deve selecionar a data e hora UTC, pois os cron jobs enviam lembretes de acordo com a hora UTC.","notified_date":"Data de Notifica\u00e7\u00e3o","reminder_saved_successfully":"Lembrete salvo com sucesso.","reminder_to":"Lembrete para","reminder_updated_successfully":"Lembrete atualizado com sucesso.","send_email_reminder":"Enviar lembrete por e-mail","sent":"Enviado","set_reminder":"Definir lembrete","ticket_reminder":"Lembretes de ingressos","yes":"Sim"},"reminders":"Lembretes","reset":{"confirm_password":"Confirme a Senha","email":"O email","password":"Senha","recalled_your_login_info":"Recuperou suas informa\u00e7\u00f5es de login?","reset_password":"Redefinir senha","set_a_new_password":"Definir uma nova senha","sign_in":"Assinar em"},"sales":"Vendas","service":{"add":"Adicionar","edit_service":"Editar servi\u00e7o","name":"Nome","new_service":"Novo servi\u00e7o","no_service_available":"Nenhum servi\u00e7o dispon\u00edvel.","no_service_found":"Nenhum servi\u00e7o encontrado.","service_not_found":"Servi\u00e7o n\u00e3o encontrado.","service_saved_successfully":"Servi\u00e7o salvo com sucesso.","service_updated_successfully":"Servi\u00e7o atualizado com sucesso.","service_used_somewhere_else":"Servi\u00e7o usado em outro lugar."},"services":"Servi\u00e7os","setting":{"application_name":"Nome da Aplica\u00e7\u00e3o","choose":"Escolher","company_domain":"Dom\u00ednio da empresa","current_version":"Vers\u00e3o Atual","favicon":"Favicon","file_type":"Tipo de arquivo","logo":"Logotipo da empresa","setting_updated_successfully":"Configura\u00e7\u00e3o atualizada com sucesso."},"settings":"Configura\u00e7\u00f5es","staff":"Funcion\u00e1rios","status":{"additional_contact":"Contato Adicional","answered":"Respondidos","attempted":"Tentada","cancelled":"Cancelado","closed":"Fechados","contacted":"Contatada","finished":"Acabado","in_progress":"Em progresso","new_opportunity":"Nova oportunidade","not_attempted":"N\u00e3o tentado","not_started":"n\u00e3o foi iniciado","on_hold":"Em espera","open":"Abrir"},"success":"Sucesso","support":"Apoio, suporte","tag":{"add":"Adicionar","add_new_tag":"Adicionar nova tag","description":"Descri\u00e7\u00e3o","edit_tag":"Editar Tag","name":"Nome","new_tag":"Nova Tag","no_tag_available":"Nenhuma tag dispon\u00edvel.","no_tag_found":"Nenhuma tag encontrada.","tag_details":"Detalhes da tag","tag_not_found":"Tag n\u00e3o encontrada.","tag_saved_successfully":"Tag salva com sucesso.","tag_updated_successfully":"Tag atualizada com sucesso."},"tags":"Tags","task":{"awaiting_feedback":"Aguardando Feedback","billable":"Fatur\u00e1vel","completed":"Conclu\u00edda","due_date":"Data de vencimento","edit_task":"Editar Tarefa","hourly_rate":"Taxa hor\u00e1ria","in_progress":"Em progresso","name":"Nome","new_task":"Nova tarefa","no_task_available":"Nenhuma tarefa dispon\u00edvel.","not_started":"n\u00e3o foi iniciado","priority":"Prioridade","public":"P\u00fablico","related_to":"Relacionado a","start_date":"Data de in\u00edcio","status":"Status","subject":"Sujeito","task_details":"Detalhes da Tarefa","task_saved_successfully":"Tarefa salva com sucesso.","task_status_updated_successfully":"Status da tarefa atualizado com sucesso.","task_updated_successfully":"Tarefa atualizada com sucesso.","testing":"Testando","ticket":"Bilhete"},"tasks":"Tarefas","tax_rate":{"edit_tax_rate":"Editar taxa de imposto","new_tax_rate":"Nova taxa de imposto","no_tax_rate_available":"Nenhuma taxa de imposto dispon\u00edvel.","no_tax_rate_found":"Nenhuma taxa de imposto encontrada.","tax_rate":"Taxa de imposto","tax_rate_not_found":"Taxa de imposto n\u00e3o encontrada.","tax_rate_saved_successfully":"Taxa de imposto salva com sucesso.","tax_rate_updated_successfully":"Taxa de imposto atualizada com sucesso."},"tax_rates":"Taxas de impostos","this_week_payments":"Pagamentos desta semana","ticket":{"add":"Adicionar","added_by":"Adicionado por","assign_to":"Atribuir a","attachments":"Anexos","body":"Corpo","cc":"CC","contact":"Contato","department":"Departamento","details":"Detalhes","edit_ticket":"Editar Ticket","email":"O email","name":"Nome","new_ticket":"Novo t\u00edquete","no_ticket_available":"Nenhum ingresso dispon\u00edvel.","no_ticket_found":"Nenhum t\u00edquete encontrado.","note":"Nota","predefined_reply":"Resposta Predefinida","priority":"Prioridade","reminder":"Lembrete","service":"Servi\u00e7o","subject":"Sujeito","tags":"Tags","task":"Tarefa","ticket_details":"Detalhes do bilhete","ticket_not_found":"Ticket introuvable.","ticket_saved_successfully":"Ticket salvo com sucesso.","ticket_status_updated_successfully":"Status do ticket atualizado com sucesso.","ticket_to_contact":"Bilhete para contato","ticket_updated_successfully":"Ticket atualizado com sucesso.","ticket_without_contact":"Ingresso sem contato","tickets_status":"Status dos ingressos","you_can_add_multiples_images_and_files":"Voc\u00ea pode adicionar v\u00e1rias imagens e arquivos"},"ticket_priorities":"Prioridade de t\u00edquete","ticket_priority":{"add":"Adicionar","add_new_ticket_priority":"Adicionar nova prioridade de t\u00edquete","edit_ticket_priority":"Editar prioridade de t\u00edquete","name":"Nome","new_ticket_priority":"Nova prioridade de t\u00edquete","no_ticket_priority_available":"Nenhuma prioridade de t\u00edquete dispon\u00edvel.","no_ticket_priority_found":"Nenhuma prioridade de t\u00edquete encontrada.","ticket_priority_not_found":"Prioridade de t\u00edquete n\u00e3o encontrada.","ticket_priority_saved_successfully":"Prioridade de ingresso salva com sucesso.","ticket_priority_updated_successfully":"Prioridade do ticket atualizada com sucesso.","ticket_priority_used_somewhere_else":"Prioridade do ticket usado em outro lugar."},"ticket_status":{"add":"Adicionar","add_new_ticket_status":"Adicionar novo status de t\u00edquete","color":"Cor","edit_ticket_status":"Editar status do t\u00edquete","name":"Nome","new_ticket_status":"Status do novo t\u00edquete","status_order":"Ordem de status","ticket_status":"Status do t\u00edquete","ticket_status_saved_successfully":"Status do ticket salvo com sucesso.","ticket_status_updated_successfully":"Status do ticket atualizado com sucesso.","ticket_status_used_somewhere_else":"Status do ticket usado em outro lugar."},"tickets":"Ingressos","translation_manager":"Gerente de Tradu\u00e7\u00e3o","translator_manager":{"edit_language":"Edit Language","language_added_successfully":"Idioma adicionado com sucesso.","language_short_code":"Insira o c\u00f3digo curto do idioma. ou seja, ingl\u00eas = en","language_updated_successfully":"Langue mise \u00e0 jour avec succ\u00e8s.","translation":"Translation"},"user":{"change_language":"Mudar idioma","change_password":"Mudar senha","edit_profile":"Editar Perfil","email":"O email","first_name":"Primeiro nome","language":"L\u00edngua","language_updated_successfully":"Idioma atualizado com sucesso.","last_name":"\u00daltimo nome","logout":"Sair","name":"Nome","password":"Senha","password_confirmation":"Confirme a Senha","password_updated_successfully":"Senha atualizada com sucesso.","phone":"telefone","profile":"Perfil","profile_updated_successfully":"Perfil atualizado com sucesso.","return_to_admin":"Retornar para Admin"},"users":"Comercial","weekdays":{"fri":"SEX","mon":"SEG","sat":"Sentado","sun":"SOL","thu":"QUI","tue":"TER","wed":"QUA"}},"pt.pagination":{"next":"Pr\u00f3xima &raquo;","previous":"&laquo; Anterior"},"pt.passwords":{"reset":"Sua senha foi redefinida!","sent":"Enviamos seu link de redefini\u00e7\u00e3o de senha por e-mail!","throttled":"Aguarde antes de tentar novamente.","token":"Este token de redefini\u00e7\u00e3o de senha \u00e9 inv\u00e1lido.","user":"N\u00e3o conseguimos encontrar um usu\u00e1rio com esse endere\u00e7o de e-mail."},"pt.validation":{"accepted":"O :attribute deve ser aceito.","active_url":"O :attribute n\u00e3o \u00e9 um URL v\u00e1lido.","after":"O :attribute deve ser uma data ap\u00f3s: date.","after_or_equal":"O :attribute deve ser uma data posterior ou igual a: date.","alpha":"O :attribute pode conter apenas letras.","alpha_dash":"O :attribute pode conter apenas letras, n\u00fameros, tra\u00e7os e sublinhados.","alpha_num":"O :attribute pode conter apenas letras e n\u00fameros.","array":"O :attribute deve ser um array.","attributes":[],"before":"O :attribute deve ser uma data antes de: date.","before_or_equal":"O :attribute deve ser uma data anterior ou igual a: date.","between":{"array":"O :attribute deve ter entre :min e :max items.","file":"O :attribute deve estar entre :min e :max kilobytes.","numeric":"O :attribute deve estar entre :min e :max.","string":"O :attribute deve estar entre :min e :max caracteres."},"boolean":"O campo :attribute deve ser verdadeiro ou falso.","confirmed":"A confirma\u00e7\u00e3o do :attribute n\u00e3o corresponde.","custom":{"attribute-name":{"rule-name":"mensagem personalizada"}},"date":"O :attribute n\u00e3o \u00e9 uma data v\u00e1lida.","date_equals":"O :attribute deve ser uma data igual a: date.","date_format":"O :attribute n\u00e3o corresponde ao formato: format.","different":"O :attribute e: other devem ser diferentes.","digits":"O :attribute deve ser: digits digits.","digits_between":"O :attribute deve estar entre :min e :max digits.","dimensions":"O :attribute tem dimens\u00f5es de imagem inv\u00e1lidas.","distinct":"O campo :attribute tem um valor duplicado.","email":"O :attribute deve ser um endere\u00e7o de email v\u00e1lido.","ends_with":" :attribute deve terminar com um dos seguintes itens:: values.","exists":"O :attribute selecionado: \u00e9 inv\u00e1lido.","file":"O :attribute deve ser um arquivo.","filled":"O campo do :attribute deve ter um valor.","gt":{"array":"O :attribute deve ter mais de itens de: value.","file":"O :attribute deve ser maior que kilobytes de: value.","numeric":"O :attribute deve ser maior que: value.","string":"O :attribute deve ser maior que caracteres de: value."},"gte":{"array":"O :attribute deve ter itens de: value ou mais.","file":"O :attribute deve ser maior ou igual kilobytes de: value.","numeric":"O :attribute deve ser maior ou igual a: value.","string":"O :attribute deve ser maior ou igual a caracteres de: value."},"image":"O :attribute deve ser uma imagem.","in":"O :attribute selecionado: \u00e9 inv\u00e1lido.","in_array":"O campo do :attribute n\u00e3o existe em: other.","integer":"O :attribute deve ser um n\u00famero inteiro.","ip":"O :attribute deve ser um endere\u00e7o IP v\u00e1lido.","ipv4":"O :attribute deve ser um endere\u00e7o IPv4 v\u00e1lido.","ipv6":"O :attribute deve ser um endere\u00e7o IPv6 v\u00e1lido.","json":"O :attribute deve ser uma sequ\u00eancia JSON v\u00e1lida.","lt":{"array":"O :attribute deve ter menos que itens de: value.","file":"O :attribute deve ser menor que kilobytes de: value.","numeric":"O :attribute deve ser menor que: value.","string":"O :attribute deve ser menor que caracteres de: value."},"lte":{"array":"O :attribute n\u00e3o deve ter mais que itens de :value.","file":"O :attribute deve ser menor ou igual a kilobytes de: value.","numeric":"O :attribute deve ser menor ou igual a: value.","string":"O :attribute deve ser menor ou igual a caracteres de: value."},"max":{"array":"O :attribute pode n\u00e3o ter mais que: max items.","file":"O :attribute n\u00e3o pode ser maior que: max kilobytes.","numeric":"O :attribute n\u00e3o pode ser maior que: max.","string":"O :attribute n\u00e3o pode ser maior que: max caracteres."},"mimes":"O :attribute deve ser um arquivo do tipo:: values.","mimetypes":"O :attribute deve ser um arquivo do tipo:: values.","min":{"array":"O :attribute deve ter pelo menos itens :min imos.","file":"O :attribute deve ser pelo menos :min kilobytes.","numeric":"O :attribute deve ser pelo menos :min.","string":"O :attribute deve ter pelo menos caracteres :min imos."},"not_in":"O :attribute selecionado: \u00e9 inv\u00e1lido.","not_regex":"O formato do :attribute \u00e9 inv\u00e1lido.","numeric":"O :attribute deve ser um n\u00famero.","password":"A senha est\u00e1 incorreta.","present":"O campo do :attribute deve estar presente.","regex":"O formato do :attribute \u00e9 inv\u00e1lido.","required":"O: campo de :attribute \u00e9 obrigat\u00f3rio.","required_if":"O campo :attribute \u00e9 obrigat\u00f3rio quando: other \u00e9: value.","required_unless":"O campo :attribute \u00e9 obrigat\u00f3rio, a menos que: other esteja em: values.","required_with":"O campo :attribute \u00e9 obrigat\u00f3rio quando: values estiver presente.","required_with_all":"O campo :attribute \u00e9 obrigat\u00f3rio quando: values est\u00e3o presentes.","required_without":"O campo :attribute \u00e9 obrigat\u00f3rio quando: values n\u00e3o est\u00e1 presente.","required_without_all":"O campo :attribute \u00e9 obrigat\u00f3rio quando nenhum dos: values estiver presente.","same":"O :attribute e: other devem corresponder.","size":{"array":"O :attribute deve conter itens de: size.","file":"O :attribute deve ser: size kilobytes.","numeric":"O :attribute deve ser: size.","string":"O :attribute deve ser: size de caracteres."},"starts_with":"O :attribute deve come\u00e7ar com um dos seguintes itens:: values.","string":"O :attribute deve ser uma string.","timezone":"O :attribute deve ser uma zona v\u00e1lida.","unique":"O :attribute j\u00e1 foi utilizado.","uploaded":"O :attribute falhou ao carregar.","url":"O formato do :attribute \u00e9 inv\u00e1lido.","uuid":"O :attribute deve ser um UUID v\u00e1lido."},"ru.auth":{"failed":"\u042d\u0442\u0438 \u0443\u0447\u0435\u0442\u043d\u044b\u0435 \u0434\u0430\u043d\u043d\u044b\u0435 \u043d\u0435 \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0443\u044e\u0442 \u043d\u0430\u0448\u0438\u043c \u0437\u0430\u043f\u0438\u0441\u044f\u043c.","throttle":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u043c\u043d\u043e\u0433\u043e \u043f\u043e\u043f\u044b\u0442\u043e\u043a \u0432\u0445\u043e\u0434\u0430 \u0432 \u0441\u0438\u0441\u0442\u0435\u043c\u0443. \u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u043f\u043e\u0432\u0442\u043e\u0440\u0438\u0442\u0435 \u043f\u043e\u043f\u044b\u0442\u043a\u0443 \u0447\u0435\u0440\u0435\u0437: \u0441\u0435\u043a\u0443\u043d\u0434\u044b, \u0441\u0435\u043a\u0443\u043d\u0434\u044b."},"ru.messages":{"activity_log":{"activity_logs":"\u0416\u0443\u0440\u043d\u0430\u043b\u044b \u0430\u043a\u0442\u0438\u0432\u043d\u043e\u0441\u0442\u0438","loading_more_date":"\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430 \u0434\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0445 \u0434\u0430\u043d\u043d\u044b\u0445","sorry_we_not_find_any_data":"\u041c\u044b \u043d\u0435 \u043c\u043e\u0436\u0435\u043c \u043d\u0430\u0439\u0442\u0438 \u043d\u0438\u043a\u0430\u043a\u0438\u0445 \u0434\u0430\u043d\u043d\u044b\u0445, \u0441\u0434\u0435\u043b\u0430\u0439\u0442\u0435 \u0445\u043e\u0442\u044f \u0431\u044b 1 \u0437\u0430\u043f\u0438\u0441\u044c","we_could_find_any_data":"\u041c\u044b \u043d\u0435 \u0441\u043c\u043e\u0433\u043b\u0438 \u043d\u0430\u0439\u0442\u0438 \u043d\u0438\u043a\u0430\u043a\u0438\u0445 \u0434\u0430\u043d\u043d\u044b\u0445 \u0418\u0437\u0432\u0438\u043d\u0438\u0442\u0435"},"address":{"city":"\u0413\u043e\u0440\u043e\u0434","country":"\u0421\u0442\u0440\u0430\u043d\u0430","state":"\u0421\u043e\u0441\u0442\u043e\u044f\u043d\u0438\u0435","street":"\u0423\u043b\u0438\u0446\u0430","zip_code":"\u041f\u043e\u0447\u0442\u043e\u0432\u044b\u0439 \u0438\u043d\u0434\u0435\u043a\u0441"},"announcement":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","announcement_date":"\u0414\u0430\u0442\u0430 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u044f","announcement_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u044f","announcement_not_found":"\u041e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e","announcement_saved_successfully":"\u041e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043e.","announcement_updated_successfully":"\u041e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u043e.","edit_announcement":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435","message":"\u0421\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","new_announcement":"\u041d\u043e\u0432\u043e\u0435 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435","no_announcement_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0439","no_announcement_found":"\u041e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e.","show_my_name":"\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u043c\u043e\u0435 \u0438\u043c\u044f","show_to_clients":"\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u043a\u043b\u0438\u0435\u043d\u0442\u0430\u043c","show_to_staff":"\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u043f\u0435\u0440\u0441\u043e\u043d\u0430\u043b\u0443","subject":"\u0422\u0435\u043c\u0430"},"announcements":"\u041e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u044f","article":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","article_details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u0435\u0435 \u043e \u0441\u0442\u0430\u0442\u044c\u0435","article_not_found":"\u0421\u0442\u0430\u0442\u044c\u044f \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","article_saved_successfully":"\u0421\u0442\u0430\u0442\u044c\u044f \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","article_updated_successfully":"\u0421\u0442\u0430\u0442\u044c\u044f \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","attachment":"\u0412\u043b\u043e\u0436\u0435\u043d\u0438\u0435","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","disabled":"\u041e\u0442\u043a\u043b\u044e\u0447\u0435\u043d\u043e","edit_article":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u0442\u0430\u0442\u044c\u044e","group":"\u0413\u0440\u0443\u043f\u043f\u0430","internal_article":"\u0412\u043d\u0443\u0442\u0440\u0435\u043d\u043d\u044f\u044f \u0441\u0442\u0430\u0442\u044c\u044f","new_article":"\u041d\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0442\u044c\u044f","no_article_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0441\u0442\u0430\u0442\u0435\u0439.","no_article_found":"\u0421\u0442\u0430\u0442\u044c\u044f \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","subject":"\u0422\u0435\u043c\u0430","upload_image":"\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044c \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435"},"article_group":{"add_new_article_group":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u0443\u044e \u0433\u0440\u0443\u043f\u043f\u0443 \u0441\u0442\u0430\u0442\u0435\u0439","article_group_saved_successfully":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0441\u0442\u0430\u0442\u0435\u0439 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","article_group_updated_successfully":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0441\u0442\u0430\u0442\u0435\u0439 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","article_group_used_somewhere_else":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0441\u0442\u0430\u0442\u0435\u0439 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0432 \u0434\u0440\u0443\u0433\u043e\u043c \u043c\u0435\u0441\u0442\u0435.","article_groups":"\u0413\u0440\u0443\u043f\u043f\u044b \u0441\u0442\u0430\u0442\u0435\u0439","color":"\u0426\u0432\u0435\u0442","edit_article_group":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0433\u0440\u0443\u043f\u043f\u0443 \u0441\u0442\u0430\u0442\u0435\u0439","group_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0433\u0440\u0443\u043f\u043f\u044b","new_article_group":"\u041d\u043e\u0432\u0430\u044f \u0433\u0440\u0443\u043f\u043f\u0430 \u0441\u0442\u0430\u0442\u0435\u0439","order":"\u0417\u0430\u043a\u0430\u0437"},"articles":"\u0421\u0442\u0430\u0442\u044c\u0438","calendars":"\u041a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u0438","change_password":{"change_information_about_yourself_on_this_page":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044e \u043e \u0441\u0435\u0431\u0435 \u043d\u0430 \u044d\u0442\u043e\u0439 \u0441\u0442\u0440\u0430\u043d\u0438\u0446\u0435.","confirm_password":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0435 \u043f\u0430\u0440\u043e\u043b\u044c","current_password":"\u0422\u0435\u043a\u0443\u0449\u0438\u0439 \u043f\u0430\u0440\u043e\u043b\u044c","edit_profile":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0444\u0438\u043b\u044c","new_password":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0430\u0440\u043e\u043b\u044c"},"client_dashboard":"\u041f\u0430\u043d\u0435\u043b\u044c \u0443\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u044f \u043a\u043b\u0438\u0435\u043d\u0442\u0430","cms":"CMS","comment":{"add_comment":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0439","added_by":"\u041a\u0435\u043c \u0434\u043e\u0431\u0430\u0432\u043b\u0435\u043d\u043e","comments_saved_successfully":"\u041a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0439 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","comments_updated_successfully":"\u041a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0439 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","edit_comment":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0439","new_comment":"\u041d\u043e\u0432\u044b\u0439 \u043a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0439","no_comments_added_yet":"\u041a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0435\u0432 \u043f\u043e\u043a\u0430 \u043d\u0435\u0442"},"comments":"\u041a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0438","common":{"action":"\u0414\u0435\u0439\u0441\u0442\u0432\u0438\u0435","active":"\u0430\u043a\u0442\u0438\u0432\u043d\u044b\u0439","add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","admin_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u0430\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440\u0430","announcement":"\u041e\u0431\u044a\u044f\u0432\u043b\u0435\u043d\u0438\u0435","apply":"\u041f\u043e\u0434\u0430\u0442\u044c \u0437\u0430\u044f\u0432\u043b\u0435\u043d\u0438\u0435","article":"\u0421\u0442\u0430\u0442\u044c\u044f","article_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0441\u0442\u0430\u0442\u0435\u0439","assignee":"\u041f\u0440\u0430\u0432\u043e\u043f\u0440\u0435\u0435\u043c\u043d\u0438\u043a","attachment_deleted":"\u041f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0443\u0434\u0430\u043b\u0435\u043d\u043e.","back":"\u041d\u0430\u0437\u0430\u0434","cancel":"\u041e\u0442\u043c\u0435\u043d\u0438\u0442\u044c","choose":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c","client_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","contract_type":"\u0424\u043e\u0440\u043c\u0430 \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","country":"\u0421\u0442\u0440\u0430\u043d\u0430","created_on":"\u0414\u0430\u0442\u0430 \u0441\u043e\u0437\u0434\u0430\u043d\u0438\u044f","custom":"\u041e\u0431\u044b\u0447\u0430\u0439","customer":"\u041f\u043e\u043a\u0443\u043f\u0430\u0442\u0435\u043b\u044c","customer_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","data_base_entries":"\u041f\u043e\u043a\u0430\u0437\u0430\u043d\u043e \u043e\u0442 _START_ \u0434\u043e _END_ \u0438\u0437 _TOTAL_ \u0437\u0430\u043f\u0438\u0441\u0435\u0439","deactive":"\u0414\u0435\u0430\u043a\u0442\u0438\u0432\u0438\u0440\u043e\u0432\u0430\u043d","default_country_code":"\u041a\u043e\u0434 \u0441\u0442\u0440\u0430\u043d\u044b \u043f\u043e \u0443\u043c\u043e\u043b\u0447\u0430\u043d\u0438\u044e","delete":"\u0423\u0434\u0430\u043b\u0438\u0442\u044c","delete_attachment":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e \"\u0412\u043b\u043e\u0436\u0435\u043d\u0438\u0435\"?","delete_confirm":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430 \u043d\u0430\u043f\u0435\u0447\u0430\u0442\u0430\u0439\u0442\u0435","delete_confirm_common":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e","delete_note":"\u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u0443 \"\u0417\u0430\u043c\u0435\u0442\u043a\u0443\"?","deleted":"\u0423\u0434\u0430\u043b\u0435\u043d\u043e!","department":"\u041e\u0442\u0434\u0435\u043b\u0435\u043d\u0438\u0435","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","download":"\u0421\u043a\u0430\u0447\u0430\u0442\u044c","download_as_pdf":"\u0421\u043a\u0430\u0447\u0430\u0442\u044c \u043a\u0430\u043a PDF","drafted":"\u0421\u043e\u0441\u0442\u0430\u0432\u043b\u0435\u043d","edit":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","expense":"\u0420\u0430\u0441\u0445\u043e\u0434","expense_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","filter_by":"(\u043e\u0442\u0444\u0438\u043b\u044c\u0442\u0440\u043e\u0432\u0430\u043d\u043e \u0438\u0437 _MAX_ \u0437\u0430\u043f\u0438\u0441\u0435\u0439)","from":"\u0418\u0437","goal":"\u0426\u0435\u043b\u044c","has_been_delete":" \u0431\u044b\u043b \u0443\u0434\u0430\u043b\u0435\u043d.","incomes_vs_expenses":"\u0414\u043e\u0445\u043e\u0434\u044b \u043f\u0440\u043e\u0442\u0438\u0432 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","last_updated":"\u041f\u043e\u0441\u043b\u0435\u0434\u043d\u0435\u0435 \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0438\u0435","lead":"\u0412\u0435\u0441\u0442\u0438","lead_source":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","menu_entry":"\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u0437\u0430\u043f\u0438\u0441\u0438 _MENU_","n\/a":"N\/A","name":"\u0418\u043c\u044f","no":"\u041d\u0435\u0442","no_data_available_in_table":"\u0414\u0430\u043d\u043d\u044b\u0435 \u043e\u0442\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u044e\u0442 \u0432 \u0442\u0430\u0431\u043b\u0438\u0446\u0435","no_entry":"\u041f\u043e\u043a\u0430\u0437\u0430\u043d\u043e \u043e\u0442 0 \u0434\u043e 0 \u0438\u0437 0 \u0437\u0430\u043f\u0438\u0441\u0435\u0439","no_matching":"\u0421\u043e\u0432\u043f\u0430\u0434\u0430\u044e\u0449\u0438\u0445 \u0437\u0430\u043f\u0438\u0441\u0435\u0439 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e","note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","note_delete":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u0431\u044b\u043b\u043e \u0443\u0434\u0430\u043b\u0435\u043d\u043e.   ","of":"\u0418\u0437","ok":"\u0425\u041e\u0420\u041e\u0428\u041e","payment_mode":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b","predefined_reply":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442","product_1":"\u0422\u043e\u0432\u0430\u0440","product_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0442\u043e\u0432\u0430\u0440\u043e\u0432","product_header":"\u0422\u043e\u0432\u0430\u0440","proposal":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435","quantity_is_not_greater_than":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e \u043d\u0435 \u0431\u043e\u043b\u044c\u0448\u0435 9999999","save":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c","search":"\u0418\u0441\u043a\u0430\u0442\u044c","search_results":"\u0412\u0430\u0448\u0438 \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442\u044b \u043f\u043e\u0438\u0441\u043a\u0430 \u0438\u0434\u0443\u0442 \u0441\u044e\u0434\u0430 ...","service":"\u043e\u0431\u0441\u043b\u0443\u0436\u0438\u0432\u0430\u043d\u0438\u0435","showing":"\u041e\u0442\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435","status":"\u0421\u0442\u0430\u0442\u0443\u0441","tag":"\u042f\u0440\u043b\u044b\u043a","tax_rate":"\u0421\u0442\u0430\u0432\u043a\u0430 \u043d\u0430\u043b\u043e\u0433\u0430","term_and_conditions":"\u0421\u0440\u043e\u043a \u0438 \u0443\u0441\u043b\u043e\u0432\u0438\u044f","ticket_priority":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432","to":"\u041a","to_delete_this":"\u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e","total_amount":"\u041e\u0431\u0449\u0435\u0435 \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e","type_delete":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \"\u0423\u0434\u0430\u043b\u0438\u0442\u044c\", \u0447\u0442\u043e\u0431\u044b \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e","view":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440","weekly_payment_records":"\u0415\u0436\u0435\u043d\u0435\u0434\u0435\u043b\u044c\u043d\u044b\u0435 \u043e\u0442\u0447\u0435\u0442\u044b \u043e \u043f\u043b\u0430\u0442\u0435\u0436\u0430\u0445","yes":"\u0414\u0430"},"company":{"address":"\u0410\u0434\u0440\u0435\u0441","city":"\u0413\u043e\u0440\u043e\u0434","company":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","company_information_format":"\u0424\u043e\u0440\u043c\u0430\u0442 \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u0438 \u043e \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438 (PDF \u0438 HTML)","country_code":"\u041a\u043e\u0434 \u0441\u0442\u0440\u0430\u043d\u044b","currency":"\u0412\u0430\u043b\u044e\u0442\u0430","details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","state":"\u0421\u043e\u0441\u0442\u043e\u044f\u043d\u0438\u0435","vat_number":"\u041d\u043e\u043c\u0435\u0440 \u041d\u0414\u0421","website":"\u0412\u0435\u0431-\u0441\u0430\u0439\u0442","zip_code":"\u041f\u043e\u0447\u0442\u043e\u0432\u044b\u0439 \u0438\u043d\u0434\u0435\u043a\u0441"},"company_information":"\u0418\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","contact":{"Tickets":"\u0411\u0438\u043b\u0435\u0442\u044b","active":"\u0430\u043a\u0442\u0438\u0432\u043d\u044b\u0439","by_deleting_this_contact":"\u041f\u0440\u0438 \u0443\u0434\u0430\u043b\u0435\u043d\u0438\u0438 \u044d\u0442\u043e\u0433\u043e \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430 \u0431\u0443\u0434\u0435\u0442 \u0443\u0434\u0430\u043b\u0435\u043d \u0432\u0435\u0441\u044c \u0435\u0433\u043e \u043f\u0440\u043e\u0435\u043a\u0442.","contact_details":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442\u043d\u044b\u0435 \u0434\u0430\u043d\u043d\u044b\u0435","contact_not_found":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","contact_saved_successfully":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","contact_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","contact_updated_successfully":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","contract":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442","contracts":"\u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u044b","credit_note":"\u041a\u0440\u0435\u0434\u0438\u0442\u043e\u0432\u0430\u044f \u043d\u043e\u0442\u0430","customer_name":"\u0418\u043c\u044f \u043a\u043b\u0438\u0435\u043d\u0442\u0430","deactive":"\u0414\u0435\u0430\u043a\u0442\u0438\u0432\u0438\u0440\u043e\u0432\u0430\u043d","delete_contact_confirm":"\u0412\u044b \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e\u0442 \u043a\u043e\u043d\u0442\u0430\u043a\u0442?","direction":"\u041d\u0430\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435","edit_contact":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u043e\u043d\u0442\u0430\u043a\u0442","email_notifications":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u044f \u043f\u043e \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u0435","estimate":"\u041e\u0446\u0435\u043d\u0438\u0442\u044c","estimates":"\u043e\u0446\u0435\u043d\u043a\u0438","first_name":"\u0418\u043c\u044f","full_name":"\u041f\u043e\u043b\u043d\u043e\u0435 \u0438\u043c\u044f","impersonate":"\u0412\u044b\u0434\u0430\u0432\u0430\u0442\u044c \u0441\u0435\u0431\u044f \u0437\u0430","invoice":"\u0421\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0430","invoices":"\u0421\u0447\u0435\u0442\u0430-\u0444\u0430\u043a\u0442\u0443\u0440\u044b","last_name":"\u0424\u0430\u043c\u0438\u043b\u0438\u044f","make_sure_to_set_appistent_permissions_for_this_contact":"\u0423\u0431\u0435\u0434\u0438\u0442\u0435\u0441\u044c, \u0447\u0442\u043e \u0434\u043b\u044f \u044d\u0442\u043e\u0433\u043e \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430 \u0443\u0441\u0442\u0430\u043d\u043e\u0432\u043b\u0435\u043d\u044b \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0443\u044e\u0449\u0438\u0435 \u0440\u0430\u0437\u0440\u0435\u0448\u0435\u043d\u0438\u044f","new_contact":"\u041d\u043e\u0432\u044b\u0439 \u043a\u043e\u043d\u0442\u0430\u043a\u0442","no_contact_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u043e\u0432.","no_contact_found":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442\u044b \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u044b.","password":"\u043f\u0430\u0440\u043e\u043b\u044c","permissions":"\u0420\u0430\u0437\u0440\u0435\u0448\u0435\u043d\u0438\u044f","position":"\u041f\u043e\u0437\u0438\u0446\u0438\u044f","primary_contact":"\u041e\u0441\u043d\u043e\u0432\u043d\u043e\u0435 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u043d\u043e\u0435 \u043b\u0438\u0446\u043e","project":"\u041f\u0440\u043e\u0435\u043a\u0442","projects":"\u041f\u0440\u043e\u0435\u043a\u0442\u044b","proposals":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u044f","send_password_email":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e \u0441 \u043f\u0430\u0440\u043e\u043b\u0435\u043c SET","send_welcome_email":"\u041d\u0435 \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u044f\u0442\u044c \u043f\u0440\u0438\u0432\u0435\u0442\u0441\u0442\u0432\u0435\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e","support":"\u0421\u043b\u0443\u0436\u0431\u0430 \u043f\u043e\u0434\u0434\u0435\u0440\u0436\u043a\u0438","task":"\u0417\u0430\u0434\u0430\u0447\u0430"},"contacts":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442\u044b","contract":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","authorized_signature":"\u041f\u043e\u0434\u043f\u0438\u0441\u044c \u0430\u0432\u0442\u043e\u0440\u0438\u0437\u043e\u0432\u0430\u043d\u043d\u043e\u0433\u043e \u043b\u0438\u0446\u0430","contract_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","contract_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u043e\u0432","contract_not_found":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d","contract_summary":"\u0420\u0435\u0437\u044e\u043c\u0435 \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","contract_type_id":"\u0422\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","contract_value":"\u0421\u0442\u043e\u0438\u043c\u043e\u0441\u0442\u044c \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","contracts_by_type":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u044b \u043f\u043e \u0442\u0438\u043f\u0443","contracts_expiring_this_month":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u044b \u0438\u0441\u0442\u0435\u043a\u0430\u044e\u0442 \u0432 \u044d\u0442\u043e\u043c \u043c\u0435\u0441\u044f\u0446\u0435","contracts_saved_successfully":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","contracts_updated_successfully":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","contracts_value_by_type":"\u0421\u0442\u043e\u0438\u043c\u043e\u0441\u0442\u044c \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u043e\u0432 \u043f\u043e \u0442\u0438\u043f\u0443","customer_id":"\u041a\u043b\u0438\u0435\u043d\u0442","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_contract":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442","end_date":"\u0414\u0430\u0442\u0430 \u043e\u043a\u043e\u043d\u0447\u0430\u043d\u0438\u044f","is_hide":"\u0421\u043a\u0440\u044b\u0442\u044c \u043e\u0442 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","is_trash":"\u041a\u043e\u0440\u0437\u0438\u043d\u0430","new_contract":"\u041d\u043e\u0432\u044b\u0439 \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442","no_contract_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u043e\u0432","no_contract_found":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","sign":"\u0417\u043d\u0430\u043a","start_date":"\u0414\u0430\u0442\u0430 \u043d\u0430\u0447\u0430\u043b\u0430","subject":"\u0422\u0435\u043c\u0430","task":"\u0417\u0430\u0434\u0430\u0447\u0430"},"contract_type":{"add_new_contract_type":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u0442\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","contract_by_type":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u043f\u043e \u0442\u0438\u043f\u0443","contract_saved_successfully":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","contract_type_used_somewhere_else":"\u0422\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0433\u0434\u0435-\u0442\u043e \u0435\u0449\u0435.","contract_updated_successfully":"\u041a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d..","contract_value_by_type":"\u0421\u0442\u043e\u0438\u043c\u043e\u0441\u0442\u044c \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430 \u043f\u043e \u0442\u0438\u043f\u0443","edit_contract_type":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0442\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","new_contract_type":"\u041d\u043e\u0432\u044b\u0439 \u0442\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430"},"contract_types":"\u0422\u0438\u043f\u044b \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u043e\u0432","contracts":"\u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u044b","countries":"\u0421\u0442\u0440\u0430\u043d\u044b","country":{"add":"\u0414\u043e\u0431\u0430\u0432\u043b\u044f\u0442\u044c","country_not_found":"\u0421\u0442\u0440\u0430\u043d\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","country_saved_successfully":"\u0421\u0442\u0440\u0430\u043d\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","country_updated_successfully":"\u0421\u0442\u0440\u0430\u043d\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","country_used_somewhere_else":"\u0421\u0442\u0440\u0430\u043d\u0430 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0432 \u0434\u0440\u0443\u0433\u043e\u043c \u043c\u0435\u0441\u0442\u0435.","edit_country":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0442\u0440\u0430\u043d\u0443","name":"\u0418\u043c\u044f","new_country":"\u041d\u043e\u0432\u0430\u044f \u0441\u0442\u0440\u0430\u043d\u0430","no_country_available":"\u0421\u0442\u0440\u0430\u043d\u0430 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u0430.","no_country_found":"\u0421\u0442\u0440\u0430\u043d\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430."},"credit_note":{"authorized_signature":"\u041f\u043e\u0434\u043f\u0438\u0441\u044c \u0430\u0432\u0442\u043e\u0440\u0438\u0437\u043e\u0432\u0430\u043d\u043d\u043e\u0433\u043e \u043b\u0438\u0446\u0430","client_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","closed":"\u0417\u0430\u043a\u0440\u044b\u0442\u043e","credit_note":"\u041a\u0440\u0435\u0434\u0438\u0442\u043e\u0432\u0430\u044f \u043d\u043e\u0442\u0430","credit_note_date":"\u0414\u0430\u0442\u0430 \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u043e\u0439 \u043d\u043e\u0442\u044b","credit_note_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u043e\u0439 \u043d\u043e\u0442\u044b","credit_note_details_updated_successfully":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u043e\u0439 \u043d\u043e\u0442\u044b \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u044b.","credit_note_not_found":"\u041a\u0440\u0435\u0434\u0438\u0442\u043d\u0430\u044f \u043d\u043e\u0442\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","credit_note_number":"\u041d\u043e\u043c\u0435\u0440 \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u043e\u0439 \u043d\u043e\u0442\u044b","credit_note_pdf":"\u041a\u0440\u0435\u0434\u0438\u0442\u043e\u0432\u0430\u044f \u0441\u043f\u0440\u0430\u0432\u043a\u0430 PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"\u041a\u0440\u0435\u0434\u0438\u0442-\u043d\u043e\u0442\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","credit_note_updated_successfully":"\u041a\u0440\u0435\u0434\u0438\u0442-\u043d\u043e\u0442\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","drafted":"\u0421\u043e\u0441\u0442\u0430\u0432\u043b\u0435\u043d","edit_credit_note":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u0443\u044e \u043d\u043e\u0442\u0443","invoice_credited":"\u0421\u0447\u0435\u0442 \u0437\u0430\u0447\u0438\u0441\u043b\u0435\u043d","mark_as_closed":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0437\u0430\u043a\u0440\u044b\u0442\u043e\u0435","mark_as_draft":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","mark_as_open":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043a\u0440\u044b\u0442\u043e\u0435","mark_as_void":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0435","new_credit_note":"\u041d\u043e\u0432\u0430\u044f \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u0430\u044f \u043d\u043e\u0442\u0430","no_credit_note_available":"\u041d\u0435\u0442 \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u043e\u0439 \u043d\u043e\u0442\u044b.","no_credit_note_found":"\u041a\u0440\u0435\u0434\u0438\u0442\u043e\u0432\u0430\u044f \u043d\u043e\u0442\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","open":"\u043e\u0442\u043a\u0440\u044b\u0442\u043e","quantity_is_not_greater_than":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e \u043d\u0435 \u0431\u043e\u043b\u044c\u0448\u0435 9999999","reference":"\u0421\u0441\u044b\u043b\u043a\u0430","refunds":"\u0412\u043e\u0437\u0432\u0440\u0430\u0442","save_and_send":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u0438 \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","save_as_draft":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","terms_and_conditions":"\u0423\u0441\u043b\u043e\u0432\u0438\u044f \u0438 \u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f","title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","view_credit_note_as_customer":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u043a\u0440\u0435\u0434\u0438\u0442\u043d\u0443\u044e \u043d\u043e\u0442\u0443 \u043a\u0430\u043a \u043a\u043b\u0438\u0435\u043d\u0442","void":"\u041f\u0443\u0441\u0442\u043e\u0442\u0430"},"credit_notes":"\u041a\u0440\u0435\u0434\u0438\u0442\u043d\u044b\u0435 \u0437\u0430\u043f\u0438\u0441\u0438","customer":{"add_address_details":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0434\u0435\u0442\u0430\u043b\u0438 \u0430\u0434\u0440\u0435\u0441\u0430","address":"\u0410\u0434\u0440\u0435\u0441","address_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e\u0431 \u0430\u0434\u0440\u0435\u0441\u0435","address_not_found":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e\u0431 \u0430\u0434\u0440\u0435\u0441\u0435 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u044b.","billing_address":"\u041f\u043b\u0430\u0442\u0435\u0436\u043d\u044b\u0439 \u0430\u0434\u0440\u0435\u0441","billing_address_details_not_available":"\u0418\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e\u0431 \u0430\u0434\u0440\u0435\u0441\u0435 \u0432\u044b\u0441\u0442\u0430\u0432\u043b\u0435\u043d\u0438\u044f \u0441\u0447\u0435\u0442\u0430 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u0430","by_deleting_this_customer":"\u041f\u0440\u0438 \u0443\u0434\u0430\u043b\u0435\u043d\u0438\u0438 \u044d\u0442\u043e\u0433\u043e \u043a\u043b\u0438\u0435\u043d\u0442\u0430 \u0432\u0441\u0435 \u0435\u0433\u043e \u043f\u0440\u043e\u0435\u043a\u0442, \u043a\u043e\u043d\u0442\u0430\u043a\u0442, \u0441\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0430, \u0441\u043c\u0435\u0442\u0430, \u043a\u0440\u0435\u0434\u0438\u0442-\u043d\u043e\u0442\u0430, \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0438 \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442 \u0431\u0443\u0434\u0443\u0442 \u0443\u0434\u0430\u043b\u0435\u043d\u044b.","city":"\u0413\u043e\u0440\u043e\u0434","company_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","copy_billing_address":"\u041a\u043e\u043f\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u043b\u0430\u0442\u0435\u0436\u043d\u044b\u0439 \u0430\u0434\u0440\u0435\u0441","country":"\u0421\u0442\u0440\u0430\u043d\u0430","currency":"\u0412\u0430\u043b\u044e\u0442\u0430","customer_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043a\u043b\u0438\u0435\u043d\u0442\u0435","customer_saved_successfully":"\u041a\u043b\u0438\u0435\u043d\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","customer_updated_successfully":"\u041a\u043b\u0438\u0435\u043d\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","customers":"\u041a\u043b\u0438\u0435\u043d\u0442\u044b","default_language":"\u042f\u0437\u044b\u043a \u043f\u043e \u0443\u043c\u043e\u043b\u0447\u0430\u043d\u0438\u044e","delete_customer_confirm":"\u0412\u044b \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e\u0433\u043e \u043a\u043b\u0438\u0435\u043d\u0442\u0430?","do_not_fill_shipping_address_customer_invoices":"\u041d\u0435 \u0437\u0430\u043f\u043e\u043b\u043d\u044f\u0439\u0442\u0435 \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044e \u043e\u0431 \u0430\u0434\u0440\u0435\u0441\u0435 \u0434\u043e\u0441\u0442\u0430\u0432\u043a\u0438, \u0435\u0441\u043b\u0438 \u0432\u044b \u043d\u0435 \u0431\u0443\u0434\u0435\u0442\u0435 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u044c \u0430\u0434\u0440\u0435\u0441 \u0434\u043e\u0441\u0442\u0430\u0432\u043a\u0438 \u0432 \u0441\u0447\u0435\u0442\u0430\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432.s","edit_customer":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043a\u043b\u0438\u0435\u043d\u0442\u0430","groups":"\u0413\u0440\u0443\u043f\u043f\u044b","new_customer":"\u041d\u043e\u0432\u044b\u0439 \u043a\u043b\u0438\u0435\u043d\u0442","no_customer_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432.","no_customer_found":"\u041a\u043b\u0438\u0435\u043d\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","same_as_a_customer_info":"\u0422\u043e \u0436\u0435, \u0447\u0442\u043e \u0438 \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u043a\u043b\u0438\u0435\u043d\u0442\u0435","search_customer":"\u0412\u0441\u0435\u0433\u043e \u043f\u043e \u043f\u0440\u043e\u0435\u043a\u0442\u0443","shipping_address":"\u0410\u0434\u0440\u0435\u0441 \u0434\u043e\u0441\u0442\u0430\u0432\u043a\u0438","shipping_address_details_not_available":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e\u0431 \u0430\u0434\u0440\u0435\u0441\u0435 \u0434\u043e\u0441\u0442\u0430\u0432\u043a\u0438 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b","state":"\u0421\u043e\u0441\u0442\u043e\u044f\u043d\u0438\u0435","street":"\u0423\u043b\u0438\u0446\u0430","total_contact":"\u0412\u0441\u0435\u0433\u043e \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u043e\u0432","total_customers":"\u0412\u0441\u0435\u0433\u043e \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","total_project":"\u0412\u0441\u0435\u0433\u043e \u043f\u043e \u043f\u0440\u043e\u0435\u043a\u0442\u0443","type":"\u0422\u0438\u043f","vat_number":"\u041d\u043e\u043c\u0435\u0440 \u041d\u0414\u0421","website":"\u0412\u0435\u0431-\u0441\u0430\u0439\u0442","zip_code":"\u041f\u043e\u0447\u0442\u043e\u0432\u044b\u0439 \u0438\u043d\u0434\u0435\u043a\u0441"},"customer_group":{"action":"\u0414\u0435\u0439\u0441\u0442\u0432\u0438\u0435","add_new_customer_group":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u0443\u044e \u0433\u0440\u0443\u043f\u043f\u0443 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","customer_group_saved_successfully":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","customer_group_updated_successfully":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_customer_group":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0433\u0440\u0443\u043f\u043f\u0443 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","name":"\u0418\u043c\u044f","new_customer_group":"\u041d\u043e\u0432\u0430\u044f \u0433\u0440\u0443\u043f\u043f\u0430 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432"},"customer_groups":"\u0413\u0440\u0443\u043f\u043f\u044b \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","customers":"\u041a\u043b\u0438\u0435\u043d\u0442\u044b","dashboard":"\u041f\u0430\u043d\u0435\u043b\u044c \u0438\u043d\u0441\u0442\u0440\u0443\u043c\u0435\u043d\u0442\u043e\u0432","department":{"department_not_found":"\u041e\u0442\u0434\u0435\u043b \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","department_saved_successfully":"\u041e\u0442\u0434\u0435\u043b \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","department_updated_successfully":"\u041e\u0442\u0434\u0435\u043b \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","departments":"\u0432\u0435\u0434\u043e\u043c\u0441\u0442\u0432\u0430","edit_department":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043e\u0442\u0434\u0435\u043b","hide_from_clients":"\u0421\u043a\u0440\u044b\u0442\u044c \u043e\u0442 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","new_department":"\u041d\u043e\u0432\u044b\u0439 \u043e\u0442\u0434\u0435\u043b","no_department_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043e\u0442\u0434\u0435\u043b\u043e\u0432.","no_department_found":"\u041e\u0442\u0434\u0435\u043b \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d."},"edit_profile":{"change_password":"\u0421\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","edit_profile":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0444\u0438\u043b\u044c","hello":"\u041f\u0440\u0438\u0432\u0435\u0442","hi":"\u041f\u0440\u0438\u0432\u0435\u0442","login":"\u0412\u043e\u0439\u0442\u0438","login_register":"\u0412\u043e\u0439\u0442\u0438 \/ \u0417\u0430\u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0438\u0440\u043e\u0432\u0430\u0442\u044c\u0441\u044f","logout":"\u0412\u044b\u0439\u0442\u0438","mark_all_as_read":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u0432\u0441\u0435 \u043a\u0430\u043a \u043f\u0440\u043e\u0447\u0438\u0442\u0430\u043d\u043d\u044b\u0435","notification":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u044f","register":"\u0417\u0430\u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0438\u0440\u043e\u0432\u0430\u0442\u044c\u0441\u044f","welcome":"\u0414\u043e\u0431\u0440\u043e \u043f\u043e\u0436\u0430\u043b\u043e\u0432\u0430\u0442\u044c"},"email":{"email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","forgot_password":"\u0417\u0430\u0431\u044b\u043b\u0438 \u043f\u0430\u0440\u043e\u043b\u044c","recalled_your_login_info":"\u0412\u044b \u0432\u0441\u043f\u043e\u043c\u043d\u0438\u043b\u0438 \u0432\u0430\u0448\u0438 \u0434\u0430\u043d\u043d\u044b\u0435 \u0434\u043b\u044f \u0432\u0445\u043e\u0434\u0430?","reset_password":"\u0421\u0431\u0440\u043e\u0441\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","send_reset_link":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u0441\u0441\u044b\u043b\u043a\u0443 \u0434\u043b\u044f \u0441\u0431\u0440\u043e\u0441\u0430","sign_in":"\u0412\u043e\u0439\u0442\u0438"},"email_template":{"available_merge_fields":"\u0414\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0435 \u043f\u043e\u043b\u044f \u0441\u043b\u0438\u044f\u043d\u0438\u044f","disabled":"\u041e\u0442\u043a\u043b\u044e\u0447\u0435\u043d\u043e","edit_email_template":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0448\u0430\u0431\u043b\u043e\u043d \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0433\u043e \u043f\u0438\u0441\u044c\u043c\u0430","email_message":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u0441\u043e\u043e\u0431\u0449\u0435\u043d\u0438\u0435","enable":"\u0412\u043a\u043b\u044e\u0447\u0438\u0442\u044c","from_name":"\u041e\u0442 \u0438\u043c\u0435\u043d\u0438","send_plain_text":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0431\u044b\u0447\u043d\u044b\u0439 \u0442\u0435\u043a\u0441\u0442","subject":"\u0422\u0435\u043c\u0430","template_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u0448\u0430\u0431\u043b\u043e\u043d\u0430"},"email_templates":"\u0428\u0430\u0431\u043b\u043e\u043d\u044b \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","error":"\u041e\u0448\u0438\u0431\u043a\u0430","estimate":{"accepted":"\u041f\u0420\u0418\u041d\u042f\u0422\u041e","adjustment":"\u0420\u0435\u0433\u0443\u043b\u0438\u0440\u043e\u0432\u043a\u0430","amount":"\u0421\u0443\u043c\u043c\u0430","amount_due":"\u0421\u0443\u043c\u043c\u0430 \u043a \u043e\u043f\u043b\u0430\u0442\u0435","authorized_signature":"\u041f\u043e\u0434\u043f\u0438\u0441\u044c \u0430\u0432\u0442\u043e\u0440\u0438\u0437\u043e\u0432\u0430\u043d\u043d\u043e\u0433\u043e \u043b\u0438\u0446\u0430","bill_to":"\u041a\u043e\u043c\u0443 \u0441\u0447\u0435\u0442","client_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","convert_estimate":"\u041f\u0440\u0435\u043e\u0431\u0440\u0430\u0437\u043e\u0432\u0430\u0442\u044c \u043e\u0446\u0435\u043d\u043a\u0443","convert_estimate_to_invoice":"\u0423\u0441\u043f\u0435\u0448\u043d\u043e \u043f\u0440\u0435\u043e\u0431\u0440\u0430\u0437\u043e\u0432\u0430\u0442\u044c \u0441\u043c\u0435\u0442\u0443 \u0432 \u0441\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0443.","declined":"\u041e\u0422\u041a\u041b\u041e\u041d\u0415\u041d","discount":"\u0421\u043a\u0438\u0434\u043a\u0430","draft":"\u0427\u0415\u0420\u041d\u041e\u0412\u041e\u0419 \u0412\u0410\u0420\u0418\u0410\u041d\u0422","drafted":"\u0421\u043e\u0441\u0442\u0430\u0432\u043b\u0435\u043d","edit_estimate":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043e\u0446\u0435\u043d\u043a\u0443","estimate":"\u041e\u0446\u0435\u043d\u0438\u0442\u044c","estimate_date":"\u0420\u0430\u0441\u0447\u0435\u0442\u043d\u0430\u044f \u0434\u0430\u0442\u0430","estimate_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043e\u0446\u0435\u043d\u043a\u0438","estimate_not_found":"\u041e\u0446\u0435\u043d\u043a\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430","estimate_number":"\u0420\u0430\u0441\u0447\u0435\u0442\u043d\u043e\u0435 \u0447\u0438\u0441\u043b\u043e","estimate_overview":"\u041e\u0411\u0417\u041e\u0420 \u0421\u043c\u0435\u0442\u044b","estimate_pdf":"\u041e\u0446\u0435\u043d\u0438\u0442\u044c PDF","estimate_prefix":"EN-","estimate_saved_successfully":"\u041e\u0446\u0435\u043d\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","estimate_status_updated_successfully":"\u041e\u0446\u0435\u043d\u043e\u0447\u043d\u044b\u0439 \u0441\u0442\u0430\u0442\u0443\u0441 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","estimate_updated_successfully":"\u041e\u0446\u0435\u043d\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","estimation_details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u0430\u044f \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e\u0431 \u043e\u0446\u0435\u043d\u043a\u0435","expired":"\u0418\u0421\u0422\u0415\u041a\u0428\u0418\u0419","expiry_date":"\u0421\u0440\u043e\u043a \u0433\u043e\u0434\u043d\u043e\u0441\u0442\u0438","item":"\u0422\u043e\u0432\u0430\u0440","mark_as_accepted":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043f\u0440\u0438\u043d\u044f\u0442\u043e\u0435","mark_as_declined":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043a\u043b\u043e\u043d\u0435\u043d\u043d\u043e\u0435","mark_as_draft":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","mark_as_expired":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043f\u0440\u043e\u0441\u0440\u043e\u0447\u0435\u043d\u043d\u044b\u0439","mark_as_send":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043d\u043e\u0435","more":"\u0415\u0449\u0435","new_estimate":"\u041d\u043e\u0432\u0430\u044f \u043e\u0446\u0435\u043d\u043a\u0430","no_estimate_available":"\u041e\u0446\u0435\u043d\u043a\u0430 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u0430","no_estimate_found":"\u041e\u0446\u0435\u043d\u043a\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","not_sent":"\u041d\u0415 \u041e\u0422\u041f\u0420\u0410\u0412\u041b\u0415\u041d\u041e","qty":"\u041a\u043e\u043b-\u0432\u043e","rate":"\u041e\u0446\u0435\u043d\u0438\u0442\u044c","save_and_send":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u0438 \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","save_as_draft":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","sent":"\u041f\u041e\u0421\u041b\u0410\u041b","ship_to":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","status":"\u0421\u0442\u0430\u0442\u0443\u0441","sub_total":"\u041f\u0440\u043e\u043c\u0435\u0436\u0443\u0442\u043e\u0447\u043d\u044b\u0439 \u0438\u0442\u043e\u0433","task":"\u0417\u0430\u0434\u0430\u0447\u0430","taxes":"\u041d\u0430\u043b\u043e\u0433\u0438","terms_conditions":"\u0423\u0441\u043b\u043e\u0432\u0438\u044f \u0438 \u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f","title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","total":"\u0418\u0442\u043e\u0433\u043e","total_estimates":"\u041e\u0431\u0449\u0430\u044f \u043e\u0446\u0435\u043d\u043a\u0430","total_paid":"\u0412\u0441\u0435\u0433\u043e \u0432\u044b\u043f\u043b\u0430\u0447\u0435\u043d\u043e","view_estimate_as_customer":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0441\u043c\u0435\u0442\u0443 \u0432 \u043a\u0430\u0447\u0435\u0441\u0442\u0432\u0435 \u043a\u043b\u0438\u0435\u043d\u0442\u0430"},"estimates":"\u041e\u0446\u0435\u043d\u043a\u0438","expense":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","amount":"\u0421\u0443\u043c\u043c\u0430","amount_with_tax":"\u0421\u0443\u043c\u043c\u0430 \u0441 \u043d\u0430\u043b\u043e\u0433\u043e\u043c","apply_tax":"\u041f\u0440\u0438\u043c\u0435\u043d\u0438\u0442\u044c \u043d\u0430\u043b\u043e\u0433","apply_tax_message":"\u0412\u044b\u0447\u0435\u0441\u0442\u044c \u043e\u0431\u0449\u0443\u044e \u0441\u0443\u043c\u043c\u0443 \u043d\u0430\u043b\u043e\u0433\u0430 \u0438\u0437 \u0441\u0443\u043c\u043c\u044b","attachment":"\u0412\u043b\u043e\u0436\u0435\u043d\u0438\u0435","auto_create_invoice":"\u0410\u0432\u0442\u043e\u043c\u0430\u0442\u0438\u0447\u0435\u0441\u043a\u043e\u0435 \u0441\u043e\u0437\u0434\u0430\u043d\u0438\u0435 \u0441\u0447\u0435\u0442\u0430-\u0444\u0430\u043a\u0442\u0443\u0440\u044b","billable":"\u041e\u043f\u043b\u0430\u0447\u0438\u0432\u0430\u0435\u043c\u044b\u0439","choose_file":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0444\u0430\u0439\u043b","currency":"\u0412\u0430\u043b\u044e\u0442\u0430","customer":"\u041a\u043b\u0438\u0435\u043d\u0442","details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","edit_expense":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0440\u0430\u0441\u0445\u043e\u0434\u044b","expense_amount":"\u0421\u0443\u043c\u043c\u0430 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","expense_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","expense_category_by_chart":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432 \u043f\u043e \u0434\u0438\u0430\u0433\u0440\u0430\u043c\u043c\u0435","expense_date":"\u0414\u0430\u0442\u0430 \u043e\u043f\u043b\u0430\u0442\u044b","expense_details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u0430\u044f \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u0440\u0430\u0441\u0445\u043e\u0434\u0430\u0445","expense_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","expense_not_found":"\u0420\u0430\u0441\u0445\u043e\u0434 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","expense_saved_successfully":"\u0420\u0430\u0441\u0445\u043e\u0434 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","expense_updated_successfully":"\u0420\u0430\u0441\u0445\u043e\u0434\u044b \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u044b.","name":"\u0418\u043c\u044f","new_expense":"\u041d\u043e\u0432\u044b\u0439 \u0440\u0430\u0441\u0445\u043e\u0434","no_expense_available":"\u0420\u0430\u0441\u0445\u043e\u0434 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","no_expense_found":"\u041d\u0438\u043a\u0430\u043a\u0438\u0445 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432 \u043d\u0435 \u043e\u0431\u043d\u0430\u0440\u0443\u0436\u0435\u043d\u043e.","note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","notes":"\u0417\u0430\u043c\u0435\u0442\u043a\u0438","payment_mode":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b","preview_attachment":"\u041f\u0440\u0435\u0434\u0432\u0430\u0440\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 \u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440 \u0432\u043b\u043e\u0436\u0435\u043d\u0438\u044f","reference":"\u0421\u0441\u044b\u043b\u043a\u0430","reminders":"\u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","send_email":"\u041e\u0442\u043f\u0440\u0430\u0432\u043b\u044f\u0442\u044c \u0441\u0447\u0435\u0442 \u043d\u0430 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0443\u044e \u043f\u043e\u0447\u0442\u0443 \u043a\u043b\u0438\u0435\u043d\u0442\u0430 \u043f\u0440\u0438 \u043f\u043e\u0432\u0442\u043e\u0440\u043d\u043e\u043c \u0441\u043e\u0437\u0434\u0430\u043d\u0438\u0438 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","tax_1":"\u041d\u0430\u043b\u043e\u0433 1 (\u0432%)","tax_2":"\u041d\u0430\u043b\u043e\u0433 2 (\u0432%)","tax_applied":"\u041f\u0440\u0438\u043c\u0435\u043d\u0435\u043d \u043d\u0430\u043b\u043e\u0433","view_attachment":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0432\u043b\u043e\u0436\u0435\u043d\u0438\u0435"},"expense_by_category":"\u0420\u0430\u0441\u0445\u043e\u0434 \u043f\u043e \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f\u043c","expense_categories":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","expense_category":{"add_new_expense_category":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u0443\u044e \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044e \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","cost_categories":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u0438 \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","cost_category":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","edit_category":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044e \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","expense_category_by_chart":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432 \u043f\u043e \u0434\u0438\u0430\u0433\u0440\u0430\u043c\u043c\u0435","expense_category_saved_successfully":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","expense_category_updated_successfully":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","expense_category_used_somewhere_else":"\u041a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0433\u0434\u0435-\u0442\u043e \u0435\u0449\u0435.","expense_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","new_category":"\u041d\u043e\u0432\u0430\u044f \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044f \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432"},"expenses":"\u0420\u0430\u0441\u0445\u043e\u0434\u044b","general":"\u041e\u0431\u0449\u0438\u0435","goal":{"achievement":"\u0414\u043e\u0441\u0442\u0438\u0436\u0435\u043d\u0438\u0435","add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_goal":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0446\u0435\u043b\u044c","end_date":"\u0414\u0430\u0442\u0430 \u043e\u043a\u043e\u043d\u0447\u0430\u043d\u0438\u044f","goal_details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u0430\u044f \u0438\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u0446\u0435\u043b\u0438","goal_id":"\u0422\u0438\u043f \u0446\u0435\u043b\u0438","goal_saved_successfully":"\u0426\u0435\u043b\u044c \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","goal_type":"\u0422\u0438\u043f \u0446\u0435\u043b\u0438","goal_updated_successfully":"\u0426\u0435\u043b\u044c \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","is_not_notify":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u044f\u0442\u044c \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u043e\u0432, \u0435\u0441\u043b\u0438 \u0446\u0435\u043b\u044c \u043d\u0435 \u0434\u043e\u0441\u0442\u0438\u0433\u043d\u0443\u0442\u0430","is_notify":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u044f\u0442\u044c \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a\u043e\u0432 \u043e \u0434\u043e\u0441\u0442\u0438\u0436\u0435\u043d\u0438\u0438 \u0446\u0435\u043b\u0438","new_goal":"\u041d\u043e\u0432\u0430\u044f \u0446\u0435\u043b\u044c","no_goal_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0446\u0435\u043b\u0435\u0439.","no_goal_found":"\u0426\u0435\u043b\u044c \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","progress":"\u041f\u0440\u043e\u0433\u0440\u0435\u0441\u0441","staff_member":"\u0421\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a","start_date":"\u0414\u0430\u0442\u0430 \u043d\u0430\u0447\u0430\u043b\u0430","subject":"\u0422\u0435\u043c\u0430","user_id":"\u0421\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a"},"goal_type":{"description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_goal_type":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0442\u0438\u043f \u0446\u0435\u043b\u0438","name":"\u0418\u043c\u044f","new_goal_type":"\u041d\u043e\u0432\u044b\u0439 \u0442\u0438\u043f \u0446\u0435\u043b\u0438"},"goals":"\u0426\u0435\u043b\u0438","incomes":"\u0414\u043e\u0445\u043e\u0434\u044b","invoice":{"activity_log":"\u0416\u0443\u0440\u043d\u0430\u043b \u0430\u043a\u0442\u0438\u0432\u043d\u043e\u0441\u0442\u0438","add_item":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0442\u043e\u0432\u0430\u0440","add_shipping_address":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0430\u0434\u0440\u0435\u0441 \u0434\u043e\u0441\u0442\u0430\u0432\u043a\u0438","adjustment":"\u0420\u0435\u0433\u0443\u043b\u0438\u0440\u043e\u0432\u043a\u0430","admin_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u0430\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440\u0430","allowed_payment_modes_for_this_invoice":"\u0414\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u044b\u0435 \u0441\u043f\u043e\u0441\u043e\u0431\u044b \u043e\u043f\u043b\u0430\u0442\u044b \u0434\u043b\u044f \u044d\u0442\u043e\u0433\u043e \u0441\u0447\u0435\u0442\u0430-\u0444\u0430\u043a\u0442\u0443\u0440\u044b","amount":"\u0421\u0443\u043c\u043c\u0430","amount_due":"\u0421\u0443\u043c\u043c\u0430 \u043a \u043e\u043f\u043b\u0430\u0442\u0435","authorized_signature":"\u041f\u043e\u0434\u043f\u0438\u0441\u044c \u0430\u0432\u0442\u043e\u0440\u0438\u0437\u043e\u0432\u0430\u043d\u043d\u043e\u0433\u043e \u043b\u0438\u0446\u0430","bank":"\u0411\u0430\u043d\u043a","bill_tasks":"\u0417\u0430\u0434\u0430\u043d\u0438\u044f \u043f\u043e \u0441\u0447\u0435\u0442\u0443","bill_to":"\u0412\u044b\u0441\u0442\u0430\u0432\u0438\u0442\u044c \u0441\u0447\u0435\u0442","cancelled":"\u041e\u0422\u041c\u0415\u041d\u0415\u041d","client_note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","currency":"\u0412\u0430\u043b\u044e\u0442\u0430","customer":"\u041a\u043b\u0438\u0435\u043d\u0442","discount":"\u0421\u043a\u0438\u0434\u043a\u0430","discount_type":"\u0422\u0438\u043f \u0441\u043a\u0438\u0434\u043a\u0438","draft":"\u041f\u0420\u041e\u0415\u041a\u0422","drafted":"\u0421\u043e\u0441\u0442\u0430\u0432\u043b\u0435\u043d","due_date":"\u0421\u0440\u043e\u043a \u0441\u0434\u0430\u0447\u0438","edit_contract_type":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0442\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","edit_invoice":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0443","fixed":"\u0418\u0441\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043e","hours":"\u0427\u0430\u0441\u044b","hsn_tax":"\u041d\u0430\u043b\u043e\u0433\u043e\u0432\u044b\u0439 \u043a\u043e\u0434\u0435\u043a\u0441 \u0412\u0421\u041d","invoice":"\u0421\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0430","invoice_date":"\u0414\u0430\u0442\u0430 \u0432\u044b\u0441\u0442\u0430\u0432\u043b\u0435\u043d\u0438\u044f \u0441\u0447\u0435\u0442\u0430","invoice_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0441\u0447\u0435\u0442\u0430","invoice_not_found":"\u0421\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","invoice_number":"\u041d\u043e\u043c\u0435\u0440 \u0441\u0447\u0435\u0442\u0430","invoice_overview":"\u041e\u0411\u0417\u041e\u0420 \u0421\u0427\u0415\u0422\u0410","invoice_payments":"\u041f\u043b\u0430\u0442\u0435\u0436\u0438 \u043f\u043e \u0441\u0447\u0435\u0442\u0430\u043c","invoice_pdf":"\u0421\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0430 PDF","invoice_prefix":"INV-","invoice_saved_successfully":"\u0421\u0447\u0435\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","invoice_updated_successfully":"\u0421\u0447\u0435\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","item":"\u0422\u043e\u0432\u0430\u0440","mark_as_cancelled":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043c\u0435\u043d\u0435\u043d\u043d\u043e\u0435","mark_as_draft":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","mark_as_paid":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u043e\u0435","mark_as_partially_paid":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0430\u0441\u0442\u0438\u0447\u043d\u043e \u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u0443\u044e","mark_as_sent":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043d\u043e\u0435","more":"\u0411\u043e\u043b\u044c\u0448\u0435","new_contract_type":"\u041d\u043e\u0432\u044b\u0439 \u0442\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","new_invoice":"\u041d\u043e\u0432\u044b\u0439 \u0441\u0447\u0435\u0442","no_invoice_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0441\u0447\u0435\u0442\u043e\u0432.","no_invoice_found":"\u0421\u0447\u0435\u0442-\u0444\u0430\u043a\u0442\u0443\u0440\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","no_payments_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043f\u043b\u0430\u0442\u0435\u0436\u0435\u0439","not_sent":"\u041d\u0415 \u041e\u0422\u041f\u0420\u0410\u0412\u041b\u0415\u041d","notes":"\u041d\u043e\u0442\u044b","offline_payment":"\u0410\u0432\u0442\u043e\u043d\u043e\u043c\u043d\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","online_payment":"\u041e\u043d\u043b\u0430\u0439\u043d-\u043f\u043b\u0430\u0442\u0435\u0436","overdue":"\u041f\u0415\u0420\u0415\u0421\u0420\u041e\u0427\u0415\u041d","paid":"\u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u044b\u0439","paid_cap":"\u041f\u041b\u0410\u0422\u041d\u042b\u0415","partially_paid":"\u0427\u0430\u0441\u0442\u0438\u0447\u043d\u043e \u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043e","partially_paid_cap":"\u0427\u0410\u0421\u0422\u0418\u0427\u041d\u041e \u041e\u041f\u041b\u0410\u0427\u0415\u041d\u041e","pay_now":"\u041e\u043f\u043b\u0430\u0442\u0438\u0442\u044c \u0441\u0435\u0439\u0447\u0430\u0441","payment":"\u041e\u043f\u043b\u0430\u0442\u0430","payment_details":"\u041f\u043b\u0430\u0442\u0435\u0436\u043d\u044b\u0435 \u0440\u0435\u043a\u0432\u0438\u0437\u0438\u0442\u044b","payments":"\u041f\u043b\u0430\u0442\u0435\u0436\u0438","prevent_sending_overdue_reminders_for_this_invoice":"\u0417\u0430\u043f\u0440\u0435\u0442\u0438\u0442\u044c \u043e\u0442\u043f\u0440\u0430\u0432\u043a\u0443 \u043f\u0440\u043e\u0441\u0440\u043e\u0447\u0435\u043d\u043d\u044b\u0445 \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0439 \u043f\u043e \u044d\u0442\u043e\u043c\u0443 \u0441\u0447\u0435\u0442\u0443","qty":"\u041a\u043e\u043b-\u0432\u043e","qty \/ hours":"\u041a\u043e\u043b-\u0432\u043e \/ \u0447\u0430\u0441\u044b","qty_hours":"\u041a\u043e\u043b-\u0432\u043e \/ \u0447\u0430\u0441\u044b","quick_invoices_info":"\u0418\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u0431\u044b\u0441\u0442\u0440\u044b\u0445 \u0441\u0447\u0435\u0442\u0430\u0445","reminders":"\u041d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u044f","sale_agent":"\u0410\u0433\u0435\u043d\u0442 \u043f\u043e \u043f\u0440\u043e\u0434\u0430\u0436\u0430\u043c","save_and_send":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u0438 \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","save_as_draft":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","ship_to":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u0432","show_quantity_as":"\u041f\u043e\u043a\u0430\u0437\u044b\u0432\u0430\u0442\u044c \u043a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e \u043a\u0430\u043a","sub_total":"\u041f\u0440\u043e\u043c\u0435\u0436\u0443\u0442\u043e\u0447\u043d\u044b\u0439 \u0438\u0442\u043e\u0433","task":"\u0417\u0430\u0434\u0430\u0447\u0430","tax":"\u041d\u0430\u043b\u043e\u0433\u0438","taxes":"\u041d\u0430\u043b\u043e\u0433\u0438","terms_conditions":"\u0423\u0441\u043b\u043e\u0432\u0438\u044f \u0438 \u043f\u043e\u043b\u043e\u0436\u0435\u043d\u0438\u044f","title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","total":"\u0418\u0442\u043e\u0433\u043e","total_invoices":"\u0412\u0441\u0435\u0433\u043e \u0441\u0447\u0435\u0442\u043e\u0432","total_paid":"\u0412\u0441\u0435\u0433\u043e \u0432\u044b\u043f\u043b\u0430\u0447\u0435\u043d\u043e","transactions":"\u043e\u043f\u0435\u0440\u0430\u0446\u0438\u0438","unmark_as_cancelled":"\u0421\u043d\u044f\u0442\u044c \u043e\u0442\u043c\u0435\u0442\u043a\u0443 \u043a\u0430\u043a \u043e\u0442\u043c\u0435\u043d\u0435\u043d\u043d\u0443\u044e","unpaid":"\u043d\u0435\u043e\u043f\u043b\u0430\u0447\u0435\u043d\u043d\u044b\u0439","unpaid_cap":"\u041d\u0415\u041e\u041f\u041b\u0410\u0427\u0418\u0412\u0410\u0415\u041c\u0410\u042f","view_invoice_as_customer":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0441\u0447\u0435\u0442 \u0432 \u043a\u0430\u0447\u0435\u0441\u0442\u0432\u0435 \u043a\u043b\u0438\u0435\u043d\u0442\u0430"},"invoices":"\u0421\u0447\u0435\u0442\u0430-\u0444\u0430\u043a\u0442\u0443\u0440\u044b","kanban_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u041a\u0410\u041d\u0411\u0410\u041d","kanban_view":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440 \u041a\u0410\u041d\u0411\u0410\u041d","last_week_payments":"\u041f\u043b\u0430\u0442\u0435\u0436\u0438 \u0437\u0430 \u043f\u043e\u0441\u043b\u0435\u0434\u043d\u044e\u044e \u043d\u0435\u0434\u0435\u043b\u044e","lead":{"chart":"\u0414\u0438\u0430\u0433\u0440\u0430\u043c\u043c\u0430","contacted_today":"\u0421\u0432\u044f\u0437\u0430\u043b\u0438\u0441\u044c \u0441\u0435\u0433\u043e\u0434\u043d\u044f","convert_to_customer":"\u041f\u0440\u0435\u043e\u0431\u0440\u0430\u0437\u043e\u0432\u0430\u0442\u044c \u0432 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","date_contacted":"\u0414\u0430\u0442\u0430 \u043e\u0431\u0440\u0430\u0449\u0435\u043d\u0438\u044f","details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","edit_lead":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043b\u0438\u0434","estimate_budget":"\u041e\u0446\u0435\u043d\u0438\u0442\u044c \u0431\u044e\u0434\u0436\u0435\u0442","lead_convert_customer":"\u0412\u0435\u0434\u0443\u0449\u0438\u0439 \u043a\u043e\u043d\u0432\u0435\u0440\u0441\u0438\u043e\u043d\u043d\u044b\u0439 \u043a\u043b\u0438\u0435\u043d\u0442","lead_convert_customer_chart":"\u0414\u0438\u0430\u0433\u0440\u0430\u043c\u043c\u0430 \u043a\u043e\u043d\u0432\u0435\u0440\u0441\u0438\u0438 \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","lead_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043b\u0438\u0434\u0435","lead_list":"\u0421\u043f\u0438\u0441\u043e\u043a \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","lead_not_found":"Prospect non trouv\u00e9.","lead_saved_successfully":"\u041b\u0438\u0434 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","lead_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","lead_updated_successfully":"\u041b\u0438\u0434 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","leads_overview":"\u041e\u0431\u0437\u043e\u0440 \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","member":"\u0447\u043b\u0435\u043d","name":"\u0438\u043c\u044f","new_lead":"\u041d\u043e\u0432\u044b\u0439 \u043b\u0438\u0434\u0435\u0440","no_lead_available":"\u0421\u0432\u0438\u043d\u0435\u0446 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u0435\u043d.","no_lead_found":"\u0421\u0432\u0438\u043d\u0435\u0446 \u043d\u0435 \u043e\u0431\u043d\u0430\u0440\u0443\u0436\u0435\u043d.","notes":"\u0417\u0430\u043c\u0435\u0442\u043a\u0438","reminder":"\u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","source":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a","task":"\u0417\u0430\u0434\u0430\u0447\u0430"},"lead_convert_to_customer":"\u041b\u0438\u0434 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0440\u0443\u0435\u0442\u0441\u044f \u0432 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","lead_source":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","edit_lead_source":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0438\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u043b\u0438\u0434\u0430","lead_source_count":"\u041a\u043e\u043b\u0438\u0447\u0435\u0441\u0442\u0432\u043e \u0441\u0432\u0438\u043d\u0446\u043e\u0432","lead_source_not_found":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u0441\u0432\u0438\u043d\u0446\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","lead_source_saved_successfully":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","lead_source_updated_successfully":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u043b\u0438\u0434\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","name":"\u0418\u043c\u044f","new_lead_source":"\u041d\u043e\u0432\u044b\u0439 \u0438\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","no_lead_source_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0438\u0441\u0442\u043e\u0447\u043d\u0438\u043a\u043e\u0432 \u0441\u0432\u0438\u043d\u0446\u0430.","no_lead_source_found":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u0441\u0432\u0438\u043d\u0446\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d."},"lead_sources":"\u0418\u0441\u0442\u043e\u0447\u043d\u0438\u043a\u0438 \u043b\u0438\u0434\u043e\u0432","lead_status":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","add_new_lead_status":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u0441\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430","color":"\u0426\u0432\u0435\u0442","edit_lead_status":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430","lead_status":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430","lead_status_saved_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","lead_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","lead_status_used_somewhere_else":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0433\u0434\u0435-\u0442\u043e \u0435\u0449\u0435.","name":"\u0418\u043c\u044f","new_lead_status":"\u041d\u043e\u0432\u044b\u0439 \u0441\u0442\u0430\u0442\u0443\u0441 \u043b\u0438\u0434\u0430","order":"\u0417\u0430\u043a\u0430\u0437"},"leads":"\u0412\u0435\u0434\u0435\u0442","list_view":"\u0421\u043f\u0438\u0441\u043e\u043a \u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440","login":{"admin":"\u0410\u0434\u043c\u0438\u043d","client":"\u041a\u043b\u0438\u0435\u043d\u0442","create_one":"Create One","don't have an account":"\u041d\u0435\u0442 \u0443\u0447\u0435\u0442\u043d\u043e\u0439 \u0437\u0430\u043f\u0438\u0441\u0438?","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","forgot_password":"\u0417\u0430\u0431\u044b\u043b\u0438 \u043f\u0430\u0440\u043e\u043b\u044c","login":"\u0412\u043e\u0439\u0442\u0438","password":"\u043f\u0430\u0440\u043e\u043b\u044c","remember_me":"\u0417\u0430\u043f\u043e\u043c\u043d\u0438\u0442\u044c \u043c\u0435\u043d\u044f"},"member":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","by_deleting_this_member":"\u041f\u0440\u0438 \u0443\u0434\u0430\u043b\u0435\u043d\u0438\u0438 \u044d\u0442\u043e\u0433\u043e \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0430 \u0432\u0441\u0435 \u0435\u0433\u043e \u043f\u0440\u043e\u0435\u043a\u0442, \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0438 \u0446\u0435\u043b\u044c \u0431\u0443\u0434\u0443\u0442 \u0443\u0434\u0430\u043b\u0435\u043d\u044b.","choose":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c","created_on":"\u0414\u0430\u0442\u0430 \u0441\u043e\u0437\u0434\u0430\u043d\u0438\u044f","default_language":"\u042f\u0437\u044b\u043a \u043f\u043e \u0443\u043c\u043e\u043b\u0447\u0430\u043d\u0438\u044e","delete_member_confirm":"\u0412\u044b \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0443\u0434\u0430\u043b\u0438\u0442\u044c \u044d\u0442\u043e\u0433\u043e \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0430?","direction":"\u041d\u0430\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u0435","edit_member":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0430","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","email_is_not_verified":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u043d\u0435 \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0430","email_is_verified":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0430","email_verified":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u043f\u0440\u043e\u0432\u0435\u0440\u0435\u043d\u0430","email_verified_successfully":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0430.","email_verify":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430 \u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044c","facebook":"\u0424\u0435\u0439\u0441\u0431\u0443\u043a","first_name":"\u0418\u043c\u044f","hourly_rate":"\u041f\u043e\u0447\u0430\u0441\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0432\u043a\u0430","image":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c","is_administrator":"\u0410\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440","is_enable":"\u0412\u043a\u043b\u044e\u0447\u0438\u0442\u044c \u0434\u0432\u0443\u0445\u0444\u0430\u043a\u0442\u043e\u0440\u043d\u0443\u044e \u0430\u0443\u0442\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0446\u0438\u044e","last_name":"\u0424\u0430\u043c\u0438\u043b\u0438\u044f","linkedin":"\u041b\u0438\u043d\u043a\u0435\u0434\u0438\u043d","member_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0430","member_informations":"\u0418\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u0447\u043b\u0435\u043d\u0430\u0445","member_not_found":"\u0423\u0447\u0430\u0441\u0442\u043d\u0438\u043a \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","member_saved_successfully":"\u0423\u0447\u0430\u0441\u0442\u043d\u0438\u043a \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","member_security":"\u0411\u0435\u0437\u043e\u043f\u0430\u0441\u043d\u043e\u0441\u0442\u044c \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u043e\u0432","member_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","member_updated_successfully":"\u0423\u0447\u0430\u0441\u0442\u043d\u0438\u043a \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","new_member":"\u041d\u043e\u0432\u044b\u0439 \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a","no_member_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u043e\u0432.","no_member_found":"\u0423\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u043e\u0432 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e.","password":"\u043f\u0430\u0440\u043e\u043b\u044c","password_confirmation":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","permissions":"\u0420\u0430\u0437\u0440\u0435\u0448\u0435\u043d\u0438\u044f","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","profile":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c","resend_email_verification":"\u041f\u043e\u0432\u0442\u043e\u0440\u043d\u043e \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0438\u0435 \u043f\u043e \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u0435","send_welcome_email":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u043f\u0440\u0438\u0432\u0435\u0442\u0441\u0442\u0432\u0435\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e","skype":"\u0421\u043a\u0430\u0439\u043f","staff_member":"\u041d\u0435 \u0448\u0442\u0430\u0442\u043d\u044b\u0439 \u0441\u043e\u0442\u0440\u0443\u0434\u043d\u0438\u043a","total_members":"\u0412\u0441\u0435\u0433\u043e \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u043e\u0432","verification_mail_has_been_sent":"\u041f\u0438\u0441\u044c\u043c\u043e \u0441 \u043f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0438\u0435\u043c \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043e."},"members":"\u0423\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0438","menu_settings":"\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u043c\u0435\u043d\u044e","months":{"apr":"\u0430\u043f\u0440","aug":"\u0430\u0432\u0433","dec":"\u0434\u0435\u043a\u0430\u0431\u0440\u044c","feb":"\u0444\u0435\u0432\u0440\u0430\u043b\u044c","jan":"\u042f\u043d","jul":"\u0438\u044e\u043b\u044c","jun":"\u0438\u044e\u043d\u044c","mar":"\u043c\u0430\u0440\u0442","may":"\u041c\u0430\u0439","nov":"\u043d\u043e\u044f\u0431\u0440\u044c","oct":"\u043e\u043a\u0442\u044f\u0431\u0440\u044c","sep":"\u0441\u0435\u043d"},"new_language":"\u041d\u043e\u0432\u044b\u0439 \u044f\u0437\u044b\u043a","no_matching_records_found":"\u0421\u043e\u0432\u043f\u0430\u0434\u0430\u044e\u0449\u0438\u0445 \u0437\u0430\u043f\u0438\u0441\u0435\u0439 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e","note":{"add_note":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","edit_note":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0437\u0430\u043c\u0435\u0442\u043a\u0443","new_note":"\u041d\u043e\u0432\u0430\u044f \u0437\u0430\u043c\u0435\u0442\u043a\u0430","no_notes_added_yet":"\u0417\u0430\u043c\u0435\u0442\u043a\u0438 \u0435\u0449\u0435 \u043d\u0435 \u0434\u043e\u0431\u0430\u0432\u043b\u0435\u043d\u044b","notes_saved_successfully":"\u0417\u0430\u043c\u0435\u0442\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","notes_updated_successfully":"\u0417\u0430\u043c\u0435\u0442\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430."},"notes":"\u0417\u0430\u043c\u0435\u0442\u043a\u0438","notification":{"all_notification_read_successfully":"\u0412\u0441\u0435 \u0443\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u044f \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043f\u0440\u043e\u0447\u0438\u0442\u0430\u043d\u044b.","empty_notifications":"\u041c\u044b \u043d\u0435 \u0441\u043c\u043e\u0433\u043b\u0438 \u043d\u0430\u0439\u0442\u0438 \u043d\u0438\u043a\u0430\u043a\u0438\u0445 \u0443\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u0439","mark_all_as_read":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u0432\u0441\u0435 \u043a\u0430\u043a \u043f\u0440\u043e\u0447\u0438\u0442\u0430\u043d\u043d\u043e\u0435","notification_read_successfully":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043f\u0440\u043e\u0447\u0438\u0442\u0430\u043d\u043e.","notifications":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u044f"},"others":"\u0414\u0440\u0443\u0433\u0438\u0435","payment":{"amount":"\u0421\u0443\u043c\u043c\u0430","amount_received":"\u041f\u043e\u043b\u0443\u0447\u0435\u043d\u043d\u0430\u044f \u0441\u0443\u043c\u043c\u0430","date":"\u0414\u0430\u0442\u0430","new_payment":"\u041d\u043e\u0432\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","payment_date":"\u0414\u0430\u0442\u0430 \u043f\u043b\u0430\u0442\u0435\u0436\u0430","payment_mode":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b","payment_saved_successfully":"\u041f\u043b\u0430\u0442\u0435\u0436 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","send_mail_to_customer_contacts":"\u041d\u0435 \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u044f\u0442\u044c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e \u0441 \u0437\u0430\u043f\u0438\u0441\u044c\u044e \u043e\u043f\u043b\u0430\u0442\u044b \u0441\u0447\u0435\u0442\u0430 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430\u043c \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","transaction_id":"\u0418\u0434\u0435\u043d\u0442\u0438\u0444\u0438\u043a\u0430\u0442\u043e\u0440 \u0442\u0440\u0430\u043d\u0437\u0430\u043a\u0446\u0438\u0438","your_payment_is_completed":"\u0412\u0430\u0448 \u043f\u043b\u0430\u0442\u0435\u0436 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0437\u0430\u0432\u0435\u0440\u0448\u0435\u043d.","your_payment_is_ont_completed":"\u0412\u0430\u0448 \u043f\u043b\u0430\u0442\u0435\u0436 \u043d\u0435 \u0437\u0430\u0432\u0435\u0440\u0448\u0435\u043d."},"payment_mode":{"active":"\u0410\u043a\u0442\u0438\u0432\u043d\u044b\u0439","add_new_payment_mode":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u0441\u043f\u043e\u0441\u043e\u0431 \u043e\u043f\u043b\u0430\u0442\u044b","bank_accounts":"\u0411\u0430\u043d\u043a\u043e\u0432\u0441\u043a\u0438\u0435 \u0441\u0447\u0435\u0442\u0430","edit_payment_mode":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0440\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b","expenses_only":"\u0422\u043e\u043b\u044c\u043a\u043e \u0440\u0430\u0441\u0445\u043e\u0434\u044b","invoices_only":"\u0422\u043e\u043b\u044c\u043a\u043e \u0441\u0447\u0435\u0442\u0430","new_payment_mode":"\u041d\u043e\u0432\u044b\u0439 \u0440\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b","no_payment_mode_available":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u0435\u043d.","no_payment_mode_found":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","on_invoice_pdf":"\u0432 PDF-\u0444\u0430\u0439\u043b\u0435 \u0441\u0447\u0435\u0442\u0430","payment_mode_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0440\u0435\u0436\u0438\u043c\u0430 \u043e\u043f\u043b\u0430\u0442\u044b","payment_mode_not_found":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","payment_mode_saved_successfully":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","payment_mode_updated_successfully":"\u0420\u0435\u0436\u0438\u043c \u043e\u043f\u043b\u0430\u0442\u044b \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","payment_mode_used_somewhere_else":"\u0421\u043f\u043e\u0441\u043e\u0431 \u043e\u043f\u043b\u0430\u0442\u044b \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0433\u0434\u0435-\u0442\u043e \u0435\u0449\u0435.","selected_by_default_on_invoice":"\u0412\u044b\u0431\u0440\u0430\u043d\u043e \u043f\u043e \u0443\u043c\u043e\u043b\u0447\u0430\u043d\u0438\u044e \u0432 \u0441\u0447\u0435\u0442\u0435","show":"\u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c"},"payment_modes":"\u0420\u0435\u0436\u0438\u043c\u044b \u043e\u043f\u043b\u0430\u0442\u044b","placeholder":{"add_note":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u0437\u0430\u043c\u0435\u0442\u043a\u0443...","add_product":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043f\u0440\u043e\u0434\u0443\u043a\u0442","bill_tasks":"\u0411\u0438\u043b\u043b \u0417\u0430\u0434\u0430\u0447\u0438","contact_number_is_invalid_number":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442\u043d\u044b\u0439 \u043d\u043e\u043c\u0435\u0440 \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u0435\u043d","enter_email":"\u0412\u0432\u0435\u0434\u0438\u0442\u0435 \u0430\u0434\u0440\u0435\u0441 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","invalid_country_code":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u043a\u043e\u0434 \u0441\u0442\u0440\u0430\u043d\u044b","invalid_number":"Invalid Number","search_customers":"\u041f\u043e\u0438\u0441\u043a \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","search_menu":"\u041c\u0435\u043d\u044e \u043f\u043e\u0438\u0441\u043a\u0430","select_article_group":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u0440\u0443\u043f\u043f\u0443 \u0441\u0442\u0430\u0442\u0435\u0439","select_assignee":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u0440\u0430\u0432\u043e\u043f\u0440\u0435\u0435\u043c\u043d\u0438\u043a\u0430","select_billing_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u043e\u043f\u043b\u0430\u0442\u044b","select_contact":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u044b","select_contract_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u043a\u043e\u043d\u0442\u0440\u0430\u043a\u0442\u0430","select_country":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0441\u0442\u0440\u0430\u043d\u0443","select_currency":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0432\u0430\u043b\u044e\u0442\u0443","select_customer":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043a\u043b\u0438\u0435\u043d\u0442\u0430","select_department":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043e\u0442\u0434\u0435\u043b","select_discount_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u0441\u043a\u0438\u0434\u043a\u0438","select_document_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u0441\u043a\u0438\u0434\u043a\u0438","select_email_status":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0441\u0442\u0430\u0442\u0443\u0441 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","select_email_template":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0448\u0430\u0431\u043b\u043e\u043d \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","select_expanse_category":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043a\u0430\u0442\u0435\u0433\u043e\u0440\u0438\u044e \u0440\u0430\u0441\u0445\u043e\u0434\u043e\u0432","select_file":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u0444\u0430\u0439\u043b","select_goal":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0446\u0435\u043b\u044c","select_goal_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u0446\u0435\u043b\u0438","select_group":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u0440\u0443\u043f\u043f\u044b","select_groups":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u0440\u0443\u043f\u043f\u044b","select_internal_article":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0432\u043d\u0443\u0442\u0440\u0435\u043d\u043d\u044e\u044e \u0441\u0442\u0430\u0442\u044c\u044e","select_item":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c \u043f\u0440\u0435\u0434\u043c\u0435\u0442","select_language":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u044f\u0437\u044b\u043a","select_lead":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u041b\u0438\u0434","select_lead_source":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0438\u0441\u0442\u043e\u0447\u043d\u0438\u043a \u043f\u043e\u0442\u0435\u043d\u0446\u0438\u0430\u043b\u044c\u043d\u044b\u0445 \u043a\u043b\u0438\u0435\u043d\u0442\u043e\u0432","select_member":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0447\u0430\u0441\u0442\u043d\u0438\u043a\u0430","select_option":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043e\u043f\u0446\u0438\u044e","select_payment_mode":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0441\u043f\u043e\u0441\u043e\u0431 \u043e\u043f\u043b\u0430\u0442\u044b","select_predefined_reply":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u043e\u0442\u043e\u0432\u044b\u0439 \u043e\u0442\u0432\u0435\u0442","select_priority":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442","select_product":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u0440\u043e\u0434\u0443\u043a\u0442","select_product_group":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0433\u0440\u0443\u043f\u043f\u0443 \u043f\u0440\u043e\u0434\u0443\u043a\u0442\u043e\u0432","select_reminder_to":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","select_sale_agent":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0430\u0433\u0435\u043d\u0442\u0430 \u043f\u043e \u043f\u0440\u043e\u0434\u0430\u0436\u0435","select_service":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0441\u043b\u0443\u0433\u0443","select_show_to_client":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u041f\u043e\u043a\u0430\u0437\u0430\u0442\u044c \u043a\u043b\u0438\u0435\u043d\u0442\u0443","select_source":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0438\u0441\u0442\u043e\u0447\u043d\u0438\u043a","select_status":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0441\u0442\u0430\u0442\u0443\u0441,","select_tags":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0435\u0433\u0438","select_tax":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043d\u0430\u043b\u043e\u0433","select_tax1":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043d\u0430\u043b\u043e\u0433 1","select_tax2":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043d\u0430\u043b\u043e\u0433 2","select_template_type":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0442\u0438\u043f \u0448\u0430\u0431\u043b\u043e\u043d\u0430","select_ticket_priority":"\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u043f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432","too_long":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u0434\u043e\u043b\u0433\u043e","too_short":"\u0421\u043b\u0438\u0448\u043a\u043e\u043c \u043a\u043e\u0440\u043e\u0442\u043a\u0438\u0439","valid_number":"Valid Number"},"please_enter_language_short_code":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u0441\u043e\u043a\u0440\u0430\u0449\u0435\u043d\u043d\u044b\u0439 \u043a\u043e\u0434 \u044f\u0437\u044b\u043a\u0430. \u0442.\u0435. \u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 = en.","predefined_replies":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0435 \u043e\u0442\u0432\u0435\u0442\u044b","predefined_reply":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","add_new_predefined_reply":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u043f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442","body":"\u0422\u0435\u043b\u043e","edit_predefined_reply":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442","new_predefined_reply":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442","no_predefined_reply_available":"\u041d\u0435\u0442 \u043f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u043e\u0433\u043e \u043e\u0442\u0432\u0435\u0442\u0430.","no_predefined_reply_found":"\u041f\u0440\u0435\u0434\u0432\u0430\u0440\u0438\u0442\u0435\u043b\u044c\u043d\u043e \u0437\u0430\u0434\u0430\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","predefined_reply_details":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0435 \u0434\u0435\u0442\u0430\u043b\u0438 \u043e\u0442\u0432\u0435\u0442\u0430","predefined_reply_not_found":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","predefined_reply_saved_successfully":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","predefined_reply_updated_successfully":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","reply_name":"\u0418\u043c\u044f \u043e\u0442\u0432\u0435\u0442\u0430"},"product_group":{"add_new_product_group":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u0443\u044e \u0433\u0440\u0443\u043f\u043f\u0443 \u043f\u0440\u043e\u0434\u0443\u043a\u0442\u043e\u0432","edit_product_group":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0433\u0440\u0443\u043f\u043f\u0443 \u043f\u0440\u043e\u0434\u0443\u043a\u0442\u043e\u0432","new_product_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043d\u043e\u0432\u044b\u0445 \u043f\u0440\u043e\u0434\u0443\u043a\u0442\u043e\u0432","product_group_saved_successfully":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0442\u043e\u0432\u0430\u0440\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","product_group_updated_successfully":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0442\u043e\u0432\u0430\u0440\u043e\u0432 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","product_group_used_somewhere_else":"\u0413\u0440\u0443\u043f\u043f\u0430 \u043f\u0440\u043e\u0434\u0443\u043a\u0442\u043e\u0432, \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u043c\u0430\u044f \u0432 \u0434\u0440\u0443\u0433\u043e\u043c \u043c\u0435\u0441\u0442\u0435."},"product_groups":"\u0413\u0440\u0443\u043f\u043f\u044b \u043f\u0440\u043e\u0434\u0443\u043a\u0442\u043e\u0432","products":{"edit_product":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0440\u043e\u0434\u0443\u043a\u0442","new_product":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0440\u043e\u0434\u0443\u043a\u0442","product_group":"\u0413\u0440\u0443\u043f\u043f\u0430 \u0442\u043e\u0432\u0430\u0440\u043e\u0432","product_saved_successfully":"\u0422\u043e\u0432\u0430\u0440 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","product_updated_successfully":"\u041f\u0440\u043e\u0434\u0443\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","products":"\u0422\u043e\u0432\u0430\u0440\u044b","rate":"\u041e\u0446\u0435\u043d\u0438\u0442\u044c","tax":"\u041d\u0430\u043b\u043e\u0433","title":"\u0417\u0430\u0433\u043e\u043b\u043e\u0432\u043e\u043a","unit":"\u0415\u0434\u0438\u043d\u0438\u0446\u0430"},"profile":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c","project":{"admin_area":"\u0430\u0434\u043c\u0438\u043d\u043a\u0430","allow_customer_to":"\u0420\u0430\u0437\u0440\u0435\u0448\u0438\u0442\u044c \u043f\u043e\u043a\u0443\u043f\u0430\u0442\u0435\u043b\u044e","billing_type":"\u0422\u0438\u043f \u0431\u0438\u043b\u043b\u0438\u043d\u0433\u0430","calculate_progress_through_tasks":"\u0420\u0430\u0441\u0441\u0447\u0438\u0442\u044b\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0433\u0440\u0435\u0441\u0441 \u043f\u043e \u0437\u0430\u0434\u0430\u0447\u0430\u043c","cancelled":"\u041e\u0442\u043c\u0435\u043d\u0435\u043d\u043e","comment_on_project_tasks":"\u043a\u043e\u043c\u043c\u0435\u043d\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0437\u0430\u0434\u0430\u0447\u0438 \u043f\u0440\u043e\u0435\u043a\u0442\u0430","create_tasks":"\u0441\u043e\u0437\u0434\u0430\u0432\u0430\u0442\u044c \u0437\u0430\u0434\u0430\u0447\u0438","customer":"\u041a\u043b\u0438\u0435\u043d\u0442","deadline":"\u0421\u0440\u043e\u043a","edit_project":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0435\u043a\u0442","edit_tasks":"\u0440\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0437\u0430\u0434\u0430\u0447\u0438","estimated_hours":"\u0420\u0430\u0441\u0447\u0435\u0442\u043d\u044b\u0435 \u0447\u0430\u0441\u044b","finished":"\u0413\u043e\u0442\u043e\u0432\u043e","hide_project_tasks_on_main_tasks_table":"\u0441\u043a\u0440\u044b\u0442\u044c \u0437\u0430\u0434\u0430\u0447\u0438 \u043f\u0440\u043e\u0435\u043a\u0442\u0430 \u0432 \u0442\u0430\u0431\u043b\u0438\u0446\u0435 \u043e\u0441\u043d\u043e\u0432\u043d\u044b\u0445 \u0437\u0430\u0434\u0430\u0447","in_progress":"\u0412\u044b\u043f\u043e\u043b\u043d\u044f\u0435\u0442\u0441\u044f","members":"\u0421\u0432\u044f\u0437\u0430\u0442\u044c\u0441\u044f \u0441 \u043d\u0430\u043c\u0438","new_project":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0440\u043e\u0435\u043a\u0442","no_project_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043f\u0440\u043e\u0435\u043a\u0442\u043e\u0432","no_project_found":"Proje Bulunamad\u0131","not_started":"\u041d\u0435 \u043d\u0430\u0447\u0430\u0442\u043e","on_hold":"\u041d\u0430 \u0443\u0434\u0435\u0440\u0436\u0430\u043d\u0438\u0438","only_task_created_from_contact":"\u0442\u043e\u043b\u044c\u043a\u043e \u0437\u0430\u0434\u0430\u0447\u0430 \u0441\u043e\u0437\u0434\u0430\u043d\u0430 \u0438\u0437 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430","open_discussions":"\u043e\u0442\u043a\u0440\u044b\u0442\u044b\u0435 \u043e\u0431\u0441\u0443\u0436\u0434\u0435\u043d\u0438\u044f","progress":"\u041f\u0440\u043e\u0433\u0440\u0435\u0441\u0441","project_details":"\u0421\u0432\u0435\u0434\u0435\u043d\u0438\u044f \u043e \u043f\u0440\u043e\u0435\u043a\u0442\u0435","project_name":"\u041d\u0430\u0437\u0432\u0430\u043d\u0438\u0435 \u043f\u0440\u043e\u0435\u043a\u0442\u0430","project_saved_successfully":"\u041f\u0440\u043e\u0435\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","project_settings":"\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u043f\u0440\u043e\u0435\u043a\u0442\u0430","project_updated_successfully":"\u041f\u0440\u043e\u0435\u043a\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","projects_summary":"\u0421\u0432\u043e\u0434\u043a\u0430 \u043f\u0440\u043e\u0435\u043a\u0442\u043e\u0432","quick_invoices_info":"\u0418\u043d\u0444\u043e\u0440\u043c\u0430\u0446\u0438\u044f \u043e \u0431\u044b\u0441\u0442\u0440\u044b\u0445 \u0441\u0447\u0435\u0442\u0430\u0445","send_project_created_email":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0435 \u043f\u0438\u0441\u044c\u043c\u043e \u043e \u0441\u043e\u0437\u0434\u0430\u043d\u0438\u0438 \u043f\u0440\u043e\u0435\u043a\u0442\u0430","start_date":"\u0414\u0430\u0442\u0430 \u043d\u0430\u0447\u0430\u043b\u0430","statistics_by_project_status":"\u0421\u0442\u0430\u0442\u0438\u0441\u0442\u0438\u043a\u0430 \u043f\u043e \u0441\u0442\u0430\u0442\u0443\u0441\u0443 \u043f\u0440\u043e\u0435\u043a\u0442\u0430","status":"\u0421\u0442\u0430\u0442\u0443\u0441","task":"\u0417\u0430\u0434\u0430\u0447\u0430","total_projects":"\u0412\u0441\u0435\u0433\u043e \u043f\u0440\u043e\u0435\u043a\u0442\u043e\u0432","upload_attachments_on_tasks":"\u0437\u0430\u0433\u0440\u0443\u0436\u0430\u0442\u044c \u0432\u043b\u043e\u0436\u0435\u043d\u0438\u044f \u043f\u043e \u0437\u0430\u0434\u0430\u0447\u0430\u043c","upload_files":"\u0437\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044c \u0444\u0430\u0439\u043b\u044b","view_account_statement":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0432\u044b\u043f\u0438\u0441\u043a\u0443 \u043f\u043e \u0441\u0447\u0435\u0442\u0443","view_activity_log":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0436\u0443\u0440\u043d\u0430\u043b \u0430\u043a\u0442\u0438\u0432\u043d\u043e\u0441\u0442\u0438","view_finance_overview":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u043e\u0431\u0437\u043e\u0440 \u0444\u0438\u043d\u0430\u043d\u0441\u043e\u0432","view_gantt":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0434\u0438\u0430\u0433\u0440\u0430\u043c\u043c\u0443 \u0413\u0430\u043d\u0442\u0430","view_milestones":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0432\u0435\u0445\u0438","view_task_attachments":"\u043f\u0440\u043e\u0441\u043c\u0430\u0442\u0440\u0438\u0432\u0430\u0442\u044c \u0432\u043b\u043e\u0436\u0435\u043d\u0438\u044f \u0437\u0430\u0434\u0430\u0447","view_task_checklist_items":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u044d\u043b\u0435\u043c\u0435\u043d\u0442\u044b \u043a\u043e\u043d\u0442\u0440\u043e\u043b\u044c\u043d\u043e\u0433\u043e \u0441\u043f\u0438\u0441\u043a\u0430 \u0437\u0430\u0434\u0430\u0447","view_task_comments":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u043a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0438 \u043a \u0437\u0430\u0434\u0430\u0447\u0435","view_task_total_logged_time":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u043e\u0431\u0449\u0435\u0435 \u0432\u0440\u0435\u043c\u044f \u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0430\u0446\u0438\u0438 \u0437\u0430\u0434\u0430\u0447\u0438","view_tasks":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0437\u0430\u0434\u0430\u0447\u0438","view_team_members":"\u043f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u0447\u043b\u0435\u043d\u043e\u0432 \u043a\u043e\u043c\u0430\u043d\u0434\u044b","view_timesheets":"\u043f\u0440\u043e\u0441\u043c\u0430\u0442\u0440\u0438\u0432\u0430\u0442\u044c \u0442\u0430\u0431\u0435\u043b\u0438 \u0443\u0447\u0435\u0442\u0430 \u0440\u0430\u0431\u043e\u0447\u0435\u0433\u043e \u0432\u0440\u0435\u043c\u0435\u043d\u0438","visible_tables":"\u0412\u0438\u0434\u0438\u043c\u044b\u0435 \u0442\u0430\u0431\u043b\u0438\u0446\u044b"},"projects":"\u041f\u0440\u043e\u0435\u043a\u0442\u044b","proposal":{"accept":"ACCEPT","accepted":"\u041f\u0420\u0418\u041d\u042f\u0422\u041e","adjustment":"\u0420\u0435\u0433\u0443\u043b\u0438\u0440\u043e\u0432\u043a\u0430","amount":"\u0421\u0443\u043c\u043c\u0430","amount_due":"\u0421\u0443\u043c\u043c\u0430 \u043a \u043e\u043f\u043b\u0430\u0442\u0435","assigned":"\u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u043d\u044b\u0439","authorized_signature":"\u041f\u043e\u0434\u043f\u0438\u0441\u044c \u0443\u043f\u043e\u043b\u043d\u043e\u043c\u043e\u0447\u0435\u043d\u043d\u043e\u0433\u043e \u043b\u0438\u0446\u0430","bank":"\u0411\u0430\u043d\u043a","bill_to":"\u041a\u043e\u043c\u0443 \u0441\u0447\u0435\u0442","comments":"\u041a\u043e\u043c\u043c\u0435\u043d\u0442\u0430\u0440\u0438\u0438","convert":"\u041f\u0435\u0440\u0435\u0440\u0430\u0431\u0430\u0442\u044b\u0432\u0430\u0442\u044c","convert_proposal":"\u041f\u0440\u0435\u043e\u0431\u0440\u0430\u0437\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435","date":"\u0414\u0430\u0442\u0430","decline":"\u0421\u041d\u0418\u0416\u0415\u041d\u0418\u0415","declined":"DECLINED","discount":"\u0421\u043a\u0438\u0434\u043a\u0430","draft":"\u0427\u0415\u0420\u041d\u041e\u0412\u041e\u0419 \u0412\u0410\u0420\u0418\u0410\u041d\u0422","drafted":"\u0421\u043e\u0441\u0442\u0430\u0432\u043b\u0435\u043d","edit_proposal":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435","item":"\u0422\u043e\u0432\u0430\u0440","lead":"\u041f\u0440\u0438\u0432\u0435\u0441\u0442\u0438","mark_as_accepted":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043f\u0440\u0438\u043d\u044f\u0442\u044b\u0439","mark_as_declined":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043a\u043b\u043e\u043d\u0435\u043d\u043d\u044b\u0439","mark_as_draft":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","mark_as_open":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043a\u0440\u044b\u0442\u043e\u0435","mark_as_revised":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u0438\u0441\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043d\u043e\u0435","mark_as_send":"\u041e\u0442\u043c\u0435\u0442\u0438\u0442\u044c \u043a\u0430\u043a \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u043d\u043e\u0435","member":"\u0447\u043b\u0435\u043d","new_proposal":"\u041d\u043e\u0432\u043e\u0435 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435","no_payments_available":"\u041f\u043b\u0430\u0442\u0435\u0436 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u0435\u043d","no_proposal_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0439.","no_proposal_found":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0439 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e.","offer_date":"\u0414\u0430\u0442\u0430 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u044f","offline_payment":"\u0410\u0432\u0442\u043e\u043d\u043e\u043c\u043d\u044b\u0439 \u043f\u043b\u0430\u0442\u0435\u0436","online_payment":"\u041e\u043d\u043b\u0430\u0439\u043d-\u043f\u043b\u0430\u0442\u0435\u0436","open":"\u041e\u0422\u041a\u0420\u042b\u0422\u041e","open_till":"\u041e\u0442\u043a\u0440\u044b\u0432\u0430\u0442\u044c \u0434\u043e","pay_now":"\u041e\u041f\u041b\u0410\u0422\u0418\u0422\u042c \u0421\u0415\u0419\u0427\u0410\u0421","payment":"\u041e\u043f\u043b\u0430\u0442\u0430","proposal":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435","proposal_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u044f","proposal_not_found":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e.","proposal_number":"\u041d\u043e\u043c\u0435\u0440 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u044f","proposal_overview":"\u041e\u0411\u0417\u041e\u0420 \u041f\u0420\u0415\u0414\u041b\u041e\u0416\u0415\u041d\u0418\u042f","proposal_pdf":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043e.","proposal_to":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u043a","proposal_updated_successfully":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u043e.","qty":"\u041a\u043e\u043b-\u0432\u043e","rate":"\u0421\u0442\u0430\u0432\u043a\u0430","related":"\u0421\u0432\u044f\u0437\u0430\u043d\u043d\u044b\u0435","revised":"REVISED","save_and_send":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u0438 \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","save_as_draft":"\u0421\u043e\u0445\u0440\u0430\u043d\u0438\u0442\u044c \u043a\u0430\u043a \u0447\u0435\u0440\u043d\u043e\u0432\u0438\u043a","sent":"\u041f\u041e\u0421\u041b\u0410\u041b","ship_to":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c","status":"\u0421\u0442\u0430\u0442\u0443\u0441 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u044f","sub_total":"\u041f\u0440\u043e\u043c\u0435\u0436\u0443\u0442\u043e\u0447\u043d\u044b\u0439 \u0438\u0442\u043e\u0433","subject":"\u0422\u0435\u043c\u0430","task":"\u0417\u0430\u0434\u0430\u0447\u0430","taxes":"\u043d\u0430\u043b\u043e\u0433\u0438","to":"\u043a","total":"\u0418\u0442\u043e\u0433\u043e","total_paid":"\u0412\u0441\u0435\u0433\u043e \u0432\u044b\u043f\u043b\u0430\u0447\u0435\u043d\u043e","total_proposal":"\u041e\u0431\u0449\u0435\u0435 \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435","transactions":"\u043e\u043f\u0435\u0440\u0430\u0446\u0438\u0438","view_proposal_as_customer":"\u041f\u0440\u043e\u0441\u043c\u043e\u0442\u0440\u0435\u0442\u044c \u043f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u043a\u0430\u043a \u043a\u043b\u0438\u0435\u043d\u0442"},"proposals":"\u041f\u0440\u0435\u0434\u043b\u043e\u0436\u0435\u043d\u0438\u044f","range":{"last_30":"\u041f\u043e\u0441\u043b\u0435\u0434\u043d\u0438\u0435 30 \u0434\u043d\u0435\u0439","last_month":"\u041f\u0440\u043e\u0448\u043b\u044b\u0439 \u043c\u0435\u0441\u044f\u0446","last_week":"\u041f\u0440\u043e\u0448\u043b\u0430\u044f \u043d\u0435\u0434\u0435\u043b\u044f","this_month":"\u042d\u0442\u043e\u0442 \u043c\u0435\u0441\u044f\u0446","this_week":"\u041d\u0430 \u044d\u0442\u043e\u0439 \u043d\u0435\u0434\u0435\u043b\u0435","today":"\u0421\u0435\u0433\u043e\u0434\u043d\u044f"},"register":{"already_have_an_account":"\u0423\u0436\u0435 \u0435\u0441\u0442\u044c \u0430\u043a\u043a\u0430\u0443\u043d\u0442?","choose":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c","confirm_password":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0435 \u043f\u0430\u0440\u043e\u043b\u044c","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","first_name":"\u0418\u043c\u044f","last_name":"\u0424\u0430\u043c\u0438\u043b\u0438\u044f","password":"\u043f\u0430\u0440\u043e\u043b\u044c","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","profile_picture":"\u0418\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435 \u043f\u0440\u043e\u0444\u0438\u043b\u044f","register":"\u0417\u0430\u0440\u0435\u0433\u0438\u0441\u0442\u0440\u0438\u0440\u043e\u0432\u0430\u0442\u044c\u0441\u044f","sign_in":"\u0412\u043e\u0439\u0442\u0438 \u0432 \u0441\u0438\u0441\u0442\u0435\u043c\u0443"},"reminder":{"add_new":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_reminder":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","email_status":"\u0421\u0442\u0430\u0442\u0443\u0441 \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b","is_notified":"\u0423\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d","new_reminder":"\u041d\u043e\u0432\u043e\u0435 \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","no":"\u041d\u0435\u0442","note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","note_text":"\u041e\u0431\u0440\u0430\u0442\u0438\u0442\u0435 \u0432\u043d\u0438\u043c\u0430\u043d\u0438\u0435, \u0447\u0442\u043e \u0432\u044b \u0434\u043e\u043b\u0436\u043d\u044b \u0432\u044b\u0431\u0440\u0430\u0442\u044c \u0434\u0430\u0442\u0443 \u0438 \u0432\u0440\u0435\u043c\u044f UTC, \u0442\u0430\u043a \u043a\u0430\u043a \u0437\u0430\u0434\u0430\u043d\u0438\u044f cron \u043e\u0442\u043f\u0440\u0430\u0432\u043b\u044f\u044e\u0442 \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u044f \u0432 \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0438\u0438 \u0441\u043e \u0432\u0440\u0435\u043c\u0435\u043d\u0435\u043c UTC.","notified_date":"\u0414\u0430\u0442\u0430 \u0443\u0432\u0435\u0434\u043e\u043c\u043b\u0435\u043d\u0438\u044f","reminder_saved_successfully":"\u041d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043e.","reminder_to":"\u041d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","reminder_updated_successfully":"\u041d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u043e.","send_email_reminder":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u0442\u044c \u043f\u0438\u0441\u044c\u043c\u043e \u0441 \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435\u043c","sent":"\u041e\u0442\u043f\u0440\u0430\u0432\u0438\u043b","set_reminder":"\u0423\u0441\u0442\u0430\u043d\u043e\u0432\u0438\u0442\u044c \u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","ticket_reminder":"\u041d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u044f \u043e \u0431\u0438\u043b\u0435\u0442\u0430\u0445","yes":"\u0414\u0430"},"reminders":"\u041d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u044f","reset":{"confirm_password":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u0435 \u043f\u0430\u0440\u043e\u043b\u044c","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","password":"\u043f\u0430\u0440\u043e\u043b\u044c","recalled_your_login_info":"\u0412\u044b \u0432\u0441\u043f\u043e\u043c\u043d\u0438\u043b\u0438 \u0432\u0430\u0448\u0438 \u0434\u0430\u043d\u043d\u044b\u0435 \u0434\u043b\u044f \u0432\u0445\u043e\u0434\u0430?","reset_password":"\u0421\u0431\u0440\u043e\u0441\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","set_a_new_password":"\u0423\u0441\u0442\u0430\u043d\u043e\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u043f\u0430\u0440\u043e\u043b\u044c","sign_in":"\u0412\u043e\u0439\u0442\u0438"},"sales":"\u041f\u0440\u043e\u0434\u0430\u0436\u0438","service":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","edit_service":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0441\u043b\u0443\u0436\u0431\u0443","name":"\u0418\u043c\u044f","new_service":"\u041d\u043e\u0432\u0430\u044f \u0443\u0441\u043b\u0443\u0433\u0430","no_service_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0443\u0441\u043b\u0443\u0433.","no_service_found":"\u0421\u043b\u0443\u0436\u0431\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","service_not_found":"\u0421\u0435\u0440\u0432\u0438\u0441 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","service_saved_successfully":"\u0421\u0435\u0440\u0432\u0438\u0441 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","service_updated_successfully":"\u0421\u0435\u0440\u0432\u0438\u0441 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","service_used_somewhere_else":"\u0423\u0441\u043b\u0443\u0433\u0430 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0432 \u0434\u0440\u0443\u0433\u043e\u043c \u043c\u0435\u0441\u0442\u0435."},"services":"\u0423\u0441\u043b\u0443\u0433\u0438","setting":{"application_name":"\u0418\u043c\u044f \u043f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u044f","choose":"\u0412\u044b\u0431\u0440\u0430\u0442\u044c","company_domain":"\u0414\u043e\u043c\u0435\u043d \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","current_version":"\u0422\u0435\u043a\u0443\u0449\u0430\u044f \u0432\u0435\u0440\u0441\u0438\u044f","favicon":"\u0424\u0430\u0432\u0438\u043a\u043e\u043d","file_type":"\u0422\u0438\u043f \u0444\u0430\u0439\u043b\u0430","logo":"\u041b\u043e\u0433\u043e\u0442\u0438\u043f \u043a\u043e\u043c\u043f\u0430\u043d\u0438\u0438","setting_updated_successfully":"\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u044b."},"settings":"\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438","staff":"\u041f\u0435\u0440\u0441\u043e\u043d\u0430\u043b","status":{"additional_contact":"\u0414\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u0439 \u043a\u043e\u043d\u0442\u0430\u043a\u0442","answered":"\u041e\u0442\u0432\u0435\u0442\u0438\u043b","attempted":"\u041f\u043e\u043f\u044b\u0442\u043a\u0430","cancelled":"\u041e\u0442\u043c\u0435\u043d\u0435\u043d\u043e","closed":"\u0417\u0430\u043a\u0440\u044b\u0442\u043e","contacted":"\u0421\u0432\u044f\u0437\u0430\u043b\u0438\u0441\u044c","finished":"\u0413\u043e\u0442\u043e\u0432\u043e","in_progress":"\u0412\u044b\u043f\u043e\u043b\u043d\u044f\u0435\u0442\u0441\u044f","new_opportunity":"\u041d\u043e\u0432\u0430\u044f \u0432\u043e\u0437\u043c\u043e\u0436\u043d\u043e\u0441\u0442\u044c","not_attempted":"\u041d\u0435 \u043f\u044b\u0442\u0430\u043b\u0441\u044f","not_started":"\u041d\u0435 \u043d\u0430\u0447\u0430\u0442\u043e","on_hold":"\u041d\u0430 \u0443\u0434\u0435\u0440\u0436\u0430\u043d\u0438\u0438","open":"\u041e\u0442\u043a\u0440\u044b\u0442\u044c"},"success":"\u0423\u0441\u043f\u0435\u0445","support":"\u041f\u043e\u0434\u0434\u0435\u0440\u0436\u043a\u0430","tag":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","add_new_tag":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u0442\u0435\u0433","description":"\u041e\u043f\u0438\u0441\u0430\u043d\u0438\u0435","edit_tag":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0442\u0435\u0433","name":"\u0418\u043c\u044f","new_tag":"\u041d\u043e\u0432\u044b\u0439 \u0442\u0435\u0433","no_tag_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0442\u0435\u0433\u043e\u0432.","no_tag_found":"\u0422\u0435\u0433 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","tag_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0442\u0435\u0433\u0430","tag_not_found":"\u0422\u0435\u0433 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","tag_saved_successfully":"\u0422\u0435\u0433 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","tag_updated_successfully":"\u0422\u0435\u0433 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d."},"tags":"\u0422\u0435\u0433\u0438","task":{"awaiting_feedback":"\u0412 \u043e\u0436\u0438\u0434\u0430\u043d\u0438\u0438 \u043e\u0431\u0440\u0430\u0442\u043d\u043e\u0439 \u0441\u0432\u044f\u0437\u0438","billable":"\u041e\u043f\u043b\u0430\u0447\u0438\u0432\u0430\u0435\u043c\u044b\u0439","completed":"\u0417\u0430\u0432\u0435\u0440\u0448\u0435\u043d\u043e","due_date":"\u0421\u0440\u043e\u043a \u0441\u0434\u0430\u0447\u0438","edit_task":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0437\u0430\u0434\u0430\u0447\u0443","hourly_rate":"\u041f\u043e\u0447\u0430\u0441\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0432\u043a\u0430","in_progress":"\u0412 \u0445\u043e\u0434\u0435 \u0432\u044b\u043f\u043e\u043b\u043d\u0435\u043d\u0438\u044f","name":"\u0418\u043c\u044f","new_task":"\u041d\u043e\u0432\u0430\u044f \u0437\u0430\u0434\u0430\u0447\u0430","no_task_available":"\u041d\u0435\u0442 \u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0445 \u0437\u0430\u0434\u0430\u0447.","not_started":"\u041d\u0435 \u043d\u0430\u0447\u0430\u0442\u043e","priority":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442","public":"\u041e\u0431\u0449\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u043d\u044b\u0439","related_to":"\u0421\u0432\u044f\u0437\u0430\u043d\u043e \u0441","start_date":"\u0414\u0430\u0442\u0430 \u043d\u0430\u0447\u0430\u043b\u0430","status":"\u0421\u0442\u0430\u0442\u0443\u0441","subject":"\u0422\u0435\u043c\u0430","task_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0437\u0430\u0434\u0430\u0447\u0438","task_saved_successfully":"\u0417\u0430\u0434\u0430\u043d\u0438\u0435 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u043e.","task_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u0434\u0430\u0447\u0438 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","task_updated_successfully":"\u0417\u0430\u0434\u0430\u0447\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430.","testing":"\u0422\u0435\u0441\u0442\u0438\u0440\u043e\u0432\u0430\u043d\u0438\u0435","ticket":"\u0411\u0438\u043b\u0435\u0442"},"tasks":"\u0417\u0430\u0434\u0430\u0447\u0438","tax_rate":{"edit_tax_rate":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043d\u0430\u043b\u043e\u0433\u043e\u0432\u0443\u044e \u0441\u0442\u0430\u0432\u043a\u0443","new_tax_rate":"\u041d\u043e\u0432\u0430\u044f \u043d\u0430\u043b\u043e\u0433\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0432\u043a\u0430","no_tax_rate_available":"\u041d\u0430\u043b\u043e\u0433\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0432\u043a\u0430 \u043e\u0442\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u0435\u0442.","no_tax_rate_found":"\u0421\u0442\u0430\u0432\u043a\u0430 \u043d\u0430\u043b\u043e\u0433\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","tax_rate":"\u0421\u0442\u0430\u0432\u043a\u0430 \u043d\u0430\u043b\u043e\u0433\u0430","tax_rate_not_found":"\u0421\u0442\u0430\u0432\u043a\u0430 \u043d\u0430\u043b\u043e\u0433\u0430 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u0430.","tax_rate_saved_successfully":"\u041d\u0430\u043b\u043e\u0433\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0432\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d\u0430.","tax_rate_updated_successfully":"\u041d\u0430\u043b\u043e\u0433\u043e\u0432\u0430\u044f \u0441\u0442\u0430\u0432\u043a\u0430 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d\u0430."},"tax_rates":"\u0421\u0442\u0430\u0432\u043a\u0438 \u043d\u0430\u043b\u043e\u0433\u0430","this_week_payments":"\u041f\u043b\u0430\u0442\u0435\u0436\u0438 \u043d\u0430 \u044d\u0442\u043e\u0439 \u043d\u0435\u0434\u0435\u043b\u0435","ticket":{"Predefined_reply":"\u041f\u0440\u0435\u0434\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d\u043d\u044b\u0439 \u043e\u0442\u0432\u0435\u0442","add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","added_by":"\u041a\u0435\u043c \u0434\u043e\u0431\u0430\u0432\u043b\u0435\u043d\u043e","assign_to":"\u041d\u0430\u0437\u043d\u0430\u0447\u0438\u0442\u044c","attachments":"\u0412\u043b\u043e\u0436\u0435\u043d\u0438\u044f","body":"\u0422\u0435\u043b\u043e","cc":"CC","contact":"\u041a\u043e\u043d\u0442\u0430\u043a\u0442","department":"\u043e\u0442\u0434\u0435\u043b","details":"\u041f\u043e\u0434\u0440\u043e\u0431\u043d\u043e\u0441\u0442\u0438","edit_ticket":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u0431\u0438\u043b\u0435\u0442","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","name":"\u0418\u043c\u044f","new_ticket":"\u041d\u043e\u0432\u044b\u0439 \u0431\u0438\u043b\u0435\u0442","no_ticket_available":"\u0411\u0438\u043b\u0435\u0442\u043e\u0432 \u043d\u0435\u0442.","no_ticket_found":"\u0411\u0438\u043b\u0435\u0442\u043e\u0432 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d\u043e.","note":"\u041f\u0440\u0438\u043c\u0435\u0447\u0430\u043d\u0438\u0435","priority":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442","reminder":"\u043d\u0430\u043f\u043e\u043c\u0438\u043d\u0430\u043d\u0438\u0435","service":"\u0421\u0435\u0440\u0432\u0438\u0441","subject":"\u0422\u0435\u043c\u0430","tags":"\u0422\u0435\u0433\u0438","task":"\u0417\u0430\u0434\u0430\u0447\u0430","ticket_details":"\u0414\u0435\u0442\u0430\u043b\u0438 \u0431\u0438\u043b\u0435\u0442\u0430","ticket_not_found":"\u0411\u0438\u043b\u0435\u0442 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","ticket_saved_successfully":"\u0411\u0438\u043b\u0435\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","ticket_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","ticket_to_contact":"\u0411\u0438\u043b\u0435\u0442 \u0434\u043b\u044f \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430","ticket_updated_successfully":"\u0411\u0438\u043b\u0435\u0442 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","ticket_without_contact":"\u0411\u0438\u043b\u0435\u0442 \u0431\u0435\u0437 \u043a\u043e\u043d\u0442\u0430\u043a\u0442\u0430","tickets_status":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0431\u0438\u043b\u0435\u0442\u043e\u0432","you_can_add_multiples_images_and_files":"\u0412\u044b \u043c\u043e\u0436\u0435\u0442\u0435 \u0434\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u0435\u0441\u043a\u043e\u043b\u044c\u043a\u043e \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0439 \u0438 \u0444\u0430\u0439\u043b\u043e\u0432"},"ticket_priorities":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432","ticket_priority":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","add_new_ticket_priority":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u043f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0437\u0430\u044f\u0432\u043a\u0438","edit_ticket_priority":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0437\u0430\u044f\u0432\u043a\u0438","name":"\u0418\u043c\u044f","new_ticket_priority":"\u041d\u043e\u0432\u044b\u0439 \u043f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u0430","no_ticket_priority_available":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432 \u043d\u0435\u0434\u043e\u0441\u0442\u0443\u043f\u0435\u043d.","no_ticket_priority_found":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","ticket_priority_not_found":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432 \u043d\u0435 \u043d\u0430\u0439\u0434\u0435\u043d.","ticket_priority_saved_successfully":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0437\u0430\u044f\u0432\u043a\u0438 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","ticket_priority_updated_successfully":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0437\u0430\u044f\u0432\u043a\u0438 \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d \u0443\u0441\u043f\u0435\u0448\u043d\u043e.","ticket_priority_used_somewhere_else":"\u041f\u0440\u0438\u043e\u0440\u0438\u0442\u0435\u0442 \u0431\u0438\u043b\u0435\u0442\u043e\u0432 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0433\u0434\u0435-\u0442\u043e \u0435\u0449\u0435."},"ticket_status":{"add":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c","add_new_ticket_status":"\u0414\u043e\u0431\u0430\u0432\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u0441\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438","color":"\u0426\u0432\u0435\u0442","edit_ticket_status":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u0441\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438","name":"\u0418\u043c\u044f","new_ticket_status":"\u041d\u043e\u0432\u044b\u0439 \u0441\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438","status_order":"\u0421\u0442\u0430\u0442\u0443\u0441\u043d\u044b\u0439 \u0437\u0430\u043a\u0430\u0437","ticket_status":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438","ticket_status_saved_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d.","ticket_status_updated_successfully":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0437\u0430\u044f\u0432\u043a\u0438 \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","ticket_status_used_somewhere_else":"\u0421\u0442\u0430\u0442\u0443\u0441 \u0431\u0438\u043b\u0435\u0442\u0430 \u0438\u0441\u043f\u043e\u043b\u044c\u0437\u0443\u0435\u0442\u0441\u044f \u0433\u0434\u0435-\u0442\u043e \u0435\u0449\u0435."},"tickets":"\u0411\u0438\u043b\u0435\u0442\u044b","translation_manager":"\u041c\u0435\u043d\u0435\u0434\u0436\u0435\u0440 \u043f\u0435\u0440\u0435\u0432\u043e\u0434\u043e\u0432","translator_manager":{"edit_language":"\u0418\u0437\u043c\u0435\u043d\u0438\u0442\u044c \u044f\u0437\u044b\u043a","language_added_successfully":"\u042f\u0437\u044b\u043a \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u0434\u043e\u0431\u0430\u0432\u043b\u0435\u043d.","language_short_code":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u0432\u0432\u0435\u0434\u0438\u0442\u0435 \u043a\u0440\u0430\u0442\u043a\u0438\u0439 \u043a\u043e\u0434 \u044f\u0437\u044b\u043a\u0430. \u0442\u043e \u0435\u0441\u0442\u044c \u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 = en","language_updated_successfully":"\u042f\u0437\u044b\u043a \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","translation":"\u041f\u0435\u0440\u0435\u0432\u043e\u0434"},"user":{"change_language":"\u0421\u043c\u0435\u043d\u0438\u0442\u044c \u044f\u0437\u044b\u043a","change_password":"\u0421\u043c\u0435\u043d\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","edit_profile":"\u0420\u0435\u0434\u0430\u043a\u0442\u0438\u0440\u043e\u0432\u0430\u0442\u044c \u043f\u0440\u043e\u0444\u0438\u043b\u044c","email":"\u042d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u0430\u044f \u043f\u043e\u0447\u0442\u0430","first_name":"\u0418\u043c\u044f","language":"\u042f\u0437\u044b\u043a","language_updated_successfully":"\u042f\u0437\u044b\u043a \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","last_name":"\u0424\u0430\u043c\u0438\u043b\u0438\u044f","logout":"\u0412\u044b\u0439\u0442\u0438","name":"\u0418\u043c\u044f","password":"\u043f\u0430\u0440\u043e\u043b\u044c","password_confirmation":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0434\u0438\u0442\u044c \u043f\u0430\u0440\u043e\u043b\u044c","password_updated_successfully":"\u041f\u0430\u0440\u043e\u043b\u044c \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","phone":"\u0422\u0435\u043b\u0435\u0444\u043e\u043d","profile":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c","profile_updated_successfully":"\u041f\u0440\u043e\u0444\u0438\u043b\u044c \u0443\u0441\u043f\u0435\u0448\u043d\u043e \u043e\u0431\u043d\u043e\u0432\u043b\u0435\u043d.","return_to_admin":"\u0412\u0435\u0440\u043d\u0443\u0442\u044c\u0441\u044f \u043a \u0430\u0434\u043c\u0438\u043d\u0438\u0441\u0442\u0440\u0430\u0442\u043e\u0440\u0443"},"users":"\u041f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u0438","weekdays":{"fri":"\u041f\u0422","mon":"\u041f\u041d","sat":"\u0421\u0438\u0434\u0435\u043b","sun":"\u0421\u041e\u041b\u041d\u0426\u0415","thu":"\u0427\u0422","tue":"\u0412\u0422","wed":"\u041c\u042b \u0411"}},"ru.pagination":{"next":"\u0441\u043b\u0435\u0434\u0443\u044e\u0449\u0438\u0439 &raquo;","previous":"&laquo; \u043f\u0440\u0435\u0434\u044b\u0434\u0443\u0449\u0438\u0439"},"ru.passwords":{"reset":"\u0412\u0430\u0448 \u043f\u0430\u0440\u043e\u043b\u044c \u0431\u044b\u043b \u0441\u0431\u0440\u043e\u0448\u0435\u043d!","sent":"\u041c\u044b \u043e\u0442\u043f\u0440\u0430\u0432\u0438\u043b\u0438 \u0432\u0430\u043c \u0441\u0441\u044b\u043b\u043a\u0443 \u0434\u043b\u044f \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f \u043f\u043e \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u0435!","throttled":"\u041f\u043e\u0436\u0430\u043b\u0443\u0439\u0441\u0442\u0430, \u043f\u043e\u0434\u043e\u0436\u0434\u0438\u0442\u0435, \u043f\u0440\u0435\u0436\u0434\u0435 \u0447\u0435\u043c \u043f\u043e\u0432\u0442\u043e\u0440\u0438\u0442\u044c \u043f\u043e\u043f\u044b\u0442\u043a\u0443.","token":"\u042d\u0442\u043e\u0442 \u0442\u043e\u043a\u0435\u043d \u0441\u0431\u0440\u043e\u0441\u0430 \u043f\u0430\u0440\u043e\u043b\u044f \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u0435\u043d.","user":"\u041c\u044b \u043d\u0435 \u043c\u043e\u0436\u0435\u043c \u043d\u0430\u0439\u0442\u0438 \u043f\u043e\u043b\u044c\u0437\u043e\u0432\u0430\u0442\u0435\u043b\u044f \u0441 \u0442\u0430\u043a\u0438\u043c \u0430\u0434\u0440\u0435\u0441\u043e\u043c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b."},"ru.validation":{"accepted":":attribute \u0431\u044b\u0442\u044c \u043f\u0440\u0438\u043d\u044f\u0442.","active_url":":attribute \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u043c URL.","after":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0430\u0442\u043e\u0439 \u043f\u043e\u0441\u043b\u0435 :date.","after_or_equal":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0430\u0442\u043e\u0439 \u043f\u043e\u0441\u043b\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :date.","alpha":":attribute \u043c\u043e\u0436\u0435\u0442 \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u0442\u043e\u043b\u044c\u043a\u043e \u0431\u0443\u043a\u0432\u044b.","alpha_dash":":attribute \u043c\u043e\u0436\u0435\u0442 \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u0442\u043e\u043b\u044c\u043a\u043e \u0431\u0443\u043a\u0432\u044b, \u0446\u0438\u0444\u0440\u044b, \u0442\u0438\u0440\u0435 \u0438 \u043f\u043e\u0434\u0447\u0435\u0440\u043a\u0438\u0432\u0430\u043d\u0438\u044f.","alpha_num":":attribute \u043c\u043e\u0436\u0435\u0442 \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u0442\u043e\u043b\u044c\u043a\u043e \u0431\u0443\u043a\u0432\u044b \u0438 \u0446\u0438\u0444\u0440\u044b.","array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0430\u0441\u0441\u0438\u0432\u043e\u043c.","attributes":[],"before":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0430\u0442\u043e\u0439 \u0434\u043e :date.","before_or_equal":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0430\u0442\u043e\u0439 \u0434\u043e \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :date.","between":{"array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0438\u043c\u0435\u0442\u044c \u0437\u043d\u0430\u0447\u0435\u043d\u0438\u044f \u043c\u0435\u0436\u0434\u0443 :min \u0438 :max items.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u0436\u0434\u0443 :min \u0438 :max \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u0436\u0434\u0443 :min \u0438 :max.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u0436\u0434\u0443 :min \u0438 :max \u0441\u0438\u043c\u0432\u043e\u043b\u0430\u043c\u0438."},"boolean":"\u041f\u043e\u043b\u0435 :attribute \u0434\u043e\u043b\u0436\u043d\u043e \u0431\u044b\u0442\u044c \u0438\u0441\u0442\u0438\u043d\u043d\u044b\u043c \u0438\u043b\u0438 \u043b\u043e\u0436\u043d\u044b\u043c.","confirmed":"\u041f\u043e\u0434\u0442\u0432\u0435\u0440\u0436\u0434\u0435\u043d\u0438\u0435 :attribute \u043d\u0435 \u0441\u043e\u0432\u043f\u0430\u0434\u0430\u0435\u0442.","custom":{"attribute-name":{"rule-name":"custom-message"}},"date":":attribute \u043d\u0435 \u044f\u0432\u043b\u044f\u0435\u0442\u0441\u044f \u0434\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u043e\u0439 \u0434\u0430\u0442\u043e\u0439.","date_equals":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0430\u0442\u043e\u0439, \u0440\u0430\u0432\u043d\u043e\u0439 :date.","date_format":":attribute \u043d\u0435 \u0441\u043e\u043e\u0442\u0432\u0435\u0442\u0441\u0442\u0432\u0443\u0435\u0442 \u0444\u043e\u0440\u043c\u0430\u0442\u0443: \u0444\u043e\u0440\u043c\u0430\u0442.","different":":attribute \u0438 :other \u0434\u043e\u043b\u0436\u043d\u044b \u0431\u044b\u0442\u044c \u0440\u0430\u0437\u043d\u044b\u043c\u0438.","digits":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c: \u0446\u0438\u0444\u0440\u044b \u0446\u0438\u0444\u0440\u044b.","digits_between":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u0436\u0434\u0443 :min \u0438 :max digits.","dimensions":":attribute \u0438\u043c\u0435\u0435\u0442 \u043d\u0435\u0434\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u044b\u0435 \u0440\u0430\u0437\u043c\u0435\u0440\u044b \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u044f.","distinct":"\u041f\u043e\u043b\u0435 :attribute \u0438\u043c\u0435\u0435\u0442 \u043f\u043e\u0432\u0442\u043e\u0440\u044f\u044e\u0449\u0435\u0435\u0441\u044f \u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435.","email":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u043c \u0430\u0434\u0440\u0435\u0441\u043e\u043c \u044d\u043b\u0435\u043a\u0442\u0440\u043e\u043d\u043d\u043e\u0439 \u043f\u043e\u0447\u0442\u044b.","ends_with":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0437\u0430\u043a\u0430\u043d\u0447\u0438\u0432\u0430\u0442\u044c\u0441\u044f \u043e\u0434\u043d\u0438\u043c \u0438\u0437 \u0441\u043b\u0435\u0434\u0443\u044e\u0449\u0438\u0445: :value.","exists":"\u0412\u044b\u0431\u0440\u0430\u043d\u043d\u044b\u0439 :attribute \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u0435\u043d.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0444\u0430\u0439\u043b\u043e\u043c.","filled":"\u041f\u043e\u043b\u0435 :attribute \u0434\u043e\u043b\u0436\u043d\u043e \u0438\u043c\u0435\u0442\u044c \u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435..","gt":{"array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0438\u043c\u0435\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0447\u0435\u043c: :value \u044d\u043b\u0435\u043c\u0435\u043d\u0442\u043e\u0432.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0447\u0435\u043c: :value \u0432 \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442\u0430\u0445.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0447\u0435\u043c :value.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0447\u0435\u043c: :value \u0441\u0438\u043c\u0432\u043e\u043b\u043e\u0432."},"gte":{"array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0438\u043c\u0435\u0442\u044c: \u044d\u043b\u0435\u043c\u0435\u043d\u0442\u044b :value \u0438\u043b\u0438 \u0431\u043e\u043b\u0435\u0435.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :value \u0432 \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442\u0430\u0445.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :value.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :value value."},"image":":attribute:\u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0438\u0437\u043e\u0431\u0440\u0430\u0436\u0435\u043d\u0438\u0435\u043c..","in":":attribute selected: \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u0435\u043d.","in_array":"\u041f\u043e\u043b\u0435 :attribute \u043d\u0435 \u0441\u0443\u0449\u0435\u0441\u0442\u0432\u0443\u0435\u0442 \u0432 :other.","integer":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0446\u0435\u043b\u044b\u043c \u0447\u0438\u0441\u043b\u043e\u043c.","ip":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u043c IP-\u0430\u0434\u0440\u0435\u0441\u043e\u043c.","ipv4":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u043c \u0430\u0434\u0440\u0435\u0441\u043e\u043c IPv4.","ipv6":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u043c \u0430\u0434\u0440\u0435\u0441\u043e\u043c IPv6.","json":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u043e\u0439 \u0441\u0442\u0440\u043e\u043a\u043e\u0439 JSON..","lt":{"array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 :value.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0447\u0435\u043c :value \u0432 \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442\u0430\u0445.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0447\u0435\u043c :value.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0447\u0435\u043c :value \u0441\u0438\u043c\u0432\u043e\u043b\u043e\u0432."},"lte":{"array":":attribute \u043d\u0435 \u0434\u043e\u043b\u0436\u0435\u043d \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435, \u0447\u0435\u043c :value items.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :value \u0432 \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442\u0430\u0445.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :value.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043c\u0435\u043d\u044c\u0448\u0435 \u0438\u043b\u0438 \u0440\u0430\u0432\u0435\u043d :value."},"max":{"array":":attribute \u043c\u043e\u0436\u0435\u0442 \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u043d\u0435 \u0431\u043e\u043b\u0435\u0435 :max \u044d\u043b\u0435\u043c\u0435\u043d\u0442\u043e\u0432.","file":":attribute:\u043d\u0435 \u043c\u043e\u0436\u0435\u0442 \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435, \u0447\u0435\u043c :max \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442.","numeric":":attribute \u043d\u0435 \u043c\u043e\u0436\u0435\u0442 \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435, \u0447\u0435\u043c :max.","string":":attribute \u043d\u0435 \u043c\u043e\u0436\u0435\u0442 \u0431\u044b\u0442\u044c \u0431\u043e\u043b\u044c\u0448\u0435, \u0447\u0435\u043c :max \u0441\u0438\u043c\u0432\u043e\u043b\u043e\u0432."},"mimes":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0444\u0430\u0439\u043b\u043e\u043c \u0442\u0438\u043f\u0430: :values.","mimetypes":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0444\u0430\u0439\u043b\u043e\u043c \u0442\u0438\u043f\u0430: :values.","min":{"array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u043a\u0430\u043a :min items.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043d\u0435 \u043c\u0435\u043d\u0435\u0435 :min \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u043d\u0435 \u043c\u0435\u043d\u0435\u0435 :min.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c \u043d\u0435 \u043c\u0435\u043d\u0435\u0435 :min \u0441\u0438\u043c\u0432\u043e\u043b\u043e\u0432."},"not_in":":attribute selected: \u043d\u0435\u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u0435\u043d.","not_regex":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u0444\u043e\u0440\u043c\u0430\u0442 :attribute.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0447\u0438\u0441\u043b\u043e\u043c.","password":"\u041f\u0430\u0440\u043e\u043b\u044c \u043d\u0435\u0432\u0435\u0440\u043d\u044b\u0439.","present":"\u041f\u043e\u043b\u0435: :attribute \u0434\u043e\u043b\u0436\u043d\u043e \u043f\u0440\u0438\u0441\u0443\u0442\u0441\u0442\u0432\u043e\u0432\u0430\u0442\u044c.","regex":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u0444\u043e\u0440\u043c\u0430\u0442 :attribute.","required":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435.","required_if":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435, \u043a\u043e\u0433\u0434\u0430 :other is :value.","required_unless":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435, \u0435\u0441\u043b\u0438 :other \u043d\u0435 \u043d\u0430\u0445\u043e\u0434\u0438\u0442\u0441\u044f \u0432 :values.","required_with":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435, \u0435\u0441\u043b\u0438 \u043f\u0440\u0438\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u0435\u0442 :values.","required_with_all":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435, \u043a\u043e\u0433\u0434\u0430 :values \u043f\u0440\u0438\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u044e\u0442.","required_without":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435, \u0435\u0441\u043b\u0438: :values \u043e\u0442\u0441\u0443\u0442\u0441\u0442\u0432\u0443\u044e\u0442.","required_without_all":"\u041f\u043e\u043b\u0435: :attribute \u043e\u0431\u044f\u0437\u0430\u0442\u0435\u043b\u044c\u043d\u043e\u0435, \u0435\u0441\u043b\u0438 \u043d\u0435\u0442 \u043d\u0438 \u043e\u0434\u043d\u043e\u0433\u043e \u0438\u0437 :values.","same":":attribute \u0438 :other \u0434\u043e\u043b\u0436\u043d\u044b \u0441\u043e\u0432\u043f\u0430\u0434\u0430\u0442\u044c.","size":{"array":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0441\u043e\u0434\u0435\u0440\u0436\u0430\u0442\u044c: size items.","file":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0438\u043c\u0435\u0442\u044c \u0440\u0430\u0437\u043c\u0435\u0440: \u043a\u0438\u043b\u043e\u0431\u0430\u0439\u0442.","numeric":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c: size.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c: \u0440\u0430\u0437\u043c\u0435\u0440 \u0441\u0438\u043c\u0432\u043e\u043b\u043e\u0432."},"starts_with":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u043d\u0430\u0447\u0438\u043d\u0430\u0442\u044c\u0441\u044f \u0441 \u043e\u0434\u043d\u043e\u0433\u043e \u0438\u0437 \u0441\u043b\u0435\u0434\u0443\u044e\u0449\u0438\u0445 :values.","string":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0441\u0442\u0440\u043e\u043a\u043e\u0439.","timezone":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u043e\u043f\u0443\u0441\u0442\u0438\u043c\u043e\u0439 \u0437\u043e\u043d\u043e\u0439.","unique":":attribute \u0443\u0436\u0435 \u0437\u0430\u043d\u044f\u0442.","uploaded":"\u041d\u0435 \u0443\u0434\u0430\u043b\u043e\u0441\u044c \u0437\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044c :attribute.","url":"\u041d\u0435\u0432\u0435\u0440\u043d\u044b\u0439 \u0444\u043e\u0440\u043c\u0430\u0442 :attribute.","uuid":":attribute \u0434\u043e\u043b\u0436\u0435\u043d \u0431\u044b\u0442\u044c \u0434\u0435\u0439\u0441\u0442\u0432\u0438\u0442\u0435\u043b\u044c\u043d\u044b\u043c UUID."},"tr.auth":{"failed":"Bu kimlik bilgileri kay\u0131tlar\u0131m\u0131zla e\u015fle\u015fmiyor.","throttle":"\u00c7ok fazla giri\u015f denemesi. L\u00fctfen birka\u00e7 :saniye i\u00e7inde tekrar deneyin."},"tr.messages":{"activity_log":{"activity_logs":"Etkinlik G\u00fcnl\u00fckleri","loading_more_date":"Daha Fazla Veri Y\u00fckleme","sorry_we_not_find_any_data":"Herhangi bir veri bulam\u0131yoruz, en az 1 giri\u015f yapal\u0131m","we_could_find_any_data":"Maalesef herhangi bir veri bulamad\u0131k"},"address":{"city":"Kent","country":"\u00fclke","state":"Durum","street":"sokak","zip_code":"Posta kodu"},"announcement":{"add":"Ekle","announcement_date":"Duyuru Tarihi","announcement_details":"Duyuru Ayr\u0131nt\u0131lar\u0131","announcement_not_found":"Duyuru Bulunamad\u0131","announcement_saved_successfully":"Duyuru ba\u015far\u0131yla kaydedildi.","announcement_updated_successfully":"Duyuru ba\u015far\u0131yla g\u00fcncellendi.","edit_announcement":"Duyuru D\u00fczenleyin","message":"\u0130leti","new_announcement":"Yeni Duyuru","no_announcement_available":"Duyuru Yok","no_announcement_found":"Duyuru Bulunamad\u0131.","show_my_name":"Ad\u0131m\u0131 G\u00f6ster","show_to_clients":"M\u00fc\u015fterilere G\u00f6ster","show_to_staff":"Personele G\u00f6ster","subject":"konu"},"announcements":"Duyurular","article":{"add":"Ekle","article_details":"Makale Ayr\u0131nt\u0131lar\u0131","article_not_found":"Makale Bulunamad\u0131.","article_saved_successfully":"Makale ba\u015far\u0131yla kaydedildi.","article_updated_successfully":"Makale ba\u015far\u0131yla g\u00fcncellendi.","attachment":"Ek dosya","description":"A\u00e7\u0131klama","disabled":"engelli","edit_article":"Makaleyi D\u00fczenle","group":"grup","internal_article":"Dahili Makale","new_article":"Yeni Makale","no_article_available":"Mevcut Makale Yok.","no_article_found":"Makale Bulunamad\u0131.","subject":"konu","upload_image":"Foto\u011fraf y\u00fckleniyor"},"article_group":{"add_new_article_group":"Yeni Makale Grubu Ekle","article_group_saved_successfully":"Makale Grubu ba\u015far\u0131yla kaydedildi.","article_group_updated_successfully":"Makale Grubu ba\u015far\u0131yla g\u00fcncellendi.","article_group_used_somewhere_else":"Makale Grubu ba\u015fka bir yerde kullan\u0131ld\u0131.","article_groups":"Makale Gruplar\u0131","color":"Renk","edit_article_group":"Makale Grubunu D\u00fczenle","group_name":"Grup ismi","new_article_group":"Yeni Makale Grubu","order":"Sipari\u015f"},"articles":"Nesne","calendars":"Takvimler","change_password":{"change_information_about_yourself_on_this_page":" Bu sayfada kendinizle ilgili bilgileri de\u011fi\u015ftirin.","confirm_password":"\u015eifreyi Onayla","current_password":"\u015eimdiki \u015eifre","edit_profile":"Profili D\u00fczenle","new_password":"Yeni \u015eifre"},"client_dashboard":"M\u00fc\u015fteri G\u00f6sterge Tablosu","cms":"CMS","comment":{"add_comment":"Yorum ekle","added_by":"Taraf\u0131ndan eklendi","comments_saved_successfully":"Yorum ba\u015far\u0131yla kaydedildi.","comments_updated_successfully":"Yorum ba\u015far\u0131yla g\u00fcncellendi.","edit_comment":"Yorumu D\u00fczenle","new_comment":"Yeni yorum","no_comments_added_yet":"Hen\u00fcz Yorum Eklenmemi\u015f"},"comments":"Yorumlar","common":{"action":"Aksiyon","active":"Aktif","add":"Ekle","admin_note":"Y\u00f6netici Notu","announcement":"Duyuru","apply":"Uygulamak","article":"Madde","article_group":"Makale Grubu","assignee":"Vekil","attachment_deleted":"Ek silindi.","back":"Geri","cancel":"\u0130ptal etmek","choose":"Se\u00e7","client_note":"M\u00fc\u015fteri Notu","contract_type":"s\u00f6zle\u015fme tipi","country":"\u00dclke","created_on":"Olu\u015fturulma Tarihi","custom":"Gelenek","customer":"M\u00fc\u015fteri","customer_group":"m\u00fc\u015fteri grubu","data_base_entries":"_TOTAL_ giri\u015ften _START_ - _END_ aras\u0131 g\u00f6steriliyor","deactive":"Deaktif","default_country_code":"Varsay\u0131lan \u00dclke Kodu","delete":"Sil","delete_attachment":"Bu \"Eki\" silmek istedi\u011finizden emin misiniz?","delete_confirm":"L\u00fctfen yaz\u0131n","delete_confirm_common":"Bunu silmek istedi\u011finizden emin misiniz?","delete_note":"Bu \"Notu\" silmek istedi\u011finizden emin misiniz?","deleted":"Silindi!","department":"Departman","description":"A\u00e7\u0131klama","download":"\u0130ndir","download_as_pdf":"PDF Olarak \u0130ndir","drafted":"Taslak","edit":"D\u00fczenle","email":"E-posta","expense":"gider","expense_category":"Gider Kategorisi","filter_by":"(_MAX_ toplam giri\u015ften filtrelendi)","from":"\u0130tibaren","goal":"Hedef","has_been_delete":" silindi.","incomes_vs_expenses":"Gelirler ve Giderler","last_updated":"Son g\u00fcncelleme","lead":"\u00d6nc\u00fcl\u00fck etmek","lead_source":"\u00d6nc\u00fc kaynak","menu_entry":"_MENU_ giri\u015fi g\u00f6ster","n\/a":"N\/A","name":"ad","no":"Hay\u0131r","no_data_available_in_table":"Tabloda Veri Yok","no_entry":"0 girdiden 0 ile 0 aras\u0131 g\u00f6steriliyor","no_matching":"Hi\u00e7bir e\u015fle\u015fen kay\u0131t bulunamad\u0131","note":"Not","note_delete":"Not silindi.","of":"N\u0131n-nin","ok":"TAMAM","payment_mode":"\u00d6deme \u015fekli","predefined_reply":"\u00d6ntan\u0131ml\u0131 Yan\u0131t","product_1":"\u00dcr\u00fcn","product_group":"\u00dcr\u00fcn grubu","product_header":"\u00dcr\u00fcn","proposal":"Teklif","quantity_is_not_greater_than":"Miktar 9999999'dan b\u00fcy\u00fck de\u011fil","save":"Kay\u0131t etmek","search":"Arama","search_results":"Arama Sonu\u00e7lar\u0131n\u0131z Buraya Gelecek ...","service":"Hizmet","showing":"G\u00f6steriliyor","status":"durum","tag":"Etiket","tax_rate":"Vergi oran\u0131","term_and_conditions":"D\u00f6nem ve Ko\u015fullar","ticket_priority":"Bilet \u00d6nceli\u011fi","to":"\u0130le","to_delete_this":"bunu silmek i\u00e7in","total_amount":"Toplam tutar","type_delete":"Bunu silmek i\u00e7in l\u00fctfen \"silmek\" yaz\u0131n","view":"G\u00f6r\u00fcn\u00fcm","weekly_payment_records":"Haftal\u0131k \u00d6deme Kay\u0131tlar\u0131","yes":"Evet"},"company":{"address":"Adres","city":"Kent","company":"\u015eirket Ad\u0131","company_information_format":"\u015eirket Bilgi Format\u0131 (PDF ve HTML)","country_code":"\u00dclke kodu","currency":"Para birimi","details":"\u015eirket Detaylar\u0131","phone":"Telefon","state":"Durum","vat_number":"VAT Number","website":"\u0130nternet sitesi","zip_code":"Posta kodu"},"company_information":"\u015eirket Bilgisi","contact":{"active":"Aktif","by_deleting_this_contact":"Bu ki\u015fiyi sildi\u011finizde t\u00fcm projesi silinecektir.","contact_details":"\u0130leti\u015fim detaylar\u0131","contact_not_found":"Ki\u015fi Bulunamad\u0131.","contact_saved_successfully":"Ki\u015fi ba\u015far\u0131yla kaydedildi.","contact_status_updated_successfully":"Ki\u015fi durumu ba\u015far\u0131yla g\u00fcncellendi.","contact_updated_successfully":"Ki\u015fi ba\u015far\u0131yla g\u00fcncellendi.","contract":"s\u00f6zle\u015fme","contracts":"S\u00f6zle\u015fmeler","credit_note":"Kredi notu","customer_name":"m\u00fc\u015fteri ad\u0131","deactive":"Deaktif","delete_contact_confirm":"Bu ki\u015fiyi silmek istedi\u011finizden emin misiniz?","edit_contact":"Ki\u015fiyi D\u00fczenle","email_notifications":"E-posta Bildirimleri","estimate":"Tahmin","estimates":"Tahminler","first_name":"\u0130sim","full_name":"Ad Soyad","impersonate":"kimli\u011fine b\u00fcr\u00fcn","invoice":"Fatura","invoices":"Faturalar","last_name":"Soyad\u0131","make_sure_to_set_appropriate_permissions_for_this_contact":"Bu ki\u015fi i\u00e7in uygun izinleri ayarlad\u0131\u011f\u0131n\u0131zdan emin olun","new_contact":"Yeni ba\u011flant\u0131","no_contact_available":"Uygun ki\u015fi yok.","no_contact_found":"Ki\u015fi Bulunamad\u0131.","password":"Parola","permissions":"\u0130zinler","position":"Durum","primary_contact":"Birincil \u0130lgili Ki\u015fi","project":"proje","projects":"Projeler","proposals":"Teklif","send_password_email":"SET \u015fifre e-postas\u0131n\u0131 g\u00f6nder","send_welcome_email":"Ho\u015fgeldin e-postas\u0131 g\u00f6ndermeyin","support":"Destek","task":"G\u00f6rev","tickets":"Biletler"},"contacts":"\u0130leti\u015fim","contract":{"add":"Ekle","authorized_signature":"Yetkili imza","contract_details":"S\u00f6zle\u015fme Ayr\u0131nt\u0131lar\u0131","contract_list":"S\u00f6zle\u015fme Listesi","contract_not_found":"S\u00f6zle\u015fme Bulunamad\u0131","contract_summary":"S\u00f6zle\u015fme \u00d6zeti","contract_type_id":"S\u00f6zle\u015fme tipi","contract_value":"S\u00f6zle\u015fme De\u011feri","contracts_by_type":"T\u00fcre G\u00f6re S\u00f6zle\u015fmeler","contracts_expiring_this_month":"Bu ay sona eren s\u00f6zle\u015fmeler","contracts_saved_successfully":"S\u00f6zle\u015fme ba\u015far\u0131yla kaydedildi.","contracts_updated_successfully":"S\u00f6zle\u015fme ba\u015far\u0131yla g\u00fcncellendi.","contracts_value_by_type":"T\u00fcre G\u00f6re Kontrat De\u011feri","customer_id":"M\u00fc\u015fteri","description":"A\u00e7\u0131klama","edit_contract":"S\u00f6zle\u015fmeyi D\u00fczenle","end_date":"Biti\u015f tarihi","is_hide":"M\u00fc\u015fteriden gizle","is_trash":"\u00c7\u00f6p","new_contract":"Yeni s\u00f6zle\u015fme","no_contract_available":"Mevcut S\u00f6zle\u015fme Yok","no_contract_found":"S\u00f6zle\u015fme Bulunamad\u0131","sign":"\u0130\u015faret","start_date":"Ba\u015flang\u0131\u00e7 tarihi","subject":"konu"},"contract_type":{"add_new_contract_type":"Yeni S\u00f6zle\u015fme T\u00fcr\u00fc Ekle","contract_by_type":"T\u00fcre G\u00f6re S\u00f6zle\u015fme","contract_type_saved_successfully":"S\u00f6zle\u015fme T\u00fcr\u00fc ba\u015far\u0131yla kaydedildi.","contract_type_updated_successfully":"S\u00f6zle\u015fme T\u00fcr\u00fc ba\u015far\u0131yla g\u00fcncellendi.","contract_type_used_somewhere_else":"S\u00f6zle\u015fme T\u00fcr\u00fc ba\u015fka bir yerde kullan\u0131l\u0131yor.","contract_value_by_type":"T\u00fcre G\u00f6re S\u00f6zle\u015fme De\u011feri","edit_contract_type":"S\u00f6zle\u015fme T\u00fcr\u00fcn\u00fc D\u00fczenle","new_contract_type":"Yeni S\u00f6zle\u015fme T\u00fcr\u00fc"},"contract_types":"S\u00f6zle\u015fme T\u00fcrleri","contracts":"S\u00f6zle\u015fmeler","countries":"\u00dclkeler","country":{"add":"Ekle","country_not_found":"\u00dclke Bulunamad\u0131.","country_saved_successfully":"\u00dclke ba\u015far\u0131yla kaydedildi.","country_updated_successfully":"\u00dclke ba\u015far\u0131yla g\u00fcncellendi.","country_used_somewhere_else":"\u00dclke ba\u015fka bir yerde kullan\u0131l\u0131r.","edit_country":"\u00dclkeyi D\u00fczenle","name":"\u0130sim","new_country":"Yeni \u00fclke","no_country_available":"Mevcut \u00dclke Yok.","no_country_found":"\u00dclke Bulunamad\u0131."},"credit_note":{"authorized_signature":"Yetkili imza","client_note":"Not","closed":"Kapal\u0131","credit_note":"Alacak Dekontu","credit_note_date":"Alacak Dekontu Tarihi","credit_note_details":"Alacak Dekontu Ayr\u0131nt\u0131lar\u0131","credit_note_details_updated_successfully":"Kredi Notu ayr\u0131nt\u0131lar\u0131 ba\u015far\u0131yla g\u00fcncellendi.","credit_note_not_found":"Alacak Dekontu Bulunamad\u0131.","credit_note_number":"Alacak Dekont Numaras\u0131","credit_note_pdf":"Alacak Dekontu PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"Kredi Dekontu ba\u015far\u0131yla kaydedildi.","credit_note_updated_successfully":"Kredi Notu ba\u015far\u0131yla g\u00fcncellendi.","drafted":"Taslak","edit_credit_note":"Alacak Dekontunu D\u00fczenle","invoice_credited":"Fatura Kredilendirildi","mark_as_closed":"Kapal\u0131 Olarak \u0130\u015faretle","mark_as_draft":"Taslak Olarak \u0130\u015faretle","mark_as_open":"A\u00e7\u0131k Olarak \u0130\u015faretle","mark_as_void":"Ge\u00e7ersiz Olarak \u0130\u015faretle","new_credit_note":"Yeni Alacak Dekontu","no_credit_note_available":"Alacak Dekontu Yoktur.","no_credit_note_found":"Alacak Dekontu Bulunamad\u0131.","open":"A\u00e7\u0131k","quantity_is_not_greater_than":"Miktar 9999999'dan b\u00fcy\u00fck de\u011fil","reference":"Referans","refunds":"Geri \u00f6demeler","save_and_send":"Kaydet ve G\u00f6nder","save_as_draft":"Taslak Olarak Kaydet","terms_and_conditions":"\u015eartlar ve Ko\u015fullar","title":"Ba\u015fl\u0131k","view_credit_note_as_customer":"Kredi Notunu M\u00fc\u015fteri Olarak G\u00f6r\u00fcnt\u00fcle","void":"Ge\u00e7ersiz"},"credit_notes":"Kredi notlar\u0131","customer":{"add_address_details":"Adres Ayr\u0131nt\u0131lar\u0131n\u0131 Ekle","address":"Adres","address_details":"adres detaylar\u0131","address_not_found":"Adres Ayr\u0131nt\u0131lar\u0131 Bulunamad\u0131.","billing_address":"Fatura Adresi","billing_address_details_not_available":"Fatura Adresi Ayr\u0131nt\u0131lar\u0131 Kullan\u0131lam\u0131yor","by_deleting_this_customer":"Bu m\u00fc\u015fterinin silinmesi ile t\u00fcm projesi, konta\u011f\u0131, faturas\u0131, tahmini, alacak dekontu, teklifi ve s\u00f6zle\u015fmesi silinecektir.","city":"Kent","company_name":"\u015eirket Ad\u0131","copy_billing_address":"Fatura Adresini Kopyala","country":"\u00fclke","currency":"Para birimi","customer_details":"M\u00fc\u015fteri detaylar\u0131","customer_saved_successfully":"M\u00fc\u015fteri ba\u015far\u0131yla kaydedildi.","customer_updated_successfully":"M\u00fc\u015fteri ba\u015far\u0131yla g\u00fcncellendi.","customers":"M\u00fc\u015fteriler","default_language":"Varsay\u0131lan dil","delete_customer_confirm":"Bu m\u00fc\u015fteriyi silmek istedi\u011finizden emin misiniz?","do_not_fill_shipping_address_customer_invoices":"M\u00fc\u015fteri faturalar\u0131nda g\u00f6nderim adresi kullanmayacaksan\u0131z g\u00f6nderim adresi bilgilerini doldurmay\u0131n","edit_customer":"M\u00fc\u015fteriyi D\u00fczenle","groups":"Gruplar","new_customer":"Yeni m\u00fc\u015fteri","no_customer_available":"M\u00fc\u015fteri Bulunmamaktad\u0131r.","no_customer_found":"M\u00fc\u015fteri Bulunamad\u0131.","phone":"Telefon","same_as_a_customer_info":"M\u00fc\u015fteri Bilgileriyle Ayn\u0131","search_customer":"Toplam Proje","shipping_address":"teslimat adresi","shipping_address_details_not_available":"G\u00f6nderim Adresi Ayr\u0131nt\u0131lar\u0131 Mevcut De\u011fil","state":"Durum","street":"sokak","total_contact":"Toplam \u0130leti\u015fim","total_customers":"Toplam M\u00fc\u015fteri","total_project":"Toplam Proje","type":"tip","vat_number":"KDV Numaras\u0131","website":"\u0130nternet sitesi","zip_code":"Posta kodu"},"customer_group":{"action":"Aksiyon","add_new_customer_group":"Yeni M\u00fc\u015fteri Grubu Ekle","customer_group_saved_successfully":"M\u00fc\u015fteri Grubu ba\u015far\u0131yla kaydedildi.","customer_group_updated_successfully":"M\u00fc\u015fteri Grubu ba\u015far\u0131yla g\u00fcncellendi.","description":"A\u00e7\u0131klama","edit_customer_group":"M\u00fc\u015fteri Grubunu D\u00fczenle","name":"ad","new_customer_group":"Yeni M\u00fc\u015fteri Grubu"},"customer_groups":"M\u00fc\u015fteri Gruplar\u0131","customers":"M\u00fc\u015fteriler","dashboard":"G\u00f6sterge Paneli","department":{"department_not_found":"B\u00f6l\u00fcm Bulunamad\u0131.","department_saved_successfully":"Departman ba\u015far\u0131yla kaydedildi.","department_updated_successfully":"Departman ba\u015far\u0131yla g\u00fcncellendi.","departments":"B\u00f6l\u00fcmler","edit_department":"B\u00f6l\u00fcm\u00fc D\u00fczenle","hide_from_clients":"M\u00fc\u015fterilerden gizle","new_department":"Yeni Departman","no_department_available":"Mevcut Departman Yok.","no_department_found":"B\u00f6l\u00fcm Bulunamad\u0131."},"edit_profile":{"change_password":"\u015eifre de\u011fi\u015ftir","edit_profile":"Profili D\u00fczenle","hello":"Merhaba","hi":"Selam","login":"Oturum a\u00e7","login_register":"Giri\u015f \/ Kay\u0131t","logout":"\u00c7\u0131k\u0131\u015f Yap","mark_all_as_read":"T\u00fcm\u00fcn\u00fc Okundu Olarak \u0130\u015faretle","notification":"Bildirimler","register":"Kay\u0131t ol","welcome":"Ho\u015fgeldiniz"},"email":{"email":"E-posta","forgot_password":"Parolan\u0131z\u0131 m\u0131 unuttunuz","recalled_your_login_info":"Giri\u015f bilgilerinizi hat\u0131rlad\u0131n\u0131z m\u0131?","reset_password":"\u015eifreyi yenile","send_reset_link":"S\u0131f\u0131rlama Ba\u011flant\u0131s\u0131 G\u00f6nder","sign_in":"Oturum a\u00e7"},"email_template":{"available_merge_fields":"Kullan\u0131labilir birle\u015ftirme alanlar\u0131","disabled":"engelli","edit_email_template":"E-posta \u015eablonunu D\u00fczenle","email_message":"E-posta mesaj\u0131","enable":"etkinle\u015ftirme","from_name":"\u0130simden","send_plain_text":"D\u00fcz Metin olarak g\u00f6nder","subject":"konu","template_name":"\u015fablon ad\u0131"},"email_templates":"E-posta \u015eablonlar\u0131","error":"Hata","estimate":{"accepted":"KABUL ED\u0130LM\u0130\u015e","adjustment":"ayarlama","amount":"Miktar","amount_due":"Alacak miktar\u0131","authorized_signature":"Yetkili imza","bill_to":"Ya fatura edilecek","client_note":"M\u00fc\u015fteri Notu","convert_estimate":"Tahmini D\u00f6n\u00fc\u015ft\u00fcr","convert_estimate_to_invoice":"Tahmini Ba\u015far\u0131yla Faturaya D\u00f6n\u00fc\u015ft\u00fcr.","declined":"REDDED\u0130LD\u0130","discount":"\u0130ndirim","draft":"TASLAK","drafted":"Taslak","edit_estimate":"Tahmini D\u00fczenle","estimate":"Tahmin","estimate_date":"Tahmin Tarihi","estimate_details":"Tahmin Ayr\u0131nt\u0131lar\u0131","estimate_not_found":"Tahmin Bulunamad\u0131","estimate_number":"Tahmini Numara","estimate_overview":"GENEL BAKI\u015e TAHM\u0130N\u0130","estimate_pdf":"PDF tahmin et","estimate_prefix":"EN-","estimate_saved_successfully":"Tahmin ba\u015far\u0131yla kaydedildi.","estimate_status_updated_successfully":"Tahmin durumu ba\u015far\u0131yla g\u00fcncellendi.","estimate_updated_successfully":"Tahmin ba\u015far\u0131yla g\u00fcncellendi.","expired":"S\u00dcRES\u0130 DOLDU","expiry_date":"Son kullanma tarihi","item":"\u00dcr\u00fcn","mark_as_accepted":"Kabul Edildi Olarak \u0130\u015faretle","mark_as_declined":"Reddedildi Olarak \u0130\u015faretle","mark_as_draft":"Taslak Olarak \u0130\u015faretle","mark_as_expired":"S\u00fcresi Doldu Olarak \u0130\u015faretle","mark_as_send":"G\u00f6nder Olarak \u0130\u015faretle","more":"Daha","new_estimate":"Yeni Tahmin","no_estimate_available":"Tahmin Yok","no_estimate_found":"Tahmin Bulunamad\u0131.","not_sent":"G\u00d6NDER\u0130LMED\u0130","qty":"Adet","rate":"oran","save_and_send":"Kaydet ve G\u00f6nder","save_as_draft":"Taslak Olarak Kaydet","sent":"G\u00d6NDER\u0130LD\u0130","ship_to":"Al\u0131c\u0131","status":"durum","sub_total":"Ara toplam","taxes":"Vergiler","terms_conditions":"\u015fartlar ve ko\u015fullar","title":"Ba\u015fl\u0131k","total":"Toplam","total_estimates":"Toplam Tahminler","total_paid":"Toplam \u00d6denen","view_estimate_as_customer":"Tahmini M\u00fc\u015fteri Olarak G\u00f6r\u00fcnt\u00fcle"},"estimates":"Tahminler","expense":{"add":"Ekle","amount":"Miktar","amount_with_tax":"Vergili Tutar","apply_tax":"Vergi Uygula","apply_tax_message":"Tutardan Vergi toplam\u0131n\u0131 \u00e7\u0131kar","attachment":"Ek dosya","auto_create_invoice":"Otomatik Fatura Olu\u015ftur","billable":"Faturaland\u0131r\u0131labilir","choose_file":"Dosya se\u00e7in","currency":"Para birimi","customer":"M\u00fc\u015fteri","details":"ayr\u0131nt\u0131lar","edit_expense":"Gider D\u00fczenle","expense_amount":"Gider Tutar\u0131","expense_category":"Gider Kategorisi","expense_category_by_chart":"Grafi\u011fe G\u00f6re Gider Kategorisi","expense_date":"Gider Tarihi","expense_details":"Gider Ayr\u0131nt\u0131lar\u0131","expense_list":"Gider Listesi","expense_not_found":"Gider Bulunamad\u0131.","expense_saved_successfully":"Gider ba\u015far\u0131yla kaydedildi.","expense_updated_successfully":"Gider ba\u015far\u0131yla g\u00fcncellendi.","name":"ad","new_expense":"Yeni Gider","no_expense_available":"Masraf Yoktur.","no_expense_found":"Gider Bulunamad\u0131.","note":"Not","notes":"notlar","payment_mode":"\u00d6deme \u015fekli","preview_attachment":"Eki \u00d6nizle","receipt_attachment":"Makbuz Eki","reference":"Referans","reminders":"Hat\u0131rlatma","send_email":"Gider yeniden olu\u015fturuldu\u011funda faturay\u0131 m\u00fc\u015fterinin e-postas\u0131na g\u00f6nderin","tax_1":"Vergi 1 (% olarak)","tax_2":"Vergi 2 (% olarak)","tax_applied":"Uygulanan Vergi","view_attachment":"Eki g\u00f6r\u00fcnt\u00fcle"},"expense_by_category":"Kategoriye G\u00f6re Gider","expense_categories":"Gider Kategorileri","expense_category":{"add_new_expense_category":"Yeni Gider Kategorisi Ekle","edit_category":"Gider Kategorisini D\u00fczenle","expense_categories":"Gider Kategorileri","expense_category":"Gider Kategorisi","expense_category_saved_successfully":"Gider Kategorisi ba\u015far\u0131yla kaydedildi.","expense_category_updated_successfully":"Gider Kategorisi ba\u015far\u0131yla g\u00fcncellendi.","expense_category_used_somewhere_else":"Gider Kategorisi ba\u015fka bir yerde kullan\u0131ld\u0131.","new_category":"Yeni Gider Kategorisi"},"expenses":"Masraflar","general":"Genel","goal":{"achievement":"Kazan\u0131m","add":"Ekle","description":"A\u00e7\u0131klama","edit_goal":"Hedefi D\u00fczenleyin","end_date":"Biti\u015f tarihi","goal_details":"Hedef Ayr\u0131nt\u0131lar\u0131","goal_id":"Hedef T\u00fcr\u00fc","goal_saved_successfully":"Hedef ba\u015far\u0131yla kaydedildi.","goal_type":"Hedef T\u00fcr\u00fc","goal_updated_successfully":"Hedef ba\u015far\u0131yla g\u00fcncellendi.","is_not_notify":"Hedefe ula\u015f\u0131lamad\u0131\u011f\u0131nda personeli bilgilendirin","is_notify":"Hedefe ula\u015f\u0131ld\u0131\u011f\u0131nda personeli bilgilendirin","new_goal":"Yeni hedef","no_goal_available":"Mevcut Hedef Yok.","no_goal_found":"Hedef Bulunamad\u0131.","progress":"\u0130lerleme","staff_member":"Personel","start_date":"Ba\u015flang\u0131\u00e7 tarihi","subject":"konu","user_id":"Personel"},"goal_type":{"description":"A\u00e7\u0131klama","edit_goal_type":"Hedef T\u00fcr\u00fcn\u00fc D\u00fczenle","name":"ad","new_goal_type":"Yeni Hedef T\u00fcr\u00fc"},"goals":"Hedefler","incomes":"gelirler","invoice":{"activity_log":"Etkinlik G\u00fcnl\u00fc\u011f\u00fc","add_item":"\u00fcr\u00fcn ekle","add_shipping_address":"G\u00f6nderim adresi ekleyin","adjustment":"ayarlama","admin_note":"Y\u00f6netici Notu","allowed_payment_modes_for_this_invoice":"Bu Fatura \u0130\u00e7in \u0130zin Verilen \u00d6deme Modlar\u0131","amount":"Miktar","amount_due":"Alacak miktar\u0131","authorized_signature":"Yetkili imza","bank":"Banka","bill_tasks":"Bill G\u00f6revleri","bill_to":"ya fatura edilecek","cancelled":"\u0130PTAL ED\u0130LD\u0130","client_note":"M\u00fc\u015fteri Notu","currency":"Para birimi","customer":"M\u00fc\u015fteri","discount":"\u0130ndirim","discount_type":"\u0130ndirim Tipi","draft":"TASLAK","drafted":"Taslak","due_date":"Biti\u015f tarihi","edit_contract_type":"S\u00f6zle\u015fme T\u00fcr\u00fcn\u00fc D\u00fczenle","edit_invoice":"Faturay\u0131 D\u00fczenle","fixed":"Sabit","hours":"Saatler","hsn_tax":"HSN Vergi Kodu","invoice":"Fatura","invoice_date":"Fatura tarihi","invoice_details":"Fatura detaylar\u0131","invoice_not_found":"Fatura Bulunamad\u0131.","invoice_number":"Fatura numaras\u0131","invoice_overview":"FATURA GENEL BAKI\u015e","invoice_payments":"InvoiceFatura \u00d6demeleri","invoice_pdf":"Fatura PDF","invoice_prefix":"INV-","invoice_saved_successfully":"Fatura ba\u015far\u0131yla kaydedildi.","invoice_updated_successfully":"Fatura ba\u015far\u0131yla g\u00fcncellendi.","item":"\u00dcr\u00fcn","mark_as_cancelled":"\u0130ptal Edildi Olarak \u0130\u015faretle","mark_as_draft":"Taslak Olarak \u0130\u015faretle","mark_as_paid":"\u00d6dendi Olarak \u0130\u015faretle","mark_as_partially_paid":"K\u0131smen \u00d6dendi Olarak \u0130\u015faretle","mark_as_sent":"G\u00f6nderildi Olarak \u0130\u015faretle","more":"Daha","new_contract_type":"Yeni S\u00f6zle\u015fme T\u00fcr\u00fc","new_invoice":"Yeni fatura","no_invoice_available":"Fatura Yok.","no_invoice_found":"Fatura Bulunamad\u0131.","no_payments_available":"\u00d6deme yok","not_sent":"G\u00d6NDER\u0130LMED\u0130","notes":"notlar","offline_payment":"\u00c7evrimd\u0131\u015f\u0131 \u00d6deme","online_payment":"Online \u00f6deme","overdue":"S\u00dcRES\u0130 DOLDU","paid":"\u00f6denmi\u015f","paid_cap":"\u00dcCRETL\u0130","partially_paid":"K\u0131smen \u00f6denmi\u015f","partially_paid_cap":"KISMEN \u00d6DENM\u0130\u015e","pay_now":"\u015eimdi \u00f6de","payment":"\u00d6deme","payment_details":"\u00f6deme detaylar\u0131","payments":"\u00d6demeler","prevent_sending_overdue_reminders_for_this_invoice":"Bu fatura i\u00e7in s\u00fcresi ge\u00e7mi\u015f hat\u0131rlat\u0131c\u0131lar\u0131n g\u00f6nderilmesini \u00f6nleyin","qty":"Adet","qty\/hours":"Adet \/ Saat","qty_hours":"Adet \/ Saat","quick_invoices_info":"H\u0131zl\u0131 Fatura Bilgileri","reminders":"Hat\u0131rlatmalar","sale_agent":"Sat\u0131\u015f Temsilcisi","save_and_send":"Kaydet ve G\u00f6nder","save_as_draft":"Taslak olarak kaydet","ship_to":"Al\u0131c\u0131","show_quantity_as":"Miktar\u0131 \u015fu \u015fekilde g\u00f6ster:","sub_total":"Ara toplam","taxes":"Vergiler","terms_conditions":"\u015fartlar ve ko\u015fullar","title":"Ba\u015fl\u0131k","total":"Toplam","total_invoices":"Toplam Faturalar","total_paid":"Toplam \u00d6denen","transactions":"i\u015flemler","unmark_as_cancelled":"\u0130ptal Edildi Olarak \u0130\u015faretini Kald\u0131r","unpaid":"\u00f6denmemi\u015f","unpaid_cap":"\u00d6DENMEYEN","view_invoice_as_customer":"Faturay\u0131 M\u00fc\u015fteri Olarak G\u00f6r\u00fcnt\u00fcle"},"invoices":"Faturalar","kanban_list":"KANBAN Listesi","kanban_view":"KANBAN G\u00f6r\u00fcn\u00fcm","last_week_payments":"Ge\u00e7en Hafta \u00d6demeleri","lead":{"chart":"Grafik","contacted_today":"Bug\u00fcn ileti\u015fime ge\u00e7ildi","convert_to_customer":"M\u00fc\u015fteriye D\u00f6n\u00fc\u015ft\u00fcr","date_contacted":"\u0130leti\u015fim Tarihi","details":"ayr\u0131nt\u0131lar","edit_lead":"Potansiyel M\u00fc\u015fteriyi D\u00fczenle","estimate_budget":"Tahmini B\u00fct\u00e7e","lead_convert_customer":"Potansiyel M\u00fc\u015fteri D\u00f6n\u00fc\u015f\u00fcm\u00fc M\u00fc\u015fterisi","lead_convert_customer_chart":"Potansiyel M\u00fc\u015fteri D\u00f6n\u00fc\u015ft\u00fcrme M\u00fc\u015fteri Tablosu","lead_details":"Potansiyel M\u00fc\u015fteri Ayr\u0131nt\u0131lar\u0131","lead_list":"Kur\u015fun Listesi","lead_not_found":"Kur\u015fun Bulunamad\u0131.","lead_saved_successfully":"M\u00fc\u015fteri aday\u0131 ba\u015far\u0131yla kaydedildi.","lead_status_updated_successfully":"M\u00fc\u015fteri aday\u0131 durumu ba\u015far\u0131yla g\u00fcncellendi.","lead_updated_successfully":"M\u00fc\u015fteri aday\u0131 ba\u015far\u0131yla g\u00fcncellendi.","leads_overview":"Potansiyel M\u00fc\u015fterilere Genel Bak\u0131\u015f","member":"\u00dcye","name":"ad","new_lead":"Yeni Kur\u015fun","no_lead_available":"Kullan\u0131labilir Kur\u015fun Yok.","no_lead_found":"Kur\u015fun Bulunamad\u0131.","notes":"notlar","reminder":"Hat\u0131rlatma","source":"Kaynak"},"lead_convert_to_customer":"M\u00fc\u015fteri Aday\u0131na D\u00f6n\u00fc\u015ft\u00fcr","lead_source":{"add":"Ekle","edit_lead_source":"Potansiyel M\u00fc\u015fteri Kayna\u011f\u0131n\u0131 D\u00fczenle","lead_source_count":"Kur\u015fun say\u0131s\u0131","lead_source_not_found":"Potansiyel M\u00fc\u015fteri Kayna\u011f\u0131 Bulunamad\u0131.","lead_source_saved_successfully":"M\u00fc\u015fteri Kayna\u011f\u0131 ba\u015far\u0131yla kaydedildi.","lead_source_updated_successfully":"Lead Source ba\u015far\u0131yla g\u00fcncellendi.","name":"ad","new_lead_source":"Yeni Potansiyel M\u00fc\u015fteri Kayna\u011f\u0131","no_lead_source_available":"Kullan\u0131labilir Kur\u015fun Kayna\u011f\u0131 Yok.","no_lead_source_found":"Potansiyel M\u00fc\u015fteri Kayna\u011f\u0131 Bulunamad\u0131."},"lead_sources":"Olas\u0131 Sat\u0131\u015f Kaynaklar\u0131","lead_status":{"add":"Ekle","add_new_lead_status":"Yeni M\u00fc\u015fteri Aday\u0131 Durumu Ekle","color":"Renk","edit_lead_status":"Potansiyel M\u00fc\u015fteri Durumunu D\u00fczenle","lead_status":"Potansiyel M\u00fc\u015fteri Durumu","lead_status_saved_successfully":"M\u00fc\u015fteri Aday\u0131 Durumu ba\u015far\u0131yla kaydedildi.","lead_status_updated_successfully":"M\u00fc\u015fteri Aday\u0131 Durumu ba\u015far\u0131yla g\u00fcncellendi.","lead_status_used_somewhere_else":"Lead Durumu ba\u015fka bir yerde kullan\u0131ld\u0131.","name":"ad","new_lead_status":"Yeni Potansiyel M\u00fc\u015fteri Durumu","order":"Sipari\u015f"},"leads":"\u0130lanlar","list_view":"Listesi G\u00f6r\u00fcn\u00fcm","login":{"admin":"Y\u00f6netici","client":"M\u00fc\u015fteri","create_one":"Bir tane yarat","don't have an account":"Hesab\u0131n yok mu?","email":"E-posta","forgot_password":"Parolan\u0131z\u0131 m\u0131 unuttunuz","login":"Oturum a\u00e7","password":"Parola","remember_me":"Beni hat\u0131rla"},"member":{"add":"Ekle","by_deleting_this_member":"Bu \u00fcye silindi\u011finde t\u00fcm projesi, teklifi ve hedefi silinecektir.","choose":"Se\u00e7","created_on":"Olu\u015fturulma Tarihi","default_language":"Varsay\u0131lan dil","delete_member_confirm":"Bu \u00fcyeyi silmek istedi\u011finizden emin misiniz?","edit_member":"\u00dcyeyi D\u00fczenle","email":"E-posta","email_is_not_verified":"E-posta teyit edilmedi","email_is_verified":"E-posta do\u011fruland\u0131","email_verified":"E-posta Do\u011fruland\u0131","email_verified_successfully":"E-posta Ba\u015far\u0131yla Do\u011fruland\u0131.","email_verify":"E-posta Do\u011frulama","facebook":"Facebook","first_name":"\u0130sim","hourly_rate":"Saatlik \u00fccret","image":"Profil","is_administrator":"y\u00f6netici","is_enable":"\u0130ki Fakt\u00f6rl\u00fc Kimlik Do\u011frulamay\u0131 Etkinle\u015ftir","last_name":"Soyad\u0131","linkedin":"Linkedin","member_details":"\u00dcye Ayr\u0131nt\u0131lar\u0131","member_informations":"\u00fcye bilgisi","member_not_found":"\u00dcye bulunamad\u0131.","member_saved_successfully":"\u00dcye ba\u015far\u0131yla kaydedildi.","member_security":"\u00dcye G\u00fcvenli\u011fi","member_status_updated_successfully":"\u00dcye durumu ba\u015far\u0131yla g\u00fcncellendi.","member_updated_successfully":"\u00dcye ba\u015far\u0131yla g\u00fcncellendi.","new_member":"Yeni \u00dcye","no_member_available":"Mevcut \u00dcye Yok.","no_member_found":"\u00dcye Bulunamad\u0131.","password":"Parola","password_confirmation":"\u015eifreyi Onayla","permissions":"\u0130zinler","phone":"Telefon","profile":"Profil","resend_email_verification":"E-posta Do\u011frulamay\u0131 Yeniden G\u00f6nder","send_welcome_email":"Kar\u015f\u0131lama e-postas\u0131 g\u00f6nder","skype":"Skype","staff_member":"Personel \u00dcyesi De\u011fil","total_members":"Toplam \u00dcye","verification_mail_has_been_sent":"Do\u011frulama e-postas\u0131 ba\u015far\u0131yla g\u00f6nderildi."},"members":"\u00dcyeler","menu_settings":"Men\u00fc Ayarlar\u0131","months":{"apr":"Nisan","aug":"a\u011fustos","dec":"Aral\u0131k","feb":"\u015eubat","jan":"Ocak","jul":"Temmuz","jun":"Haziran","mar":"Mart","may":"May\u0131s","nov":"kas\u0131m","oct":"Ekim","sep":"Eyl\u00fcl"},"new_language":"Yeni dil","no_matching_records_found":"Hi\u00e7bir e\u015fle\u015fen kay\u0131t bulunamad\u0131","note":{"add_note":"Not ekle","edit_note":"Notu D\u00fczenle","new_note":"Yeni Not","no_notes_added_yet":"Hen\u00fcz Not Eklenmemi\u015f","notes_saved_successfully":"Not ba\u015far\u0131yla kaydedildi.","notes_updated_successfully":"Not ba\u015far\u0131yla g\u00fcncellendi."},"notes":"notlar","notification":{"all_notification_read_successfully":"T\u00fcm Bildirimler ba\u015far\u0131yla okundu.","empty_notifications":"Herhangi bir bildirim bulamad\u0131k","mark_all_as_read":"T\u00fcm\u00fcn\u00fc Okundu Olarak \u0130\u015faretle","notification_read_successfully":"Bildirim ba\u015far\u0131yla okundu.","notifications":"Bildirimler"},"others":"Di\u011ferleri","payment":{"amount":"Miktar","amount_received":"Al\u0131nan Miktar","date":"tarih","new_payment":"Yeni \u00d6deme","note":"Not","payment_date":"\u00d6deme tarihi","payment_mode":"\u00d6deme \u015fekli","payment_saved_successfully":"\u00d6deme ba\u015far\u0131yla kaydedildi.","send_mail_to_customer_contacts":"Fatura \u00f6demesi kaydedilmi\u015f e-postay\u0131 m\u00fc\u015fteri irtibatlar\u0131na g\u00f6ndermeyin","transaction_id":"\u0130\u015flem Kimli\u011fi","your_payment_is_completed":"\u00d6demeniz ba\u015far\u0131yla tamamland\u0131.","your_payment_is_ont_completed":"\u00d6demeniz tamamlanmad\u0131."},"payment_mode":{"active":"Aktif","add_new_payment_mode":"Yeni \u00d6deme Modu Ekle","bank_accounts":"Banka hesab\u0131","edit_payment_mode":"\u00d6deme Modunu D\u00fczenle","expenses_only":"Yaln\u0131zca giderler","invoices_only":"Yaln\u0131zca faturalar","new_payment_mode":"Yeni \u00d6deme Modu","no_payment_mode_available":"\u00d6deme Modu Mevcut De\u011fil.","no_payment_mode_found":"\u00d6deme Modu Bulunamad\u0131.","on_invoice_pdf":"Faturada PDF","payment_mode_details":"\u00d6deme Modu Ayr\u0131nt\u0131lar\u0131","payment_mode_not_found":"\u00d6deme Modu Bulunamad\u0131.","payment_mode_saved_successfully":"\u00d6deme Modu ba\u015far\u0131yla kaydedildi.","payment_mode_updated_successfully":"\u00d6deme Modu ba\u015far\u0131yla g\u00fcncellendi.","payment_mode_used_somewhere_else":"\u00d6deme Modu ba\u015fka bir yerde kullan\u0131ld\u0131.","selected_by_default_on_invoice":"Faturada varsay\u0131lan olarak se\u00e7ilir","show":"G\u00f6stermek"},"payment_modes":"\u00d6deme Modlar\u0131","placeholder":{"add_note":"Not ekle...","add_product":"\u00fcr\u00fcn ekle","bill_tasks":"Fatura G\u00f6revleri","contact_number_is_invalid_number":"\u0130leti\u015fim numaras\u0131 ge\u00e7ersiz numara","enter_email":"E-posta Girin","invalid_country_code":"Ge\u00e7ersiz \u00fclke kodu","invalid_number":"Ge\u00e7ersiz numara","search_customers":"M\u00fc\u015fteri Ara","search_menu":"Arama Men\u00fcs\u00fc","select_article_group":"Makale Grubu Se\u00e7in","select_assignee":"Atanan Se\u00e7","select_billing_type":"Faturaland\u0131rma T\u00fcr\u00fcn\u00fc Se\u00e7in","select_contact":"Ki\u015fileri Se\u00e7in","select_contract_type":"S\u00f6zle\u015fme T\u00fcr\u00fcn\u00fc Se\u00e7in","select_country":"\u00dclke Se\u00e7","select_currency":"Para birimini se\u00e7in","select_customer":"M\u00fc\u015fteri Se\u00e7","select_department":"Departman Se\u00e7in","select_discount_type":"\u0130ndirim T\u00fcr\u00fcn\u00fc Se\u00e7in","select_document_type":"\u0130ndirim t\u00fcr\u00fcn\u00fc se\u00e7in","select_email_status":"E-posta Durumunu Se\u00e7in","select_email_template":"E-posta \u015eablonu Se\u00e7in","select_expanse_category":"Gider Kategorisini Se\u00e7in","select_file":"Dosya Se\u00e7","select_goal":"Hedef Se\u00e7","select_goal_type":"Hedef T\u00fcr\u00fc Se\u00e7in","select_group":"Gruplar\u0131 Se\u00e7in","select_groups":"Gruplar\u0131 Se\u00e7in","select_internal_article":"Dahili Makaleyi Se\u00e7in","select_item":"\u00d6\u011feyi se\u00e7in","select_language":"Dil Se\u00e7in","select_lead":"M\u00fc\u015fteri Aday\u0131 Se\u00e7","select_lead_source":"M\u00fc\u015fteri Aday\u0131 Kayna\u011f\u0131n\u0131 Se\u00e7in","select_member":"\u00dcye Se\u00e7","select_option":"Se\u00e7enek Se\u00e7","select_payment_mode":"\u00d6deme Modunu Se\u00e7in","select_predefined_reply":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t\u0131 Se\u00e7in","select_priority":"\u00d6ncelik Se\u00e7","select_product":"\u00dcr\u00fcn\u00fc se\u00e7","select_product_group":"\u00dcr\u00fcn Grubu Se\u00e7in","select_reminder_to":"Hat\u0131rlat\u0131c\u0131 Se\u00e7in","select_sale_agent":"Sat\u0131\u015f Temsilcisini Se\u00e7in","select_service":"Hizmet Se\u00e7in","select_show_to_client":"M\u00fc\u015fteriye G\u00f6ster'i se\u00e7in","select_source":"Kaynak Se\u00e7","select_status":"Durum Se\u00e7,","select_tags":"Etiketleri Se\u00e7","select_tax":"Vergi se\u00e7in","select_tax1":"Vergi 1'i se\u00e7in","select_tax2":"Vergi 2'yi se\u00e7in","select_template_type":"\u015eablon T\u00fcr\u00fcn\u00fc Se\u00e7in","select_ticket_priority":"Bilet \u00d6nceli\u011fini Se\u00e7in","too_long":"\u00c7ok uzun","too_short":"\u00c7ok k\u0131sa","valid_number":"Ge\u00e7erli numara"},"please_enter_language_short_code":"L\u00fctfen dil k\u0131sa kodunu girin. yani \u0130ngilizce = en.","predefined_replies":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Cevaplar","predefined_reply":{"add":"Ekle","add_new_predefined_reply":"Yeni \u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t Ekle","body":"V\u00fccut","edit_predefined_reply":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t\u0131 D\u00fczenle","new_predefined_reply":"Yeni \u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t","no_predefined_reply_available":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t Yok.","no_predefined_reply_found":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t Bulunamad\u0131.","predefined_reply_details":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t Ayr\u0131nt\u0131lar\u0131","predefined_reply_not_found":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t Bulunamad\u0131.","predefined_reply_saved_successfully":"\u00d6nceden Tan\u0131ml\u0131 Yan\u0131t ba\u015far\u0131yla kaydedildi.","predefined_reply_updated_successfully":"\u00d6nceden Tan\u0131ml\u0131 Yan\u0131t ba\u015far\u0131yla g\u00fcncellendi.","reply_name":"Cevap Ad\u0131"},"product_group":{"add_new_product_group":"Yeni \u00dcr\u00fcn Grubu Ekle","edit_product_group":"\u00dcr\u00fcn Grubunu D\u00fczenle","new_product_group":"Yeni \u00dcr\u00fcn Grubu","product_group_saved_successfully":"\u00dcr\u00fcn Grubu ba\u015far\u0131yla kaydedildi.","product_group_updated_successfully":"\u00dcr\u00fcn Grubu ba\u015far\u0131yla g\u00fcncellendi.","product_group_used_somewhere_else":"\u00dcr\u00fcn Grubu ba\u015fka bir yerde kullan\u0131lm\u0131\u015f."},"product_groups":"\u00dcr\u00fcn Gruplar\u0131","products":{"edit_product":"\u00dcr\u00fcn\u00fc D\u00fczenle","new_product":"Yeni \u00fcr\u00fcn","product_group":"\u00dcr\u00fcn grubu","product_saved_successfully":"\u00dcr\u00fcn ba\u015far\u0131yla kaydedildi.","product_updated_successfully":"\u00dcr\u00fcn ba\u015far\u0131yla g\u00fcncellendi.","products":"\u00dcr\u00fcn:% s","rate":"oran","tax":"Vergi","title":"Ba\u015fl\u0131k","unit":"birim"},"profile":"Profil","project":{"admin_area":"y\u00f6netici alan\u0131","allow_customer_to":"M\u00fc\u015fterinin yapmas\u0131na izin ver","billing_type":"Fatura T\u00fcr\u00fc","calculate_progress_through_tasks":"G\u00f6revler boyunca ilerlemeyi hesaplay\u0131n","cancelled":"\u0130ptal edildi","comment_on_project_tasks":"proje g\u00f6revleri hakk\u0131nda yorum yap","create_tasks":"g\u00f6revler olu\u015ftur","customer":"M\u00fc\u015fteri","deadline":"Son tarih","edit_project":"Projeyi D\u00fczenle","edit_tasks":"g\u00f6revleri d\u00fczenle","estimated_hours":"Tahmini Saatler","finished":"bitmi\u015f","hide_project_tasks_on_main_tasks_table":"ana g\u00f6revler tablosundaki proje g\u00f6revlerini gizle","in_progress":"Devam etmekte","members":"\u0130leti\u015fim","new_project":"Yeni proje","no_project_available":"Kullan\u0131labilir Proje Yok","no_project_found":"Proje Bulunamad\u0131","not_started":"Ba\u015flat\u0131lmad\u0131","on_hold":"Beklemede","only_task_created_from_contact":"yaln\u0131zca ki\u015fiden olu\u015fturulan g\u00f6rev","open_discussions":"a\u00e7\u0131k tart\u0131\u015fmalar","progress":"\u0130lerleme","project_details":"Proje detaylar\u0131","project_name":"proje Ad\u0131","project_saved_successfully":"Proje ba\u015far\u0131yla kaydedildi.","project_settings":"Proje ayarlar\u0131","project_updated_successfully":"Proje ba\u015far\u0131yla g\u00fcncellendi.","projects_summary":"Proje \u00d6zeti","quick_invoices_info":"H\u0131zl\u0131 Fatura Bilgileri","send_project_created_email":"Proje olu\u015fturulmu\u015f e-postay\u0131 g\u00f6nder","start_date":"Ba\u015flang\u0131\u00e7 tarihi","statistics_by_project_status":"Proje Durumuna G\u00f6re \u0130statistikler","status":"durum","total_projects":"Toplam Proje","upload_attachments_on_tasks":"ekleri g\u00f6revlere y\u00fckle","upload_files":"dosyalar\u0131 y\u00fckle","view_account_statement":"Hesap \u00d6zetini G\u00f6r\u00fcnt\u00fcle","view_activity_log":"etkinlik g\u00fcnl\u00fc\u011f\u00fcn\u00fc g\u00f6r\u00fcnt\u00fcle","view_finance_overview":"finansa genel bak\u0131\u015f\u0131 g\u00f6r\u00fcnt\u00fcle","view_gantt":"Gantt'\u0131 g\u00f6r\u00fcnt\u00fcle","view_milestones":"kilometre ta\u015flar\u0131n\u0131 g\u00f6r\u00fcnt\u00fcle","view_task_attachments":"g\u00f6rev eklerini g\u00f6r\u00fcnt\u00fcle","view_task_checklist_items":"g\u00f6rev kontrol listesi \u00f6\u011felerini g\u00f6r\u00fcnt\u00fcle","view_task_comments":"g\u00f6rev yorumlar\u0131n\u0131 g\u00f6r\u00fcnt\u00fcle","view_task_total_logged_time":"g\u00f6revin toplam kaydedilme s\u00fcresini g\u00f6r\u00fcnt\u00fcle","view_tasks":"g\u00f6revleri g\u00f6r\u00fcnt\u00fcle","view_team_members":"ekip \u00fcyelerini g\u00f6r\u00fcnt\u00fcle","view_timesheets":"zaman \u00e7izelgelerini g\u00f6r\u00fcnt\u00fcle","visible_tables":"G\u00f6r\u00fcn\u00fcr Tablolar"},"projects":"Projeler","proposal":{"accept":"KABUL ETMEK","accepted":"KABUL ED\u0130LM\u0130\u015e","adjustment":"ayarlama","amount":"Miktar","amount_due":"Alacak miktar\u0131","authorized_signature":"Yetkili imza","bank":"Banka","bill_to":"Ya fatura edilecek","comments":"Yorumlar","convert":"D\u00f6n\u00fc\u015ft\u00fcrmek","convert_proposal":"Teklifi D\u00f6n\u00fc\u015ft\u00fcr","date":"tarih","decline":"REDDET","declined":"REDDED\u0130LD\u0130","discount":"\u0130ndirim","draft":"TASLAK","drafted":"Taslak","edit_proposal":"Teklifi D\u00fczenle","item":"\u00dcr\u00fcn","lead":"\u00d6nc\u00fcl\u00fck etmek","mark_as_accepted":"Kabul Edildi Olarak \u0130\u015faretle","mark_as_declined":"Reddedildi Olarak \u0130\u015faretle","mark_as_draft":"Taslak Olarak \u0130\u015faretle","mark_as_open":"A\u00e7\u0131k Olarak \u0130\u015faretle","mark_as_revised":"G\u00f6zden Ge\u00e7irilmi\u015f Olarak \u0130\u015faretle","mark_as_send":"G\u00f6nder Olarak \u0130\u015faretle","member":"\u00dcye","new_proposal":"Yeni teklif","no_payments_available":"\u00d6deme Yok","no_proposal_available":"Mevcut Teklif Yok.","no_proposal_found":"Teklif Bulunamad\u0131.","offline_payment":"\u00c7evrimd\u0131\u015f\u0131 \u00d6deme","online_payment":"Online \u00f6deme","open":"A\u00c7IK","open_till":"A\u00e7\u0131k","pay_now":"\u015e\u0130MD\u0130 \u00d6DE","payment":"\u00d6deme","proposal":"\u00f6neri","proposal_date":"Teklif Tarihi","proposal_details":"Teklif Ayr\u0131nt\u0131lar\u0131","proposal_not_found":"Teklif Bulunamad\u0131.","proposal_number":"Teklif Numaras\u0131","proposal_overview":"TEKL\u0130FE GENEL BAKI\u015e","proposal_pdf":"Teklif PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"Teklif ba\u015far\u0131yla kaydedildi.","proposal_to":"Teklif Verme","proposal_updated_successfully":"Teklif ba\u015far\u0131yla g\u00fcncellendi.","qty":"Adet","rate":"oran","related":"\u0130li\u015fkili","revised":"REV\u0130ZE","save_and_send":"Kaydet ve G\u00f6nder","save_as_draft":"Taslak Olarak Kaydet","sent":"G\u00d6NDER\u0130LD\u0130","ship_to":"Al\u0131c\u0131","status":"Teklif Durumu","sub_total":"Ara toplam","subject":"konu","taxes":"Vergiler","to":"i\u00e7in","total":"Toplam","total_paid":"Toplam \u00d6denen","total_proposal":"Toplam Teklif","transactions":"i\u015flemler","view_proposal_as_customer":"Teklifi M\u00fc\u015fteri Olarak G\u00f6r\u00fcnt\u00fcle"},"proposals":"Teklif","range":{"last_30":"Son 30 g\u00fcn","last_month":"Ge\u00e7en ay","last_week":"Ge\u00e7en hafta","this_month":"Bu ay","this_week":"Bu hafta","today":"Bug\u00fcn"},"register":{"already_have_an_account":"Zaten hesab\u0131n\u0131z var m\u0131?","choose":"Se\u00e7","confirm_password":"\u015eifreyi Onayla","email":"E-posta","first_name":"\u0130sim","last_name":"Soyad\u0131","password":"Parola","phone":"Telefon","profile_picture":"Profil foto\u011fraf\u0131","register":"Kay\u0131t ol","sign_in":"Oturum a\u00e7"},"reminder":{"add_new":"Yeni ekle","description":"A\u00e7\u0131klama","edit_reminder":"Hat\u0131rlat\u0131c\u0131y\u0131 D\u00fczenle","email_status":"E-posta Durumu","is_notified":"Bildirildi","new_reminder":"Yeni Hat\u0131rlatma","no":"Numara","note":"Not","note_text":"L\u00fctfen UTC saatine g\u00f6re hat\u0131rlat\u0131c\u0131 g\u00f6nderen cron i\u015fleri olarak UTC tarih saatini se\u00e7meniz gerekti\u011fini unutmay\u0131n.","notified_date":"Bildirim tarihi","reminder_saved_successfully":"Hat\u0131rlat\u0131c\u0131 ba\u015far\u0131yla kaydedildi.","reminder_to":"Hat\u0131rlat\u0131c\u0131","reminder_updated_successfully":"Hat\u0131rlat\u0131c\u0131 ba\u015far\u0131yla g\u00fcncellendi.","send_email_reminder":"Hat\u0131rlatma E-postas\u0131 G\u00f6nder","sent":"G\u00f6nderilmi\u015f","set_reminder":"Hat\u0131rlat\u0131c\u0131y\u0131 Kur","ticket_reminder":"Bilet Hat\u0131rlat\u0131c\u0131lar\u0131","yes":"Evet"},"reminders":"Hat\u0131rlatmalar","reset":{"confirm_password":"\u015eifreyi Onayla","email":"E-posta","password":"Parola","recalled_your_login_info":"Giri\u015f bilgilerinizi hat\u0131rlad\u0131n\u0131z m\u0131?","reset_password":"\u015eifreyi yenile","set_a_new_password":"Yeni Parola Belirleyin","sign_in":"Oturum a\u00e7"},"sales":"Sat\u0131\u015f","service":{"add":"Ekle","edit_service":"Hizmeti D\u00fczenle","name":"ad","new_service":"Yeni Hizmet","no_service_available":"Kullan\u0131labilir Hizmet Yok.","no_service_found":"Hizmet Bulunamad\u0131.","service_not_found":"Servis bulunamad\u0131.","service_saved_successfully":"Hizmet ba\u015far\u0131yla kaydedildi.","service_updated_successfully":"Hizmet ba\u015far\u0131yla g\u00fcncellendi.","service_used_somewhere_else":"Servis ba\u015fka bir yerde kullan\u0131ld\u0131."},"services":"Hizmetler","setting":{"application_name":"Uygulama Ad\u0131","choose":"Se\u00e7","current_version":"\u015eimdiki versiyonu","favicon":"favicon","file_type":"Dosya tipi","logo":"\u015eirket logosu","setting_updated_successfully":"Ayar ba\u015far\u0131yla g\u00fcncellendi."},"settings":"Ayarlar","staff":"Personel","status":{"additional_contact":"Ek Ki\u015fi","answered":"Yan\u0131tlanan","attempted":"Denendi","cancelled":"\u0130ptal edildi","closed":"Kapal\u0131","contacted":"\u0130leti\u015fim","finished":"bitmi\u015f","in_progress":"Devam etmekte","new_opportunity":"Yeni f\u0131rsat","not_attempted":"Kalk\u0131\u015fmad\u0131","not_started":"Ba\u015flat\u0131lmad\u0131","on_hold":"Beklemede","open":"A\u00e7\u0131k"},"success":"Ba\u015far\u0131","support":"Destek","tag":{"add":"Ekle","add_new_tag":"Yeni Etiket Ekle","description":"A\u00e7\u0131klama","edit_tag":"Etiketi d\u00fczenle","name":"ad","new_tag":"Yeni Etiket","no_tag_available":"Mevcut Etiket Yok.","no_tag_found":"Etiket Bulunamad\u0131.","tag_details":"Etiket Ayr\u0131nt\u0131lar\u0131","tag_not_found":"Etiket Bulunamad\u0131.","tag_saved_successfully":"Etiket ba\u015far\u0131yla kaydedildi.","tag_updated_successfully":"Etiket ba\u015far\u0131yla g\u00fcncellendi."},"tags":"Etiketler","task":{"awaiting_feedback":"Geri d\u00f6n\u00fc\u015f bekleniyor","billable":"Faturaland\u0131r\u0131labilir","completed":"Tamamland\u0131","due_date":"Biti\u015f tarihi","edit_task":"G\u00f6revi D\u00fczenle","hourly_rate":"Saatlik \u00fccret","in_progress":"Devam etmekte","name":"ad","new_task":"Yeni g\u00f6rev","no_task_available":"Kullan\u0131labilir G\u00f6rev Yok.","not_started":"Ba\u015flat\u0131lmad\u0131","priority":"\u00f6ncelik","public":"halka a\u00e7\u0131k","related_to":"\u0130le ilgili","start_date":"Ba\u015flang\u0131\u00e7 tarihi","status":"durum","subject":"konu","task_details":"G\u00f6rev Ayr\u0131nt\u0131lar\u0131","task_saved_successfully":"G\u00f6rev ba\u015far\u0131yla kaydedildi.","task_status_updated_successfully":"G\u00f6rev durumu ba\u015far\u0131yla g\u00fcncellendi.","task_updated_successfully":"G\u00f6rev ba\u015far\u0131yla g\u00fcncellendi.","testing":"Test yapmak","ticket":"Bilet"},"tasks":"G\u00f6revler","tax_rate":{"edit_tax_rate":"Vergi Oran\u0131n\u0131 D\u00fczenle","new_tax_rate":"Yeni Vergi Oran\u0131","no_tax_rate_available":"Vergi Oran\u0131 Yok.","no_tax_rate_found":"Vergi Oran\u0131 Bulunamad\u0131.","tax_rate":"Vergi Oran\u0131","tax_rate_not_found":"Vergi Oran\u0131 Bulunamad\u0131.","tax_rate_saved_successfully":"Vergi Oran\u0131 ba\u015far\u0131yla kaydedildi.","tax_rate_updated_successfully":"Vergi Oran\u0131 ba\u015far\u0131yla g\u00fcncellendi."},"tax_rates":"Vergi oranlar\u0131","this_week_payments":"Bu Hafta \u00d6demeler","ticket":{"add":"Ekle","added_by":"Taraf\u0131ndan eklendi","assign_to":"Atamak","attachments":"Ekler","body":"V\u00fccut","cc":"CC","contact":"\u0130leti\u015fim","department":"B\u00f6l\u00fcm","details":"ayr\u0131nt\u0131lar","edit_ticket":"Bileti D\u00fczenle","email":"E-posta","name":"ad","new_ticket":"Yeni Bilet","no_ticket_available":"Kullan\u0131labilir Bilet Yok.","no_ticket_found":"Bilet Bulunamad\u0131.","note":"Not","predefined_reply":"\u00d6nceden Tan\u0131mlanm\u0131\u015f Yan\u0131t","priority":"\u00f6ncelik","reminder":"Hat\u0131rlatma","service":"Hizmet","subject":"konu","tags":"Etiketler","ticket_details":"Bilet Detaylar\u0131","ticket_not_found":"Bilet Bulunamad\u0131.","ticket_saved_successfully":"Bilet ba\u015far\u0131yla kaydedildi.","ticket_status_updated_successfully":"Bilet durumu ba\u015far\u0131yla g\u00fcncellendi.","ticket_to_contact":"\u0130leti\u015fim i\u00e7in Bilet","ticket_updated_successfully":"Bilet ba\u015far\u0131yla g\u00fcncellendi.","ticket_without_contact":"Temass\u0131z Bilet","tickets_status":"Bilet Durumu","you_can_add_multiples_images_and_files":"Birden fazla resim ve dosya ekleyebilirsiniz"},"ticket_priorities":"Bilet \u00d6nceli\u011fi","ticket_priority":{"add":"Ekle","add_new_ticket_priority":"Yeni Bilet \u00d6nceli\u011fi Ekle","edit_ticket_priority":"Bilet \u00d6nceli\u011fini D\u00fczenle","name":"ad","new_ticket_priority":"Yeni Bilet \u00d6nceli\u011fi","no_ticket_priority_available":"Bilet \u00d6nceli\u011fi Yok.","no_ticket_priority_found":"Bilet \u00d6nceli\u011fi Bulunamad\u0131.","ticket_priority_not_found":"Bilet \u00d6nceli\u011fi Bulunamad\u0131.","ticket_priority_saved_successfully":"Bilet \u00d6nceli\u011fi ba\u015far\u0131yla kaydedildi.","ticket_priority_updated_successfully":"Bilet \u00d6nceli\u011fi ba\u015far\u0131yla g\u00fcncellendi.","ticket_priority_used_somewhere_else":"Bilet \u00d6nceli\u011fi ba\u015fka bir yerde kullan\u0131ld\u0131."},"ticket_status":{"add":"Ekle","add_new_ticket_status":"Yeni Bilet Durumu Ekle","color":"Renk","edit_ticket_status":"Bilet Durumunu D\u00fczenle","name":"ad","new_ticket_status":"Yeni Bilet Durumu","status_order":"Durum S\u0131ras\u0131","ticket_status":"Bilet Durumu","ticket_status_saved_successfully":"Bilet Durumu ba\u015far\u0131yla kaydedildi.","ticket_status_updated_successfully":"Bilet Durumu ba\u015far\u0131yla g\u00fcncellendi.","ticket_status_used_somewhere_else":"Bilet Durumu ba\u015fka bir yerde kullan\u0131lm\u0131\u015f."},"tickets":"Biletler","translation_manager":"\u00c7eviri Y\u00f6neticisi","translator_manager":{"edit_language":"Dili D\u00fczenle","language_added_successfully":"Dil ba\u015far\u0131yla eklendi.","language_short_code":"L\u00fctfen dil k\u0131sa kodunu girin. yani \u0130ngilizce = tr","language_updated_successfully":"Dil Ba\u015far\u0131yla G\u00fcncellendi.","translation":"Terc\u00fcme"},"user":{"change_language":"Dili de\u011fi\u015ftir","change_password":"\u015eifre de\u011fi\u015ftir","edit_profile":"Profili D\u00fczenle","email":"E-posta","first_name":"\u0130sim","language":"Dil","language_updated_successfully":"Dil ba\u015far\u0131yla g\u00fcncellendi.","last_name":"Soyad\u0131","logout":"\u00c7\u0131k\u0131\u015f Yap","name":"ad","password":"Parola","password_confirmation":"\u015eifreyi Onayla","password_updated_successfully":"\u015eifre ba\u015far\u0131yla g\u00fcncellendi.","phone":"Telefon","profile":"Profil","profile_updated_successfully":"Profil ba\u015far\u0131yla g\u00fcncellendi.","return_to_admin":"Y\u00f6neticiye D\u00f6n"},"users":"Kullan\u0131c\u0131lar","weekdays":{"fri":"Cuma","mon":"AY","sat":"Oturdu","sun":"G\u00dcNE\u015e","thu":"PHU","tue":"sal","wed":"EVLENMEK"}},"tr.pagination":{"next":"Sonraki &raquo;","previous":"&laquo; \u00d6nceki"},"tr.passwords":{"reset":"\u015eifreniz s\u0131f\u0131rland\u0131!","sent":"\u015eifre s\u0131f\u0131rlama ba\u011flant\u0131n\u0131z\u0131 e-postayla g\u00f6nderdik!","throttled":"L\u00fctfen tekrar denemeden \u00f6nce bekleyin.","token":"Bu \u015fifre s\u0131f\u0131rlama kodu ge\u00e7ersiz.","user":"Bu e-posta adresine sahip bir kullan\u0131c\u0131 bulam\u0131yoruz."},"tr.validation":{"accepted":":attribute kabul edilmelidir.","active_url":":attribute ge\u00e7erli bir URL de\u011fil.","after":":attribute, tarihinden sonraki bir tarih olmal\u0131d\u0131r :date.","after_or_equal":":attribute , tarihten sonraki tarih veya ona e\u015fit bir olmal\u0131d\u0131r :tarih .","alpha":":attribute yaln\u0131zca harf i\u00e7erebilir.","alpha_dash":":attribute yaln\u0131zca harf, rakam, tire ve alt \u00e7izgi i\u00e7erebilir.","alpha_num":":attribute yaln\u0131zca harf ve rakam i\u00e7erebilir.","array":":attribute bir dizi olmal\u0131d\u0131r.","attributes":[],"before":":attribute \u00f6nce bir olmal\u0131d\u0131r :date .","before_or_equal":":attribute \u00f6nce veya ona e\u015fit bir olmal\u0131d\u0131r :date .","between":{"array":":attribute:min ve:max \u00f6\u011feler aras\u0131nda olmal\u0131d\u0131r.","file":":attribute:min ve:max kilobayt aras\u0131nda olmal\u0131d\u0131r.","numeric":":attribute:min ve:max aras\u0131nda olmal\u0131d\u0131r.","string":":attribute:min ve:max karakter aras\u0131nda olmal\u0131d\u0131r."},"boolean":":attribute alan\u0131 do\u011fru veya yanl\u0131\u015f olmal\u0131d\u0131r.","confirmed":":attribute onay\u0131 e\u015fle\u015fmiyor.","custom":{"attribute-name":{"rule-name":"\u00f6zel mesaj"}},"date":":attribute ge\u00e7erli bir tarih de\u011fil.","date_equals":":attribute, e\u015fit bir olmal\u0131d\u0131r:tarih .","date_format":":attribute e\u015fle\u015fmiyor bi\u00e7im:format.","different":":attribute ve:other farkl\u0131 olmal\u0131d\u0131r.","digits":":attribute \u015fu olmal\u0131d\u0131r:digits basamak.","digits_between":":attribute:min ve:max basamak aras\u0131nda olmal\u0131d\u0131r.","dimensions":":attribute resim boyutlar\u0131 ge\u00e7ersiz.","distinct":":attribute alan\u0131 yinelenen bir de\u011fere sahip.","email":":attribute ge\u00e7erli bir e-posta adresi olmal\u0131d\u0131r.","ends_with":":attribute a\u015fa\u011f\u0131dakilerden biriyle bitmelidir:values.","exists":"Se\u00e7ilen:attribute ge\u00e7ersiz.","file":":attribute bir dosya olmal\u0131d\u0131r.","filled":":attribute alan\u0131n\u0131n bir de\u011feri olmal\u0131d\u0131r.","gt":{"array":":attribute birden fazla :de\u011ferine sahip olmal\u0131d\u0131r.","file":":attribute \u015fu de\u011ferden b\u00fcy\u00fck olmal\u0131d\u0131r:value kilobayt.","numeric":":attribute de\u011ferinden b\u00fcy\u00fck :value.","string":"attribute birden fazla :value de\u011ferine sahip olmal\u0131d\u0131r."},"gte":{"array":":attribute \u015funlar olmal\u0131d\u0131r:value \u00f6\u011feleri veya daha fazlas\u0131.","file":":attribute b\u00fcy\u00fck veya e\u015fit olmal\u0131d\u0131r:value kilobayt.","numeric":":attribute: de\u011ferinden b\u00fcy\u00fck veya e\u015fit olmal\u0131d\u0131r :value.","string":":attribute, :de\u011fer karakterlerinden b\u00fcy\u00fck veya e\u015fit olmal\u0131d\u0131r."},"image":":attribute bir resim olmal\u0131d\u0131r.","in":"Se\u00e7ilen:attribute ge\u00e7ersiz.","in_array":":attribute alan\u0131:other lerinde :bulunmaz.","integer":":attribute bir tamsay\u0131 olmal\u0131d\u0131r.","ip":":attribute ge\u00e7erli bir IP adresi olmal\u0131d\u0131r.","ipv4":":attribute ge\u00e7erli bir IPv4 adresi olmal\u0131d\u0131r.","ipv6":":attribute ge\u00e7erli bir IPv6 adresi olmal\u0131d\u0131r.","json":":attribute ge\u00e7erli bir JSON dizesi olmal\u0131d\u0131r.","lt":{"array":":attribute :value den az olmal\u0131d\u0131r.","file":":attribute den k\u00fc\u00e7\u00fck olmal\u0131d\u0131r:value kilobayt.","numeric":":attribute k\u00fc\u00e7\u00fck olmal\u0131d\u0131r :value.","string":":attribute inden k\u00fc\u00e7\u00fck olmal\u0131d\u0131r:value karakterleri."},"lte":{"array":":attribute birden fazla :value de\u011ferine sahip olmamal\u0131d\u0131r.","file":":attribute e\u015fit veya daha k\u00fc\u00e7\u00fck olmal\u0131d\u0131r:value kilobayt.","numeric":":attribute:value inden k\u00fc\u00e7\u00fck veya e\u015fit olmal\u0131d\u0131r.","string":":attribute, :value karakterlerinden k\u00fc\u00e7\u00fck veya e\u015fit olmal\u0131d\u0131r."},"max":{"array":":attribute en fazla :max \u00f6\u011fe i\u00e7eremez.","file":":attribute en fazla:max kilobayt ola   maz.","numeric":":attribute \u015fu de\u011ferden b\u00fcy\u00fck olamaz:max.","string":":attribute en fazla: max karakter olabilir."},"mimes":":attribute \u015fu t\u00fcrden bir dosya olmal\u0131d\u0131r::values.","mimetypes":":attribute \u015fu t\u00fcrden bir dosya olmal\u0131d\u0131r::values.","min":{"array":":attribute en az: min \u00f6\u011fe olmal\u0131d\u0131r.","file":":attribute en az: min kilobayt olmal\u0131d\u0131r.","numeric":":attribute en az: min olmal\u0131d\u0131r.","string":":attribute en az: min karakter olmal\u0131d\u0131r."},"not_in":"Se\u00e7ilen:attribute ge\u00e7ersiz.","not_regex":":attribute bi\u00e7imi ge\u00e7ersiz.","numeric":":attribute bir say\u0131 olmal\u0131d\u0131r.","password":"\u015eifre yanl\u0131\u015f.","present":":attribute alan\u0131 mevcut olmal\u0131d\u0131r.","regex":":attribute bi\u00e7imi ge\u00e7ersiz.","required":":attribute alan\u0131 zorunludur.","required_if":":attribute alan\u0131 \u015fu durumlarda gereklidir:other is:value.","required_unless":":attribute: de\u011ferleri olmad\u0131\u011f\u0131 s\u00fcrece: :other is:value.","required_with":":attribute alan\u0131 a\u015fa\u011f\u0131daki durumlarda gereklidir :values mevcut.","required_with_all":":attribute alan\u0131 a\u015fa\u011f\u0131daki durumlarda gereklidir :values mevcut.","required_without":":attribute alan\u0131 a\u015fa\u011f\u0131daki durumlarda gereklidir :values mevcut olmayan.","required_without_all":":attribute alan\u0131, :values lerin hi\u00e7biri olmad\u0131\u011f\u0131nda zorunludur.","same":":attribute ve:other leriyle e\u015fle\u015fmelidir.","size":{"array":":attribute \u015funlar\u0131 i\u00e7ermelidir:size \u00f6\u011feleri.","file":":attribute size olmal\u0131d\u0131r:size kilobayt.","numeric":":attribute: size olmal\u0131d\u0131r.","string":":attribute:size karakterleri olmal\u0131d\u0131r."},"starts_with":":attribute a\u015fa\u011f\u0131dakilerden biriyle ba\u015flamal\u0131d\u0131r::values.","string":":attribute bir dize olmal\u0131d\u0131r.","timezone":":attribute ge\u00e7erli bir b\u00f6lge olmal\u0131d\u0131r.","unique":":attribute zaten al\u0131nm\u0131\u015f.","uploaded":":attribute y\u00fcklenemedi.","url":":attribute bi\u00e7imi ge\u00e7ersiz.","uuid":":attribute ge\u00e7erli bir UUID olmal\u0131d\u0131r."},"zh.auth":{"failed":"\u8fd9\u4e9b\u51ed\u636e\u4e0e\u6211\u4eec\u7684\u8bb0\u5f55\u4e0d\u5339\u914d\u3002","throttle":"\u767b\u5f55\u5c1d\u8bd5\u8fc7\u591a\u3002 \u8bf7\u5728\uff1aseconds\u79d2\u540e\u91cd\u8bd5\u3002"},"zh.messages":{"activity_log":{"activity_logs":"\u6d3b\u52d5\u65e5\u8a8c","loading_more_date":"\u52a0\u8f7d\u66f4\u591a\u6570\u636e","sorry_we_not_find_any_data":"\u6211\u5011\u627e\u4e0d\u5230\u4efb\u4f55\u6578\u64da\uff0c\u8acb\u81f3\u5c11\u8f38\u51651\u500b","we_could_find_any_data":"\u627e\u4e0d\u5230\u4efb\u4f55\u6578\u64da\u5c0d\u4e0d\u8d77"},"address":{"city":"\u5e02","country":"\u56fd\u5bb6","state":"\u5dde","street":"\u8857","zip_code":"\u90ae\u653f\u7f16\u7801"},"announcement":{"add":"\u52a0","announcement_date":"\u516c\u544a\u65e5\u671f","announcement_details":"\u516c\u544a\u8be6\u60c5","announcement_not_found":"\u627e\u4e0d\u5230\u516c\u544a","announcement_saved_successfully":"\u516c\u544a\u4fdd\u5b58\u6210\u529f\u3002","announcement_updated_successfully":"\u516c\u544a\u66f4\u65b0\u6210\u529f\u3002","edit_announcement":"\u7f16\u8f91\u516c\u544a","message":"\u4fe1\u606f","new_announcement":"\u65b0\u516c\u544a","no_announcement_available":"\u7121\u516c\u544a\u53ef\u7528","on_announcement_found":"\u627e\u4e0d\u5230\u516c\u544a\u3002","show_my_name":"\u663e\u793a\u6211\u7684\u540d\u5b57","show_to_clients":"\u5411\u5ba2\u6237\u5c55\u793a","show_to_staff":"\u5411\u5458\u5de5\u5c55\u793a","subject":"\u5b66\u79d1"},"announcements":"\u516c\u544a\u5185\u5bb9","article":{"add":"\u52a0","article_details":"\u6587\u7ae0\u8be6\u60c5","article_not_found":"\u627e\u4e0d\u5230\u6587\u7ae0\u3002","article_saved_successfully":"\u6587\u7ae0\u4fdd\u5b58\u6210\u529f\u3002","article_updated_successfully":"\u6587\u7ae0\u66f4\u65b0\u6210\u529f\u3002","attachment":"\u9644\u4ef6","description":"\u63cf\u8ff0","disabled":"\u6b8b\u969c\u4eba\u58eb","edit_article":"\u7f16\u8f91\u6587\u7ae0","group":"\u7ec4","internal_article":"\u5185\u90e8\u6587\u7ae0","new_article":"\u65b0\u6587\u7ae0","no_article_available":"\u6ca1\u6709\u53ef\u7528\u7684\u6587\u7ae0\u3002","no_article_found":"\u627e\u4e0d\u5230\u6587\u7ae0\u3002","subject":"\u5b66\u79d1","upload_image":"\u4e0a\u4f20\u56fe\u7247"},"article_group":{"add_new_article_group":"\u6dfb\u52a0\u65b0\u6587\u7ae0\u7ec4","article_group_saved_successfully":"\u6587\u7ae0\u7ec4\u4fdd\u5b58\u6210\u529f\u3002","article_group_updated_successfully":"\u6587\u7ae0\u7ec4\u66f4\u65b0\u6210\u529f\u3002","article_group_used_somewhere_else":"\u6587\u7ae0\u7ec4\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u3002","article_groups":"\u6587\u7ae0\u7ec4","color":"\u989c\u8272","edit_article_group":"\u7f16\u8f91\u6587\u7ae0\u7ec4","group_name":"\u56e2\u961f\u540d\u5b57","new_article_group":"\u65b0\u6587\u7ae0\u7ec4","order":"\u8ba2\u8d2d"},"articles":"\u6587\u7ae0","calendars":"\u884c\u4e8b\u5386","change_password":{"change_information_about_yourself_on_this_page":" \u5728\u6b64\u9875\u9762\u4e0a\u66f4\u6539\u6709\u5173\u60a8\u81ea\u5df1\u7684\u4fe1\u606f\u3002","confirm_password":"\u786e\u8ba4\u5bc6\u7801","current_password":"\u5f53\u524d\u5bc6\u7801","edit_profile":"\u7f16\u8f91\u4e2a\u4eba\u8d44\u6599","new_password":"\u65b0\u5bc6\u7801"},"client_dashboard":"\u5ba2\u6237\u4eea\u8868\u677f","cms":"\u4e0d\u80b2\u7cfb","comment":{"add_comment":"\u6dfb\u52a0\u8bc4\u8bba","added_by":"\u6dfb\u52a0\u4eba","comments_saved_successfully":"\u8bc4\u8bba\u4fdd\u5b58\u6210\u529f\u3002","comments_updated_successfully":"\u8bc4\u8bba\u66f4\u65b0\u6210\u529f\u3002","edit_comment":"\u7f16\u8f91\u8bc4\u8bba","new_comment":"\u65b0\u8bc4\u8bba","no_comments_added_yet":"\u8fd8\u6ca1\u6709\u6dfb\u52a0\u8bc4\u8bba"},"comments":"\u6ce8\u91ca","common":{"action":"\u884c\u52a8","active":"\u6d3b\u6027","add":"\u52a0","admin_note":"\u7ba1\u7406\u5458\u8bf4\u660e","announcement":"\u516c\u544a","apply":"\u7533\u8bf7","article":"\u6587\u7ae0","article_group":"\u6587\u7ae0\u7ec4","assignee":"\u53d7\u8ba9\u4eba","attachment_deleted":"\u9644\u4ef6\u5df2\u88ab\u5220\u9664\u3002","back":"\u80cc\u90e8","cancel":"\u53d6\u6d88","choose":"\u9009\u62e9","client_note":"\u5ba2\u6237\u987b\u77e5","contract_type":"\u5408\u540c\u7c7b\u578b","country":"\u56fd\u5bb6","created_on":"\u521b\u5efa\u4e8e","custom":"\u98ce\u4fd7","customer":"\u987e\u5ba2","customer_group":"\u5ba2\u6237\u7fa4","data_base_entries":"\u663e\u793a _START_ \u5230 _END_ \u4e2a\u6761\u76ee\uff0c\u5171 _TOTAL_ \u4e2a\u6761\u76ee","deactive":"\u65e0\u6548","default_country_code":"\u9ed8\u8ba4\u56fd\u5bb6\u4ee3\u7801","delete":"\u5220\u9664","delete_attachment":"\u60a8\u786e\u5b9a\u8981\u5220\u9664\u6b64\u201c\u9644\u4ef6\u201d\u5417\uff1f","delete_confirm":"\u8bf7\u8f93\u5165","delete_confirm_common":"\u4f60\u786e\u5b9a\u8981\u5220\u9664\u8fd9\u4e2a","delete_note":"\u60a8\u786e\u5b9a\u8981\u5220\u9664\u6b64\u201c\u5907\u6ce8\u201d\u5417\uff1f","deleted":"\u5df2\u5220\u9664!","department":"\u90e8\u95e8","description":"\u63cf\u8ff0","download":"\u4e0b\u8f7d","download_as_pdf":"\u4e0b\u8f7d\u4e3aPDF","drafted":"\u5df2\u8d77\u8349","edit":"\u7f16\u8f91","email":"\u7535\u5b50\u90ae\u4ef6","expense":"\u8d39\u7528","expense_category":"\u8d39\u7528\u7c7b\u522b","filter_by":"(\u4ece _MAX_ \u4e2a\u603b\u6761\u76ee\u4e2d\u8fc7\u6ee4)","from":"\u4ece","goal":"\u76ee\u6807","has_been_delete":" \u5df2\u88ab\u5220\u9664\u3002","incomes_vs_expenses":"\u6536\u5165\u4e0e\u652f\u51fa","last_updated":"\u6700\u8fd1\u66f4\u65b0\u65f6\u95f4","lead":"\u5e26\u9886","lead_source":"\u94c5\u6e90","menu_entry":"\u663e\u793a _MENU_ \u6761\u76ee","n\/a":"\u4e0d\u9002\u7528","name":"\u540d\u79f0","no":"\u6ca1\u6709","no_data_available_in_table":"\u8868\u4e2d\u6ca1\u6709\u53ef\u7528\u6570\u636e","no_entry":"\u663e\u793a 0 \u5230 0 \u4e2a\u6761\u76ee\uff0c\u5171 0 \u4e2a\u6761\u76ee","no_matching":"\u672a\u627e\u5230\u5339\u914d\u7684\u8bb0\u5f55","note":"\u7b14\u8bb0","note_delete":"\u6ce8\u91ca\u5df2\u88ab\u5220\u9664\u3002","of":"\u7684","ok":"\u597d\u7684","payment_mode":"\u4ed8\u6b3e\u65b9\u5f0f","predefined_reply":"\u9884\u5b9a\u4e49\u56de\u590d","product_1":"\u4ea7\u54c1","product_group":"\u4ea7\u54c1\u7ec4","product_header":"\u4ea7\u54c1","proposal":"\u63d0\u8bae","quantity_is_not_greater_than":"\u6570\u91cf\u4e0d\u5927\u4e8e9999999","save":"\u4fdd\u5b58","search":"\u641c\u7d22","search_results":"\u60a8\u7684\u641c\u7d22\u7ed3\u679c\u5728\u8fd9\u91cc...","service":"\u670d\u52a1","showing":"\u663e\u793a\u4e2d","status":"\u72b6\u6001","tag":"\u6807\u7b7e","tax_rate":"\u7a0e\u7387","term_and_conditions":"\u6761\u6b3e\u53ca\u7ec6\u5219","ticket_priority":"\u7968\u52a1\u4f18\u5148","to":"\u81f3","to_delete_this":"\u5220\u9664\u8fd9\u4e2a","total_amount":"\u7e3d\u91d1\u984d","type_delete":"\u8bf7\u8f93\u5165\u201cdelete\u201d\u5220\u9664\u6b64\u5185\u5bb9","view":"\u89c6\u56fe","weekly_payment_records":"\u6bcf\u5468\u4ed8\u6b3e\u8bb0\u5f55","yes":"\u662f"},"company":{"address":"\u5730\u5740","city":"\u5e02","company":"\u516c\u53f8\u540d","company_information_format":"\u516c\u53f8\u4fe1\u606f\u683c\u5f0f\uff08PDF\u548cHTML\uff09","country_code":"\u56fd\u5bb6\u4ee3\u7801","currency":"\u8d27\u5e01","details":"\u516c\u53f8\u8d44\u6599","phone":"\u7535\u8bdd","state":"\u5dde","vat_number":"\u589e\u503c\u7a0e\u53f7","website":"\u7f51\u7ad9","zip_code":"\u90ae\u653f\u7f16\u7801"},"company_information":"\u516c\u53f8\u4fe1\u606f","contact":{"active":"\u6d3b\u6027","by_deleting_this_contact":"\u901a\u8fc7\u5220\u9664\u6b64\u8054\u7cfb\u4eba\uff0c\u5176\u6240\u6709\u9879\u76ee\u90fd\u5c06\u88ab\u5220\u9664\u3002","contact_details":"\u8054\u7cfb\u65b9\u5f0f","contact_not_found":"\u627e\u4e0d\u5230\u8054\u7edc\u4eba\u3002","contact_saved_successfully":"\u8054\u7cfb\u4eba\u4fdd\u5b58\u6210\u529f\u3002","contact_status_updated_successfully":"\u8054\u7cfb\u4eba\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","contact_updated_successfully":"\u8054\u7cfb\u4eba\u66f4\u65b0\u6210\u529f\u3002","contract":"\u5408\u540c","contracts":"\u5408\u7ea6","credit_note":"\u4fe1\u7528\u7968\u636e","customer_name":"\u987e\u5ba2\u59d3\u540d","deactive":"\u65e0\u6548","delete_contact_confirm":"\u60a8\u786e\u5b9a\u8981\u5220\u9664\u6b64\u8054\u7cfb\u4eba\u5417\uff1f","edit_contact":"\u66f4\u6539\u8054\u7cfb\u8d44\u6599","email_notifications":"\u90ae\u4ef6\u901a\u77e5","estimate":"\u4f30\u8ba1","estimates":"\u4f30\u7b97\u503c","first_name":"\u540d\u5b57","full_name":"\u5168\u540d","impersonate":"\u6a21\u4eff","invoice":"\u53d1\u7968","invoices":"\u53d1\u7968","last_name":"\u59d3","make_sure_to_set_appropriate_permissions_for_this_contact":"\u786e\u4fdd\u4e3a\u6b64\u8054\u7cfb\u4eba\u8bbe\u7f6e\u9002\u5f53\u7684\u6743\u9650","new_contact":"\u65b0\u8054\u7cfb\u4eba","no_contact_available":"\u6c92\u6709\u53ef\u7528\u7684\u806f\u7d61\u4eba\u3002","on_contact_found":"\u627e\u4e0d\u5230\u8054\u7cfb\u4eba\u3002","password":"\u5bc6\u7801","permissions":"\u6743\u9650","position":"\u4f4d\u7f6e","primary_contact":"\u4e3b\u8981\u8054\u7edc\u4eba","project":"\u9879\u76ee","projects":"\u4e13\u6848","proposals":"\u63d0\u6848","send_password_email":"\u53d1\u9001SET\u5bc6\u7801\u7535\u5b50\u90ae\u4ef6","send_welcome_email":"\u4e0d\u53d1\u9001\u6b22\u8fce\u7535\u5b50\u90ae\u4ef6","support":"\u652f\u6301","task":"\u4efb\u52a1","tickets":"\u5165\u573a\u5238"},"contacts":"\u8054\u7edc\u4eba","contract":{"add":"\u52a0","authorized_signature":"\u6388\u6743\u7b7e\u540d","contract_details":"\u5408\u7ea6\u660e\u7ec6","contract_list":"\u5408\u7ea6\u6e05\u5355","contract_not_found":"\u627e\u4e0d\u5230\u5408\u540c","contract_summary":"\u5408\u7ea6\u6458\u8981","contract_type_id":"\u5408\u540c\u7c7b\u578b","contract_value":"\u5408\u7ea6\u4ef7\u503c","contracts_by_type":"\u5408\u540c\u7c7b\u578b","contracts_expiring_this_month":"\u672c\u6708\u5230\u671f\u7684\u5408\u7ea6","contracts_saved_successfully":"\u5408\u7ea6\u4fdd\u5b58\u6210\u529f\u3002","contracts_updated_successfully":"\u5408\u7ea6\u66f4\u65b0\u6210\u529f\u3002","contracts_value_by_type":"\u5408\u540c\u4ef7\u503c\u6309\u7c7b\u578b","customer_id":"\u987e\u5ba2","description":"\u63cf\u8ff0","edit_contract":"\u7f16\u8f91\u5408\u7ea6","end_date":"\u7ed3\u675f\u65e5\u671f","is_hide":"\u5bf9\u5ba2\u6237\u9690\u85cf","is_trash":"\u5783\u573e","new_contract":"\u65b0\u5408\u7ea6","no_contract_available":"\u6ca1\u6709\u53ef\u7528\u7684\u5408\u540c","on_contract_found":"\u627e\u4e0d\u5230\u5408\u540c\u3002","sign":"\u6807\u5fd7","start_date":"\u5f00\u59cb\u65e5\u671f","subject":"\u5b66\u79d1"},"contract_type":{"add_new_contract_type":"\u6dfb\u52a0\u65b0\u5408\u7ea6\u7c7b\u578b","contract_by_type":"\u5408\u540c\u7c7b\u578b","contract_type_saved_successfully":"\u5408\u7ea6\u7c7b\u578b\u4fdd\u5b58\u6210\u529f\u3002","contract_type_updated_successfully":"\u5408\u7ea6\u7c7b\u578b\u66f4\u65b0\u6210\u529f\u3002","contract_type_used_somewhere_else":"Contract Type used somewhere else.","contract_value_by_type":"\u6309\u7c7b\u578b\u5212\u5206\u7684\u5408\u540c\u4ef7\u503c","edit_contract_type":"\u7f16\u8f91\u5408\u7ea6\u7c7b\u578b","new_contract_type":"\u65b0\u5408\u7ea6\u7c7b\u578b"},"contract_types":"\u5408\u7ea6\u7c7b\u578b","contracts":"\u5408\u7ea6","countries":"\u56fd\u5bb6","country":{"add":"\u6dfb\u52a0","country_not_found":"\u672a\u627e\u5230\u56fd\u5bb6\u3002","country_saved_successfully":"\u56fd\u5bb6\u4fdd\u5b58\u6210\u529f\u3002","country_updated_successfully":"\u56fd\u5bb6\u66f4\u65b0\u6210\u529f\u3002","country_used_somewhere_else":"\u56fd\u5bb6\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u3002","edit_country":"\u7f16\u8f91\u56fd\u5bb6","name":"\u540d\u79f0","new_country":"\u65b0\u56fd\u5bb6","no_country_available":"\u6ca1\u6709\u53ef\u7528\u7684\u56fd\u5bb6\/\u5730\u533a\u3002","no_country_found":"\u672a\u627e\u5230\u56fd\u5bb6\u3002"},"credit_note":{"authorized_signature":"\u6388\u6743\u7b7e\u540d","client_note":"\u6ce8\u91ca","closed":"\u5173\u95ed","credit_note":"\u4fe1\u7528\u8bb0\u5f55","credit_note_date":"\u8d37\u65b9\u901a\u77e5\u5355\u65e5\u671f","credit_note_details":"\u8d37\u65b9\u901a\u77e5\u5355\u8be6\u7ec6\u4fe1\u606f","credit_note_details_updated_successfully":"\u4fe1\u7528\u7968\u636e\u8be6\u60c5\u66f4\u65b0\u6210\u529f\u3002","credit_note_not_found":"\u672a\u627e\u5230\u8d37\u65b9\u901a\u77e5\u5355\u3002","credit_note_number":"\u8d37\u65b9\u7968\u636e\u7f16\u53f7","credit_note_pdf":"\u4fe1\u7528\u8bb0\u5f55PDF","credit_note_prefix":"CN-","credit_note_saved_successfully":"\u4fe1\u7528\u8bb0\u5f55\u4fdd\u5b58\u6210\u529f\u3002","credit_note_updated_successfully":"\u4fe1\u7528\u8bb0\u5f55\u66f4\u65b0\u6210\u529f\u3002","drafted":"\u5df2\u8d77\u8349","edit_credit_note":"\u7f16\u8f91\u8d37\u65b9\u901a\u77e5\u5355","invoice_credited":"\u53d1\u7968\u5df2\u8bb0\u5165","mark_as_closed":"\u6807\u8bb0\u4e3a\u5df2\u5173\u95ed","mark_as_draft":"\u6807\u8bb0\u4e3a\u8349\u7a3f","mark_as_open":"\u6807\u8bb0\u4e3a\u6253\u5f00","mark_as_void":"\u6807\u8bb0\u4e3a\u65e0\u6548","new_credit_note":"\u65b0\u8d37\u65b9\u901a\u77e5\u5355","no_credit_note_available":"\u6ca1\u6709\u53ef\u7528\u7684\u8d37\u65b9\u901a\u77e5\u5355\u3002","on_credit_note_found":"\u627e\u4e0d\u5230\u8d37\u65b9\u901a\u77e5\u5355\u3002","open":"\u6253\u5f00","quantity_is_not_greater_than":"\u6570\u91cf\u4e0d\u5927\u4e8e9999999","reference":"\u53c2\u8003","refunds":"\u9000\u6b3e","save_and_send":"\u4fdd\u5b58\u5e76\u53d1\u9001","save_as_draft":"\u53e6\u5b58\u4e3a\u8349\u7a3f","terms_and_conditions":"\u6761\u6b3e\u548c\u6761\u4ef6","title":"\u6807\u9898","view_credit_note_as_customer":"\u4ee5\u5ba2\u6237\u8eab\u4efd\u67e5\u770b\u8d37\u65b9\u901a\u77e5\u5355","void":"\u7a7a\u6d1e"},"credit_notes":"\u4fe1\u7528\u7968\u636e","customer":{"add_address_details":"\u6dfb\u52a0\u5730\u5740\u8be6\u7ec6\u4fe1\u606f","address":"\u5730\u5740","address_details":"\u8be6\u7ec6\u5730\u5740","address_not_found":"\u627e\u4e0d\u5230\u5730\u5740\u8be6\u7ec6\u4fe1\u606f\u3002","billing_address":"\u5e10\u5355\u5730\u5740","billing_address_details_not_available":"\u5e10\u5355\u5730\u5740\u8be6\u7ec6\u4fe1\u606f\u4e0d\u53ef\u7528","by_deleting_this_customer":"\u901a\u8fc7\u5220\u9664\u6b64\u5ba2\u6237\u7684\u6240\u6709\u9879\u76ee\uff0c\u8054\u7cfb\u65b9\u5f0f\uff0c\u53d1\u7968\uff0c\u4f30\u8ba1\uff0c\u8d37\u65b9\u901a\u77e5\u5355\uff0c\u6295\u6807\u548c\u5408\u540c\uff0c\u5c06\u88ab\u5220\u9664\u3002","city":"\u5e02","company_name":"\u516c\u53f8\u540d","copy_billing_address":"\u590d\u5236\u5e10\u5355\u5730\u5740","country":"\u56fd\u5bb6","currency":"\u8d27\u5e01","customer_details":"\u987e\u5ba2\u4fe1\u606f","customer_saved_successfully":"\u5ba2\u6237\u4fdd\u5b58\u6210\u529f\u3002","customer_updated_successfully":"\u5ba2\u6237\u66f4\u65b0\u6210\u529f\u3002","customers":"\u987e\u5ba2","default_language":"\u9884\u8bbe\u8bed\u8a00","delete_customer_confirm":"\u60a8\u786e\u5b9a\u8981\u5220\u9664\u6b64\u5ba2\u6237\u5417\uff1f","do_not_fill_shipping_address_customer_invoices":"\u5982\u679c\u60a8\u4e0d\u4f1a\u5728\u5ba2\u6237\u53d1\u7968\u4e0a\u4f7f\u7528\u9001\u8d27\u5730\u5740\uff0c\u8bf7\u4e0d\u8981\u586b\u5199\u9001\u8d27\u5730\u5740\u4fe1\u606f","edit_customer":"\u7f16\u8f91\u5ba2\u6237","groups":"\u56e2\u4f53","new_customer":"\u65b0\u5ba2\u6237","no_customer_available":"\u6ca1\u6709\u53ef\u7528\u7684\u5ba2\u6237\u3002","no_customer_found":"\u627e\u4e0d\u5230\u5ba2\u6237\u3002","phone":"\u7535\u8bdd","same_as_a_customer_info":"\u4e0e\u5ba2\u6237\u4fe1\u606f\u76f8\u540c","search_customer":"\u641c\u7d22\u5ba2\u6237","shipping_address":"\u9001\u8d27\u5730\u5740","shipping_address_details_not_available":"\u6536\u8d27\u5730\u5740\u8be6\u7ec6\u4fe1\u606f\u4e0d\u53ef\u7528","state":"\u5dde","street":"\u8857","total_contact":"\u603b\u8054\u7edc\u4eba","total_customers":"\u5ba2\u6237\u603b\u6570","total_project":"\u603b\u9879\u76ee","type":"\u7c7b\u578b","vat_number":"\u589e\u503c\u7a0e\u53f7","website":"\u7f51\u7ad9","zip_code":"\u90ae\u653f\u7f16\u7801"},"customer_group":{"action":"\u884c\u52a8","add_new_customer_group":"\u6dfb\u52a0\u65b0\u5ba2\u6237\u7ec4","customer_group_saved_successfully":"\u5ba2\u6237\u7ec4\u4fdd\u5b58\u6210\u529f\u3002","customer_group_updated_successfully":"\u5ba2\u6237\u7ec4\u66f4\u65b0\u6210\u529f\u3002","description":"\u63cf\u8ff0","edit_customer_group":"\u7f16\u8f91\u5ba2\u6237\u7ec4","name":"\u540d\u79f0","new_customer_group":"\u65b0\u5ba2\u6237\u7fa4"},"customer_groups":"\u5ba2\u6237\u7fa4","customers":"\u987e\u5ba2","dashboard":"\u4eea\u8868\u677f","department":{"department_not_found":"\u627e\u4e0d\u5230\u90e8\u95e8\u3002","department_saved_successfully":"\u90e8\u95e8\u4fdd\u5b58\u6210\u529f\u3002","department_updated_successfully":"\u90e8\u95e8\u66f4\u65b0\u6210\u529f\u3002","departments":"\u90e8\u95e8","edit_department":"\u7f16\u8f91\u90e8","hide_from_clients":"\u5bf9\u5ba2\u6237\u9690\u85cf","new_department":"\u65b0\u90e8\u95e8","no_department_available":"\u6ca1\u6709\u53ef\u7528\u7684\u90e8\u95e8\u3002","on_department_found":"\u627e\u4e0d\u5230\u90e8\u95e8\u3002"},"edit_profile":{"change_password":"\u66f4\u6539\u5bc6\u7801","edit_profile":"\u7f16\u8f91\u4e2a\u4eba\u8d44\u6599","hello":"\u4f60\u597d","hi":"\u4f60\u597d","login":"\u767b\u5f55","login_register":"\u767b\u5f55\/\u6ce8\u518c","logout":"\u767b\u51fa","mark_all_as_read":"\u6807\u8bb0\u4e3a\u5df2\u8bfb","notification":"\u901a\u77e5\u4e8b\u9879","register":"\u5bc4\u5b58\u5668","welcome":"\u6b22\u8fce"},"email":{"email":"\u7535\u5b50\u90ae\u4ef6","forgot_password":"\u5fd8\u8bb0\u5bc6\u7801","recalled_your_login_info":"\u53ec\u56de\u60a8\u7684\u767b\u5f55\u4fe1\u606f\uff1f","reset_password":"\u91cd\u8bbe\u5bc6\u7801","send_reset_link":"\u53d1\u9001\u91cd\u7f6e\u94fe\u63a5","sign_in":"\u767b\u5165"},"email_template":{"available_merge_fields":"\u53ef\u7528\u7684\u5408\u5e76\u5b57\u6bb5","disabled":"\u6b8b\u969c\u4eba\u58eb","edit_email_template":"\u7f16\u8f91\u7535\u5b50\u90ae\u4ef6\u6a21\u677f","email_message":"\u7535\u90ae\u8baf\u606f","enable":"\u542f\u7528","from_name":"\u6765\u81ea\u540d\u5b57","send_plain_text":"\u4ee5\u7eaf\u6587\u672c\u5f62\u5f0f\u53d1\u9001","subject":"\u5b66\u79d1","template_name":"\u6a21\u677f\u540d\u79f0"},"email_templates":"\u7535\u5b50\u90ae\u4ef6\u8303\u672c","error":"\u062e\u0637\u0623","estimate":{"accepted":"\u516c\u8ba4","adjustment":"\u8c03\u6574","amount":"\u91cf","amount_due":"\u5e94\u4ed8\u91d1\u989d","authorized_signature":"\u6388\u6743\u7b7e\u540d","bill_to":"\u8bb0\u8d26\u5230","client_note":"\u5ba2\u6237\u987b\u77e5","convert_estimate":"\u8f6c\u6362\u4f30\u7b97","convert_estimate_to_invoice":"\u5c06\u4f30\u8ba1\u8f6c\u6362\u4e3a\u53d1\u7968\u6210\u529f\u3002","declined":"\u62d2\u7edd","discount":"\u6298\u6263","draft":"\u8349\u6848","drafted":"\u5df2\u8d77\u8349","edit_estimate":"\u7f16\u8f91\u4f30\u7b97","estimate":"\u4f30\u8ba1","estimate_date":"\u4f30\u8ba1\u65e5\u671f","estimate_details":"\u4f30\u7b97\u660e\u7ec6","estimate_not_found":"\u627e\u4e0d\u5230\u4f30\u7b97","estimate_number":"\u4f30\u8ba1\u6570","estimate_overview":"\u6982\u89c2","estimate_pdf":"\u4f30\u8ba1PDF","estimate_prefix":"EN-","estimate_saved_successfully":"\u4f30\u8ba1\u4fdd\u5b58\u6210\u529f\u3002","estimate_status_updated_successfully":"\u4f30\u8ba1\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","estimate_updated_successfully":"\u4f30\u8ba1\u66f4\u65b0\u6210\u529f\u3002","expired":"\u5df2\u8fc7\u671f","expiry_date":"\u5230\u671f\u65e5","item":"\u4ea7\u54c1","mark_as_accepted":"\u6807\u8bb0\u4e3a\u63a5\u53d7","mark_as_declined":"\u6807\u8bb0\u4e3a\u5df2\u62d2\u7edd","mark_as_draft":"\u6807\u8bb0\u4e3a\u8349\u7a3f","mark_as_expired":"\u6807\u8bb0\u4e3a\u5df2\u8fc7\u671f","mark_as_send":"\u6807\u8bb0\u4e3a\u53d1\u9001","more":"\u66f4\u591a","new_estimate":"\u65b0\u4f30\u7b97","no_estimate_available":"\u6c92\u6709\u4f30\u8a08\u53ef\u7528","not_sent":"\u672a\u53d1\u9001","on_estimate_found":"\u627e\u4e0d\u5230\u4f30\u7b97\u503c\u3002","qty":"\u6570\u91cf","rate":"\u7387","save_and_send":"\u4fdd\u5b58\u5e76\u53d1\u9001","save_as_draft":"\u53e6\u5b58\u4e3a\u8349\u7a3f","sent":"\u5df2\u53d1\u9001","ship_to":"\u8fd0\u9001\u5230","status":"\u72b6\u6001","sub_total":"\u5c0f\u8ba1","taxes":"\u7a0e\u6536","terms_conditions":"\u6761\u6b3e\u53ca\u7ec6\u5219","title":"\u6807\u9898","total":"\u603b","total_estimates":"\u4f30\u8ba1\u603b\u6570","total_paid":"\u603b\u652f\u4ed8","view_estimate_as_customer":"\u4ee5\u5ba2\u6237\u8eab\u4efd\u67e5\u770b\u4f30\u7b97"},"estimates":"\u4f30\u7b97\u503c","expense":{"add":"\u52a0","amount":"\u91cf","amount_with_tax":"\u542b\u7a0e\u91d1\u989d","apply_tax":"\u62a5\u7a0e","apply_tax_message":"\u4ece\u91d1\u989d\u4e2d\u51cf\u53bb\u7a0e\u91d1\u603b\u989d","attachment":"\u9644\u4ef6","auto_create_invoice":"\u81ea\u52a8\u521b\u5efa\u53d1\u7968","billable":"\u53ef\u5f00\u7968","choose_file":"\u9009\u62e9\u6587\u4ef6","currency":"\u8d27\u5e01","customer":"\u987e\u5ba2","details":"\u7ec6\u8282","edit_expense":"\u7f16\u8f91\u8d39\u7528","expense_amount":"\u8d39\u7528\u91d1\u989d","expense_category":"\u8d39\u7528\u7c7b\u522b","expense_category_by_chart":"\u8d39\u7528\u5206\u7c7b\u8868","expense_date":"\u8d39\u7528\u65e5\u671f","expense_details":"\u8d39\u7528\u660e\u7ec6","expense_list":"\u8d39\u7528\u6e05\u5355","expense_not_found":"\u627e\u4e0d\u5230\u8d39\u7528\u3002","expense_saved_successfully":"\u8d39\u7528\u4fdd\u5b58\u6210\u529f\u3002","expense_updated_successfully":"\u8d39\u7528\u66f4\u65b0\u6210\u529f\u3002","name":"\u540d\u79f0","new_expense":"\u65b0\u8d39\u7528","no_expense_available":"\u6ca1\u6709\u53ef\u7528\u7684\u8d39\u7528\u3002","note":"\u6ce8\u610f","notes":"\u7b14\u8bb0","on_expense_found":"\u627e\u4e0d\u5230\u8d39\u7528\u3002","payment_mode":"\u4ed8\u6b3e\u65b9\u5f0f","preview_attachment":"\u9884\u89c8\u9644\u4ef6","receipt_attachment":"\u6536\u636e\u9644\u4ef6","reference":"\u53c2\u8003","reminders":"\u63d0\u9192","send_email":"\u91cd\u65b0\u521b\u5efa\u8d39\u7528\u540e\u5c06\u53d1\u7968\u53d1\u9001\u5230\u5ba2\u6237\u7535\u5b50\u90ae\u4ef6","tax_1":"\u7a0e\u91d11\uff08\uff05\uff09","tax_2":"\u7a0e2\uff08\uff05\uff09","tax_applied":"\u9002\u7528\u7a0e\u9879","view_attachment":"\u67e5\u770b\u9644\u4ef6"},"expense_by_category":"\u6309\u7c7b\u522b\u7684\u8d39\u7528","expense_categories":"\u8d39\u7528\u7c7b\u522b","expense_category":{"add_new_expense_category":"\u6dfb\u52a0\u65b0\u7684\u8d39\u7528\u7c7b\u522b","edit_category":"\u7f16\u8f91\u8d39\u7528\u7c7b\u522b","expense_categories":"\u8d39\u7528\u7c7b\u522b","expense_category":"\u8d39\u7528\u7c7b\u522b","expense_category_saved_successfully":"\u8d39\u7528\u7c7b\u522b\u4fdd\u5b58\u6210\u529f\u3002","expense_category_updated_successfully":"\u8d39\u7528\u7c7b\u522b\u66f4\u65b0\u6210\u529f\u3002","expense_category_used_somewhere_else":"\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u7684\u8d39\u7528\u7c7b\u522b\u3002","new_category":"\u65b0\u8d39\u7528\u7c7b\u522b"},"expenses":"\u82b1\u8d39","general":"\u4e00\u822c","goal":{"achievement":"\u6210\u5c31","add":"\u52a0","description":"\u63cf\u8ff0","edit_goal":"\u7f16\u8f91\u76ee\u6807","end_date":"\u7ed3\u675f\u65e5\u671f","goal_details":"\u76ee\u6807\u8be6\u60c5","goal_id":"\u76ee\u6807\u7c7b\u578b","goal_saved_successfully":"\u76ee\u6807\u4fdd\u5b58\u6210\u529f\u3002","goal_type":"\u76ee\u6807\u7c7b\u578b","goal_updated_successfully":"\u76ee\u6807\u66f4\u65b0\u6210\u529f\u3002","is_not_notify":"\u672a\u8fbe\u5230\u76ee\u6807\u65f6\u901a\u77e5\u5458\u5de5","is_notify":"\u8fbe\u5230\u76ee\u6807\u65f6\u901a\u77e5\u5458\u5de5","new_goal":"\u65b0\u76ee\u6807","no_goal_available":"\u6ca1\u6709\u53ef\u7528\u7684\u76ee\u6807\u3002","no_goal_found":"\u627e\u4e0d\u5230\u76ee\u6807\u3002","progress":"\u8fdb\u5c55","staff_member":"\u5de5\u4f5c\u4eba\u5458","start_date":"\u5f00\u59cb\u65e5\u671f","subject":"\u5b66\u79d1","user_id":"\u5de5\u4f5c\u4eba\u5458"},"goal_type":{"description":"\u63cf\u8ff0","edit_goal_type":"\u4fee\u6539\u76ee\u6807\u7c7b\u578b","name":"\u540d\u79f0","new_goal_type":"\u65b0\u76ee\u6807\u7c7b\u578b"},"goals":"\u76ee\u6807","incomes":"\u6536\u5165","invoice":{"activity_log":"\u6d3b\u52a8\u65e5\u5fd7","add_item":"\u6dfb\u52a0\u4ea7\u54c1","add_shipping_address":"\u6dfb\u52a0\u9001\u8d27\u5730\u5740","adjustment":"\u8c03\u6574","admin_note":"\u7ba1\u7406\u5458\u8bf4\u660e","allowed_payment_modes_for_this_invoice":"\u6b64\u53d1\u7968\u7684\u5141\u8bb8\u4ed8\u6b3e\u65b9\u5f0f","amount":"\u91cf","amount_due":"\u5e94\u4ed8\u91d1\u989d","authorized_signature":"\u6388\u6743\u7b7e\u540d","bank":"\u94f6\u884c","bill_tasks":"\u8d26\u5355\u4efb\u52a1","bill_to":"\u8bb0\u8d26\u5230","cancelled":"\u53d6\u6d88","client_note":"\u5ba2\u6237\u987b\u77e5","currency":"\u8d27\u5e01","customer":"\u987e\u5ba2","discount":"\u6298\u6263","discount_type":"\u4f18\u60e0\u7c7b\u578b","draft":"\u8349\u6848","drafted":"\u5df2\u8d77\u8349","due_date":"\u622a\u6b62\u65e5\u671f","edit_contract_type":"\u7f16\u8f91\u5408\u7ea6\u7c7b\u578b","edit_invoice":"\u7f16\u8f91\u53d1\u7968","fixed":"\u56fa\u5b9a","hours":"\u5c0f\u65f6","hsn_tax":"HSN \u7a0e\u7801","invoice":"\u53d1\u7968","invoice_date":"\u53d1\u7968\u65e5\u671f","invoice_details":"\u53d1\u7968\u660e\u7ec6","invoice_not_found":"\u627e\u4e0d\u5230\u53d1\u7968\u3002","invoice_number":"\u53d1\u7968\u53f7\u7801","invoice_overview":"\u53d1\u7968\u603b\u89c8","invoice_payments":"\u53d1\u7968\u4ed8\u6b3e","invoice_pdf":"\u53d1\u7968PDF","invoice_prefix":"INV-","invoice_saved_successfully":"\u53d1\u7968\u4fdd\u5b58\u6210\u529f\u3002","invoice_updated_successfully":"\u53d1\u7968\u66f4\u65b0\u6210\u529f\u3002","item":"\u4ea7\u54c1","mark_as_cancelled":"\u6807\u8bb0\u4e3a\u5df2\u53d6\u6d88","mark_as_draft":"\u6807\u8bb0\u4e3a\u8349\u7a3f","mark_as_paid":"\u6807\u8bb0\u4e3a\u5df2\u4ed8\u8d39","mark_as_partially_paid":"\u6807\u8bb0\u4e3a\u90e8\u5206\u4ed8\u8d39","mark_as_sent":"\u6807\u8bb0\u4e3a\u5df2\u53d1\u9001","more":"\u66f4\u591a","new_contract_type":"\u65b0\u5408\u7ea6\u7c7b\u578b","new_invoice":"\u65b0\u53d1\u7968","no_invoice_available":"\u6ca1\u6709\u53ef\u7528\u7684\u53d1\u7968\u3002","no_payments_available":"\u6ca1\u6709\u53ef\u7528\u7684\u4ed8\u6b3e","not_sent":"\u672a\u53d1\u9001","notes":"\u7b14\u8bb0","offline_payment":"\u79bb\u7ebf\u4ed8\u6b3e","on_invoice_found":"\u627e\u4e0d\u5230\u53d1\u7968\u3002","online_payment":"\u7f51\u4e0a\u652f\u4ed8","overdue":"\u903e\u671f","paid":"\u5df2\u4ed8\u8d39","paid_cap":"\u5df2\u4ed8","partially_paid":"\u90e8\u5206\u4ed8\u6b3e","partially_paid_cap":"\u90e8\u5206\u652f\u4ed8","pay_now":"\u73b0\u5728\u4ed8\u6b3e","payment":"\u4ed8\u6b3e","payment_details":"\u4ed8\u6b3e\u8be6\u60c5","payments":"\u4ed8\u6b3e\u65b9\u5f0f","prevent_sending_overdue_reminders_for_this_invoice":"\u9632\u6b62\u53d1\u9001\u6b64\u53d1\u7968\u7684\u8fc7\u671f\u63d0\u9192","qty":"\u6570\u91cf","qty\/hours":"\u6570\u91cf\/\u5c0f\u65f6","qty_hours":"\u6570\u91cf\/\u5c0f\u65f6","quick_invoices_info":"\u5feb\u901f\u53d1\u7968\u4fe1\u606f","recurring_invoice":"\u5b9a\u671f\u53d1\u7968","reminders":"\u63d0\u9192\u4e8b\u9879","sale_agent":"\u9500\u552e\u4ee3\u7406","save_and_send":"\u4fdd\u5b58\u5e76\u53d1\u9001","save_as_draft":"\u53e6\u5b58\u4e3a\u8349\u7a3f","ship_to":"\u8fd0\u9001\u5230","show_quantity_as":"\u663e\u793a\u6570\u91cf\u4e3a","sub_total":"\u5c0f\u8ba1","taxes":"\u7a0e\u6536","terms_conditions":"\u6761\u6b3e\u53ca\u7ec6\u5219","title":"\u6807\u9898","total":"\u603b","total_invoices":"\u603b\u53d1\u7968","total_paid":"\u603b\u652f\u4ed8","transactions":"\u4ea4\u6613\u6b21\u6570","unmark_as_cancelled":"\u53d6\u6d88\u6807\u8bb0\u4e3a\u5df2\u53d6\u6d88","unpaid":"\u672a\u4ed8","unpaid_cap":"\u672a\u4ed8","view_invoice_as_customer":"\u4ee5\u5ba2\u6237\u8eab\u4efd\u67e5\u770b\u53d1\u7968"},"invoices":"\u53d1\u7968","kanban_list":"\u770b\u677f\u6e05\u5355","kanban_view":"\u770b\u677f\u89c6\u56fe","last_week_payments":"\u4e0a\u5468\u4ed8\u6b3e","lead":{"chart":"\u56fe\u8868","contacted_today":"\u4eca\u5929\u8054\u7cfb","convert_to_customer":"\u8f6c\u6362\u4e3a\u5ba2\u6237","date_contacted":"\u8054\u7edc\u65e5\u671f","details":"\u7ec6\u8282","edit_lead":"\u7f16\u8f91\u6f5c\u5728\u5ba2\u6237","estimate_budget":"\u4f30\u8ba1\u9884\u7b97","lead_convert_customer":"\u6f5c\u5728\u5ba2\u6237\u8f6c\u6362","lead_convert_customer_chart":"\u6f5c\u5728\u5ba2\u6237\u8f6c\u6362\u5ba2\u6237\u56fe\u8868","lead_details":"\u6f5c\u5728\u5ba2\u6237\u8be6\u7ec6\u4fe1\u606f","lead_list":"\u6f5c\u5728\u5ba2\u6237\u6e05\u5355","lead_not_found":"\u627e\u4e0d\u5230\u6f5c\u5728\u5ba2\u6237\u3002","lead_saved_successfully":"\u7ebf\u7d22\u4fdd\u5b58\u6210\u529f\u3002","lead_status_updated_successfully":"\u7ebf\u7d22\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","lead_updated_successfully":"\u7ebf\u7d22\u66f4\u65b0\u6210\u529f\u3002","leads_overview":"\u6f5c\u5728\u5ba2\u6237\u6982\u8ff0","member":"\u4f1a\u5458","name":"\u540d\u79f0","new_lead":"\u65b0\u7ebf\u7d22","no_lead_available":"\u65e0\u94c5\u3002","no_lead_found":"\u627e\u4e0d\u5230\u6f5c\u5728\u5ba2\u6237\u3002","notes":"\u7b14\u8bb0","reminder":"\u63d0\u9192","source":"\u8d44\u6e90"},"lead_convert_to_customer":"\u6f5c\u5728\u5ba2\u6237\u8f6c\u5316\u4e3a\u5ba2\u6237","lead_source":{"add":"\u52a0","edit_lead_source":"\u7f16\u8f91\u6f5c\u5728\u5ba2\u6237\u6765\u6e90","lead_source_count":"\u6f5c\u5728\u5ba2\u6237\u6570","lead_source_not_found":"\u627e\u4e0d\u5230\u6f5c\u5728\u5ba2\u6237\u6765\u6e90\u3002","lead_source_saved_successfully":"\u7ebf\u7d22\u6765\u6e90\u4fdd\u5b58\u6210\u529f\u3002","lead_source_updated_successfully":"\u7ebf\u7d22\u6765\u6e90\u66f4\u65b0\u6210\u529f\u3002","name":"\u540d\u79f0","new_lead_source":"\u65b0\u6f5c\u5728\u5ba2\u6237","no_lead_source_available":"\u6ca1\u6709\u53ef\u7528\u7684\u6f5c\u5728\u5ba2\u6237\u6765\u6e90\u3002","on_lead_source_found":"\u627e\u4e0d\u5230\u6f5c\u5728\u5ba2\u6237\u3002"},"lead_sources":"\u94c5\u6765\u6e90","lead_status":{"add":"\u52a0","add_new_lead_status":"\u6dfb\u52a0\u65b0\u7684\u6f5c\u5728\u5ba2\u6237\u72b6\u6001","color":"\u989c\u8272","edit_lead_status":"\u7f16\u8f91\u9500\u552e\u7ebf\u7d22\u72b6\u6001","lead_status":"\u6f5c\u5728\u5ba2\u6237\u72b6\u6001","lead_status_saved_successfully":"\u5df2\u6210\u529f\u4fdd\u5b58\u6f5c\u5728\u5ba2\u6237\u72b6\u6001\u3002","lead_status_updated_successfully":"\u7ebf\u7d22\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","lead_status_used_somewhere_else":"\u94c5\u72b6\u6001\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u3002","name":"\u540d\u79f0","new_lead_status":"\u65b0\u7ebf\u7d22\u72b6\u6001","order":"\u8ba2\u8d2d"},"leads":"\u6f5c\u5728\u5ba2\u6237","list_view":"\u5217\u8868\u663e\u793a","login":{"admin":"\u7ba1\u7406\u5458","client":"\u5ba2\u6237","create_one":"\u521b\u5efa\u4e00\u4e2a","don't have an account":"\u8fd8\u6ca1\u6709\u5e10\u53f7\uff1f","email":"\u7535\u5b50\u90ae\u4ef6","forgot_password":"\u5fd8\u8bb0\u5bc6\u7801","login":"\u767b\u5f55","password":"\u5bc6\u7801","remember_me":"\u8bb0\u5f97\u6211"},"member":{"add":"\u52a0","by_deleting_this_member":"\u901a\u8fc7\u5220\u9664\u6b64\u6210\u5458\u7684\u6240\u6709\u9879\u76ee\uff0c\u63d0\u6848\u548c\u76ee\u6807\uff0c\u5c06\u5220\u9664\u5b83\u4eec\u3002","choose":"\u9009\u62e9","created_on":"\u521b\u5efa\u4e8e","default_language":"\u9884\u8bbe\u8bed\u8a00","delete_member_confirm":"\u60a8\u786e\u5b9a\u8981\u5220\u9664\u8be5\u6210\u5458\u5417\uff1f","edit_member":"\u7f16\u8f91\u4f1a\u5458","email":"\u7535\u5b50\u90ae\u4ef6","email_is_not_verified":"\u90ae\u4ef6\u672a\u9a8c\u8bc1","email_is_verified":"\u7535\u5b50\u90ae\u4ef6\u5df2\u9a8c\u8bc1","email_verified":"\u7535\u5b50\u90ae\u4ef6\u5df2\u9a8c\u8bc1","email_verified_successfully":"\u7535\u5b50\u90ae\u4ef6\u9a8c\u8bc1\u6210\u529f\u3002","email_verify":"\u7535\u5b50\u90ae\u4ef6\u9a8c\u8bc1","facebook":"\u8138\u4e66","first_name":"\u540d\u5b57","hourly_rate":"\u6bcf\u5c0f\u65f6\u6536\u8d39","image":"\u4e2a\u4eba\u8d44\u6599","is_enable":"\u542f\u7528\u4e24\u56e0\u7d20\u8eab\u4efd\u9a8c\u8bc1","last_name":"\u59d3","linkedin":"\u9886\u82f1","member_details":"\u4f1a\u5458\u8d44\u6599","member_informations":"\u4f1a\u5458\u4fe1\u606f","member_not_found":"\u627e\u4e0d\u5230\u4f1a\u5458\u3002","member_saved_successfully":"\u4f1a\u5458\u4fdd\u5b58\u6210\u529f\u3002","member_security":"\u4f1a\u5458\u5b89\u5168","member_status_updated_successfully":"\u4f1a\u5458\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","member_updated_successfully":"\u4f1a\u5458\u66f4\u65b0\u6210\u529f\u3002","new_member":"\u65b0\u6210\u5458","no_member_available":"\u6ca1\u6709\u53ef\u7528\u4f1a\u5458\u3002","on_member_found":"\u627e\u4e0d\u5230\u4f1a\u5458\u3002","password":"\u5bc6\u7801","password_confirmation":"\u786e\u8ba4\u5bc6\u7801","permissions":"\u6743\u9650","phone":"\u7535\u8bdd","profile":"\u4e2a\u4eba\u8d44\u6599","resend_email_verification":"\u91cd\u65b0\u53d1\u9001\u7535\u5b50\u90ae\u4ef6\u9a8c\u8bc1","send_welcome_email":"\u53d1\u9001\u6b22\u8fce\u7535\u5b50\u90ae\u4ef6","skype":"Skype","staff_member":"\u4e0d\u662f\u804c\u5458","total_members":"\u6703\u54e1\u7e3d\u6578","verification_mail_has_been_sent":"\u9a8c\u8bc1\u90ae\u4ef6\u5df2\u53d1\u9001\u6210\u529f\u3002"},"members":"\u4f1a\u5458","menu_settings":"\u83dc\u5355\u8bbe\u5b9a","months":{"apr":"\u56db\u6708","aug":"\u4e5d\u6708","dec":"\u592a\u9633","feb":"\u4e8c\u6708","jan":"\u7b80","jul":"\u516b\u6708","jun":"\u541b","mar":"\u4e09\u6708","may":"\u53ef\u80fd","nov":"\u5341\u4e8c\u6708","oct":"\u5341\u4e00\u6708","sep":"\u5341\u6708"},"new_language":"\u65b0\u8bed\u8a00","no_matching_records_found":"\u6ca1\u6709\u627e\u5230\u5339\u914d\u7684\u8bb0\u5f55","note":{"add_note":"\u52a0\u6ce8","edit_note":"\u7f16\u8f91\u7b14\u8bb0","new_note":"\u65b0\u7b14\u8bb0","no_notes_added_yet":"\u5c1a\u672a\u6dfb\u52a0\u6ce8\u91ca","notes_saved_successfully":"\u7b14\u8bb0\u4fdd\u5b58\u6210\u529f\u3002","notes_updated_successfully":"\u7b14\u8bb0\u66f4\u65b0\u6210\u529f\u3002"},"notes":"\u7b14\u8bb0","notification":{"all_notification_read_successfully":"\u6240\u6709\u901a\u77e5\u8bfb\u53d6\u6210\u529f\u3002","empty_notifications":"\u6211\u4eec\u627e\u4e0d\u5230\u4efb\u4f55\u901a\u77e5","mark_all_as_read":"\u6807\u8bb0\u4e3a\u5df2\u8bfb","notification_read_successfully":"\u901a\u77e5\u8bfb\u53d6\u6210\u529f\u3002","notifications":"\u901a\u77e5"},"others":"\u5176\u4ed6","payment":{"amount":"\u91cf","amount_received":"\u6536\u5230\u91d1\u989d","date":"\u65e5\u671f","new_payment":"\u65b0\u4ed8\u6b3e","note":"\u6ce8\u610f","payment_date":"\u652f\u4ed8\u65e5\u671f","payment_mode":"\u4ed8\u6b3e\u65b9\u5f0f","payment_saved_successfully":"\u4ed8\u6b3e\u4fdd\u5b58\u6210\u529f\u3002","send_mail_to_customer_contacts":"\u4e0d\u8981\u5c06\u53d1\u7968\u4ed8\u6b3e\u8bb0\u5f55\u7684\u7535\u5b50\u90ae\u4ef6\u53d1\u9001\u7ed9\u5ba2\u6237\u8054\u7cfb\u4eba","transaction_id":"\u4ea4\u6613\u7f16\u53f7","your_payment_is_completed":"\u60a8\u7684\u4ed8\u6b3e\u5df2\u6210\u529f\u5b8c\u6210\u3002","your_payment_is_ont_completed":"\u60a8\u7684\u4ed8\u6b3e\u672a\u5b8c\u6210\u3002"},"payment_mode":{"active":"\u6d3b\u6027","add_new_payment_mode":"\u6dfb\u52a0\u65b0\u7684\u4ed8\u6b3e\u65b9\u5f0f","bank_accounts":"\u94f6\u884c\u8d26\u6237","edit_payment_mode":"\u7f16\u8f91\u4ed8\u6b3e\u65b9\u5f0f","expenses_only":"\u4ec5\u8d39\u7528","invoices_only":"\u4ec5\u53d1\u7968","new_payment_mode":"\u65b0\u7684\u4ed8\u6b3e\u65b9\u5f0f","no_payment_mode_available":"\u6ca1\u6709\u53ef\u7528\u7684\u4ed8\u6b3e\u65b9\u5f0f\u3002","on_invoice_pdf":"\u5728\u53d1\u7968PDF\u4e0a","on_payment_mode_found":"\u627e\u4e0d\u5230\u4ed8\u6b3e\u65b9\u5f0f\u3002","payment_mode_details":"\u4ed8\u6b3e\u65b9\u5f0f\u8be6\u60c5","payment_mode_not_found":"\u627e\u4e0d\u5230\u4ed8\u6b3e\u65b9\u5f0f\u3002","payment_mode_saved_successfully":"\u652f\u4ed8\u65b9\u5f0f\u4fdd\u5b58\u6210\u529f\u3002","payment_mode_updated_successfully":"\u652f\u4ed8\u65b9\u5f0f\u66f4\u65b0\u6210\u529f\u3002","payment_mode_used_somewhere_else":"\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u7684\u4ed8\u6b3e\u65b9\u5f0f\u3002","selected_by_default_on_invoice":"\u9ed8\u8ba4\u9009\u4e2d\u53d1\u7968","show":"\u8868\u6f14"},"payment_modes":"\u4ed8\u6b3e\u65b9\u5f0f","placeholder":{"add_note":"\u6dfb\u52a0\u6ce8\u91ca...","add_product":"\u6dfb\u52a0\u4ea7\u54c1","bill_tasks":"\u8d26\u5355\u4efb\u52a1","contact_number_is_invalid_number":"\u8054\u7edc\u53f7\u7801\u662f\u65e0\u6548\u53f7\u7801","enter_email":"\u8f93\u5165\u7535\u5b50\u90ae\u4ef6","invalid_country_code":"\u56fd\u5bb6\u4ee3\u7801\u65e0\u6548","invalid_number":"\u65e0\u6548\u53f7\u7801","search_customers":"\u641c\u7d22\u5ba2\u6237","search_menu":"\u641c\u7d22\u83dc\u5355","select_article_group":"\u9009\u62e9\u6587\u7ae0\u7ec4","select_assignee":"\u9009\u62e9\u53d7\u8ba9\u4eba","select_billing_type":"\u9009\u62e9\u8ba1\u8d39\u7c7b\u578b","select_contact":"\u9009\u62e9\u8054\u7cfb\u4eba","select_contract_type":"\u9009\u62e9\u5408\u7ea6\u7c7b\u578b","select_country":"\u9009\u62e9\u56fd\u5bb6","select_currency":"\u9009\u62e9\u8d27\u5e01","select_customer":"\u9009\u62e9\u5ba2\u6237","select_department":"\u9009\u62e9\u90e8\u95e8","select_discount_type":"\u9009\u62e9\u6298\u6263\u7c7b\u578b","select_document_type":"\u9009\u62e9\u6298\u6263\u7c7b\u578b","select_email_status":"\u9009\u62e9\u7535\u5b50\u90ae\u4ef6\u72b6\u6001","select_email_template":"\u9009\u62e9\u7535\u5b50\u90ae\u4ef6\u6a21\u677f","select_expanse_category":"\u9009\u62e9\u8d39\u7528\u7c7b\u522b","select_file":"\u9009\u62e9\u6587\u4ef6","select_goal":"\u9009\u62e9\u76ee\u6807","select_goal_type":"\u9009\u62e9\u76ee\u6807\u7c7b\u578b","select_group":"\u9009\u62e9\u7ec4","select_groups":"\u9009\u62e9\u7ec4","select_internal_article":"\u9009\u62e9\u5185\u90e8\u6587\u7ae0","select_item":"\u9009\u62e9\u7269\u54c1","select_language":"\u9009\u62e9\u8bed\u8a00","select_lead":" \u9009\u62e9\u6f5c\u5728\u5ba2\u6237","select_lead_source":"\u9009\u62e9\u6f5c\u5728\u5ba2\u6237\u6765\u6e90","select_member":"\u9009\u62e9\u4f1a\u5458","select_option":"\u9009\u62e9\u9009\u9879","select_payment_mode":"\u9009\u62e9\u4ed8\u6b3e\u65b9\u5f0f","select_predefined_reply":"\u9009\u62e9\u9884\u5b9a\u4e49\u56de\u590d","select_priority":"\u9009\u62e9\u4f18\u5148\u7ea7","select_product":"\u9009\u62e9\u4ea7\u54c1","select_product_group":"\u9009\u62e9\u4ea7\u54c1\u7ec4","select_reminder_to":"\u9009\u62e9\u63d0\u9192\u5230","select_sale_agent":"\u9009\u62e9\u9500\u552e\u4ee3\u7406","select_service":"\u9009\u62e9\u670d\u52a1","select_show_to_client":"\u9009\u62e9\u5411\u5ba2\u6237\u5c55\u793a","select_source":"\u9009\u62e9\u6765\u6e90","select_status":"\u9009\u62e9\u72b6\u6001","select_tags":"\u9009\u62e9\u6807\u7b7e","select_tax":"\u9009\u62e9\u7a0e","select_tax1":"\u9009\u62e9\u7a0e 1","select_tax2":"\u9009\u62e9\u7a0e 2","select_template_type":"\u9009\u62e9\u6a21\u677f\u7c7b\u578b","select_ticket_priority":"\u9009\u62e9\u7968\u52a1\u4f18\u5148\u7ea7","too_long":"\u592a\u957f","too_short":"\u592a\u77ed","valid_number":"\u6709\u6548\u53f7\u7801"},"please_enter_language_short_code":"\u8bf7\u8f93\u5165\u8bed\u8a00\u77ed\u4ee3\u7801\u3002 \u5373\u82f1\u8bed= zh\u3002","predefined_replies":"\u9884\u5b9a\u4e49\u7684\u56de\u590d","predefined_reply":{"add":"\u52a0","add_new_predefined_reply":"\u6dfb\u52a0\u65b0\u7684\u9884\u5b9a\u4e49\u56de\u590d","body":"\u8eab\u4f53","edit_predefined_reply":"\u7f16\u8f91\u9884\u5b9a\u4e49\u7684\u56de\u590d","new_predefined_reply":"\u65b0\u7684\u9884\u5b9a\u4e49\u56de\u590d","no_predefined_reply_available":"\u6ca1\u6709\u53ef\u7528\u7684\u9884\u5b9a\u4e49\u7b54\u590d\u3002","no_predefined_reply_found":"\u627e\u4e0d\u5230\u9884\u5b9a\u4e49\u7684\u56de\u590d\u3002","predefined_reply_details":"\u9884\u5b9a\u4e49\u7684\u56de\u590d\u8be6\u7ec6\u4fe1\u606f","predefined_reply_not_found":"\u672a\u627e\u5230\u9884\u5b9a\u4e49\u7684\u56de\u590d\u3002","predefined_reply_saved_successfully":"\u9884\u5b9a\u4e49\u56de\u590d\u5df2\u6210\u529f\u4fdd\u5b58\u3002","predefined_reply_updated_successfully":"\u9884\u5b9a\u4e49\u56de\u590d\u66f4\u65b0\u6210\u529f\u3002","reply_name":"\u56de\u590d\u540d\u79f0"},"product_group":{"add_new_product_group":"\u6dfb\u52a0\u65b0\u4ea7\u54c1\u7ec4","edit_product_group":"\u7f16\u8f91\u4ea7\u54c1\u7ec4","new_product_group":"\u65b0\u4ea7\u54c1\u7ec4","product_group_saved_successfully":"\u4ea7\u54c1\u7ec4\u4fdd\u5b58\u6210\u529f\u3002","product_group_updated_successfully":"\u4ea7\u54c1\u7ec4\u66f4\u65b0\u6210\u529f\u3002","product_group_used_somewhere_else":"\u4ea7\u54c1\u7ec4\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u3002"},"product_groups":"\u4ea7\u54c1\u7ec4","products":{"edit_product":"\u7f16\u8f91\u4ea7\u54c1","new_product":"\u65b0\u4ea7\u54c1","product_group":"\u4ea7\u54c1\u7ec4","product_saved_successfully":"\u4ea7\u54c1\u4fdd\u5b58\u6210\u529f\u3002","product_updated_successfully":"\u4ea7\u54c1\u66f4\u65b0\u6210\u529f\u3002","products":"\u4ea7\u54c1\u5c55\u793a","rate":"\u7387","tax":"\u7a0e","title":"\u6807\u9898","unit":"\u5355\u5143"},"profile":"\u4e2a\u4eba\u8d44\u6599","project":{"admin_area":"\u7ba1\u7406\u533a","allow_customer_to":"\u5141\u8bb8\u5ba2\u6237","billing_type":"\u5e10\u5355\u7c7b\u578b","calculate_progress_through_tasks":"\u8ba1\u7b97\u4efb\u52a1\u8fdb\u5ea6","cancelled":"\u53d6\u6d88","comment_on_project_tasks":"\u8bc4\u8bba\u9879\u76ee\u4efb\u52a1","create_tasks":"\u521b\u5efa\u4efb\u52a1","customer":"\u987e\u5ba2","deadline":"\u6700\u540e\u671f\u9650","edit_project":"\u7f16\u8f91\u4e13\u6848","edit_tasks":"\u7f16\u8f91\u4efb\u52a1","estimated_hours":"\u9884\u8ba1\u65f6\u95f4","finished":"\u5df2\u5b8c\u6210","hide_project_tasks_on_main_tasks_table":"\u5728\u4e3b\u8981\u4efb\u52a1\u8868\u4e0a\u9690\u85cf\u9879\u76ee\u4efb\u52a1","in_progress":"\u8fdb\u884c\u4e2d","members":"\u8054\u7cfb","new_project":"\u65b0\u9879\u76ee","no_project_available":"\u6ca1\u6709\u53ef\u7528\u7684\u9879\u76ee","no_project_found":"\u627e\u4e0d\u5230\u9805\u76ee","not_started":"\u6ca1\u6709\u5f00\u59cb","on_hold":"\u7b49\u5019\u63a5\u542c","only_task_created_from_contact":"\u4ec5\u7531\u8054\u7cfb\u4eba\u521b\u5efa\u7684\u4efb\u52a1","open_discussions":"\u516c\u5f00\u8ba8\u8bba","progress":"\u8fdb\u5c55","project_details":"\u9879\u76ee\u8be6\u60c5","project_name":"\u9879\u76ee\u540d\u79f0","project_saved_successfully":"\u9879\u76ee\u4fdd\u5b58\u6210\u529f\u3002","project_settings":"\u9879\u76ee\u8bbe\u5b9a","project_updated_successfully":"\u9879\u76ee\u66f4\u65b0\u6210\u529f\u3002","projects_summary":"\u9879\u76ee\u603b\u7ed3","quick_invoices_info":"\u5feb\u901f\u53d1\u7968\u4fe1\u606f","send_project_created_email":"\u53d1\u9001\u9879\u76ee\u521b\u5efa\u7684\u7535\u5b50\u90ae\u4ef6","start_date":"\u5f00\u59cb\u65e5\u671f","statistics_by_project_status":"\u6309\u9879\u76ee\u72b6\u6001\u7edf\u8ba1","status":"\u72b6\u6001","total_projects":"\u603b\u9879\u76ee","upload_attachments_on_tasks":"\u4e0a\u4f20\u4efb\u52a1\u9644\u4ef6","upload_files":"\u4e0a\u4f20\u6587\u4ef6","view_account_statement":"\u67e5\u770b\u5e10\u6237\u5bf9\u5e10\u5355","view_activity_log":"\u67e5\u770b\u6d3b\u52a8\u65e5\u5fd7","view_finance_overview":"\u67e5\u770b\u8d22\u52a1\u6982\u89c8","view_gantt":"\u67e5\u770b\u7518\u7279","view_milestones":"\u67e5\u770b\u91cc\u7a0b\u7891","view_task_attachments":"\u67e5\u770b\u4efb\u52a1\u9644\u4ef6","view_task_checklist_items":"\u67e5\u770b\u4efb\u52a1\u6e05\u5355\u9879\u76ee","view_task_comments":"\u67e5\u770b\u4efb\u52a1\u6ce8\u91ca","view_task_total_logged_time":"\u67e5\u770b\u4efb\u52a1\u7684\u603b\u8bb0\u5f55\u65f6\u95f4","view_tasks":"\u67e5\u770b\u4efb\u52a1","view_team_members":"\u67e5\u770b\u56e2\u961f\u6210\u5458","view_timesheets":"\u67e5\u770b\u65f6\u95f4\u8868","visible_tables":"\u53ef\u89c1\u8868"},"projects":"\u4e13\u6848","proposal":{"accept":"\u63a5\u53d7","accepted":"\u516c\u8ba4","adjustment":"\u8c03\u6574","amount":"\u91cf","amount_due":"\u5e94\u4ed8\u91d1\u989d","authorized_signature":"\u6388\u6743\u7b7e\u540d","bank":"\u94f6\u884c","bill_to":"\u8bb0\u8d26\u5230","comments":"\u6ce8\u91ca","convert":"\u5151\u6362","convert_proposal":"\u8f6c\u6362\u63d0\u6848","date":"\u65e5\u671f","decline":"\u4e0b\u964d","declined":"\u62d2\u7edd","discount":"\u6298\u6263","draft":"\u8349\u6848","drafted":"\u5df2\u8d77\u8349","edit_proposal":"\u7f16\u8f91\u63d0\u6848","item":"\u4ea7\u54c1","lead":"\u94c5","mark_as_accepted":"\u6807\u8bb0\u4e3a\u63a5\u53d7","mark_as_declined":"\u6807\u8bb0\u4e3a\u5df2\u62d2\u7edd","mark_as_draft":"\u6807\u8bb0\u4e3a\u8349\u7a3f","mark_as_open":"\u6807\u8bb0\u4e3a\u6253\u5f00","mark_as_revised":"\u6807\u8bb0\u4e3a\u4fee\u8ba2\u7248","mark_as_send":"\u6807\u8bb0\u4e3a\u53d1\u9001","member":"\u4f1a\u5458","new_proposal":"\u65b0\u63d0\u6848","no_payments_available":"\u6ca1\u6709\u53ef\u7528\u7684\u4ed8\u6b3e","no_proposal_available":"\u6c92\u6709\u53ef\u7528\u7684\u63d0\u6848.","no_proposal_found":"\u627e\u4e0d\u5230\u63d0\u6848\u3002","offline_payment":"\u79bb\u7ebf\u4ed8\u6b3e","online_payment":"\u7f51\u4e0a\u652f\u4ed8","open":"\u6253\u5f00","open_till":"\u5f00\u8015","pay_now":"\u73b0\u5728\u4ed8\u6b3e","payment":"\u4ed8\u6b3e","proposal":"\u63d0\u6848","proposal_date":"\u63d0\u6848\u65e5\u671f","proposal_details":"\u63d0\u6848\u8be6\u7ec6\u4fe1\u606f","proposal_not_found":"\u627e\u4e0d\u5230\u63d0\u6848.","proposal_number":"\u63d0\u6848\u7f16\u53f7","proposal_overview":"\u63d0\u6848\u6982\u8ff0","proposal_pdf":"\u63d0\u6848PDF","proposal_prefix":"PRO-","proposal_saved_successfully":"\u63d0\u6848\u4fdd\u5b58\u6210\u529f\u3002","proposal_to":"\u63d0\u6848\u81f3","proposal_updated_successfully":"\u63d0\u6848\u66f4\u65b0\u6210\u529f\u3002","qty":"\u6570\u91cf","rate":"\u7387","related":"\u6709\u5173","revised":"\u4fee\u8ba2\u7248","save_and_send":"\u4fdd\u5b58\u5e76\u53d1\u9001","save_as_draft":"\u53e6\u5b58\u4e3a\u8349\u7a3f","sent":"\u5df2\u53d1\u9001","ship_to":"\u8fd0\u9001\u5230","status":"\u63d0\u6848\u72b6\u6001","sub_total":"\u5c0f\u8ba1","subject":"\u5b66\u79d1","taxes":"\u7a0e\u6536","to":"\u81f3","total":"\u603b","total_paid":"\u603b\u652f\u4ed8","total_proposal":"\u63d0\u6848\u603b\u6570","transactions":"\u4ea4\u6613\u6b21\u6570","view_proposal_as_customer":"\u4ee5\u5ba2\u6237\u8eab\u4efd\u67e5\u770b\u6295\u6807"},"proposals":"\u63d0\u6848","range":{"last_30":"\u8fc7\u53bb 30 \u5929","last_month":"\u4e0a\u4e2a\u6708","last_week":"\u4e0a\u5468","this_month":"\u8fd9\u4e2a\u6708","this_week":"\u672c\u661f\u671f","today":"\u4eca\u5929"},"register":{"already_have_an_account":"\u5df2\u7ecf\u6709\u5e10\u53f7\u4e86\uff1f","choose":"\u9009\u62e9","confirm_password":"\u786e\u8ba4\u5bc6\u7801","email":"\u7535\u5b50\u90ae\u4ef6","first_name":"\u540d\u5b57","last_name":"\u59d3","password":"\u5bc6\u7801","phone":"\u7535\u8bdd","profile_picture":"\u4e2a\u4eba\u8d44\u6599\u56fe\u7247","register":"\u5bc4\u5b58\u5668","sign_in":"\u767b\u5165"},"reminder":{"add_new":"\u6dfb\u65b0","description":"\u63cf\u8ff0","edit_reminder":"\u7f16\u8f91\u63d0\u9192","email_status":"\u7535\u5b50\u90ae\u4ef6\u72b6\u6001","is_notified":"\u5df2\u901a\u77e5","new_reminder":"\u65b0\u63d0\u9192","no":"\u4e0d","note":"\u7b14\u8bb0","note_text":"\u8bf7\u6ce8\u610f\uff0c\u60a8\u5fc5\u987b\u9009\u62e9 UTC \u65e5\u671f\u65f6\u95f4\uff0c\u56e0\u4e3a cron \u4f5c\u4e1a\u4f1a\u6839\u636e UTC \u65f6\u95f4\u53d1\u9001\u63d0\u9192\u3002","notified_date":"\u901a\u77e5\u65e5\u671f","reminder_saved_successfully":"\u63d0\u9192\u4fdd\u5b58\u6210\u529f\u3002","reminder_to":"\u63d0\u9192","reminder_updated_successfully":"\u63d0\u9192\u66f4\u65b0\u6210\u529f\u3002","send_email_reminder":"\u53d1\u9001\u63d0\u9192\u7535\u5b50\u90ae\u4ef6","sent":"\u53d1\u9001","set_reminder":"\u8bbe\u5b9a\u63d0\u9192","ticket_reminder":"\u95e8\u7968\u63d0\u9192","yes":"\u662f\u7684"},"reminders":"\u63d0\u9192\u4e8b\u9879","reset":{"confirm_password":"\u786e\u8ba4\u5bc6\u7801","email":"\u7535\u5b50\u90ae\u4ef6","password":"\u5bc6\u7801","recalled_your_login_info":"\u53ec\u56de\u60a8\u7684\u767b\u5f55\u4fe1\u606f\uff1f","reset_password":"\u91cd\u8bbe\u5bc6\u7801","set_a_new_password":"\u8bbe\u5b9a\u65b0\u5bc6\u7801","sign_in":"\u767b\u5165"},"sales":"\u8425\u4e1a\u989d","service":{"add":"\u52a0","edit_service":"\u7f16\u8f91\u670d\u52a1","name":"\u540d\u79f0","new_service":"\u65b0\u670d\u52a1","no_service_available":"\u6ca1\u6709\u53ef\u7528\u7684\u670d\u52a1\u3002","on_service_found":"\u627e\u4e0d\u5230\u670d\u52a1\u3002","service_not_found":"\u6ca1\u6709\u53ef\u7528\u7684\u670d\u52a1\u3002","service_saved_successfully":"\u670d\u52a1\u4fdd\u5b58\u6210\u529f\u3002","service_updated_successfully":"\u670d\u52a1\u66f4\u65b0\u6210\u529f\u3002","service_used_somewhere_else":"\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u7684\u670d\u52a1\u3002"},"services":"\u670d\u52a1","setting":{"application_name":"\u5e94\u7528\u540d\u79f0","choose":"\u9009\u62e9","current_version":"\u5f53\u524d\u7248\u672c","favicon":"\u7f51\u7ad9\u56fe\u6807","file_type":"\u6587\u4ef6\u7c7b\u578b","logo":"\u516c\u53f8\u6807\u5fd7","setting_updated_successfully":"\u8bbe\u7f6e\u66f4\u65b0\u6210\u529f\u3002"},"settings":"\u8bbe\u5b9a\u503c","staff":"\u5458\u5de5","status":{"additional_contact":"\u5176\u4ed6\u8054\u7edc\u4eba","answered":"\u5df2\u56de\u7b54","attempted":"\u5c1d\u8bd5\u8fc7","cancelled":"\u53d6\u6d88","closed":"\u5173\u95ed","contacted":"\u5df2\u8054\u7edc","finished":"\u5df2\u5b8c\u6210","in_progress":"\u8fdb\u884c\u4e2d","new_opportunity":"\u65b0\u673a\u4f1a","not_attempted":"\u6ca1\u6709\u5c1d\u8bd5","not_started":"\u6ca1\u6709\u5f00\u59cb","on_hold":"\u7b49\u5019\u63a5\u542c","open":"\u6253\u5f00"},"success":"\u6210\u529f","support":"\u652f\u6301","tag":{"add":"\u52a0","add_new_tag":"\u6dfb\u52a0\u65b0\u6807\u7b7e","description":"\u63cf\u8ff0","edit_tag":"\u7f16\u8f91\u6807\u7b7e","name":"\u540d\u79f0","new_tag":"\u65b0\u6807\u7b7e","no_tag_available":"\u6ca1\u6709\u53ef\u7528\u7684\u6807\u7b7e\u3002","no_tag_found":"\u627e\u4e0d\u5230\u6807\u7b7e\u3002","tag_details":"\u6807\u7b7e\u8be6\u7ec6\u4fe1\u606f","tag_not_found":"\u627e\u4e0d\u5230\u6a19\u7c64\u3002","tag_saved_successfully":"\u6807\u7b7e\u4fdd\u5b58\u6210\u529f\u3002","tag_updated_successfully":"\u6807\u7b7e\u66f4\u65b0\u6210\u529f\u3002"},"tags":"\u6807\u7b7e","task":{"awaiting_feedback":"\u7b49\u5f85\u53cd\u9988","billable":"\u53ef\u5f00\u7968","completed":"\u5df2\u5b8c\u6210","due_date":"\u622a\u6b62\u65e5\u671f","edit_task":"\u7f16\u8f91\u4efb\u52a1","hourly_rate":"\u6bcf\u5c0f\u65f6\u6536\u8d39","in_progress":"\u8fdb\u884c\u4e2d","name":"\u540d\u79f0","new_task":"\u65b0\u4efb\u52a1","no_task_available":"\u6ca1\u6709\u53ef\u7528\u7684\u4efb\u52a1\u3002","not_started":"\u6ca1\u6709\u5f00\u59cb","priority":"\u4f18\u5148","public":"\u4e0a\u5e02","related_to":"\u76f8\u5173","start_date":"\u5f00\u59cb\u65e5\u671f","status":"\u72b6\u6001","subject":"\u5b66\u79d1","task_details":"\u4efb\u52a1\u8be6\u60c5","task_saved_successfully":"\u4efb\u52a1\u4fdd\u5b58\u6210\u529f\u3002","task_status_updated_successfully":"\u4efb\u52a1\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","task_updated_successfully":"\u4efb\u52a1\u66f4\u65b0\u6210\u529f\u3002","testing":"\u6d4b\u9a8c","ticket":"\u7968"},"tasks":"\u4efb\u52a1","tax_rate":{"edit_tax_rate":"\u7f16\u8f91\u7a0e\u7387","new_tax_rate":"\u65b0\u7a0e\u7387","no_tax_rate_available":"\u6ca1\u6709\u53ef\u7528\u7684\u7a0e\u7387\u3002","on_tax_rate_found":"\u627e\u4e0d\u5230\u7a0e\u7387\u3002","tax_rate":"\u7a0e\u7387","tax_rate_not_found":"\u627e\u4e0d\u5230\u7a0e\u7387\u3002","tax_rate_saved_successfully":"\u7a0e\u7387\u4fdd\u5b58\u6210\u529f\u3002","tax_rate_updated_successfully":"\u7a0e\u7387\u66f4\u65b0\u6210\u529f\u3002"},"tax_rates":"\u7a0e\u7387","this_week_payments":"\u672c\u5468\u4ed8\u6b3e","ticket":{"add":"\u52a0","added_by":"\u6dfb\u52a0\u4eba","assign_to":"\u5206\u914d\u7ed9","attachments":"\u9644\u4ef6","body":"\u8eab\u4f53","cc":"\u6284\u9001","contact":"\u8054\u7cfb","department":"\u90e8\u95e8","details":"\u7ec6\u8282","edit_ticket":"\u7f16\u8f91\u7968\u8bc1","email":"\u7535\u5b50\u90ae\u4ef6","name":"\u540d\u79f0","new_ticket":"\u65b0\u7968","no_ticket_available":"\u6ca1\u6709\u53ef\u7528\u7684\u7968\u3002","note":"\u6ce8\u610f","on_ticket_found":"\u627e\u4e0d\u5230\u5de5\u5355\u3002","predefined_reply":"\u9884\u5b9a\u4e49\u7684\u56de\u590d","priority":"\u4f18\u5148","reminder":"\u63d0\u9192","service":"\u670d\u52a1","subject":"\u5b66\u79d1","tags":"\u6807\u7b7e","ticket_details":"\u673a\u7968\u8be6\u60c5","ticket_not_found":"\u627e\u4e0d\u5230\u5de5\u5355\u3002","ticket_saved_successfully":"\u7968\u636e\u4fdd\u5b58\u6210\u529f\u3002","ticket_status_updated_successfully":"\u5de5\u5355\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","ticket_to_contact":"\u8054\u7cfb\u65b9\u5f0f","ticket_updated_successfully":"\u7968\u8bc1\u66f4\u65b0\u6210\u529f\u3002","ticket_without_contact":"\u6ca1\u6709\u8054\u7cfb\u7684\u7968","tickets_status":"\u95e8\u7968\u72b6\u6001","you_can_add_multiples_images_and_files":"\u60a8\u53ef\u4ee5\u6dfb\u52a0\u591a\u4e2a\u56fe\u50cf\u548c\u6587\u4ef6"},"ticket_priorities":"\u7968\u52a1\u4f18\u5148\u7ea7","ticket_priority":{"add":"\u52a0","add_new_ticket_priority":"\u6dfb\u52a0\u65b0\u5de5\u5355\u4f18\u5148\u7ea7","edit_ticket_priority":"\u7f16\u8f91\u7968\u52a1\u4f18\u5148\u6743","name":"\u540d\u79f0","new_ticket_priority":"\u65b0\u7968\u4f18\u5148","no_ticket_priority_available":"\u6ca1\u6709\u53ef\u7528\u7684\u7968\u52a1\u4f18\u5148\u6743\u3002","on_ticket_priority_found":"\u627e\u4e0d\u5230\u7968\u52a1\u4f18\u5148\u6743\u3002","ticket_priority_not_found":"\u627e\u4e0d\u5230\u7968\u52a1\u4f18\u5148\u6743\u3002","ticket_priority_saved_successfully":"\u7968\u8bc1\u4f18\u5148\u7ea7\u4fdd\u5b58\u6210\u529f\u3002","ticket_priority_updated_successfully":"Ticket Priority \u66f4\u65b0\u6210\u529f\u3002","ticket_priority_used_somewhere_else":"\u7968\u52a1\u4f18\u5148\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u3002"},"ticket_status":{"add":"\u52a0","add_new_ticket_status":"\u6dfb\u52a0\u65b0\u5de5\u5355\u72b6\u6001","color":"\u989c\u8272","edit_ticket_status":"\u7f16\u8f91\u7968\u8bc1\u72b6\u6001","name":"\u540d\u79f0","new_ticket_status":"\u65b0\u7968\u72b6\u6001","status_order":"\u72b6\u6001\u987a\u5e8f","ticket_status":"\u7968\u52a1\u72b6\u6001","ticket_status_saved_successfully":"\u5de5\u5355\u72b6\u6001\u4fdd\u5b58\u6210\u529f\u3002","ticket_status_updated_successfully":"\u5de5\u5355\u72b6\u6001\u66f4\u65b0\u6210\u529f\u3002","ticket_status_used_somewhere_else":"\u7968\u72b6\u6001\u5728\u5176\u4ed6\u5730\u65b9\u4f7f\u7528\u3002"},"tickets":"\u5165\u573a\u5238","translation_manager":"\u7ffb\u8bd1\u7ecf\u7406","translator_manager":{"edit_language":"\u7f16\u8f91\u8bed\u8a00","language_added_successfully":"\u8bed\u8a00\u6dfb\u52a0\u6210\u529f\u3002","language_short_code":"\u8bf7\u8f93\u5165\u8bed\u8a00\u77ed\u4ee3\u7801\u3002 \u5373\u82f1\u8bed= en","language_updated_successfully":"\u8bed\u8a00\u66f4\u65b0\u6210\u529f\u3002","translation":"\u7ffb\u8bd1"},"user":{"change_language":"\u6539\u53d8\u8bed\u8a00","change_password":"\u66f4\u6539\u5bc6\u7801","edit_profile":"\u7f16\u8f91\u4e2a\u4eba\u8d44\u6599","email":"\u7535\u5b50\u90ae\u4ef6","first_name":"\u540d\u5b57","language":"\u8bed\u8a00","last_name":"\u59d3","logout":"\u767b\u51fa","name":"\u540d\u79f0","password":"\u5bc6\u7801","password_confirmation":"\u786e\u8ba4\u5bc6\u7801","phone":"\u7535\u8bdd","profile":"\u4e2a\u4eba\u8d44\u6599","return_to_admin":"\u8fd4\u56de\u7ba1\u7406\u5458"},"users":"\u7528\u6237\u6570","weekdays":{"fri":"\u5468\u4e94","mon":"\u661f\u671f\u4e00","sat":"\u661f\u671f\u516d","sun":"\u592a\u9633","thu":"\u5468\u56db","tue":"\u5468\u4e8c","wed":"\u661f\u671f\u4e09"}},"zh.pagination":{"next":"\u4e0b\u4e00\u4e2a &raquo;","previous":"&laquo; \u4ee5\u524d"},"zh.passwords":{"reset":"\u60a8\u7684\u5bc6\u7801\u5df2\u91cd\u7f6e\uff01","sent":"\u6211\u4eec\u5df2\u7ecf\u901a\u8fc7\u7535\u5b50\u90ae\u4ef6\u53d1\u9001\u4e86\u60a8\u7684\u5bc6\u7801\u91cd\u7f6e\u94fe\u63a5\uff01","throttled":"\u8bf7\u7b49\u5f85\uff0c\u7136\u540e\u91cd\u8bd5\u3002","token":"\u6b64\u5bc6\u7801\u91cd\u7f6e\u4ee4\u724c\u65e0\u6548\u3002","user":"\u6211\u4eec\u627e\u4e0d\u5230\u4f7f\u7528\u8be5\u7535\u5b50\u90ae\u4ef6\u5730\u5740\u7684\u7528\u6237\u3002"},"zh.validation":{"accepted":"\uff1aattribute\u5fc5\u987b\u88ab\u63a5\u53d7\u3002","active_url":"\uff1aattribute\u4e0d\u662f\u6709\u6548\u7684URL\u3002","after":"\uff1aattribute\u5fc5\u987b\u662f\uff1adate\u4e4b\u540e\u7684\u65e5\u671f\u3002","after_or_equal":"\uff1aattribute\u5fc5\u987b\u662f\u7b49\u4e8e\u6216\u5c0f\u4e8e\uff1adate\u7684\u65e5\u671f\u3002","alpha":"\uff1aattribute\u53ea\u80fd\u5305\u542b\u5b57\u6bcd\u3002","alpha_dash":"\uff1aattribute\u53ea\u80fd\u5305\u542b\u5b57\u6bcd\uff0c\u6570\u5b57\uff0c\u7834\u6298\u53f7\u548c\u4e0b\u5212\u7ebf\u3002","alpha_num":"\uff1aattribute\u53ea\u80fd\u5305\u542b\u5b57\u6bcd\u548c\u6570\u5b57\u3002","array":"\uff1aattribute\u5fc5\u987b\u662f\u4e00\u4e2a\u6570\u7ec4\u3002","attributes":[],"before":"\uff1aattribute\u5fc5\u987b\u662f\uff1adate\u4e4b\u524d\u7684\u65e5\u671f\u3002","before_or_equal":"\uff1aattribute\u5fc5\u987b\u662f\uff1adate\u4e4b\u524d\u6216\u7b49\u4e8e\u7684\u65e5\u671f\u3002","between":{"array":"\uff1aattribute\u5fc5\u987b\u5728\uff1amin\u548c\uff1amax\u4e4b\u95f4\u3002","file":"\uff1aattribute\u5fc5\u987b\u4ecb\u4e8e\uff1amin\u548c\uff1amax\u5343\u5b57\u8282\u4e4b\u95f4\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u4ecb\u4e8e\uff1amin\u548c\uff1amax\u4e4b\u95f4\u3002","string":"\uff1aattribute\u5fc5\u987b\u4ecb\u4e8e\uff1amin\u548c\uff1amax\u4e4b\u95f4\u3002"},"boolean":"\uff1aattribute\u5b57\u6bb5\u5fc5\u987b\u4e3atrue\u6216false\u3002","confirmed":"\uff1aattribute\u786e\u8ba4\u4e0d\u5339\u914d\u3002","custom":{"attribute-name":{"rule-name":"\u81ea\u5b9a\u4e49\u6d88\u606f"}},"date":"\uff1aattribute\u4e0d\u662f\u6709\u6548\u65e5\u671f\u3002","date_equals":"\uff1aattribute\u5fc5\u987b\u662f\u7b49\u4e8e\uff1adate\u7684\u65e5\u671f\u3002","date_format":"\uff1aattribute\u4e0e\u683c\u5f0f\uff1aformat\u4e0d\u5339\u914d\u3002","different":"\uff1aattribute\u548c\uff1aother\u5fc5\u987b\u4e0d\u540c\u3002","digits":"\uff1aattribute\u5fc5\u987b\u4e3a\uff1adigits\u4f4d\u6570\u3002","digits_between":"\uff1aattribute\u5fc5\u987b\u4ecb\u4e8e\uff1amin\u548c\uff1amax\u6570\u5b57\u4e4b\u95f4\u3002","dimensions":"\uff1aattribute\u7684\u56fe\u7247\u5c3a\u5bf8\u65e0\u6548\u3002","distinct":"\uff1aattribute\u5b57\u6bb5\u5177\u6709\u91cd\u590d\u503c\u3002","email":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u7684\u7535\u5b50\u90ae\u4ef6\u5730\u5740\u3002","ends_with":"\uff1aattribute\u5fc5\u987b\u4ee5\u4e0b\u5217\u4e4b\u4e00\u7ed3\u5c3e\uff1a: values\u3002","exists":"\u6240\u9009\u7684\uff1aattribute\u65e0\u6548\u3002","file":"\uff1aattribute\u5fc5\u987b\u662f\u4e00\u4e2a\u6587\u4ef6\u3002","filled":"\uff1aattribute\u5b57\u6bb5\u5fc5\u987b\u6709\u4e00\u4e2a\u503c\u3002","gt":{"array":"\uff1aattribute\u5fc5\u987b\u5305\u542b\u591a\u4e2a\uff1avalue\u9879\u76ee\u3002","file":"\uff1aattribute\u5fc5\u987b\u5927\u4e8e\uff1avalue\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u5927\u4e8e\uff1avalue\u3002","string":"\uff1aattribute\u5fc5\u987b\u5927\u4e8e\uff1avalue\u5b57\u7b26\u3002"},"gte":{"array":"\uff1aattribute\u5fc5\u987b\u5177\u6709\uff1avalue\u9879\u6216\u66f4\u591a\u3002","file":"\uff1aattribute\u5fc5\u987b\u5927\u4e8e\u6216\u7b49\u4e8e\uff1avalue\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u5927\u4e8e\u6216\u7b49\u4e8e\uff1avalue\u3002","string":"\uff1aattribute\u5fc5\u987b\u5927\u4e8e\u6216\u7b49\u4e8e\uff1avalue\u5b57\u7b26\u3002"},"image":"\uff1aattribute\u5fc5\u987b\u662f\u56fe\u50cf\u3002","in":"\u6240\u9009\u7684\uff1aattribute\u65e0\u6548\u3002","in_array":"\uff1aattribute\u5b57\u6bb5\u5728\uff1aother\u4e2d\u4e0d\u5b58\u5728\u3002","integer":"\uff1aattribute\u5fc5\u987b\u4e3a\u6574\u6570\u3002","ip":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u7684IP\u5730\u5740\u3002","ipv4":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u7684IPv4\u5730\u5740\u3002","ipv6":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u7684IPv6\u5730\u5740\u3002","json":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u7684JSON\u5b57\u7b26\u4e32\u3002","lt":{"array":"\uff1aattribute\u5fc5\u987b\u5c11\u4e8e\uff1avalue\u4e2a\u9879\u76ee\u3002","file":"\uff1aattribute\u5fc5\u987b\u5c0f\u4e8e\uff1avalue\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u5c0f\u4e8e\uff1avalue\u3002","string":"\uff1aattribute\u5fc5\u987b\u5c0f\u4e8e\uff1avalue\u5b57\u7b26\u3002"},"lte":{"array":"\uff1aattribute\u4e0d\u5f97\u8d85\u8fc7\uff1avalue\u4e2a\u9879\u76ee\u3002","file":"\uff1aattribute\u5fc5\u987b\u5c0f\u4e8e\u6216\u7b49\u4e8e\uff1avalue\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u5c0f\u4e8e\u6216\u7b49\u4e8e\uff1avalue\u3002","string":"\uff1aattribute\u5fc5\u987b\u5c0f\u4e8e\u6216\u7b49\u4e8e\uff1avalue\u5b57\u7b26\u3002"},"max":{"array":"\uff1aattribute\u4e0d\u80fd\u8d85\u8fc7\uff1amax\u4e2a\u9879\u76ee\u3002","file":"\uff1aattribute\u4e0d\u5f97\u5927\u4e8e\uff1amax\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u4e0d\u5f97\u5927\u4e8e\uff1amax\u3002","string":"\uff1aattribute\u4e0d\u5f97\u5927\u4e8e\uff1amax\u4e2a\u5b57\u7b26\u3002"},"mimes":"\uff1aattribute\u5fc5\u987b\u662f\u7c7b\u578b\uff1a\uff1avalues\u7684\u6587\u4ef6\u3002","mimetypes":"\uff1aattribute\u5fc5\u987b\u662f\u7c7b\u578b\uff1a\uff1avalues\u7684\u6587\u4ef6\u3002","min":{"array":"\uff1aattribute\u5fc5\u987b\u81f3\u5c11\u5305\u542b\uff1amin\u4e2a\u9879\u76ee\u3002","file":"\uff1aattribute\u5fc5\u987b\u81f3\u5c11\u4e3a\uff1amin\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u81f3\u5c11\u4e3a\uff1amin\u3002","string":"\uff1aattribute\u5fc5\u987b\u81f3\u5c11\u4e3a\uff1amin\u4e2a\u5b57\u7b26\u3002"},"not_in":"\u6240\u9009\u7684\uff1aattribute\u65e0\u6548\u3002","not_regex":"\u6240\u9009\u7684\uff1aattribute\u65e0\u6548\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u4e3a\u6570\u5b57\u3002","password":"\u5bc6\u7801\u9519\u8bef\u3002","present":"\uff1aattribute\u5b57\u6bb5\u5fc5\u987b\u5b58\u5728\u3002","regex":"\uff1aattribute\u683c\u5f0f\u65e0\u6548\u3002","required":"\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u586b\u5b57\u6bb5\u3002","required_if":"\u5f53\uff1aother\u662f\uff1avalue\u65f6\uff0c\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","required_unless":"\u9664\u975e\uff1aother\u4f4d\u4e8e\uff1avalues\u4e2d\uff0c\u5426\u5219\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u586b\u5b57\u6bb5\u3002","required_with":"\u5982\u679c\u5b58\u5728\uff1avalues\uff0c\u5219\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","required_with_all":"\u5b58\u5728\uff1avalues\u65f6\uff0c\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","required_without":"\u5f53\uff1avalues\u4e0d\u5b58\u5728\u65f6\uff0c\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","required_without_all":"\u5f53\uff1avalues\u4e0d\u5b58\u5728\u65f6\uff0c\uff1aattribute\u5b57\u6bb5\u662f\u5fc5\u9700\u7684\u3002","same":"\uff1aattribute\u548c\uff1aother\u5fc5\u987b\u5339\u914d\u3002","size":{"array":"\uff1aattribute\u5fc5\u987b\u5305\u542b\uff1asize\u9879\u3002","file":"\uff1aattribute\u5fc5\u987b\u4e3a\uff1asize\u5343\u5b57\u8282\u3002","numeric":"\uff1aattribute\u5fc5\u987b\u4e3a\uff1asize\u3002","string":"\uff1aattribute\u5fc5\u987b\u4e3a\uff1asize\u5b57\u7b26\u3002"},"starts_with":"\uff1aattribute\u5fc5\u987b\u4ee5\u4e0b\u5217\u4e4b\u4e00\u5f00\u5934\uff1a\uff1avalues\u3002","string":"\uff1aattribute\u5fc5\u987b\u4e3a\u5b57\u7b26\u4e32\u3002","timezone":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u533a\u57df\u3002","unique":"\uff1aattribute\u5df2\u7ecf\u88ab\u4f7f\u7528\u3002","uploaded":"\uff1aattribute\u4e0a\u4f20\u5931\u8d25\u3002","url":"\uff1aattribute\u683c\u5f0f\u65e0\u6548\u3002","uuid":"\uff1aattribute\u5fc5\u987b\u662f\u6709\u6548\u7684UUID\u3002"}});
})();
